@@ -2,9 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_cleaner.pl 4881 2005-09-29 08:20:07Z yeupou $
+# $Id: sv_cleaner.pl 5975 2006-09-26 09:12:56Z yeupou $
 #
-#  Copyright 2003 (c) Mathieu Roy <yeupou@gnu.org> 
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org> 
+#                          BBN Technologies Corp
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -39,13 +40,13 @@ use Getopt::Long;
 use Term::ANSIColor qw(:constants);
 use POSIX qw(strftime);
 use Time::Local;
+use Date::Calc qw(Add_Delta_YMD);
 
 # Import
 our $sys_cron_cleaner;
 
 my $script = "sv_cleaner";
 my $logfile = "/var/log/sv_cleaner.log";
-my $lockfile = "/var/run/sv_cleaner.lock";
 my $getopt;
 my $help;
 my $debug;
@@ -91,14 +92,8 @@ exit if ($cron && ! $sys_cron_cleaner);
 open (LOG, ">>$logfile");
 print LOG strftime "[$script] %c - starting\n", localtime;
 
-
 # Locks: This script should not run concurrently
-#        So we add a lock
-if (-e $lockfile) {
-    print LOG "[$script] There's a lock ($lockfile), exiting\n";
-    die "There's a lock ($lockfile), exiting";
-}
-`touch $lockfile`;
+AcquireReplicationLock();
 
 
 ###********************************************************************
@@ -117,7 +112,8 @@ if (-e $lockfile) {
 #######################################################################
 
 
-my ($year, $month, $day) = split(",", `date -d "3 days ago" +%Y,%m,%d`);
+my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+($year,$month,$day) = Add_Delta_YMD($year,$month,$day, 0,0,-3);
 my $date = timelocal("0","0","0",$day,($month-1),($year-1900));
 
 my $result = DeleteUsers("status='P' AND add_date < $date");
@@ -131,7 +127,8 @@ print LOG strftime "[$script] %c ---- deleted $result unconfirmed user accounts\
 ##
 #######################################################################
  
-my ($year, $month, $day) = split(",", `date -d "1 days ago" +%Y,%m,%d`);
+my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+($year,$month,$day) = Add_Delta_YMD($year,$month,$day, 0,0,-1);
 my $date = timelocal("0","0","0",$day,($month-1),($year-1900));
 
 my $result = DeleteGroups("status='I' AND register_time < $date");
@@ -157,7 +154,8 @@ print LOG strftime "[$script] %c ---- deleted $result deleted groups\n", localti
 ##
 #######################################################################
  
-my ($year, $month, $day) = split(",", `date -d "1 days ago" +%Y,%m,%d`);
+my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+($year,$month,$day) = Add_Delta_YMD($year,$month,$day, 0,0,-1);
 my $date = timelocal("0","0","0",$day,($month-1),($year-1900));
 
 my $result = DeleteDB("form", "timestamp < $date");
@@ -171,7 +169,8 @@ print LOG strftime "[$script] %c ---- deleted $result outdated form ids\n", loca
 ##
 #######################################################################
  
-my ($year, $month, $day) = split(",", `date -d "1 year ago" +%Y,%m,%d`);
+my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+($year,$month,$day) = Add_Delta_YMD($year,$month,$day, -1,0,0);
 my $date = timelocal("0","0","0",$day,($month-1),($year-1900));
 
 my $result = DeleteDB("session", "time < $date");
@@ -235,7 +234,7 @@ if ($big_cleanup) {
     foreach my $tracker (@trackers) {
 	my @items_to_delete;
 	
-	# Find items to delete
+	# Find items to delete in tracker-specific tables
 	foreach my $line (GetDB($tracker, "1", "bug_id,group_id")) {
 	    chomp($line);
 	    my ($item_id, $group_id) = split(",", $line);
@@ -252,135 +251,72 @@ if ($big_cleanup) {
 	# Now do the cleanup on trackers
 	unless ($debug) {
 	    foreach my $item (@items_to_delete) {
+		# Clean tables that tracker-specific
 		DeleteDB($tracker, "bug_id='$item'");
 		DeleteDB($tracker."_cc", "bug_id='$item'");
-		DeleteDB($tracker."_file", "bug_id='$item'");
 		DeleteDB($tracker."_history", "bug_id='$item'");
 		DeleteDB($tracker."_dependencies", "item_id='$item' OR (is_dependent_on_item_id='$item' AND is_dependent_on_item_id_artifact='$tracker')");
+
+		# Clean tables that are common to all trackers
+		DeleteDB("trackers_file", "artifact='$tracker' AND item_id='$item'");
+		
 	    }
 	}
     }
     
     ####
-    # Now look in other database to find if there was entries of deleted 
+    # Now look in others tables to find if there was entries of deleted 
     # groups. To keep it simple and not too much rendudant, we first get
     # all the dead group_id, and then we run simple delete on all table
     # where these groups id exists
     my @dead_group_id;
     my %dead_group_id_already_found;
+
+    my @tables_to_check = ("user_group",
+			   "groups_default_permissions",
+			   "group_preferences",
+			   "group_history",
+			   "news_bytes",
+			   "forum_group_list",
+			   "trackers_watcher",
+			   "mail_group_list");
     
-    # Find entries to delete in user group
-    foreach my $line (GetDB("user_group", "1", "group_id")) {
-	chomp($line);
-	my ($group_id) = split(",", $line);
-	
-	next if $group_exists{$group_id};
-	next if $dead_group_id_already_found{$group_id};
-	
-	push(@dead_group_id, $group_id);
-	$dead_group_id_already_found{$group_id} = 1;
-	print "DBG: user_group found dead group $group_id\n" if $debug;
+    foreach my $table (@tables_to_check) {
+	foreach my $line (GetDB($table, "1", "group_id")) {
+	    chomp($line);
+	    my ($group_id) = split(",", $line);
+	    
+	    next if $group_exists{$group_id};
+	    next if $dead_group_id_already_found{$group_id};
+	    
+	    push(@dead_group_id, $group_id);
+	    $dead_group_id_already_found{$group_id} = 1;
+	    print "DBG: $table found dead group $group_id\n" if $debug;
+	}
     }
-    # Find entries to delete in group permissions
-    foreach my $line (GetDB("groups_default_permissions", "1", "group_id")) {
-	chomp($line);
-	my ($group_id) = split(",", $line);
-	
-	next if $group_exists{$group_id};
-	next if $dead_group_id_already_found{$group_id};
-	
-	push(@dead_group_id, $group_id);
-	$dead_group_id_already_found{$group_id} = 1;
-	print "DBG: groups_default_permissions found dead group $group_id\n" if $debug;
-    }
-    # Find entries to delete in group preferences
-    foreach my $line (GetDB("group_preferences", "1", "group_id")) {
-	chomp($line);
-	my ($group_id) = split(",", $line);
 
-	next if $group_exists{$group_id};
-	next if $dead_group_id_already_found{$group_id};
-	
-	push(@dead_group_id, $group_id);
-	$dead_group_id_already_found{$group_id} = 1;
-	print "DBG: group_preferences found dead group $group_id\n" if $debug;
-    }
-    # Find entries to delete in group history
-    foreach my $line (GetDB("group_history", "1", "group_id")) {
-	chomp($line);
-	my ($group_id) = split(",", $line);
-
-	next if $group_exists{$group_id};
-	next if $dead_group_id_already_found{$group_id};
-	
-	push(@dead_group_id, $group_id);
-	$dead_group_id_already_found{$group_id} = 1;
-	print "DBG: group_history found dead group $group_id\n" if $debug;
-    }    
-    # Find entries to delete in news items
-    foreach my $line (GetDB("news_bytes", "1", "group_id")) {
-	chomp($line);
-	my ($group_id) = split(",", $line);
-
-	next if $group_exists{$group_id};
-	next if $dead_group_id_already_found{$group_id};
-	
-	push(@dead_group_id, $group_id);
-	$dead_group_id_already_found{$group_id} = 1;
-	print "DBG: news_bytes found dead group $group_id\n" if $debug;
-    }
-    # Find entries to delete in forums (important for news items)
-    foreach my $line (GetDB("forum_group_list", "1", "group_id")) {
-	chomp($line);
-	my ($group_id) = split(",", $line);
-
-	next if $group_exists{$group_id};
-	next if $dead_group_id_already_found{$group_id};
-	
-	push(@dead_group_id, $group_id);
-	$dead_group_id_already_found{$group_id} = 1;
-	print "DBG: forum_group_list found dead group $group_id\n" if $debug;
-    }
+  
     # Find entries to delete in trackers query forms (dont bother removing
     # the query forms in depth values, they wont be visible anyway
     # since they refer to an query id that will be made bogus.
     # Do exactly the same for project field values.
     foreach my $tracker (@trackers) {
-	# Query forms
-	foreach my $line (GetDB($tracker."_report", "1", "group_id")) {
-	    chomp($line);
-	    my ($group_id) = split(",", $line);
-	    
-	    next if $group_exists{$group_id};
-	    next if $dead_group_id_already_found{$group_id};
-	    
-	    push(@dead_group_id, $group_id);
-	    $dead_group_id_already_found{$group_id} = 1;
-	print "DBG: ".$tracker."_report found dead group $group_id\n" if $debug;
-	}
-	# Field usage
-	foreach my $line (GetDB($tracker."_field_usage", "1", "group_id")) {
-	    chomp($line);
-	    my ($group_id) = split(",", $line);
-	    
-	    next if $group_exists{$group_id};
-	    next if $dead_group_id_already_found{$group_id};
-	    
-	    push(@dead_group_id, $group_id);
-	    $dead_group_id_already_found{$group_id} = 1;
-	    print "DBG: ".$tracker."_field_usage found dead group $group_id\n" if $debug;
-	}
-	# Field values
-	foreach my $line (GetDB($tracker."_field_value", "1", "group_id")) {
-	    chomp($line);
-	    my ($group_id) = split(",", $line);
-	    
-	    next if $group_exists{$group_id};
-	    next if $dead_group_id_already_found{$group_id};
-	    
-	    push(@dead_group_id, $group_id);
-	    $dead_group_id_already_found{$group_id} = 1;
-	    print "DBG: ".$tracker."_field_values found dead group $group_id\n" if $debug;
+	@tables_to_check = ($tracker."_report", 
+			    $tracker."_field_usage",
+			    $tracker."_field_value");
+
+	foreach my $table (@tables_to_check) {
+	    foreach my $line (GetDB($table, "1", "group_id")) {
+		chomp($line);
+		my ($group_id) = split(",", $line);
+		
+		next if $group_exists{$group_id};
+		next if $dead_group_id_already_found{$group_id};
+		
+		push(@dead_group_id, $group_id);
+		$dead_group_id_already_found{$group_id} = 1;
+		print "DBG: ".$table." found dead group $group_id\n" if $debug;
+	    }
 	}
     }
     
@@ -400,6 +336,18 @@ if ($big_cleanup) {
 	    DeleteDB("user_group", "group_id='$group_id'");
 	    DeleteDB("news_bytes", "group_id='$group_id'");
 	    DeleteDB("forum_group_list", "group_id='$group_id'");
+	    DeleteDB("trackers_watcher", "group_id='$group_id'");
+
+	    # For mailing-list, we mark the lists as deleted, so sv_mailman
+	    # will finish the job, unless their status is equal to 0,
+	    # which means they no longer exists already
+	    # (backward compat case)
+	    SetDBSettings("mail_group_list",
+			  "group_id='$group_id'",
+			  "is_public='9'");
+	    DeleteDB("mail_group_list", "group_id='$group_id' AND status='0'");
+
+
 	    foreach my $tracker (@trackers) {
 		DeleteDB($tracker."_report", "group_id='$group_id'");
 		DeleteDB($tracker."_field_usage", "group_id='$group_id'");
@@ -415,6 +363,4 @@ if ($big_cleanup) {
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
 
-unlink($lockfile);
-
 # EOF
