@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_groups.pl 4559 2005-06-30 16:38:36Z toddy $
+# $Id: sv_groups.pl 5651 2006-09-05 15:02:38Z yeupou $
 #
-#  Copyright 2001-2005 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
+#  Copyright 2001-2006 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
 #                          Mathieu Roy <yeupou--gnu.org> 
 #                          Sylvain Beucler <beuc--beuc.net>
 #                          Timothee Besset <ttimo--ttimo.net>
@@ -52,7 +52,7 @@ our $sys_cron_groups;
 
 my $script = "sv_groups";
 my $logfile = "/var/log/sv_database2system.log";
-my $lockfile = "/var/run/sv_database2system.lock";
+my $lockfile = "groups-users.lock";
 my $getopt;
 my $help;
 my $debug;
@@ -171,12 +171,8 @@ print LOG strftime "[$script] %c - starting\n", localtime;
 
 
 # Locks: There are several sv_db2sys scripts but they should not run
-#        concurrently.  So we add a lock
-if (-e $lockfile) {
-    print LOG "[$script] There's a lock ($lockfile), exiting\n";
-    die "There's a lock ($lockfile), exiting";
-}
-system("touch", $lockfile);
+#        concurrently.
+AcquireReplicationLock($lockfile);
 
 
 #######################################################################
@@ -477,6 +473,4 @@ foreach my $group (@db_groups) {
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
 
-unlink($lockfile);
-
 # EOF
