@@ -2,9 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_reminder.pl 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: sv_reminder.pl 5651 2006-09-05 15:02:38Z yeupou $
 #
-#  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org> 
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org> 
+#                          BBN Technologies Corp
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,6 +28,7 @@ use Getopt::Long;
 use Term::ANSIColor qw(:constants);
 use POSIX qw(strftime);
 use Time::Local;
+use Date::Calc qw(Add_Delta_YMD);
 
 # Import
 our $sys_cron_reminder;
@@ -37,7 +39,6 @@ our $sys_url_topdir;
 
 my $script = "sv_reminder";
 my $logfile = "/var/log/sv_reminder.log";
-my $lockfile = "/var/run/sv_reminder.lock";
 my $getopt;
 my $help;
 my $debug;
@@ -101,12 +102,7 @@ print LOG strftime "[$script] %c - starting\n", localtime;
 
 
 # Locks: This script should not run concurrently
-#        So we add a lock
-if (-e $lockfile) {
-    print LOG "[$script] There's a lock ($lockfile), exiting\n";
-    die "There's a lock ($lockfile), exiting";
-}
-`touch $lockfile`;
+AcquireReplicationLock();
 
 
 # Process: - List items+why+user. 
@@ -151,13 +147,16 @@ my ($year, $month, $day);
 
 my $now = timelocal(localtime());
 
-($year, $month, $day) = split(",", `date -d "1 day ago" +%Y,%m,%d`);
+my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+($year,$month,$day) = Add_Delta_YMD($year,$month,$day, 0,0,-1);
 my $daybefore = timelocal("0","0","0",$day,($month-1),($year-1900));
 
-($year, $month, $day) = split(",", `date -d "1 week ago" +%Y,%m,%d`);
+my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+($year,$month,$day) = Add_Delta_YMD($year,$month,$day, 0,0,-7);
 my $weekbefore = timelocal("0","0","0",$day,($month-1),($year-1900));
 
-($year, $month, $day) = split(",", `date -d "1 month  ago" +%Y,%m,%d`);
+my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+($year,$month,$day) = Add_Delta_YMD($year,$month,$day, 0,1,0);
 my $monthbefore = timelocal("0","0","0",$day,($month-1),($year-1900));
 
 print "DBG time: daybefore:$daybefore, weekbefore:$weekbefore; monthbefore:$monthbefore\n" if $debug;
@@ -432,6 +431,4 @@ print LOG strftime "[$script] $count mails sent\n", localtime if $count;
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
 
-unlink($lockfile);
-
 # EOF
