@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_users.pl 4720 2005-09-11 14:17:05Z yeupou $
+# $Id: sv_users.pl 5651 2006-09-05 15:02:38Z yeupou $
 #
-#  Copyright 2001-2005 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
+#  Copyright 2001-2006 (c) Loic Dachary <loic--gnu.org> (sv_cvs.pl)
 #                          Mathieu Roy <yeupou--gnu.org> 
 #                          Sylvain Beucler <beuc--beuc.net>
 #                          Timothee Besset <ttimo--ttimo.net>
@@ -55,7 +55,7 @@ our $sys_userx_prefix;
 
 my $script = "sv_users";
 my $logfile = "/var/log/sv_database2system.log";
-my $lockfile = "/var/run/sv_database2system.lock";
+my $lockfile = "groups-users.lock";
 my $getopt;
 my $help;
 my $debug;
@@ -147,13 +147,8 @@ open (LOG, ">>$logfile");
 print LOG strftime "[$script] %c - starting\n", localtime;
 
 # Locks: There are several sv_db2sys scripts but they should not run
-#        concurrently.  So we add a lock
-if (-e $lockfile) {
-    print LOG "[$script] There's a lock ($lockfile), exiting\n";
-    print LOG "[$script] ------------------------------------------------------\n";
-    die "There's a lock ($lockfile), exiting";
-}
-system("touch", $lockfile);
+#        concurrently.
+AcquireReplicationLock($lockfile);
 
 
 #######################################################################
@@ -679,6 +674,5 @@ print LOG strftime "[$script] %c - account deletion done\n", localtime;
 # Final exit
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
-unlink($lockfile);
 
 # END
