@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_gpgcheckfiles.pl 4581 2005-07-04 08:09:26Z yeupou $
+# $Id: sv_gpgcheckfiles.pl 5657 2006-09-05 17:34:48Z yeupou $
 #
-#  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org> 
+#  Copyright 2005-2006  (c) Mathieu Roy <yeupou--gnu.org> 
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -40,7 +40,6 @@ use Digest::MD5 qw(md5_base64);
 
 my $script = "sv_gpgcheckfiles";
 my $logfile = "/var/log/$script.log";
-my $lockfile = "/var/run/$script.lock";
 my $getopt;
 my $help;
 my $debug;
@@ -64,7 +63,7 @@ if (GetConf("sys_https_host")) {
 } else {
     $basepath .= "http://".GetConf("sys_default_domain").$url_topdir;
 }
-my $faq_url = $basepath."faq/?group=".GetConf("sys_unix_group_name");
+my $faq_url = $basepath."cookbook/?group=".GetConf("sys_unix_group_name")."#download";
 my $support_url = $basepath."support/?group=".GetConf("sys_unix_group_name");
 
 # get options
@@ -176,11 +175,7 @@ print LOG strftime "[$script] %c - starting\n", localtime;
 
 # Locks: There should be only one session of the script running at a time
 # So we add a lock
-if (-e $lockfile) {
-    print LOG "[$script] There's a lock ($lockfile), exiting\n";
-    die "There's a lock ($lockfile), exiting";
-}
-system("touch", $lockfile);
+AcquireReplicationLock();
 
 
 #####################################################################
@@ -191,6 +186,11 @@ system("touch", $lockfile);
 our %cache;
 our %cache_headers;
 
+# (by default, cacheformat is not set, so if it is still
+# not set after the cache is read, it means that we are in format 0)
+our $cacheformat = 0; 
+
+
 if (-e $cachefile && ! $nocache) {
     # If the cache does not belongs to root, exit with error. The content of
     # the cache could have been altered.
@@ -204,6 +204,14 @@ if (-e $cachefile && ! $nocache) {
     # Otherwise, run the cache
     do $cachefile;
     print "DBG: cached loaded\n" if $debug;
+
+    # If cacheformat is not equal to 1, the current version, it means it must
+    # be converted but it is the previous one
+    if ($cacheformat < 1) {
+	print "Cache is not in the current format, it will be converted\n";
+	print LOG strftime "[$script] %c - Cache is not in the current format, it will be converted\n", localtime;    
+    }
+    
 }
 
 
@@ -329,13 +337,26 @@ while (defined (my $project = readdir(MAIN))) {
 	my $signed_file = $signature_dir."/".basename($signature, ".sig");
 	my $result;
 
+	# Ignore if the signature is orphaned (.sig existing with no file
+	# to be checked)
+	next unless -e $signed_file;
+
 	# Get md5 of the signature and the related file
 	open(SIGN, $signature);
 	open(FILE, $signed_file);
 	binmode(SIGN);
 	binmode(FILE);
-	my $signature_md5 = Digest::MD5->new->addfile(*SIGN)->b64digest;
-	my $signed_file_md5 = Digest::MD5->new->addfile(*FILE)->b64digest;
+	my $signature_md5 = Digest::MD5->new->addfile(*SIGN)->b64digest.":".(stat($signature))[7];
+	my $signed_file_md5 = Digest::MD5->new->addfile(*FILE)->b64digest.":".(stat($signed_file))[7];
+
+	# Backward compat: in cacheformat v0, only real md5 were stored, not
+	# filesize. If we detected that the cache was in v0, we must override
+	# the value to ignore the filesize info.
+	if ($cacheformat < 1){
+	    $signature_md5 = Digest::MD5->new->addfile(*SIGN)->b64digest;
+	    $signed_file_md5 = Digest::MD5->new->addfile(*FILE)->b64digest;
+	}
+	  
 	
 	# Check the cache
 	my $is_cached;
@@ -377,6 +398,15 @@ while (defined (my $project = readdir(MAIN))) {
 		$cache{$signed_file} = $signed_file_md5;
 	    }
 
+	    # Backward compat: in cacheformat v0, only real md5 were stored
+	    # not filesize. If we previously detected that the cache was in v0,
+	    # then the following variables were stripped of the filesize 
+	    # info: we must put it back so it gets included in the cache
+	    if ($cacheformat < 1){
+		$cache{$signature} = $signature_md5.":".(stat($signature))[7];
+		$cache{$signed_file} = $signed_file_md5.":".(stat($signed_file))[7];
+	    }
+
 	    # Note that the directory is on his way to be clean.
 	    # This is important to remember, in case an old header is to be
 	    # removed.
@@ -430,7 +460,7 @@ while (my($project, $directory) = each(%project_area_with_nothing_signed)) {
 <p>No files were signed using GPG in this project area. As result, Savane
 was unable to verify their authenticity.<br />
 While you should assume these files are clean, truly from the project <a href="'.$basepath.'projects/'.$project.'">'.$project.'</a> as expected, there is no way to be 100% sure.</p>
-<p><a href="'.$faq_url.'">Read the FAQ</a> for more details, <a href="'.$support_url.'">post a support request</a> in case of problem.</p>
+<p><a href="'.$faq_url.'">Read the Cookbook</a> for more details, <a href="'.$support_url.'">post a support request</a> in case of problem.</p>
 </html>';
     close(HEADER);
 
@@ -662,6 +692,8 @@ unless ($debug) {
 ';
     print CACHE strftime "# %c\n", localtime;
 print CACHE '
+$cacheformat = 1;
+
 %cache = (
 ';
     my $count = 0;
@@ -706,6 +738,5 @@ print CACHE '
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
 
-unlink($lockfile);
 
 # EOF
