@@ -4,7 +4,8 @@
 #
 # $Id: sv_export.pl 4807 2005-09-19 11:11:39Z yeupou $
 #
-#  Copyright 2005 (c) Yves Perrin <yves.perrin--cern.ch>
+#  Copyright 2005-2006 (c) Yves Perrin <yves.perrin--cern.ch>
+#                          BBN Technologies Corp
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -19,7 +20,7 @@
 # You should have received a copy of the GNU General Public License
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-                                                                               
+                                                                                
 use strict;
 use Savane;
 use Savane::Mail;
@@ -27,6 +28,7 @@ use Getopt::Long;
 use Term::ANSIColor qw(:constants);
 use POSIX qw(strftime);
 use Time::Local;
+use Date::Calc qw(Add_Delta_YMD);
 
 use XML::Writer;
 use IO::File;
@@ -39,7 +41,6 @@ our $sys_url_topdir;
 
 # Configure
 my $script = "sv_export";
-my $lockfile = "/var/run/sv_export.lock";
 my $logfile = "/var/log/sv_export.log";
 
 my $getopt;
@@ -61,7 +62,7 @@ usage: $0
    script that searches the database 'export' table for pending
    requests and for each of these, extracts the relevant data,
    produces the corresponding XML representation and
-   writes it together with the appropriate XML schema into a fire
+   writes it together with the appropriate XML schema into a file
    the path of which being specified by the xml-path argument
  
         --help                  print this help
@@ -80,11 +81,7 @@ unless (-d $xml_path) {
 }
 
 #Locks: instances should not run concurrently, so we add a lock
-if (-e $lockfile) {
-  print LOG "[$script] there is a lock ($lockfile), exiting\n";
-  die "There is a lock ($lockfile), exiting",
-}
-'touch $lockfile';
+AcquireReplicationLock();
 
 # Log: Starting logging
 open (LOG, ">>$logfile");
@@ -138,7 +135,7 @@ while (my ($key, $value) = each(%jobs)) {
     }
     my $xmlfile = $user_path.'/'.$req_id.'.xml'; 
     my $xmlschema = $user_path.'/'.$req_id.'.xsd'; 
-    
+
     my %tr_fields_project;
     my %tr_fields_values;
 
@@ -147,6 +144,7 @@ while (my ($key, $value) = each(%jobs)) {
     my ($pos, $tables_val, $fields_val, $criteria_val, $key);
     my ($sel_fields, $criteria_base, $s_no_item, $fn, $fv, $unix_history_date);
     my ($history_date, $sel_fields_hist, $tables_hist, $criteria_hist);
+    my ($sel_fields_dep, $tables_dep, $criteria_dep);
     my (%this_item, $thisid, $fd, $id, $item, $label, $d, $f);
     # ----------------------
 
@@ -267,6 +265,13 @@ while (my ($key, $value) = each(%jobs)) {
 	$element =~ s/\#//g;
 	print XMLSCHEMA '      <xs:element name="'.$element.'" type="'.$tr_fields_arr{$key}.'" />'."\n";
     }
+
+    print XMLSCHEMA '      <xs:element name="depends_on" minOccurs="0">'."\n";
+    print XMLSCHEMA '        <xs:complexType>'."\n";
+    print XMLSCHEMA '          <xs:element name="item_id" type="integer" />'."\n";
+    print XMLSCHEMA '          <xs:element name="tracker" type="string" />'."\n";
+    print XMLSCHEMA '        </xs:complexType>'."\n";
+    print XMLSCHEMA '      </xs:element>'."\n";
     print XMLSCHEMA '      <xs:element name="history" minOccurs="0" maxOccurs="1">'."\n";
     print XMLSCHEMA '        <xs:complexType>'."\n";
     print XMLSCHEMA '          <xs:element name="event" minOccurs="1">'."\n";
@@ -343,25 +348,57 @@ while (my ($key, $value) = each(%jobs)) {
 	$sel_fields_hist = 'bug_id, date, field_name, old_value, new_value, user.user_name ';
 	$tables_hist = $tracker.'_history, user ';
 	$criteria_hist = 'bug_id='.$id.' AND user.user_id='.$tracker.'_history.mod_by ORDER BY date';
-	my %history_arr = ();
+        my %history_hash = {}; #hash elements will be hash of array of hashes !
 	
 	my %hist_row = GetDBHash($tables_hist,$criteria_hist,$sel_fields_hist);
 	while (my ($key, $value) = each(%hist_row)) {
-	    my ($h_bug_id, $h_date, $h_field, $h_f_old, $h_f_new, $h_f_modby) =
-		(@{$value});
+	  my ($h_bug_id, $h_date, $h_field, $h_f_old, $h_f_new, $h_f_modby) =
+             (@{$value});
 	    
-	    if (!exists($history_arr{$h_bug_id})) {
-		$history_arr{$h_bug_id} = ();
-	    }
-	    if (!exists($history_arr{$h_bug_id}{$h_date})) {
-		$history_arr{$h_bug_id}{$h_date} = ();
-	    }
-	    $history_arr{$h_bug_id}{$h_date}{$h_field} = ();
-	    $history_arr{$h_bug_id}{$h_date}{$h_field}{'old_value'} = $h_f_old;
-	    $history_arr{$h_bug_id}{$h_date}{$h_field}{'new_value'} = $h_f_new;
-	    $history_arr{$h_bug_id}{$h_date}{$h_field}{'mod_by'} = $h_f_modby;
+	  if (!exists($history_hash{$h_bug_id})) {
+	    $history_hash{$h_bug_id} = {}; # possibly many events for same id
+	  }
+	  if (!exists($history_hash{$h_bug_id}{$h_date})) {
+	    $history_hash{$h_bug_id}{$h_date} = (); # possibly many fields for same date
+            $history_hash{$h_bug_id}{$h_date}[0] = {
+                                      field => $h_field,
+                                      old_value  => $h_f_old,
+                                      new_value  => $h_f_new,
+                                      mod_by     => $h_f_modby };
+	  } else {
+            my %this_hist_date_event = {};
+            $this_hist_date_event{'field'} = $h_field;
+            $this_hist_date_event{'old_value'}  = $h_f_old;
+            $this_hist_date_event{'new_value'}  = $h_f_new;
+            $this_hist_date_event{'mod_by'}     = $h_f_modby;
+          
+            # push ($history_hash{$h_bug_id}{$h_date}, %this_hist_date_event);
+            my $hist_date_index = scalar @{$history_hash{$h_bug_id}{$h_date}};
+            # scalar returns length, so last element +1 ... no need to pre-inc
+            %{$history_hash{$h_bug_id}{$h_date}[$hist_date_index]} = 
+                 %this_hist_date_event;
+          }
 	}
 
+        # --------------------- Get the items dependencies -------------------
+                                                                                
+        $sel_fields_dep = 'is_dependent_on_item_id, is_dependent_on_item_id_artifact ';
+        $tables_dep = $tracker.'_dependencies ';
+        $criteria_dep = 'item_id='.$id;
+        my %dep_hash = {}; #hash elements will be array of hashes !!!
+                                                                                
+        my %dep_row = GetDBHash($tables_dep,$criteria_dep,$sel_fields_dep);
+        my $i = 0;
+        while (my ($key, $value) = each(%dep_row)) {
+          my %this_dep = {};
+          ($this_dep{'item_id'}, $this_dep{'tracker'}) = (@{$value});
+          if (!exists($dep_hash{$id})) {
+            $dep_hash{$id} = ();
+          }
+          %{$dep_hash{$id}[$i]} = %this_dep;
+          $i++;
+        }
+                                                                                
 	# ---------------------- Get the items data --------------------------
 	
 	$criteria = $tracker.'.bug_id='.$id.$criteria_base;  
@@ -396,19 +433,41 @@ while (my ($key, $value) = each(%jobs)) {
 		}
 		$k++;
 	    }
-	    if (exists($history_arr{$id})) {
+
+            if (exists($dep_hash{$id})) {
+                my $nb_of_dep = scalar @{$dep_hash{$id}};
+                my $i = 0;
+                while ($i < $nb_of_dep) {
+                  $writer->startTag("depends_on");
+                    $writer->startTag("item_id");
+#                   my $itid = ${$dep_hash{$id}[$i]}{'item_id'};
+#                   $writer->characters($itid);
+                    $writer->characters(${$dep_hash{$id}[$i]}{'item_id'});
+                    $writer->endTag("item_id");
+                    $writer->startTag("tracker");
+                    $writer->characters(${$dep_hash{$id}[$i]}{'tracker'});
+                    $writer->endTag("tracker");
+                  $writer->endTag("depends_on");
+                  $i++;
+                }
+            }
+
+	    if (exists($history_hash{$id})) {
 		$writer->startTag("history");
 
-		for $d (keys %{$history_arr{$id}}) {
+		for $d ( sort keys %{$history_hash{$id}}) {
 		    $writer->startTag("event");
 		    $writer->startTag("date");
 		    $writer->characters($d);
 		    $writer->endTag("date");
 
-		    for $f (keys %{$history_arr{$id}{$d}}) {
+                    my $i = 0;
+                    my $nb_of_fields = scalar @{$history_hash{$id}{$d}};
+                    while ($i < $nb_of_fields) {
 			$writer->startTag("field");
 
-			$label = $tr_fields_project{$f}{'label'};
+                        $label = $tr_fields_project{$history_hash{$id}{$d}[$i]{'field'}}{'label'};
+
 			$label =~ s/\s/_/g;
 
 			$writer->startTag("field_name");
@@ -416,18 +475,19 @@ while (my ($key, $value) = each(%jobs)) {
 			$writer->endTag("field_name");
 			
 			$writer->startTag("old_value");
-			$writer->characters($history_arr{$id}{$d}{$f}{'old_value'});
+			$writer->characters($history_hash{$id}{$d}[$i]{'old_value'});
 			$writer->endTag("old_value");
 
 			$writer->startTag("new_value");
-			$writer->characters($history_arr{$id}{$d}{$f}{'new_value'});
+			$writer->characters($history_hash{$id}{$d}[$i]{'new_value'});
 			$writer->endTag("new_value");
 
 			$writer->startTag("modified_by");
-			$writer->characters($history_arr{$id}{$d}{$f}{'mod_by'});
+			$writer->characters($history_hash{$id}{$d}[$i]{'mod_by'});
 			$writer->endTag("modified_by");
 
 			$writer->endTag("field");
+                        $i++;
 		    }
 		    $writer->endTag("event");
 		}
@@ -463,7 +523,8 @@ while (my ($key, $value) = each(%jobs)) {
 	# Otherwise, update the timestamp
 	# Assume that the script is running the correct day, so we can easily
 	# just add 7 days to the current day
-	my ($year, $month, $day) = split(",", `date -d "7 days next" +%Y,%m,%d`);
+	my ($year, $month, $day) = split(",", `date +%Y,%m,%d`);
+	($year,$month,$day) = Add_Delta_YMD($year,$month,$day, 0,0,7);
 	my $timestamp = timelocal("0","0",$req_frequency_hour,($day+7),($month-1),($year-1900));
 	SetDBSettings($export_table, "export_id='$req_id'", "date='$timestamp'"); 
 
@@ -475,6 +536,6 @@ while (my ($key, $value) = each(%jobs)) {
 # Final exit
 print LOG strftime "[$script] %c - work finished\n", localtime;
 print LOG "[$script] ------------------------------------------------------\n";
-unlink($lockfile);
+
 
 # EOF
