@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: logout.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: logout.php 5617 2006-08-23 23:23:33Z beuc $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2002 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,10 +26,18 @@
 
 require "../include/pre.php";    
 
-db_query("DELETE FROM session WHERE session_hash='$session_hash'");
+register_globals_off();
+
+if (user_isloggedin())
+{
+  # If the session was validated, we can assume that the cookie session_hash
+  # is reliable
+  db_query("DELETE FROM session WHERE session_hash='".sane_cookie("session_hash")."'");
+  session_delete_cookie('redirect_to_https');
+  session_delete_cookie('session_hash');
+  session_delete_cookie('session_uid');
+}
 
-session_cookie('session_hash','');
-session_cookie('session_uid','');
 session_redirect($GLOBALS['sys_home']);
 
 ?>
