@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: lostpw-confirm.php 5267 2005-12-22 00:34:38Z beuc $
+# $Id: lostpw-confirm.php 5788 2006-09-13 15:59:38Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -26,7 +26,13 @@
 
 require "../include/pre.php";
 
-$form_loginname = addslashes($form_loginname);
+# Logged users have no business here
+if (user_isloggedin())
+{ session_redirect($GLOBALS['sys_home']."my/"); }
+
+register_globals_off();
+
+$form_loginname = sane_post("form_loginname");
 
 # CERN_SPECIFIC: here we also have a speech about AFS which must not be
 # hardcoded
@@ -35,15 +41,15 @@ if ($GLOBALS['sys_use_pamauth'] == "yes") {
   $row_pw = db_fetch_array();
   if ($row_pw[user_pw] == 'PAM') {
     $HTML->header(array('title'=>"Lost Password Confirmation"));
-    print "<p>This account uses an AFS password. <b>You cannot change your
-           AFS password via Savannah</b>. Contact the AFS managers.";
+    print "<p>This account uses an AFS password. <strong>You cannot change your
+           AFS password via Savane</strong>. Contact the AFS managers.";
     $HTML->footer(array());
     exit;
   }
 }
 # CERN_SPECIFIC
 
-$confirm_hash = md5($session_hash . strval(time()) . strval(rand()));
+$confirm_hash = md5(sane_post("session_hash") . strval(time()) . strval(rand()));
 
 ########################
 # Account check
@@ -112,8 +118,8 @@ $message .= '(IP: '.$GLOBALS['REMOTE_ADDR'].' port: '.$GLOBALS['REMOTE_PORT'].")
 $message .= _("with").' '.$GLOBALS['HTTP_USER_AGENT']."\n\n";
 $message .= _("If you requested this verification, visit this URL\nto change your password:")."\n\n";
 $message .= $GLOBALS['sys_https_url'].$GLOBALS['sys_home']."account/lostlogin.php?confirm_hash=".$confirm_hash."\n\n";
-# There should be a discard procedure
-$message .= _("If you did not request this verification, please visit this URL to cancel it.")."\n\n";
+# FIXME: There should be a discard procedure
+#$message .= _("If you did not request this verification, please visit this URL to cancel it.")."\n\n";
 $message .= _("In any case make sure that you do not disclose this url to\n somebody else, e.g. do not mail this to a public mailinglist!\n\n");
 $message .= sprintf(_("-- the %s team."),$GLOBALS['sys_name'])."\n";
 
