@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: lostpw.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: lostpw.php 5788 2006-09-13 15:59:38Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -24,10 +24,15 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 require "../include/pre.php";
+
+# Logged users have no business here
+if (user_isloggedin())
+{ session_redirect($GLOBALS['sys_home']."my/"); }
+
 $HTML->header(array('title'=>_("Lost Account Password")));
 
 
-print '<p><b>'._("Lost your password?").'</b></p>';
+print '<p><strong>'._("Lost your password?").'</strong></p>';
 
 print '<p>'._("Hey... losing your password is serious business. It compromises the security of your account, your projects, and this site.").'</p>';
 
@@ -35,10 +40,10 @@ print '<p>'._("The form below will email a URL to the email address we have on f
 print '<p class="warn">'._("This will work only if your account was already successfully registered and activated. Note that accounts that are not activated within the three days next to their registration are automatically deleted.").'</p>';
 
 print '<form action="lostpw-confirm.php" method="post">';
-print '<p><input type="hidden" name="form_user" value="'.$form_user.'"><font class="preinput"> &nbsp;&nbsp;';
+print '<p><input type="hidden" name="form_user" value="'.$form_user.'" /><span class="preinput"> &nbsp;&nbsp;';
 print _("Login Name:");
-print ' &nbsp;&nbsp;</font><input type="text" name="form_loginname"> &nbsp;&nbsp;';
-print '<input type="submit" name="send" value="'._("Send lost password hash").'"></p>';
+print ' &nbsp;&nbsp;</span><input type="text" name="form_loginname" /> &nbsp;&nbsp;';
+print '<input type="submit" name="send" value="'._("Send lost password hash").'" /></p>';
 print '</form>';
 
 $HTML->footer(array());
