@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: register.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: register.php 5802 2006-09-14 12:40:09Z yeupou $
 #
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
@@ -28,6 +28,10 @@
 require "../include/pre.php";
 require "../include/account.php";
 
+# Logged users have no business here
+if (user_isloggedin())
+{ session_redirect($GLOBALS['sys_home']."my/"); }
+
 # ###### function register_valid()
 # ###### checks for valid register from form post
 
@@ -93,6 +97,13 @@ function register_valid()
     }
 
 
+  if (!account_emailvalid($_POST['form_email']))
+    {
+      # feedback included by the check function
+      return 0;
+    }
+
+
   ##### Avoid duplicates
 
   if (db_numrows(db_query("SELECT user_id FROM user WHERE "
@@ -107,14 +118,6 @@ function register_valid()
       fb(_("That username is blocked to avoid conflict with mailing-list addresses."),1);
       return 0;
     }
-  if (db_numrows(db_query("SELECT user_id FROM user WHERE "
-			  . "email LIKE '".addslashes($_POST[form_email])."'")) > 0)
-    {
-      fb(_("An account associated with that email address has already been created."),1);
-      return 0;
-    }
-
-
 
   ####
 
@@ -234,9 +237,9 @@ if ($_POST['update'] && register_valid())
 
   print '<h3>'.$GLOBALS['sys_name'].' : '._("New Account Registration Confirmation").'</h3>'
     .sprintf(_("Congratulations. You have registered on %s "),$GLOBALS['sys_name'])
-    .sprintf(_("Your login is: %s"), '<b>'.user_getname($newuserid).'</b>');
+    .sprintf(_("Your login is: %s"), '<strong>'.user_getname($newuserid).'</strong>');
 
-  print '<p>'._("You are now being sent a confirmation email to verify your email address. Visiting the link sent to you in this email will activate your account.").' <font class="warn">'._("Accounts not confirmed after two days are deleted from the database.").'</font></p>';
+  print '<p>'._("You are now being sent a confirmation email to verify your email address. Visiting the link sent to you in this email will activate your account.").' <span class="warn">'._("Accounts not confirmed after two days are deleted from the database.").'</span></p>';
 
 
 }
@@ -247,40 +250,40 @@ else
   site_header(array('title'=>_("User account registration"),'context'=>'account'));
 
 
-  print form_header($PHP_SELF, $form_id);
-  print '<p><font class="preinput">'._("Login Name:").'</font><br />&nbsp;&nbsp;';
+  print form_header($_SERVER["PHP_SELF"], $form_id);
+  print '<p><span class="preinput">'._("Login Name:").'</span><br />&nbsp;&nbsp;';
   print form_input("text", "form_loginname", $form_loginname);
-  print '<br /><font class="text">'.sprintf(_("If you have a %s account use that account name - dont use account name all numerical please."),$GLOBALS['sys_mail_domain']).'</font></p>';
+  print '<br /><span class="text">'.sprintf(_("If you have a %s account use that account name - Note that account names cannot consist of only numbers. At least one letter must be included."),$GLOBALS['sys_mail_domain']).'</span></p>';
 
-  print '<p><font class="preinput">'._("Password:").'</font><br />&nbsp;&nbsp;';
+  print '<p><span class="preinput">'._("Password:").'</span><br />&nbsp;&nbsp;';
   print form_input("password", "form_pw", $form_pw);
   print "</p>";
 
-  print '<p><font class="preinput">'._("Re-type Password:").'</font><br />&nbsp;&nbsp;';
+  print '<p><span class="preinput">'._("Re-type Password:").'</span><br />&nbsp;&nbsp;';
   print form_input("password", "form_pw2", $form_pw2);
   print "</p>";
 
-  print '<p><font class="preinput">'._("Real Name:").'</font><br />&nbsp;&nbsp;';
+  print '<p><span class="preinput">'._("Real Name:").'</span><br />&nbsp;&nbsp;';
   print '<input size="30" type="text" name="form_realname" value="'.$form_realname.'" /></p>';
 
-  print '<p><font class="preinput">'._("Email Address:").'</font><br />&nbsp;&nbsp;';
+  print '<p><span class="preinput">'._("Email Address:").'</span><br />&nbsp;&nbsp;';
   print '<input size="30" type="text" name="form_email" value="'.$form_email.'" />';
-  print '<br /><font class="text">'._("This email address will be verified before account activation.").'</font></p>';
+  print '<br /><span class="text">'._("This email address will be verified before account activation.").'</span></p>';
 
-
-  # CERN_SPECIFIC: speech related to AFS
   # Extension for PAM authentication
+  # FIXME: for now, only the PAM authentication that exists is for AFS.
+  #  but PAM is not limited to AFS, so we should consider a way to configure
+  #  this (to put it in site specific content probably).
   if ($sys_use_pamauth=="yes")
     {
-      print "<p>Instead of providing a new Savannah password you
-      may choose to authenticate via an <b>AFS</b> account you own
-      at this site (this requires your Savannah login name to be the
+      print "<p>Instead of providing a new password you
+      may choose to authenticate via an <strong>AFS</strong> account you own
+      at this site (this requires your new login name to be the
       same as the AFS account name):";
 
       print '<p>&nbsp;&nbsp;&nbsp;<INPUT type="checkbox"
       name="form_usepam" value="1" > use AFS based authentication';
     }
-  # CERN_SPECIFIC: speech related to AFS
 
 
   print form_footer();
