@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: index.php 5546 2006-08-10 22:03:04Z toddy $
 #
 # Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                         Derek Feichtinger <derek.feichtinger--at--cern.ch>
@@ -59,10 +59,10 @@ if ($group_id) {
 
       /* permit to the user to specify something */
       $content .=  '<form action="'. $PHP_SELF .'" method="get">';
-      $content .=  '<input type="hidden" NAME="group_id" value="'.$group_id.'">';
-      $content .=  '<h3>'.sprintf(_("Show %s and highlight version %s."),'<select name="thread_max"><option value="1"> 1</option><option value="3"> 3</option><option value="5" selected> 5</option><option value="10">10</option><option value="20">20</option><option value="50">50</option></select>', '<input type="text" size="6" name="highlight" value="'.$highlight.'">');
+      $content .=  '<input type="hidden" NAME="group_id" value="'.$group_id.'" />';
+      $content .=  '<h3>'.sprintf(_("Show %s and highlight version %s."),'<select name="thread_max"><option value="1"> 1</option><option value="3"> 3</option><option value="5" selected> 5</option><option value="10">10</option><option value="20">20</option><option value="50">50</option></select>', '<input type="text" size="6" name="highlight" value="'.$highlight.'" />');
 
-      $content .= '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"></form>';
+      $content .= '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'" /></form>';
       $content .= '</h3>';
 
       $content .= '<p>';
@@ -83,7 +83,7 @@ if ($group_id) {
 		  $content .= '<tr><td><table width="100%">'."\n";
 
 		  $i=0;
-		  $content .= '<tr class="'. utils_get_alt_row_color($i) .'"><td>&nbsp;&nbsp;</td><td width="55%" class="bold">&nbsp;</td><td width="15%" class="center"><i class="smaller">Filesize</i></td><td width="15%" class="center"><i class="smaller">File Type</i></td><td width="15%" class="center"><i class="smaller">Date</i></td></tr>'."\n";
+		  $content .= '<tr class="'. utils_get_alt_row_color($i) .'"><td>&nbsp;&nbsp;</td><td width="55%" class="bold">&nbsp;</td><td width="15%" class="center"><em class="smaller">Filesize</em></td><td width="15%" class="center"><em class="smaller">File Type</em></td><td width="15%" class="center"><em class="smaller">Date</em></td></tr>'."\n";
 
 		  /* create an array of versions */
 		  $version_dir = opendir($files_dir."/".$package_name);
