@@ -2,14 +2,14 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: forum.php 5187 2005-12-01 16:22:29Z yeupou $
+// $Id: forum.php 5547 2006-08-10 22:08:09Z toddy $
 //
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
 //
 //
 //  Copyright 2000-2003 (c) Free Software Foundation
-// 
+//
 // The Savane project is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
@@ -28,34 +28,34 @@
 require "../include/pre.php";
 require_directory("trackers");
 
-if ($forum_id) 
+if ($forum_id)
 {
   /*
 		if necessary, insert a new message into the forum
   */
-  if ($post_message == 'y') 
+  if ($post_message == 'y')
     {
       post_message($thread_id, $is_followup_to, $subject, $body, $forum_id);
     }
-	
+
   /*
 		set up some defaults if they aren't provided
   */
-  if ((!$offset) || ($offset < 0)) 
+  if ((!$offset) || ($offset < 0))
     {
       $offset=0;
-    } 
-	
-  if (!$style) 
+    }
+
+  if (!$style)
     {
       $style='nested';
     }
-	
-  if (!$max_rows || $max_rows < 5) 
+
+  if (!$max_rows || $max_rows < 5)
     {
       $max_rows=25;
     }
-	
+
   /*
 		take care of setting up/saving prefs
 
@@ -64,48 +64,48 @@ if ($forum_id)
 				if so, use it
 			if it was a custom set just posted && logged in, set pref if it's changed
   */
-  if (user_isloggedin()) 
+  if (user_isloggedin())
     {
       $_pref=$style.'|'.$max_rows;
       if ($set=='custom')
 	{
-	  if (user_get_preference('forum_style')) 
+	  if (user_get_preference('forum_style'))
 	    {
 	      $_pref=$style.'|'.$max_rows;
-	      if ($_pref == user_get_preference('forum_style')) 
+	      if ($_pref == user_get_preference('forum_style'))
 		{
 		  //do nothing - pref already stored
-		} 
+		}
 	      else
 		{
 		  //set the pref
 		  user_set_preference ('forum_style',$_pref);
 		}
-	    } 
+	    }
 	  else
 	    {
 	      //set the pref
 	      user_set_preference ('forum_style',$_pref);
 	    }
-	} 
+	}
       else
 	{
-	  if (user_get_preference('forum_style')) 
+	  if (user_get_preference('forum_style'))
 	    {
 	      $_pref_arr=explode ('|',user_get_preference('forum_style'));
 	      $style=$_pref_arr[0];
 	      $max_rows=$_pref_arr[1];
-	    } 
+	    }
 	  else
 	    {
-	      //no saved pref and we're not setting 
+	      //no saved pref and we're not setting
 	      //one because this is all default settings
 	    }
 	}
     }
-	
-	
-	
+
+
+
   /*
 		Set up navigation vars
   */
@@ -113,18 +113,18 @@ if ($forum_id)
   $group_id=db_result($result,0,'group_id');
   $forum_name=db_result($result,0,'forum_name');
 
-  // this forum_header writes the complete news item out 
+  // this forum_header writes the complete news item out
   // including the  comments \n Monitor Forum | Save Place | Admin bar
   // in case it is news
   // otherwise it pretends this item does not exist.
   // marcus marker
   forum_header(array('group'=>$group_id,'context'=>'forum','title'=>$forum_name));
 
-	
+
   //private forum check
-  if (db_result($result,0,'is_public') != '1') 
+  if (db_result($result,0,'is_public') != '1')
     {
-      if (!user_isloggedin() || !user_ismember($group_id)) 
+      if (!user_isloggedin() || !user_ismember($group_id))
 	{
 	  /*
 				If this is a private forum, kick 'em out
@@ -134,49 +134,49 @@ if ($forum_id)
 	  exit;
 	}
     }
-	
+
   //now set up the query
-  if ($style == 'nested' || $style== 'threaded' ) 
+  if ($style == 'nested' || $style== 'threaded' )
     {
       //the flat and 'no comments' view just selects the most recent messages out of the forum
       //the other views just want the top message in a thread so they can recurse.
       $threading_sql='AND forum.is_followup_to=0';
     }
-	
+
   $sql="SELECT user.user_name,user.realname,forum.has_followups,user.user_id,forum.msg_id,forum.group_forum_id,forum.subject,forum.thread_id,forum.body,forum.date,forum.is_followup_to, forum_group_list.group_id  ".
      "FROM forum,user,forum_group_list WHERE forum.group_forum_id='$forum_id' AND user.user_id=forum.posted_by $threading_sql AND forum_group_list.group_forum_id = forum.group_forum_id ".
      "ORDER BY forum.date DESC LIMIT $offset,".($max_rows+1);
-	
+
   $result=db_query($sql);
   $rows=db_numrows($result);
-	
-	
-  if ($rows > $max_rows) 
+
+
+  if ($rows > $max_rows)
     {
       $rows=$max_rows;
     }
   $total_rows=0;
-	
-  if (!$result || $rows < 1) 
+
+  if (!$result || $rows < 1)
     {
       //empty forum
       $ret_val .= 'No Messages in '.$forum_name .'<P>'. db_error();
-    } 
+    }
   else
     {
-		
+
       /*
 
       build table header
 
       */
-		
+
       //create a pop-up select box listing the forums for this project
       //determine if this person can see private forums or not
-      if (user_isloggedin() && user_ismember($group_id)) 
+      if (user_isloggedin() && user_ismember($group_id))
 	{
 	  $public_flag='0,1';
-	} 
+	}
       else
 	{
 	  $public_flag='1';
@@ -186,14 +186,14 @@ if ($forum_id)
           This is broken, it prints every forum existing in the database,
           deactivate it for now.
 
-          Forum are not supported in their current shape. Improvements 
+          Forum are not supported in their current shape. Improvements
           should first be made in the direction of code cleaning and respect
           of the methods used in others parts of the code.
-  
-       if ($group_id==$GLOBALS['sys_group_id']) 
+
+       if ($group_id==$GLOBALS['sys_group_id'])
 	{ // NEWS ADMIN
 	  print '<INPUT TYPE="HIDDEN" NAME="forum_id" VALUE="'.$forum_id.'">';
-	} 
+	}
       else
 	{
 	  $res=db_query("SELECT group_forum_id,forum_name ".
@@ -201,39 +201,39 @@ if ($forum_id)
 			"WHERE group_id='$group_id' AND is_public IN ($public_flag)");
 	  $vals=utils_result_column_to_array($res,0);
 	  $texts=utils_result_column_to_array($res,1);
-			
+
 	  $forum_popup = html_build_select_box_from_arrays ($vals,$texts,'forum_id',$forum_id,false);
 	} */
 
       //create a pop-up select box showing options for viewing threads
-		
+
       $vals=array('nested','flat','threaded','nocomments');
       $texts=array('Nested','Flat','Threaded','No Comments');
-		
+
       $options_popup=html_build_select_box_from_arrays ($vals,$texts,'style',$style,false);
-		
+
       //create a pop-up select box showing options for max_row count
       $vals=array(25,50,75,100);
       $texts=array('Show 25','Show 50','Show 75','Show 100');
-		
+
       $max_row_popup=html_build_select_box_from_arrays ($vals,$texts,'max_rows',$max_rows,false);
-		
+
       //now show the popup boxes in a form
       $ret_val .= '<TABLE BORDER="0" WIDTH="50%">
 				<FORM ACTION="'. $PHP_SELF .'" METHOD="get">
 				<INPUT TYPE="HIDDEN" NAME="set" VALUE="custom">
 				<INPUT TYPE="HIDDEN" NAME="forum_id" VALUE="'.$forum_id.'">
-				<TR><TD><FONT SIZE="-1">'. $forum_popup .
-	 '</TD><TD><FONT SIZE="-1">'. $options_popup .
-	 '</TD><TD><FONT SIZE="-1">'. $max_row_popup .
-	 '</TD><TD><FONT SIZE="-1"><INPUT TYPE="SUBMIT" NAME="SUBMIT" VALUE="Change View"></TD></TR></TABLE></FORM>';
-		
-      if ($style == 'nested') 
+				<TR><TD><span class="smaller">'. $forum_popup .
+	 '</span></TD><TD><span class="smaller">'. $options_popup .
+	 '</span></TD><TD><span class="smaller">'. $max_row_popup .
+	 '</span></TD><TD><span class="smaller"><INPUT TYPE="SUBMIT" NAME="SUBMIT" VALUE="Change View"></span></TD></TR></TABLE></FORM>';
+
+      if ($style == 'nested')
 	{
 	  /*
 				no top table row for nested threads
 	  */
-	} 
+	}
       else
 	{
 	  /*
@@ -241,21 +241,21 @@ if ($forum_id)
 
 				different header for default threading and flat now
 	  */
-			
+
 	  $title_arr=array();
 	  $title_arr[]='Thread';
 	  $title_arr[]='Author';
 	  $title_arr[]='Date';
-			
+
 	  $ret_val .= html_build_list_table_top ($title_arr);
-			
+
 	}
-		
+
       $i=0;
-      while (($total_rows < $max_rows) && ($i < $rows)) 
+      while (($total_rows < $max_rows) && ($i < $rows))
 	{
 	  $total_rows++;
-	  if ($style == 'nested') 
+	  if ($style == 'nested')
 	    {
 	      /*
 					New slashdot-inspired nested threads,
@@ -263,19 +263,19 @@ if ($forum_id)
 	      */
 	      //show this one message
 	      $ret_val .= forum_show_a_nested_message ( $result,$i ).'<BR>';
-				
-	      if (db_result($result,$i,'has_followups') > 0) 
+
+	      if (db_result($result,$i,'has_followups') > 0)
 		{
 		  //show submessages for this message
 		  $ret_val .= forum_show_nested_messages ( db_result($result,$i,'thread_id'), db_result($result,$i,'msg_id') );
 		}
-	    } else if ($style == 'flat') 
+	    } else if ($style == 'flat')
 	      {
-					
+
 		//just show the message boxes one after another
-					
+
 		$ret_val .= forum_show_a_nested_message ( $result,$i ).'<BR>';
-	      } 
+	      }
 	  else
 	    {
 	      /*
@@ -284,7 +284,7 @@ if ($forum_id)
 					phorum-esque threaded list of messages,
 					not showing message bodies
 	      */
-				
+
 	      $ret_val .= '
 					<TR class="'. utils_get_alt_row_color($total_rows) .'"><TD><A HREF="'.$GLOBALS['sys_home'].'forum/message.php?msg_id='.
 		 db_result($result, $i, 'msg_id').'">'.
@@ -295,9 +295,9 @@ if ($forum_id)
 					If so, highlite it in bold
 
 	      */
-	      if (get_forum_saved_date($forum_id) < db_result($result,$i,'date')) 
+	      if (get_forum_saved_date($forum_id) < db_result($result,$i,'date'))
 		{
-		  $ret_val .= '<B>';
+		  $ret_val .= '<strong>';
 		}
 	      /*
 					show the subject and poster
@@ -305,7 +305,7 @@ if ($forum_id)
 	      $ret_val .= db_result($result, $i, 'subject').'</A></TD>'.
 		 '<TD>'.db_result($result, $i, 'user_name').'</TD>'.
 		 '<TD>'.format_date($sys_datefmt,db_result($result,$i,'date')).'</TD></TR>';
-				
+
 	      /*
 
 	      Show subjects for submessages in this thread
@@ -313,9 +313,9 @@ if ($forum_id)
 					show_submessages() is recursive
 
 	      */
-	      if ($style == 'threaded') 
+	      if ($style == 'threaded')
 		{
-		  if (db_result($result,$i,'has_followups') > 0) 
+		  if (db_result($result,$i,'has_followups') > 0)
 		    {
 		      $ret_val .= show_submessages(db_result($result, $i, 'thread_id'),
 						   db_result($result, $i, 'msg_id'),1,0);
@@ -324,11 +324,11 @@ if ($forum_id)
 	    }
 	  $i++;
 	}
-		
+
       /*
 			This code puts the nice next/prev.
       */
-      if ($style=='nested' || $style=='flat') 
+      if ($style=='nested' || $style=='flat')
 	{
 	  $ret_val .= '<TABLE WIDTH="100%" BORDER="0">';
 	}
@@ -336,43 +336,43 @@ if ($forum_id)
 				<TR class="boxitemalt"><TD WIDTH="50%">';
       if ($offset != 0)
 	{
-	  $ret_val .= '<FONT face="Arial, Helvetica" SIZE="3" STYLE="text-decoration: none"><B>
-				<A HREF="javascript:history.back()">
-				<B><IMG SRC="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" HEIGHT=24 WIDTH=24 BORDER=0 ALIGN=MIDDLE> Previous Messages</A></B></FONT>';
-	} 
+	  $ret_val .= '<a href="javascript:history.back()">
+				<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" height="24" width="24" border="0" align="middle" />'
+                                .'<strong>'._('Previous Messages').'</strong></a>';
+	}
       else
 	{
 	  $ret_val .= '&nbsp;';
 	}
-		
+
       $ret_val .= '</TD><TD>&nbsp;</TD><TD ALIGN="RIGHT" WIDTH="50%">';
-      if (db_numrows($result) > $i) 
+      if (db_numrows($result) > $i)
 	{
-	  $ret_val .= '<FONT face="Arial, Helvetica" SIZE=3 STYLE="text-decoration: none"><B>
-				<A HREF="'.$GLOBALS['sys_home'].'forum/forum.php?max_rows='.$max_rows.'&style='.$style.'&offset='.($offset+$i).'&forum_id='.$forum_id.'">
-				<B>Next Messages <IMG SRC="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" HEIGHT=24 WIDTH=24 BORDER=0 ALIGN=MIDDLE></A>';
-	} 
+	  $ret_val .= '<a href="'.$GLOBALS['sys_home'].'forum/forum.php?max_rows='.$max_rows.'&amp;style='.$style.'&amp;offset='.($offset+$i).'&amp;forum_id='.$forum_id.'">
+				<strong>'
+                                ._('Next Messages').'</strong><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" height="24" width="24" border="0" align="middle" /></a>';
+	}
       else
 	{
 	  $ret_val .= '&nbsp;';
 	}
       $ret_val .= '</TABLE>';
     }
-	
+
   print $ret_val;
-	
+
   print '<p>&nbsp;</p>';
-	
+
   print '<h3>'.html_anchor(_("Start a New Thread:"), "newthread").'</h3>';
   show_post_form($forum_id);
-	
-  forum_footer(array());	
+
+  forum_footer(array());
 }
 else
 {
   forum_header(array('title'=>'Error'));
   print '<H1>Error - choose a forum first</H1>';
-  forum_footer(array());	
+  forum_footer(array());
 }
 
 ?>
