@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: message.php 4567 2005-06-30 17:19:37Z toddy $
+// $Id: message.php 5547 2006-08-10 22:08:09Z toddy $
 //
 // 
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -64,7 +64,7 @@ if ($msg_id) {
 	print html_build_list_table_top ($title_arr);
 
 	print "<tr><td>\n";
-	print '<b>'.db_result($result,0, "subject").'</b>';
+	print '<strong>'.db_result($result,0, "subject").'</strong>';
 	print ' ('._("posted by").' '.utils_user_link(db_result($result,0, "user_name")).", ";
 	print format_date($sys_datefmt,db_result($result,0, "date")).')';
 	print '<p>';
