@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: monitor.php 4567 2005-06-30 17:19:37Z toddy $
+// $Id: monitor.php 5547 2006-08-10 22:08:09Z toddy $
 //
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -74,7 +74,7 @@ if (user_isloggedin()) {
 			} else {
 				echo "<p style=error>Forum is now being monitored</p>";
 				echo "<P>You will now be emailed followups to this entire forum.";
-				echo "<P>To turn off monitoring, simply click the <B>Monitor Forum</B> link again.";
+				echo "<P>To turn off monitoring, simply click the <strong>Monitor Forum</strong> link again.";
 			}
 
 		} else {
