@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: who_monitors.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: who_monitors.php 5547 2006-08-10 22:08:09Z toddy $
 #
 #
 # Copyright 2003 (c) Free Software Foundation
@@ -40,7 +40,7 @@ if (user_isloggedin()) {
 		$result=db_query($sql);
 		$group_id=db_result($result,0,'group_id');
 		$forum_name=db_result($result,0,'forum_name');
-		
+
 		/*
 			Get the people who're monitoring this forum
 		*/
@@ -53,7 +53,7 @@ if (user_isloggedin()) {
 			forum_footer(array());
 		} else {
 			forum_header(array('title'=>$forum_name));
-	                ShowResultSet($result,'<H4>Currently monitoring:</H4>');
+	                utils_show_result_set($result,'Currently monitoring:');
 		}
 	} else {
 		forum_header(array('title'=>'Choose a forum First'));
@@ -65,5 +65,5 @@ if (user_isloggedin()) {
 	exit_not_logged_in();
 }
 ?>
-		
+
 
