@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: account.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: account.php 5784 2006-09-13 15:24:21Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -38,8 +38,17 @@ function account_pwvalid ($pw)
   return 1;
 }
 
-function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
+function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1, $allow_dots=0, $nameof=0, $MAX_ACCNAME_LENGTH=16, $MIN_ACCNAME_LENGTH=3)
 {
+  unset($underscore, $dashe, $dot);
+
+  # By default, we are supposed to check for an account name. But it may 
+  # be a list name or whatever
+  if (!$nameof) {
+    $nameof = _("account name");
+  }
+
+
   # By default, underscore are allowed, creating no specific issue for an
   # account name. It may creates trouble if the account is use to handle DNS...
   if ($allow_underscores) {
@@ -50,49 +59,64 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
   # and many other potential conflicts. However, it is usually convenient for
   # groups name.
   if ($allow_dashes) {
-    $dashes = "-";
+    $dash = "-";
+  }
+
+  # By default, dots are not allowed. Unix systems may allow it but it 
+  # is a source of confusion (for instance, a problem if you have the habit
+  # to things like `chown user.group`)
+  # However, it is sometimes wise to allow it, for instance if we check for
+  # a mailing-list name, which is almost like an account name + dots 
+  if ($allow_dots) {
+    $dot = ".";
   }
   
   # no spaces
   if (strrpos($name,' ') > 0)
     {
-      fb(_("There cannot be any spaces in the login name."),1);	
+      fb(sprintf(_("There cannot be any spaces in the %s"), $nameof),1);
       return 0;
     }
 
   # min and max length
-  $MIN_ACCNAME_LENGTH= 3;
-  $MAX_ACCNAME_LENGTH= 16;
-
   if (strlen($name) < $MIN_ACCNAME_LENGTH)
     {
-      fb(sprintf(ngettext("Account name is too short. It must be at least %s character.", "Account name is too short. It must be at least %s characters.", $MIN_ACCNAME_LENGTH), $MIN_ACCNAME_LENGTH),1);
+      fb(sprintf(_("The %s is too short"), $nameof), 1);
+      fb(sprintf(ngettext("It must be at least %s character.", "It must be at least %s characters.", $MIN_ACCNAME_LENGTH), $MIN_ACCNAME_LENGTH),1);
       return 0;
     }
 
   if (strlen($name) > $MAX_ACCNAME_LENGTH)
     {
-      fb(sprintf(ngettext("Account name is too long. It must be at most %s character.", "Account name is too long. It must be at most %s characters.", $MAX_ACCNAME_LENGTH), $MAX_ACCNAME_LENGTH),1);
+      fb(sprintf(_("The %s is too long"), $nameof), 1);
+      fb(sprintf(ngettext("It must be at most %s character.", "It must be at most %s characters.", $MAX_ACCNAME_LENGTH), $MAX_ACCNAME_LENGTH),1);
       return 0;
     }
 
   # must start with an alphanumeric non numeric
   if (strspn($name,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ") == 0)
     {
-      fb(_("Account name must begin with an alphabetical character."),1);
+      fb(sprintf(_("The %s must begin with an alphabetical character."), $nameof),1);
       return 0;
     }
 
   # must contain only legal characters and underscores, and maybe dashes and 
   # underscore, depending on the arguments
-  if (strspn($name,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789$underscore$dashes")
+  if (strspn($name,"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789$underscore$dash$dot")
       != strlen($name))
     {
-      if ($allow_underscore) 
-	{ fb(_("Account name must only contain alphanumerics and underscores."),1); }
-      elseif ($allow_dashes) 
-	{ fb(_("Account name must only contain alphanumerics and dashes."),1); }
-      else { fb(_("Account name must only contain alphanumerics."),1); }
+      unset($tolerated);
+      if ($allow_underscores) 
+	{ $tolerated .= _("underscores").', '; }
+      if ($allow_dashes) 
+	{ $tolerated .= _("dashes").', '; }
+      if ($allow_dots) 
+	{ $tolerated .= _("dots").', '; }
+
+      if ($tolerated)
+	{ $tolerated = ' ('._("tolerated:").' '.rtrim($tolerated, ', ').')'; }
+
+      fb(sprintf(_("The %s must only contain alphanumerics%s."), $nameof, $tolerated),1);
 
       return 0;
     }
@@ -102,13 +126,37 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
 	    . "|(uucp)|(apache)|(operator)|(invalid)|(games)|(mysql)|(httpd)|(nobody)|(dummy)|(opensource)"
 	    . "|(web)|(www)|(cvs)|(anoncvs)|(anonymous)|(shell)|(ftp)|(irc)|(debian)|(ns)|(download))$",$name))
     {
-      fb(_("That account name is reserved."),1);
+      fb(sprintf(_("That %s is reserved."), $nameof),1);
       return 0;
     }
 		
   return 1;
 }
 
+# Just check if the email address domain is not from a forbidden domain
+# or if it is not already associated to an email account
+function account_emailvalid ($email)
+{
+  if (db_numrows(db_query("SELECT user_id FROM user WHERE "
+			  . "email LIKE '".addslashes($email)."'")) > 0)
+    {
+      fb(_("An account associated with that email address has already been created."),1);
+      return 0;
+    }
+
+  utils_get_content("forbidden_mail_domains");
+
+  if ($GLOBALS['forbid_mail_domains_regexp'])
+    {
+      if (preg_match($GLOBALS['forbid_mail_domains_regexp'], addslashes($email)))
+	{
+	  fb(_("It is not allowed to associate an account with this email address."),1);
+	  return 0;
+	}
+    }
+  return 1;
+}
+
 function account_groupnamevalid ($name)
 {
   
