@@ -4,7 +4,7 @@
 #
 # $Id: title.php 4975 2005-11-15 17:25:35Z yeupou $
 #
-#  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2005-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,18 +20,23 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+# Guess the context of the current page
+function context_guess () 
+{
+  return context_guess_from_url($_SERVER[SCRIPT_NAME]);
+
+}
 
 # Get the context given the url. Fpr best efficiency, this function will 
 # return guessed values as soon as possible.
 # As contest should be always available in pages, it will be set as constants
-function context_guess () 
+function context_guess_from_url ($page, $dontset=false) 
 {
   # By default, we consider that the action, called subcontext, is browsing.
   # Only trackers allows actions that are not browsing or configuration.
   $subcontext = "browsing";
   
   # Obtain the name of the current page
-  $page = $_SERVER[SCRIPT_NAME];
   $page_basename = basename($page);
 
   # Try a first guess of the context
@@ -42,7 +47,7 @@ function context_guess ()
   if ($context == "projects")
     {
       $context = "project";
-      return context_set($context, $subcontext);
+      return context_set($context, $subcontext, $dontset);
     }
 
   # If we are in project, we need to look at the actuel script pagename
@@ -56,17 +61,17 @@ function context_guess ()
       if ($page_basename == "search.php")
 	{
 	  $subcontext = "search";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "memberlist.php")
 	{
 	  $subcontext = "members";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "memberlist-gpgkeys.php")
 	{
 	  $subcontext = "members-gpgkeys";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
     }
 
@@ -80,22 +85,22 @@ function context_guess ()
       if ($page_basename == "bookmarks.php")
 	{
 	  $subcontext = "bookmarks";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "items.php")
 	{
 	  $subcontext = "items";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "groups.php")
 	{
 	  $subcontext = "groups";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "votes.php")
 	{
 	  $subcontext = "votes";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
     }
 
@@ -105,24 +110,24 @@ function context_guess ()
       if ($page_basename == "group_type.php")
 	{
 	  $subcontext = "grouptype";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "grouplist.php")
 	{
 	  $subcontext = "groupedit";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "groupedit.php")
 	{
 	  $subcontext = "groupedit";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
       if ($page_basename == "userlist.php")
 	{
 	  $subcontext = "useredit";
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
-      return context_set($context, $subcontext);
+      return context_set($context, $subcontext, $dontset);
     }
 
 
@@ -137,20 +142,20 @@ function context_guess ()
   # we are for sure in trackers pages.
   if (defined('ARTIFACT') && $context != "admin") 
     {
-      if ($_GET[func] == "additem" || $_POST[func] == "additem" )
+      if (sane_all("func") == "additem")
 	{ 
 	  $subcontext = "postitem"; 
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
-      if ($_GET[func] == "detailitem" || $_POST[func] == "detailitem" )
+      if (sane_all("func") == "detailitem")
 	{ 
 	  $subcontext = "edititem"; 
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
-      if ($_GET[func] == "search" || $_POST[func]  == "search" )
+      if (sane_all("func") == "search")
 	{ 
 	  $subcontext = "search"; 
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
     }
 
@@ -166,23 +171,31 @@ function context_guess ()
       if (defined('ARTIFACT'))
 	{
 	  $context = ARTIFACT;
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 
 	}
       else
 	{
 	  $context = basename(dirname(dirname($page)));
-	  return context_set($context, $subcontext);
+	  return context_set($context, $subcontext, $dontset);
 	}
     }
 
   # Normally, context should have been guessed already
-  return context_set($context, $subcontext);
+  return context_set($context, $subcontext, $dontset);
 }
 
 # Defines context
-function context_set ($context, $subcontext) 
+function context_set ($context, $subcontext, $dontset=false) 
 {
+  # Dont set special mode is used? Then simply return the information
+  # (yes, this part is a bit complicated but it is only because of the 
+  # unplanned stone age menu that this things have a use)
+  if ($dontset)
+    {
+      return $context;
+    }
+
   # Defines main context, kind of pages (cvs, bug tracker...)
   define(CONTEXT, $context);
   # Defines subcontext, kind of action done (postitem...)
@@ -217,11 +230,11 @@ function context_title ()
 	}
       break;
 
-    case 'cvs': $title = _("SCM: CVS Repositories"); break;
+    case 'cvs': $title = _("CVS Repositories"); break;
 
-    case 'arch': $title = _("SCM: GNU Arch Repositories"); break;
+    case 'arch': $title = _("GNU Arch Repositories"); break;
 
-    case 'svn': $title = _("SCM: Subversion Repositories"); break;
+    case 'svn': $title = _("Subversion Repositories"); break;
       
     case 'userguide': 
       $title = _("In Depth Guide"); 
@@ -284,6 +297,20 @@ function context_title ()
 	}
       break;
       
+      # For now, forum case do as news do. 
+      # FIXME: if we were to use forum, it should state forum but only
+      # if we are sure it is not a news item. In upstream Savane, there is
+      # no forum activated.
+    case 'forum': 
+      {
+	$title = _("News"); 
+	# For site-wide news, Unset group_id so the name of the administration
+	# group is not printed in the title, redundant with the [sys_name]
+	if ($group_id == $GLOBALS['sys_group_id'])
+	  { unset($group_id); }
+	break;	
+      }
+      
     case 'mail': 
       switch (SUBCONTEXT)
 	{
@@ -308,7 +335,7 @@ function context_title ()
 	}
       break;
       
-    default: $title = $GLOBALS['sys_name'];
+    default: $title = false;
     }
 	  
 
