@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: exit.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: exit.php 5774 2006-09-13 12:12:12Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -37,9 +37,11 @@ function exit_error($title,$text=0)
   if ($text)
     { $content .= _(':').' '.$text; }
 
-  fb($content, 1);
+  # Add the content in feedback only if there is actually something
+  if ($content)
+    { fb($content, 1); }
 
-  $HTML->header(array('title'=>sprintf(_("Exiting with Error: %s"), $title)));
+  $HTML->header(array('title'=>_("Exiting with Error"),'notopmenu'=>1));
   html_feedback_top();
   
   $HTML->footer(array());
@@ -58,11 +60,11 @@ function exit_not_logged_in()
   
   if ($GLOBALS['sys_https_host'])
     {  
-      header('Location: https://'.$GLOBALS['sys_https_host'].$GLOBALS['sys_home'].'account/login.php?return_to='.urlencode($REQUEST_URI));
+      header('Location: https://'.$GLOBALS['sys_https_host'].$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($REQUEST_URI));
     } 
   else 
     {
-      header ("Location: http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."account/login.php?return_to=".urlencode($REQUEST_URI));
+      header ("Location: http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."account/login.php?uri=".urlencode($REQUEST_URI));
     }
 }
 
