@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: form.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: form.php 5803 2006-09-14 13:43:39Z yeupou $
 #
-#  Copyright 2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -48,15 +48,30 @@ function form_header ($action, $form_id=false, $method="post", $extra=false)
 }
 
 # Usual input
-function form_input ($type, $name, $value="")
+function form_input ($type, $name, $value="", $extra=false)
 {
   if ($value != "")
     { $value = 'value="'.$value.'"'; }
+  if ($extra)
+    { $extra = " $extra"; };
+    
   return '
-    <input type="'.$type.'" name="'.$name.'" '.$value.' />';
+    <input type="'.$type.'" name="'.$name.'" '.$value.$extra.' />';
 
 }
 
+# Special input: textarea
+function form_textarea ($name, $value="", $extra=false)
+{
+  if ($extra)
+    { $extra = " $extra"; };
+    
+  return '
+    <textarea name="'.$name.'"'.$extra.'>'.$value.'</textarea>';
+
+}
+
+
 # Add submit button
 function form_submit($text=false, $submit_name="update")
 {
@@ -72,8 +87,9 @@ function form_submit($text=false, $submit_name="update")
 function form_footer ($text=false, $submit_name="update")
 {
   return '
-    <p class="center">'.form_submit($text, $submit_name).'
-    </p>
+    <div class="center">
+      '.form_submit($text, $submit_name).'
+    </div>
   </form>';
 
 }
@@ -93,7 +109,21 @@ function form_check ($form_id)
       return 0;
     }
 
-  if (db_numrows(db_query("SELECT form_id FROM form WHERE user_id='".user_getid()."' AND form_id='".addslashes($form_id)."'")) < 1)
+  # See bug #6983
+  # We must clean the form id right now. This is not how the form id mechanism
+  # was designed.
+  # 
+  # Originally, form id was supposed to be deleted only when we are sure
+  # that the form was posted.
+  # However, since apache & all are multithreaded, you can end up with the
+  # case that the delay between the initial check and the end of the form
+  # is long enough to make possible a duplicate.
+  #
+  # Now, the check will remove the id. If the remove fail, it means that
+  # the form id no longer exists and then we exit. We will have only one
+  # SQL request, reducing as much as possible delays.
+  $success = db_affected_rows(db_query("DELETE FROM form WHERE user_id='".user_getid()."' AND form_id='".safeinput($form_id)."'"));
+  if (!$success)
     {
       fb(_("Duplicate Post: this form was already submitted."),1);
       return 0;
@@ -105,11 +135,8 @@ function form_check ($form_id)
 # Remove form_id from database: the item was posted
 function form_clean ($form_id)
 {
-  $success = db_affected_rows(db_query("DELETE FROM form WHERE user_id='".user_getid()."' AND form_id='".safeinput($form_id)."'"));
-  if (!$success)
-    { fb(_("Error during unique form_id removal"), 1); }
-  
-  return $success;
+  # Form_id are now directly removed by form_check
+  return 1;
 }
 
 
