@@ -2,13 +2,14 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: html.php 5927 2006-09-21 16:43:33Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
+#                          Paul Pogonyshev <pogonyshev--gmx.net>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,7 +25,7 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-# display browsing/display options: should be on top of pages, after the 
+# display browsing/display options: should be on top of pages, after the
 # specific content/page description.
 # The form should end by #options so it the user does not have to scroll down
 # too much
@@ -35,27 +36,83 @@ function html_show_displayoptions ($content, $form_opening=0, $submit=0)
 
 function html_show_boxoptions ($legend, $content, $form_opening=0, $submit=0)
 {
+
+  $script_hide = <<<EOF
+document.getElementById('boxoptionscontent').style.display='none';   document.getElementById('boxoptionslinkhide').style.display='none';   document.getElementById('boxoptionslinkshow').style.display='inline';
+EOF;
+  $script_show = <<<EOF
+document.getElementById('boxoptionscontent').style.display='inline'; document.getElementById('boxoptionslinkhide').style.display='inline'; document.getElementById('boxoptionslinkshow').style.display='none';
+EOF;
+
   $ret = '
 <fieldset class="boxoptions">
-<a name="options"></a><legend>'.$legend.'</legend>';
+<a name="options"></a>
+<legend>';
+
+  # yeupou, 2006-02: it is not ubercool to use monospace font to show
+  # plus or minus button, but all the tests I made with icons so far ended up
+  # in quite an ugly thing when the font scale change.
+  $ret .= '
+  <script type="text/javascript">';
   
+  if (sane_all("boxoptionwanted") != 1)
+    {
+      $ret .= '
+    document.write(\'<span onclick="'.addslashes($script_hide).'" id="boxoptionslinkhide" style="display: none"><span class="minusorplus">(-)</span>'.htmlspecialchars($legend, ENT_QUOTES).'</span>\');
+    document.write(\'<span onclick="'.addslashes($script_show).'" id="boxoptionslinkshow" style="display: inline"><span class="minusorplus">(+)</span>'.htmlspecialchars($legend, ENT_QUOTES).'</span>\');';
+    }
+  else
+    {
+      $ret .= '
+    document.write(\'<span onclick="'.addslashes($script_hide).'" id="boxoptionslinkhide" style="display: inline"><span class="minusorplus">(-)</span>'.htmlspecialchars($legend, ENT_QUOTES).'</span>\');
+    document.write(\'<span onclick="'.addslashes($script_show).'" id="boxoptionslinkshow" style="display: none"><span class="minusorplus">(+)</span>'.htmlspecialchars($legend, ENT_QUOTES).'</span>\');';
+
+    }
+  $ret .= '
+  </script>
+  <noscript>
+    <span id="boxoptionslinkshow">'.$legend.'</span>
+  </noscript>
+</legend>';
+
+  if (sane_all("boxoptionwanted") != 1)
+    {
+      $ret .= '
+<script type="text/javascript">
+  document.write(\'<span id="boxoptionscontent" style="display: none">\');
+</script>
+<noscript>
+  <span id="boxoptionscontent">
+</noscript>
+';
+    }
+  else
+    {
+      $ret .= '
+  <span id="boxoptionscontent">
+';
+    }
+
   if ($form_opening && $submit)
-    { 
+    {
       $ret .= '
 '.$form_opening.'
 <span class="boxoptionssubmit">'.$submit.'</span>';
     }
 
-$ret .= '
-<span class="smaller">'.$content.'</span>';
-  
+  # We add boxoptionwanted to be able to determine if a boxoption was used
+  # to update the page, in which case the boxoption must appear deployed
+  $ret .= '
+<span class="smaller">'.$content.form_input("hidden", "boxoptionwanted", "1").'</span>';
+
   if ($form_opening && $submit)
-    { 
+    {
       $ret .= '
 </form>';
     }
 
   $ret .= '
+</span>
 </fieldset>
 ';
 
@@ -99,7 +156,7 @@ function html_nextprev ($search_url, $rows, $rows_returned)
 	}
       else
 	{
-	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'" /><font class="italic">'._("Previous Results").'</font>';
+	  print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'" /><em>'._("Previous Results").'</em>';
 	}
 
       print "&nbsp; &nbsp; &nbsp;";
@@ -111,7 +168,7 @@ function html_nextprev ($search_url, $rows, $rows_returned)
 	}
       else
 	{
-	  print '<font class="italic">'._("Next Results").'</font> <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'" />';
+	  print '<em>'._("Next Results").'</em> <img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'" />';
 	}
 
       print "</h5>\n";
@@ -128,7 +185,7 @@ function html_anchor ($content, $name)
 # Print out the feedback
 function html_feedback_top()
 {
-  # By default, escape the html special chars, unless feedback_html was 
+  # By default, escape the html special chars, unless feedback_html was
   # set in the code to allow an htmlized feedback (that should happen on rare
   # occasions)
   if (!$GLOBALS[feedback_html])
@@ -137,25 +194,46 @@ function html_feedback_top()
       $GLOBALS[ffeedback] = htmlspecialchars($GLOBALS[ffeedback]);
     }
 
+  $script_hide = 'onclick="document.getElementById(\'feedback\').style.visibility=\'hidden\'; document.getElementById(\'feedbackback\').style.visibility=\'visible\';"';
+  $script_show = 'onclick="document.getElementById(\'feedback\').style.visibility=\'visible\'; document.getElementById(\'feedbackback\').style.visibility=\'hidden\';"';
+
+  # With MSIE  the feedback will be be 
+  # in relative position, so the hiding link will not make sense
+  if (strpos($_SERVER['HTTP_USER_AGENT'], "MSIE") && !$_GET["printer"])
+    { unset($script_hide); }
+  # Users can choose the same behavior, disallowing the fixed positionning
+  # of the feedback (less convenient as the feedback gets easily hidden,
+  # requires to scroll to be accessed, but seems prefered by users of 
+  # mozilla that slow scrolling down/up when there is such fixed box on the
+  # page)
+  if (user_get_preference("nonfixed_feedback"))
+    { $script_hide = 'style="top: 0; right: 0; bottom: 0; left: 0; position: relative"'; }
+
+  print '<div '.$script_show.' id="feedbackback" class="feedbackback"'.$dirtyhack.'>'._("Show feedback again").'</div>';
+
   # Only success
   if ($GLOBALS[feedback] && !$GLOBALS[ffeedback])
-    {  print '<div class="feedback"><span class="feedbacktitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.png" class="feedbackimage" alt="'._("Success").'" /> '._("Success:").'</span> '.$GLOBALS[feedback].'</div>'; }
+    {
+        print '<div id="feedback" class="feedback" '.$script_hide.'><span class="feedbacktitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.png" class="feedbackimage" alt="'._("Success").'" /> '._("Success:").'</span> '.$GLOBALS[feedback].'</div>';
+    }
 
   # Only errors
   if ($GLOBALS[ffeedback] && !$GLOBALS[feedback])
-    {  print '<div class="feedbackerror"><span class="feedbackerrortitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Error").'" /> '._("Error:").'</span>'.$GLOBALS[ffeedback].'</div>'; }
+    {
+      print '<div id="feedback" class="feedbackerror" '.$script_hide.'><span class="feedbackerrortitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Error").'" /> '._("Error:").'</span>'.$GLOBALS[ffeedback].'</div>';
+    }
 
   # Errors and success
   if ($GLOBALS[ffeedback] && $GLOBALS[feedback])
-    {  print '<div class="feedbackerrorandsuccess"><span class="feedbackerrorandsuccesstitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Some Errors").'" /> '._("Some Errors:").'</span>'.$GLOBALS[feedback].' '.$GLOBALS[ffeedback].'</div>'; }
+    {  print '<div id="feedback" class="feedbackerrorandsuccess" '.$script_hide.'><span class="feedbackerrorandsuccesstitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Some Errors").'" /> '._("Some Errors:").'</span>'.$GLOBALS[feedback].' '.$GLOBALS[ffeedback].'</div>'; }
 
   if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
     {  print '<div class="debug">DEBUG information: '.$GLOBALS[debug].'</div>'; }
 
-  # yeupou@gnu.org 2003-11-03:
+
   # We unset feedback so there will be a bottom feedback only if something
   # changed. It may confuse users, however I would find more confusing to
-  # have to lookalike feedback information providing most of the time the
+  # have two lookalike feedback information providing most of the time the
   # same information AND (that is the problem) sometimes more information
   # in the second one.
   unset($GLOBALS[feedback],$GLOBALS[ffeedback],$GLOBALS[debug]);
@@ -602,7 +680,7 @@ function html_select_restriction_box ($artifact, $row, $level="group", $notd=0,
   else
     {
       $value = $row;
-      if ($event == 2) 
+      if ($event == 2)
 	{
 	  $default = _("Same as for new items");
 	}
@@ -674,8 +752,8 @@ function html_select_typedir_box ($input_name, $current_value)
 ';
 
   # put some information
-  print '<br /><font class="smaller">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br /> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br />
-(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savane-dev@gna.org to get information about that)</font><br /><br />';
+  print '<br /><span class="smaller">Basic directory will make the backend using DownloadMakeArea(), defined in Savannah::Download; <br /> CVS directory will make the backend using CvsMakeArea(), defined in Savannah::Cvs;<br />
+(If you need to build directories with another method, the solution is to write a new sub in the appropriate perl module, please send a mail to savane-dev@gna.org to get information about that)</span><br /><br />';
 
 }
 
@@ -693,8 +771,7 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
 		<select name="'.$input_name.'">';
 
   # usual themes
-  $data = theme_list(1);
-  while (list(,$theme) = each($data))
+  foreach (theme_list() as $theme)
     {
       print "\n\t\t".'<option value="'.$theme.'"';
       if ($theme == $current)
@@ -798,7 +875,6 @@ function html_header($params)
   global $HTML;
   print $HTML->header($params);
   print html_feedback_top($GLOBALS['feedback']);
-  print $HTML->tabs($params);
 }
 
 function html_footer($params)
