@@ -2,10 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: i18n.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: i18n.php 5978 2006-09-26 14:43:45Z yeupou $
 #
-#  Copyright 2003-2004 (c) Stphane Urbanovski <s.urbanovski@ac-nancy-metz.fr>
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2006 (c) Stéphane Urbanovski <s.urbanovski--ac-nancy-metz.fr>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -40,7 +40,10 @@ $locale = $GLOBALS['sys_default_locale'];
 $supportedLanguages = array(
 			    "de"	=> "DE.UTF-8",
 			    "de_DE"	=> "DE.UTF-8",
+			    "ca"        => "ES.UTF-8",
 			    "en"	=> "US.UTF-8",
+			    "en_GB"	=> "GB.UTF-8",
+                            "es"        => "ES.UTF-8",
 			    "fr"	=> "FR.UTF-8",
 			    "fr_FR"	=> "FR.UTF-8",
 			    "it"	=> "IT.UTF-8",
@@ -52,7 +55,9 @@ $supportedLanguages = array(
 			    "pt"	=> "BR.UTF-8",
 			    "pt_BR"     => "BR.UTF-8",
 			    "ru"	=> "RU.UTF-8",
-			    "ru_RU"     => "RU.UTF-8"
+			    "ru_RU"     => "RU.UTF-8",
+			    "sv"	=> "SE.UTF-8",
+			    "sv_SE"     => "SE.UTF-8",
 			    );
 
 # Try to find the best supported language from user's navigator preferences :
@@ -193,6 +198,7 @@ if (!function_exists("ngettext")) {
     $plural_rule["ko_KR"] = 0;
     $plural_rule["pt_BR"] = ($n > 1);
     $plural_rule["ru_RU"] = ($n%10 == 1 && $n%100 != 11 ? 0 : ($n%10 >= 2 && $n%10 <= 4 && ($n%100 < 10 || $n%100 >= 20) ? 1 : 2));
+    $plural_rule["sv_SE"] = ($n != 1);
 
     # if there's no plural rule defined, use a generic one
     if (!isset($plural_rule[$locale]))
