@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: forum.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: forum.php 5953 2006-09-22 14:38:05Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -50,7 +50,7 @@ function forum_show_a_nested_message ($result,$row=0)
 		<table border="0" width="100%">
 			<tr>
 				<td class="boxitem">'.
-		'<b>'.db_result($result, $row, 'subject').'</b>'.
+		'<strong>'.db_result($result, $row, 'subject').'</strong>'.
 		' ('._("posted by").' <a href="'.$GLOBALS['sys_home'].'users/'.
 		db_result($result, $row, 'user_name') .'/">'.
 		db_result($result, $row, 'realname') .'</a>, '.
@@ -131,7 +131,7 @@ function forum_header($params)
             if (!$result || db_numrows($result) < 1)
                 {
                     $is_news=0;
-                    #print '<font class="error">'._("Error").' - '._("This news item was not found").'</font>';
+                    #print '<span class="error">'._("Error").' - '._("This news item was not found").'</span>';
                     #print "forum_name=$forum_name<br />";
                     site_project_header($params);
                     #site_project_header(array('group'=>$group_id,'context'=>'forum'));
@@ -162,13 +162,13 @@ function forum_header($params)
 ';
 
 		    print '<h3>'.html_anchor(db_result($result,0,'summary'), "content").'</h3>';
-                    print '<p class="italic">'.sprintf(_("Item posted by %s on %s."), 
-						       utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))),
-						       format_date($sys_datefmt,db_result($result,0,'date'))).'</p>';
-                    print '<p>';
-                    print  utils_make_links(nl2br( db_result($result,0,'details')), $group_id);
+                    print '<p><em>'.sprintf(_("Item posted by %s on %s."),
+                        utils_user_link(user_getname(db_result($result,0,'submitted_by')),
+                        user_getrealname(db_result($result,0,'submitted_by'))),
+                        format_date($sys_datefmt,db_result($result,0,'date')))
+                        .'</em></p>';
+                    print utils_make_links(nl2br( db_result($result,0,'details')), $group_id);
 
-                    print '<p>';
 # could this fix the bug #409 ?
                     $forum_name = db_result($result,0,'summary');
 		    print '</div>
@@ -185,15 +185,17 @@ function forum_header($params)
         {
             print '<h3 class="clearr">'.html_anchor(_("Comments:"), "comments").'</h3>';
         }
-	print '<P><B>';
+	print '<P><strong>';
 
-	if ($forum_id && user_isloggedin())
+	# yeupou, 2006-09-22: deactivate for now, it does not seem to be
+	# working and generate garbage (like mail sent to NOREPLY)
+	if (0 && $forum_id && user_isloggedin())
         {
             print '<a href="'.$GLOBALS['sys_home'].'forum/monitor.php?forum_id='.$forum_id.'">' .
-                #'<img src="'.$GLOBALS['sys_home'].'images/ic/check.png" alt="monitor">
+                #'<img src="'.$GLOBALS['sys_home'].'images/ic/check.png" alt="monitor" />
                 _("Monitor Forum (toggle)").'</a> | '.
                 '<a href="'.$GLOBALS['sys_home'].'forum/save.php?forum_id='.$forum_id.'">'.
-                #'<img src="'.$GLOBALS['sys_home'].'images/ic/save.png" alt="save">
+                #'<img src="'.$GLOBALS['sys_home'].'images/ic/save.png" alt="save" />
                 _("Save Place").'</a> | '.
                 '<A HREF="'.$GLOBALS['sys_home'].'forum/who_monitors.php?forum_id='.$forum_id.'?group_id='.$group_id.'">'.
                 'Who\'s monitoring</A> | '.
@@ -204,7 +206,7 @@ function forum_header($params)
 	/*  This functionality is depreated
     if (user_is_super_user()) alternatively: user_ismember($group_id, "F2")
       {
-        print ' | <A HREF="'.$GLOBALS['sys_home'].'forum/admin/?group_id='.$group_id.'">Admin</A></B>';
+        print ' | <A HREF="'.$GLOBALS['sys_home'].'forum/admin/?group_id='.$group_id.'">Admin</A></strong>';
       }
 	*/
 	print '</P>';
@@ -246,12 +248,6 @@ function forum_create_forum($group_id,$forum_name,$is_public=1,$create_default_m
 	return $forum_id;
 }
 
-function make_links ($data="")
-{
-	#moved make links to /include/utils.php
-	utils_make_links($data);
-}
-
 function get_forum_name($id){
 	/*
 		Takes an ID and returns the corresponding forum name
@@ -320,7 +316,7 @@ function show_thread($thread_id,$et=0)
 				See if this message is new or not
                     */
                     if (get_forum_saved_date($forum_id) < db_result($result,$i,'date'))
-                        { $ret_val .= '<B>'; }
+                        { $ret_val .= '<strong>'; }
 
                     $ret_val .= db_result($result, $i, 'subject') .'</A></TD>'.
                         '<TD>'.db_result($result, $i, 'user_name').'</TD>'.
@@ -396,7 +392,7 @@ function show_submessages($thread_id, $msg_id, $level,$et=0)
 				See if this message is new or not
 			*/
 			if (get_forum_saved_date($forum_id) < db_result($result,$i,'date'))
-                { $ret_val .= '<B>'; }
+                { $ret_val .= '<strong>'; }
 
 			$ret_val .= db_result($result, $i, 'subject').'</A></TD>'.
 				'<TD>'.db_result($result, $i, 'user_name').'</TD>'.
@@ -584,21 +580,21 @@ function show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")
 
             print '<center>';
             print '<form action="'.$GLOBALS['sys_home'].'forum/forum.php" method="POST">';
-            print '<input type="hidden" name="post_message" value="y">';
-            print '<input type="HIDDEN" name="forum_id" value="'.$forum_id.'">';
-            print '<input type="HIDDEN" name="thread_id" value="'.$thread_id.'">';
-            print '<input type="HIDDEN" name="msg_id" value="'.$is_followup_to.'">';
-            print '<input type="HIDDEN" name="is_followup_to" value="'.$is_followup_to.'">';
-            print '<table><tr><td><b>'._("Subject").':</td><td>';
-            print '<input type="TEXT" name="subject" value="'.$subject.'" size="60" maxlength="45">';
+            print '<input type="hidden" name="post_message" value="y" />';
+            print '<input type="HIDDEN" name="forum_id" value="'.$forum_id.'" />';
+            print '<input type="HIDDEN" name="thread_id" value="'.$thread_id.'" />';
+            print '<input type="HIDDEN" name="msg_id" value="'.$is_followup_to.'" />';
+            print '<input type="HIDDEN" name="is_followup_to" value="'.$is_followup_to.'" />';
+            print '<table><tr><td><strong>'._("Subject").':</td><td>';
+            print '<input type="TEXT" name="subject" value="'.$subject.'" size="60" maxlength="45" />';
             print '</td></tr>';
-            print '<tr><td><b>'._("Message").':</td><td>';
+            print '<tr><td><strong>'._("Message:").'</td><td>';
             print '<textarea name="body" value="" rows="25" cols="60" wrap="SOFT"></textarea>';
 			print '</td></tr>';
 			print '<tr><td colspan="2" align="MIDDLE">';
-			print '<font class="warn">HTML tags will display in your post as text</font>';
+			print '<span class="warn">HTML tags will display in your post as text</span>';
 			print '<br />';
-			print '<input type="SUBMIT" name="SUBMIT" value="'._("Post Comment").'">';
+			print '<input type="SUBMIT" name="SUBMIT" value="'._("Post Comment").'" />';
 			print '</td></tr></table>';
 			print '</form>';
 			print '</center>';
@@ -607,7 +603,7 @@ function show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")
 	else
         {
             print "<center>";
-            print "\n\n<font class=\"error\">"._("You could post if you were logged in").'</font>';
+            print "\n\n<span class=\"error\">"._("You could post if you were logged in").'</span>';
             print "</center>";
 
         }
@@ -664,11 +660,20 @@ function handle_monitoring($forum_id,$msg_id)
 
 /* MH 2003-11-20 */
                             $from=db_result($result,0,'realname')." <" . db_result($result,0, 'email') . ">";
-                            $to=$GLOBALS[sys_mail_replyto]; /* MH: To should be the mailinglist address! */
-                            $subject= "[" . db_result($result,0,'unix_group_name').
+                            /*$to=$GLOBALS[sys_mail_replyto];*/ /* MH: To should be the mailinglist address! */
+                            $to=$GLOBALS['sys_lists_prefix'] . db_result($result,0,'unix_group_name').
+                                "_" . db_result($result,0,'forum_name') . "@" . $GLOBALS['sys_default_domain'];
+
+/*                            $subject= "[" . db_result($result,0,'unix_group_name').
                                 "_" . db_result($result,0,'forum_name')."] ".
                                 utils_unconvert_htmlspecialchars(db_result($result,0,'subject')).
                                 "     #" . $gpkaid . "#";
+*/
+/* MH 2004-06-04 */
+                             $subject= "[" . $GLOBALS['sys_lists_prefix'] . db_result($result,0,'unix_group_name').
+                                " - " . db_result($result,0,'forum_name')."] ".
+                                utils_unconvert_htmlspecialchars(db_result($result,0,'subject')).
+                                "     #" . $gpkaid . "#";
                             $message="\n\n".
                                 "\nBy: " . db_result($result,0,'realname') ." <" .db_result($result,0, 'email') . ">" .
                                 "\n\n" . utils_unconvert_htmlspecialchars(db_result($result,0, 'body')).
@@ -683,9 +688,19 @@ function handle_monitoring($forum_id,$msg_id)
                             #$savannah_artifact_id=$forum_id;
                             $savannah_artifact=0; # these must stay zero to not mess up the subject any further
                             $savannah_artifact_id=0;
-                            $reply_to=$GLOBALS['sys_lists_prefix'] . db_result($result,0,'unix_group_name').
-                                "_" . db_result($result,0,'forum_name') . "@" . $GLOBALS['sys_mail_domain'];
-                            $additional_headers="BCC: $tolist";
+                            /*$reply_to=$GLOBALS['sys_lists_prefix'] . db_result($result,0,'unix_group_name').
+                                "_" . db_result($result,0,'forum_name') . "@" . $GLOBALS['sys_default_domain'];*/
+
+                            /* AH 04/08/2005:
+                               BCC should not be used to address reciepients. 
+                               We use the Resent-To: header to address each person individually.
+                               Thus we need to loop over recipients which are stored in the $tolist string.
+                               (Could lead to performance problems with many recipients...) */
+
+			    $toarray = explode(", ",$tolist);
+			    for($xx=0;$xx<count($toarray);$xx++) {   /* LOOP OVER RECIPIENTS */
+                               $additional_headers="Resent-To:" . $toarray[$xx];
+			       $additional_headers .= "\nPrecedence: bulk\nResent-From: MailingForum";
 
 # Custom extensions to the header:
 /*
@@ -696,10 +711,11 @@ function handle_monitoring($forum_id,$msg_id)
                                            "additional_headers: $additional_headers<br />";
 */
 
-                            sendmail_mail ($from, $to, $subject, $message,
+				sendmail_mail ($from, $to, $subject, $message,
                                            $savannah_project, $savannah_artifact,
                                            $savannah_artifact_id, $reply_to,
                                            $additional_headers);
+			    }
 
 /* AH 2002-11-14 stop */
                         }
