@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: general.php 5604 2006-08-18 21:08:25Z beuc $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -117,13 +117,16 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 
       $return .=
         news_new_subbox($i+1)
-	.'<a href="'.$GLOBALS['sys_home'].'forum/forum.php?forum_id='.db_result($result,$i,'forum_id').'"><b>'.db_result($result,$i,'summary').'</b></a>';
+	.'<a href="'.$GLOBALS['sys_home'].'forum/forum.php?forum_id='
+        .db_result($result,$i,'forum_id').'"><strong>'
+        .db_result($result,$i,'summary').'</strong></a>';
       if ($show_summaries != "false")
 	{ $return .= '<br />&nbsp;&nbsp;&nbsp;&nbsp;'; }
-      $return .= ' <font class="smaller"><i>'._("posted by").' <a href="'
+      $return .= ' <span class="smaller"><em>'._("posted by").' <a href="'
 	.$GLOBALS['sys_home'].'users/'. db_result($result,$i,'user_name') .'">'. db_result($result,$i,'user_name')
 	.'</a>, '. format_date($sys_datefmt,db_result($result,$i,'date')) .' - '
-	.$reply.'</i></font>'.$summ_txt;
+	.$reply.'</em></span>'
+        .$summ_txt;
 
 	}
     }
@@ -139,13 +142,13 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 	  # You used to be able to submit general news.
 	  $return .= news_new_subbox($i)
 	     .'<br /> <a href="'.$GLOBALS['sys_home'].'news/submit.php?group_id='
-	     .$group_id.'"><font size="-1">['._("Submit News").']</font></a>';
+	     .$group_id.'"><span class="smaller">['._("Submit News").']</span></a>';
 	}
 
       $return .= news_new_subbox($i)
-	 .'<br /> <a href="'.$GLOBALS['sys_home'].'news/?group_id='.$group_id.'"><font size="-1">['
+	 .'<br /> <a href="'.$GLOBALS['sys_home'].'news/?group_id='.$group_id.'"><span class="smaller">['
 	 .sprintf(ngettext("%d news in archive", "%d news in archive", $news_total), $news_total)
-         .']</font></a>';
+         .']</span></a>';
     }
 
   return $return;
