@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: general.php 5561 2006-08-14 08:41:55Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -86,7 +86,7 @@ function people_show_category_list()
   $result=db_query($sql);
   $rows=db_numrows($result);
   if (!$result || $rows < 1)
-    {    
+    {
       $return .= _("No Categories Found");
     }
   else
@@ -99,13 +99,13 @@ function people_show_category_list()
 	  if (db_result($count_res,0,'count') > 0)
 	    {
 	      $j++;
-	      $return .= '<li class="'.utils_get_alt_row_color($j).'"><font class="smaller">&nbsp;&nbsp;- <a href="'.$GLOBALS['sys_home'].'people/?category_id='.
+	      $return .= '<li class="'.utils_get_alt_row_color($j).'"><span class="smaller">&nbsp;&nbsp;- <a href="'.$GLOBALS['sys_home'].'people/?category_id='.
 		db_result($result,$i,'category_id') .'">'.db_result($count_res,0,'count').
-		' '.db_result($result,$i,'name') .'</a></font></li>';
+		' '.db_result($result,$i,'name') .'</a></span></li>';
 	    }
 	}
     }
-  if (!$return) 
+  if (!$return)
     { return false; }
 
   return "<ul class=\"boxli\">".$return."</ul>";
@@ -219,7 +219,7 @@ function people_show_job_inventory($job_id)
 	}
     }
   print '
-		</TABLE>';
+		</table>';
 }
 
 function people_verify_job_group($job_id,$group_id)
@@ -265,17 +265,17 @@ function people_edit_job_inventory($job_id,$group_id)
 	{
 	  print '
 			<form action="'.$PHP_SELF.'" method="POST">
-			<input type="HIDDEN" name="job_inventory_id" value="'. db_result($result,$i,'job_inventory_id') .'">
-			<input type="HIDDEN" name="job_id" value="'. db_result($result,$i,'job_id') .'">
-			<input type="HIDDEN" name="group_id" value="'.$group_id.'">
+			<input type="HIDDEN" name="job_inventory_id" value="'. db_result($result,$i,'job_inventory_id') .'" />
+			<input type="HIDDEN" name="job_id" value="'. db_result($result,$i,'job_id') .'" />
+			<input type="HIDDEN" name="group_id" value="'.$group_id.'" />
 			<tr class="'. utils_get_alt_row_color($i) .'">
-				<td><font size="-1">'. db_result($result,$i,'skill_name') . '</td>
-				<td><font size="-1">'. people_skill_level_box('skill_level_id',db_result($result,$i,'skill_level_id')). '</td>
-				<td><font size="-1">'. people_skill_year_box('skill_year_id',db_result($result,$i,'skill_year_id')). '</td>
-				<td nowrap><font size="-1"><input type="SUBMIT" name="update_job_inventory"'
+				<td><span class="smaller">'. db_result($result,$i,'skill_name') . '</span></td>
+				<td><span class="smaller">'. people_skill_level_box('skill_level_id',db_result($result,$i,'skill_level_id')). '</span></td>
+				<td><span class="smaller">'. people_skill_year_box('skill_year_id',db_result($result,$i,'skill_year_id')). '</span></td>
+				<td nowrap><span class="smaller"><input type="SUBMIT" name="update_job_inventory"'
 	    .'value="'._("Update").'"> &nbsp;
 					<input type="SUBMIT" name="delete_from_job_inventory" value="'
-	    ._("Delete").'"></td>
+	    ._("Delete").'"></span></td>
 				</tr></form>';
 	}
 
@@ -286,14 +286,14 @@ function people_edit_job_inventory($job_id,$group_id)
   print '
 	<tr><td colspan="4"><h3>'._("Add A New Skill").'</h3></td></tr>
 	<form action="'.$PHP_SELF.'" method="POST">
-	<input type="HIDDEN" name="job_id" value="'. $job_id .'">
-	<input type="HIDDEN" name="group_id" value="'.$group_id.'">
+	<input type="HIDDEN" name="job_id" value="'. $job_id .'" />
+	<input type="HIDDEN" name="group_id" value="'.$group_id.'" />
 	<tr class="'. utils_get_alt_row_color($i) .'">
-		<td><font size="-1">'. people_skill_box('skill_id'). '</td>
-		<td><font size="-1">'. people_skill_level_box('skill_level_id'). '</td>
-		<td><font size="-1">'. people_skill_year_box('skill_year_id'). '</td>
-		<td nowrap><font size="-1"><input type="SUBMIT" name="add_to_job_inventory"
-		value="'._("Add Skill").'"></td>
+		<td><span class="smaller">'. people_skill_box('skill_id'). '</span></td>
+		<td><span class="smaller">'. people_skill_level_box('skill_level_id'). '</span></td>
+		<td><span class="smaller">'. people_skill_year_box('skill_year_id'). '</span></td>
+		<td nowrap><span class="smaller"><input type="SUBMIT" name="add_to_job_inventory"
+		value="'._("Add Skill").'"></span></td>
 	</tr></form>';
 
   print '
@@ -527,15 +527,15 @@ function people_edit_skill_inventory($user_id)
 	{
 	  print '
 			<form action="'.$PHP_SELF.'" method="POST">
-			<input type="hidden" name="skill_inventory_id" value="'.db_result($result,$i,'skill_inventory_id').'">
+			<input type="hidden" name="skill_inventory_id" value="'.db_result($result,$i,'skill_inventory_id').'" />
 			<tr class="'. utils_get_alt_row_color($i) .'">
-				<td><font size="-1">'. db_result($result,$i,'skill_name') .'</td>
-				<td><font size="-1">'. people_skill_level_box('skill_level_id',db_result($result,$i,'skill_level_id')). '</td>
-				<td><font size="-1">'. people_skill_year_box('skill_year_id',db_result($result,$i,'skill_year_id')). '</td>
-				<td nowrap><font size="-1"><input type="SUBMIT" name="update_skill_inventory"'
+				<td><span class="smaller">'. db_result($result,$i,'skill_name') .'</span></td>
+				<td><span class="smaller">'. people_skill_level_box('skill_level_id',db_result($result,$i,'skill_level_id')). '</span></td>
+				<td><span class="smaller">'. people_skill_year_box('skill_year_id',db_result($result,$i,'skill_year_id')). '</span></td>
+				<td nowrap><span class="smaller"><input type="SUBMIT" name="update_skill_inventory"'
 	    .'value="'._("Update").'"> &nbsp;
 					<input type="SUBMIT" name="delete_from_skill_inventory"'
-	    .'value="'._("Delete").'"></td>
+	    .'value="'._("Delete").'"></span></td>
 			</tr>
 			</form>';
 	}
@@ -548,11 +548,11 @@ function people_edit_skill_inventory($user_id)
 	<tr><td colspan="4"><h3>'._("Add A New Skill").'</h3></td></tr>
 	<form action="'.$PHP_SELF.'" method="POST">
 	<tr class="'. utils_get_alt_row_color($i) .'">
-		<td><font size="-1">'. people_skill_box('skill_id'). '</td>
-		<td><font size="-1">'. people_skill_level_box('skill_level_id'). '</td>
-		<td><font size="-1">'. people_skill_year_box('skill_year_id'). '</td>
-		<td nowrap><font size="-1"><input type="submit" name="add_to_skill_inventory" value="'
-    ._("Add Skill").'"></td>
+		<td><span class="smaller">'. people_skill_box('skill_id'). '</span></td>
+		<td><span class="smaller">'. people_skill_level_box('skill_level_id'). '</span></td>
+		<td><span class="smaller">'. people_skill_year_box('skill_year_id'). '</span></td>
+		<td nowrap><span class="smaller"><input type="submit" name="add_to_skill_inventory" value="'
+    ._("Add Skill").'"></span></td>
 	</tr>
 	</form>';
 
