@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: pre.php 5268 2005-12-26 11:48:10Z toddy $
+# $Id: pre.php 5951 2006-09-22 13:42:44Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gna.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gna.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,16 +23,39 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+# No variable beginning by $sys_ should be set so far because these
+# are system configuration from /etc conffile.
+# Normally, the code is well thought enough so it makes no real profound
+# different if some malicious user define a $sys_ variable before the
+# conffile is read: the conffile will overwrite any important variable.
+# But it is cleaner to simply unset any $sys_ variable set before we
+# read the conffile, to tighten security as soon as possible.
+# It also avoid register_globals_off() to unset by mistake these variables
+# 
+# It use strstr so it is very fast. 
+#
+# This means that it will never possible to set $sys_ outside of the conffile.
+# (which is not a problem)
+foreach ($GLOBALS as $key => $value)
+{ 
+  # Search for sys_
+  if (!strstr($key, "sys_"))
+    { continue; }
+  
+  # Unset if found
+  unset($GLOBALS[$key]); 
+}
+
 # Defines all of the Savane hosts, databases, etc.
 # This needs to be loaded first because the lines below depend upon it.
 if (getenv('SAVANE_CONF'))
-{ require getenv('SAVANE_CONF').'/savannah.conf.php'; }
+{ require getenv('SAVANE_CONF').'/.savane.conf.php'; }
 elseif (getenv('SV_LOCAL_INC_PREFIX'))
-{ require getenv('SV_LOCAL_INC_PREFIX').'/savannah.conf.php'; }
+{ require getenv('SV_LOCAL_INC_PREFIX').'/.savane.conf.php'; }
 else
 {
   # go back to default location
-  require '/etc/savannah/savannah.conf.php';
+  require '/etc/savane/.savane.conf.php';
 }
 
 if ($GLOBALS['sys_url_topdir'] != '/')
@@ -55,6 +78,14 @@ else
   $sys_https_url = 'http://'.$GLOBALS['sys_default_domain'];
 }
 
+# If file upload limit was not defined in the configuration file
+# we set it arbitrarily to 1/2 MB, something that should work out of the
+# box on most systems.
+# (depends on MySQL max_allowed_packet and PHP upload_max_filesize
+if (!$GLOBALS['sys_upload_max'])
+{
+  $GLOBALS['sys_upload_max'] = "512";
+}
 
 
 # require_directory
@@ -163,6 +194,10 @@ require $GLOBALS['sys_www_topdir'].'/include/theme.php';
 # like title
 require $GLOBALS['sys_www_topdir'].'/include/context.php';
 
+# left-hand and top menu nav library (requires context to be set)
+require $GLOBALS['sys_www_topdir'].'/include/sitemenu.php';
+require $GLOBALS['sys_www_topdir'].'/include/pagemenu.php';
+
 # HTML layout class, may be overriden by the Theme class
 require $GLOBALS['sys_www_topdir'].'/include/Layout.class';
 
@@ -195,10 +230,6 @@ require $GLOBALS['sys_www_topdir'].'/include/form.php';
 # search tools, frequently needed
 require_directory('search');
 
-# left-hand nav library, themable
-require $GLOBALS['sys_www_topdir'].'/include/menu.php';
-
-
 /**************************************************************
        Set up proper use of UTF-8, even if the webserver does
        not serve it by default
@@ -223,25 +254,25 @@ if (isset($GLOBALS['sys_unix_group_name']))
   $sys_group_id = db_result($res_grp,0,'group_id');
 }
 
-
 # determine if they're logged in
 session_set();
 
-# set up the user's timezone if logged in
-# redirect them from http to https if asked in their session table
+
+# If logged in, do a few setups
 if (user_isloggedin())
 {
+  # Set timezone
   putenv('TZ='.user_get_timezone());
 
-  if (!session_issecure() && session_needsstayinssl())
-    {
-      if ($GLOBALS['sys_https_host'] )
-	{
-	  header('Location: https://'.$GLOBALS['sys_https_host'].$REQUEST_URI);
-	}
-    }
+  # Find out if the stone age menu is required
+  if (user_get_preference("stone_age_menu"))
+    { $GLOBALS['stone_age_menu'] = 1; }
 }
 
+# redirect them from http to https if they said so at login time
+if (!session_issecure() && isset($_COOKIE['redirect_to_https']) && $GLOBALS['sys_https_host'])
+     header('Location: https://'.$GLOBALS['sys_https_host'].$REQUEST_URI);
+
 
 /**************************************************************
        Defines every information useful
@@ -251,13 +282,31 @@ if (user_isloggedin())
 # defines the artifact we are using
 define("ARTIFACT", get_module_include_dir($GLOBALS['REQUEST_URI'], 1));
 
+# if we are on an artifact index page and we have only one argument which is
+# a numeric number, we suppose it is an item_id
+# Maybe it was a link shortcut like
+# blabla.org/task/?nnnn (blabla.org/task/?#nnnn cannot work because # is 
+# ignored by PHP as tag for html anchors)
+if ((ARTIFACT == "bugs" ||
+     ARTIFACT == "task" ||
+     ARTIFACT == "support" ||
+     ARTIFACT == "patch" ||
+     ARTIFACT == "cookbook") &&
+    is_numeric($_SERVER["argv"][0]))
+{
+  sane_set("item_id", $_SERVER["argv"][0]);
+  sane_set("func", "detailitem");
+}
+
+
 # if we got an item_id and no group_id we need to get the appropriate
 # group_id
 if (!isset($group_id) && !isset($group_name) && isset($item_id))
 {
   $result = db_query("SELECT group_id FROM ".ARTIFACT." WHERE bug_id='$item_id'");
   if (db_numrows($result))
-    {  $group_id = db_result(($result),0,'group_id'); }
+    {  
+      sane_set("group_id", db_result($result,0,'group_id')); }
   else
     {
       exit_error(_("Item not found"));
@@ -270,7 +319,7 @@ if (!isset($group_id) && !isset($group_name) && isset($item_id))
       $group_id == $sys_group_id &&
       sane_get("comingfrom"))
     {
-      $group_id = sane_get("comingfrom");
+      sane_set("group_id", sane_get("comingfrom"));
     }
 
 }
@@ -282,7 +331,7 @@ if (!isset($group_id) && !isset($group_name) && isset($forum_id))
 {
   $result = db_query("SELECT group_id FROM forum_group_list WHERE group_forum_id='$forum_id'");
   if ($result)
-    {  $group_id = db_result(($result),0,'group_id'); }
+    {  sane_set("group_id", db_result(($result),0,'group_id')); }
 }
 
 # if we got a msg_id and no group_id, we need to get the appropriate
@@ -292,7 +341,7 @@ if (!isset($group_id) && !isset($group_name) && isset($msg_id))
 {
   $result = db_query("SELECT forum_group_list.group_id,forum_group_list.forum_name,forum.group_forum_id,forum.thread_id FROM forum_group_list,forum WHERE forum_group_list.group_forum_id=forum.group_forum_id AND forum.msg_id='$msg_id'");
   if ($result)
-    {  $group_id = db_result(($result),0,'group_id'); }
+    {  sane_set("group_id", db_result(($result),0,'group_id')); }
 }
 
 
@@ -302,13 +351,13 @@ unset($res_grp);
 if (isset($group) && !isset($group_id))
 {
   $res_grp = db_query("SELECT group_id,status FROM groups WHERE unix_group_name='$group'");
-  $group_id = db_result($res_grp,0,'group_id');
-  $group_name = $group;
+  sane_set("group_id", db_result($res_grp,0,'group_id'));
+  sane_set("group_name", $group);
 }
 elseif (isset($group_id))
 {
   $res_grp = db_query("SELECT unix_group_name,status FROM groups WHERE group_id='$group_id'");
-  $group_name = db_result($res_grp,0,'unix_group_name');
+  sane_set("group_name", db_result($res_grp,0,'unix_group_name'));
 }
 
 # If group_id is defined, we are on a project page, we have several checks
