@@ -2,14 +2,14 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: admin.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: admin.php 5562 2006-08-14 08:43:48Z toddy $
 #
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--at--gnu.org>
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2006      (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,39 +27,6 @@
 
 
 
-function project_admin_header($params)
-{
-  global $DOCUMENT_ROOT,$group_id,$feedback,$group_name;
-
-  $params['toptab']='home';
-  $params['group']=$group_id;
-  site_project_header($params);
-
-  #	print 'BUG : Use of deprecated (5/5/2003) project_admin_header function !';
-
-  echo '
-	<P><B>
-	<A HREF="'.$GLOBALS['sys_home'].'project/admin/?group='.$group_name.'">Admin</A> |
-	<A HREF="'.$GLOBALS['sys_home'].'project/admin/userperms.php?group='.$group_name.'">User Permissions</A> |
-	<A HREF="'.$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$group_name.'">Edit Public Info</A> |
-	<A HREF="'.$GLOBALS['sys_home'].'project/admin/history.php?group='.$group_name.'">Project History</A>
-	<BR>';
-  #	<A HREF="/project/admin/editpackages.php?group_id='.$group_id.'">Edit/Release Files</A> |
-  echo '<A HREF="'.$GLOBALS['sys_home'].'people/createjob.php?group='.$group_name.'">Post Jobs</A> |
-	<A HREF="'.$GLOBALS['sys_home'].'people/?group='.$group_name.'">Edit Jobs</A> ';
-  #	<A HREF="/project/admin/editimages.php?group_id='.$group_id.'">Edit Screenshots</A>
-  echo '
-	</B>
-	<P>';
-}
-
-
-function project_admin_footer($params)
-{
-  site_project_footer($params);
-}
-
-
 # Nicely html-formatted output of this group's audit trail
 
 function show_grouphistory ($group_id)
@@ -118,20 +85,20 @@ function project_admin_registration_info ($row_grp)
 			. "user_group.admin_flags = 'A'");
 
 
-  print '<p><font class="preinput">'._("Project Admins").':</font><br /> ';
+  print '<p><span class="preinput">'._("Project Admins").':</span><br /> ';
   while ($row_admin = db_fetch_array($res_admin)) {
     print "<a href=\"".$GLOBALS['sys_home']."users/$row_admin[user_name]/\">$row_admin[realname] &lt;$row_admin[email]&gt;</a> ; ";
   }
 
-  print '<p><font class="preinput">'._("Registration Date").':</font><br /> '.format_date($sys_datefmt,$row_grp[register_time]);
+  print '<p><span class="preinput">'._("Registration Date").':</span><br /> '.format_date($sys_datefmt,$row_grp[register_time]);
 
-  print '<p><font class="preinput">'._("System Group Name:").'</font><br /> '.$row_grp[unix_group_name];
+  print '<p><span class="preinput">'._("System Group Name:").'</span><br /> '.$row_grp[unix_group_name];
 
-  print '<p><font class="preinput">'._("Submitted Description:").'</font><br /> '.utils_make_links($row_grp[register_purpose]);
+  print '<p><span class="preinput">'._("Submitted Description:").'</span><br /> '.utils_make_links($row_grp[register_purpose]);
 
-  print '<p><font class="preinput">'._("Required software:").'</font><br /> '.utils_make_links($row_grp[required_software]);
+  print '<p><span class="preinput">'._("Required software:").'</span><br /> '.utils_make_links($row_grp[required_software]);
 
-  print '<p><font class="preinput">'._("Other comments:").'</font><br /> '.utils_make_links($row_grp[other_comments]);
+  print '<p><span class="preinput">'._("Other comments:").'</span><br /> '.utils_make_links($row_grp[other_comments]);
 
   print '<p>';
   print utils_registration_history($row_grp[unix_group_name]);
