@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php 5287 2006-02-03 12:37:26Z ype $
+# $Id: project_home.php 5970 2006-09-26 08:34:01Z yeupou $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # Copyright 2000-2003 (c) Free Software Foundation
 #
-# Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+# Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                         Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@ if (strcasecmp($HTTP_HOST, $project->getTypeBaseHost()) != 0 && $project->getTyp
   exit;
 }
 
-$group_name = $project->getUnixName();
+sane_set("group_name", $project->getUnixName());
 
 site_project_header(array());
 
@@ -55,7 +55,7 @@ print '
 ';
 
 print $HTML->box_top(_("Membership Info"));
-print '<font class="smaller">';
+print '<span class="smaller">';
 $adminsnum = db_numrows($res_admin);
 $j = 0;
 if ($adminsnum > 0)
@@ -63,37 +63,37 @@ if ($adminsnum > 0)
     print ngettext("Project Admin:", "Project Admins:", $adminsnum);
     while ($row_admin = db_fetch_array($res_admin))
       {
-        print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
+        print '</span></div><div class="'.utils_get_alt_row_color($j++).'"><span class="smaller">';
         print "&nbsp; - ".utils_link($GLOBALS['sys_home']."users/".$row_admin[user_name], $row_admin[realname]);
       }
   }
 
 #count of developers on this project
 $membersnum = db_fetch_array(db_query("SELECT COUNT(*) AS count FROM user_group WHERE group_id=$group_id AND admin_flags<>'P'"));
-print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
-printf(ngettext("%s member", "%s members", $membersnum[count]),'<font class="bold">'.$membersnum[count].'</font>');
+print '</span></div><div class="'.utils_get_alt_row_color($j++).'"><span class="smaller">';
+printf(ngettext("%s member", "%s members", $membersnum[count]),'<strong>'.$membersnum[count].'</strong>');
 
 # if member = 1, it's obviously (or it should be) the project admin
 # if there's no admin, we need to get access to the list
 # But we show it anyway: this page can be used for request for membership,
 # provide more info that the little infobox.
-print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
-print '['.utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name, _("View Members")).']</font>'; # [ and ] are cosmetics, not supposed to be affected by any translation
+print '</span></div><div class="'.utils_get_alt_row_color($j++).'"><span class="smaller">';
+print '['.utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name, _("View Members")).']</span>'; # [ and ] are cosmetics, not supposed to be affected by any translation
 
 print $HTML->box_bottom();
 print '<br />
 ';
 print $HTML->box_top(_("Group identification"));
-print '<font class="smaller">';
-print _("Id:").' <b>#'.$group_id.'</b>';
+print '<span class="smaller">';
+print _("Id:").' <strong>#'.$group_id.'</strong>';
 $j = 0;
-print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
-print _("System Name:").' <b>'.$group_name.'</b>';
-print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
-print _("Name:").' <b>'.$project->GetName().'</b>';
-print '</font></div><div class="'.utils_get_alt_row_color($j++).'"><font class="smaller">';
-print _("Group Type:").' <b>'.$project->getTypeName().'</b>';
-print '</font>';
+print '</span></div><div class="'.utils_get_alt_row_color($j++).'"><span class="smaller">';
+print _("System Name:").' <strong>'.$group_name.'</strong>';
+print '</span></div><div class="'.utils_get_alt_row_color($j++).'"><span class="smaller">';
+print _("Name:").' <strong>'.$project->GetName().'</strong>';
+print '</span></div><div class="'.utils_get_alt_row_color($j++).'"><span class="smaller">';
+print _("Group Type:").' <strong>'.$project->getTypeName().'</strong>';
+print '</span>';
 print $HTML->box_bottom();
 print '<br />
 ';
@@ -101,9 +101,9 @@ print '<br />
 
 # As all projects use the cookbook, this is accurate is all cases
 print $HTML->box_top(_("Search in this Group"));
-print '<font class="smaller">';
+print '<span class="smaller">';
 print search_box('','');
-print '</font>';
+print '</span>';
 print $HTML->box_bottom();
 
 print '
@@ -118,40 +118,44 @@ if ($project->getTypeDescription())
 { print '<p>'.$project->getTypeDescription()."</p>\n"; }
 
 if ($project->getLongDescription())
-{
-  print "<p>" . utils_make_links(nl2br($project->getLongDescription()), $group_id)."</p>\n";
-} else
-{
-  if ($project->getDescription())
-{
-    print "<p>" . $project->getDescription()."</p>\n";
+  {
+    print "<p>" . utils_make_links(nl2br($project->getLongDescription()), $group_id)."</p>\n";
   }
 else
-{
-    print '<p>';
-    printf(_("This project has not yet submitted a short description. You can %ssubmit it%s now."), '<a href="'.$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$group_name.'">', '</a>');
-    print "</p>\n";
+  {
+    if ($project->getDescription())
+      {
+        print "<p>" . $project->getDescription()."</p>\n";
+      }
+    else
+      {
+        print '<p>';
+        printf(_("This project has not yet submitted a short description. You can %ssubmit it%s now."), '<a href="'.$GLOBALS['sys_home'].'project/admin/editgroupinfo.php?group='.$group_name.'">', '</a>');
+        print "</p>\n";
+      }
   }
-}
-print '<p>';
+
+print '<p>'._("Registration Date")._(": ").' '.format_date($sys_datefmt,$project->getStartDate())."\n";
+
 if ($project->CanUse("license"))
 {
   $license = $project->getLicense();
-  print _("License").' : ';
+  print '<br />'._("License:").' ';
   if ($LICENSE_URL[$license] != "0") {
     print utils_link($LICENSE_URL[$license], $LICENSE[$license]);
   } else {
     print $LICENSE[$license];
     if ($license == "other") {
-      print '<br>'.$project->getLicense_other().'<br>';
+      print $project->getLicense_other();
     }
   }
 }
-print '<br />'._("Registration Date").' : '.format_date($sys_datefmt,$project->getStartDate())."\n";
+
+
 if ($project->CanUse("devel_status"))
 {
   $devel_status = $project->getDevelStatus();
-  print '<br />'._("Development Status").' : '.$DEVEL_STATUS[$devel_status]."\n";
+  print '<br />'._("Development Status")._(": ").' '.$DEVEL_STATUS[$devel_status]."\n";
 }
 print '</p>
 </div><!-- end indexcenter -->
@@ -190,7 +194,7 @@ if ($GLOBALS[sys_group_id] == $group_id)
     {
       require $GLOBALS['sys_www_topdir']."/include/features_boxes.php";
       print $HTML->box_top(sprintf(_("Administration: %s server"), $GLOBALS['sys_name']));
-      print sprintf(_("Since you are administrator of this project, which one is the \"system project\", you are administrator of the whole %s server."), $GLOBALS['sys_name']);
+      print '<div class="justify">'.sprintf(_("Since you are administrator of this project, which one is the \"system project\", you are administrator of the whole %s server."), $GLOBALS['sys_name']).'</div>';
 
       print $HTML->box_nextitem(utils_get_alt_row_color($i));
 
@@ -203,7 +207,7 @@ if ($GLOBALS[sys_group_id] == $group_id)
 		       html_image("admin.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Server Admin"))).'&nbsp;'._("Pending Projects List"));
       $registration_count = number_format(stats_getprojects_pending());
       print " (";
-      printf(ngettext("%s registration pending", "%s registrations pending", $registration_count), "<b>$registration_count</b>");
+      printf(ngettext("%s registration pending", "%s registrations pending", $registration_count), "<strong>$registration_count</strong>");
       print ")";
       print $HTML->box_bottom();
       print '<br />';
@@ -213,7 +217,7 @@ if ($GLOBALS[sys_group_id] == $group_id)
 if (member_check(0, $group_id, 'A'))
 {
   print $HTML->box_top(sprintf(_("Administration: %s project"), $project->getName()));
-  print _("As administrator of this project, you can manage members and activate/deactivate/configure your project's tools.");
+  print '<div class="justify">'._("As administrator of this project, you can manage members and activate, deactivate and configure your project's tools.").'</div>';
 
   print $HTML->box_nextitem(utils_get_alt_row_color($i));
 
@@ -240,54 +244,62 @@ function specific_makesep ()
     }
 }
 
-print $HTML->box_top(_("Public Areas: Quick Overview"));
+print $HTML->box_top(_("Quick Overview"));
 $i = 1;
 $j = $i;
 
 # Homepage Link
-if ($project->Uses("homepage"))
+if ($project->Uses("homepage")
+    && $project->getUrl("homepage") != 'http://'
+    && $project->getUrl("homepage") != '')
 {
   print utils_link($project->getUrl("homepage"),
 		   html_image("www.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Homepage"))).'&nbsp;'._("Project Homepage"));
   $i++;
 }
 
+# Download area
+if($project->Uses("download")) 
+{
+  specific_makesep();
+
+  # the pointer is always the filelist, this page will handle redirect
+  # appropriately in case that no download area is here
+  print utils_link($project->getArtifactUrl("files"),
+		   html_image("download.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Filelist')).'&nbsp;'._("Download Area"));
+  $i++;
+}
+
 # Cookbook Documentation (internal)
 # Projects dont have the choice to use it, as there maybe site recipe that
 # applies to features they use.
 # FIXME: this should print the number of recipes available
 specific_makesep();
-print utils_link($project->getArtifactUrl("cookbook"),
-		 html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Cookbook"))).'&nbsp;'._("Cookbook"));
-$i++;
-
-# Documentation (extra link)
-if ($project->Uses("extralink_documentation"))
+if (!$project->Uses("extralink_documentation"))
 {
-  specific_makesep();
-
-  print utils_link($project->getUrl("extralink_documentation"),
-		   html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Other Documentation"))).'&nbsp;'._("Other Documentation"));
+  print utils_link($project->getArtifactUrl("cookbook"),
+		   html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Docs"))).'&nbsp;'._("Docs"));
   $i++;
 }
+else
+{
+  # The project have an external doc? Print it first. See pagemenu.php
+  # for explanations about this
+  print html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Docs"))).'&nbsp;'._("Docs");
 
-# Download area
-if($project->Uses("download")) {
-  specific_makesep();
-
-  # the pointer is always the filelist, this page will handle redirect
-  # appropriately in case that no download area is here
-  print utils_link($project->getArtifactUrl("files"),
-		   html_image("download.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Filelist')).'&nbsp;'._("Filelist (Download area)"));
+  print '<br /> &nbsp; - '.utils_link($project->getUrl("extralink_documentation"), _("Browse docs (External to Savane)"));
+  print '<br /> &nbsp; - '.utils_link($project->getArtifactUrl("cookbook"), _("Browse the cookbook"));
   $i++;
+
 }
 
+
 # Memberlist
 specific_makesep();
 print utils_link($GLOBALS['sys_home'].'project/memberlist.php?group='.$group_name,
 	 html_image("people.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Memberlist')).'&nbsp;'._("Project Memberlist"));
 print " (";
-printf(ngettext("%s member", "%s members", $membersnum[count]), "<b>$membersnum[count]</b>");
+printf(ngettext("%s member", "%s members", $membersnum[count]), "<strong>$membersnum[count]</strong>");
 print ")";
 $i++;
 
@@ -314,7 +326,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
     people_project_jobs_rows($group_id) != 0)
 {
 
-  print $HTML->box_top(_("Public Areas: Communication Tools"));
+  print $HTML->box_top(_("Communication Tools"));
   $i = 1;
   $j = $i;
 
@@ -335,15 +347,15 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 
 
         print " (";
-        printf(ngettext("%s open request", "%s open requests", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s open item", "%s open items", $row_count[count]), "<strong>$row_count[count]</strong>");
 	$res_count = db_query("SELECT count(*) AS count FROM support WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
 	print ', ';
-        printf(ngettext("%s total", "%s total", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s total", "%s total", $row_count[count]), "<strong>$row_count[count]</strong>");
         print ")\n";
 
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Request"), 0, group_restrictions_check($group_id, "support"));
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Requests"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse open items"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a new item"), 0, group_restrictions_check($group_id, "support"));
       }
 
     $i++;
@@ -369,14 +381,14 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
 			      . "AND forum_group_list.is_public=1");
 	$row_count = db_fetch_array($res_count);
 	print " (";
-        printf(ngettext("%s message in", "%s messages in", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s message in", "%s messages in", $row_count[count]), "<strong>$row_count[count]</strong>");
 
 	$res_count = db_query("SELECT count(*) AS count FROM forum_group_list WHERE group_id=$group_id "
 			      . "AND is_public=1");
 	$row_count = db_fetch_array($res_count);
 
         print " ";
-	printf(ngettext("%s forum", "%s forums", $row_count[count]), "<b>$row_count[count]</b>");
+	printf(ngettext("%s forum", "%s forums", $row_count[count]), "<strong>$row_count[count]</strong>");
         print ")\n";
       }
     $i++;
@@ -395,7 +407,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
       $res_count = db_query("SELECT count(*) AS count FROM mail_group_list WHERE group_id=$group_id AND is_public=1");
       $row_count = db_fetch_array($res_count);
       print " (";
-      printf(ngettext("%s public mailing-list", "%s public mailing-lists", $row_count[count]), "<b>$row_count[count]</b>");
+      printf(ngettext("%s public mailing-list", "%s public mailing-lists", $row_count[count]), "<strong>$row_count[count]</strong>");
       print ")";
 
       $i++;
@@ -411,7 +423,7 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
     $job_count = people_project_jobs_rows($group_id);
 
     print " (";
-    printf(ngettext("%s contributor wanted", "%s contributors wanted", $job_count), "<b>$job_count</b>");
+    printf(ngettext("%s contributor wanted", "%s contributors wanted", $job_count), "<strong>$job_count</strong>");
     print ")";
     $i++;
   }
@@ -429,7 +441,7 @@ if ($project->Uses("patch") ||
     $project->Uses("task") ||
     $project->Uses("patch"))
 {
-  print $HTML->box_top(_("Public Areas: Development Tools"));
+  print $HTML->box_top(_("Development Tools"));
   $i = 1;
   $j = $i;
 
@@ -437,18 +449,19 @@ if ($project->Uses("patch") ||
   #  - check if the SCM is selected by the project
   #  - check if the SCM is the default SCM, if the project use the standard
   #    webpage
-  if ($project->Uses("cvs") || $project->UsesForHomepage("cvs"))
+  # SVN goes first, CVS the outdated one goes last
+  if ($project->Uses("svn") || $project->UsesForHomepage("svn"))
     {
+      $url = $project->getArtifactUrl("svn");
 
-      $url = $project->getArtifactUrl("cvs");
+      html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Arch'));
+      print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: Subversion Repository").'</a>';
 
-      html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'CVS'));
-      print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: CVS Repository").'</a>';
-      if ($project->Uses("cvs") && $project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '')
+      if ($project->Uses("svn") && $project->getUrl("svn_viewcvs") != 'http://' && $project->getUrl("svn_viewcvs") != '')
 	{
-	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs").'">'._("Browse Sources Repository").'</a>';
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("svn_viewcvs").'">'._("Browse Sources Repository").'</a>';
 	}
-      if ($project->UsesForHomepage("cvs") && $project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '')
+      if ($project->UsesForHomepage("svn") && $project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '')
 	{
 	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
 	}
@@ -474,19 +487,19 @@ if ($project->Uses("patch") ||
       $i++;
     }
 
-  if ($project->Uses("svn") || $project->UsesForHomepage("svn"))
+  if ($project->Uses("cvs") || $project->UsesForHomepage("cvs"))
     {
+
       specific_makesep();
-      $url = $project->getArtifactUrl("svn");
+      $url = $project->getArtifactUrl("cvs");
 
-      html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'Arch'));
-      print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: Subversion Repository").'</a>';
-
-      if ($project->Uses("svn") && $project->getUrl("svn_viewcvs") != 'http://' && $project->getUrl("svn_viewcvs") != '')
+      html_image("cvs.png",array('width'=>'24', 'height'=>'24', 'alt'=>'CVS'));
+      print '&nbsp;<a href="'.$url.'">'._("Source Code Manager: CVS Repository").'</a>';
+      if ($project->Uses("cvs") && $project->getUrl("cvs_viewcvs") != 'http://' && $project->getUrl("cvs_viewcvs") != '')
 	{
-	  print '<br /> &nbsp; - <a href="'.$project->getUrl("svn_viewcvs").'">'._("Browse Sources Repository").'</a>';
+	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs").'">'._("Browse Sources Repository").'</a>';
 	}
-      if ($project->UsesForHomepage("svn") && $project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '')
+      if ($project->UsesForHomepage("cvs") && $project->getUrl("cvs_viewcvs_homepage") != 'http://' && $project->getUrl("cvs_viewcvs_homepage") != '')
 	{
 	  print '<br /> &nbsp; - <a href="'.$project->getUrl("cvs_viewcvs_homepage").'">'._("Browse Web Pages Repository").'</a>';
 	}
@@ -511,15 +524,15 @@ if ($project->Uses("patch") ||
 	$row_count = db_fetch_array($res_count);
 
         print " (";
-        printf(ngettext("%s open bug", "%s open bugs", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s open item", "%s open items", $row_count[count]), "<strong>$row_count[count]</strong>");
 	$res_count = db_query("SELECT count(*) AS count FROM bugs WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
 	print ', ';
-        printf(ngettext("%s total", "%s total", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s total", "%s total", $row_count[count]), "<strong>$row_count[count]</strong>");
         print ")\n";
 
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Bug"), 0, group_restrictions_check($group_id, "bugs"));
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Bugs"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse open items"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a new item"), 0, group_restrictions_check($group_id, "bugs"));
       }
     $i++;
   }
@@ -541,15 +554,15 @@ if ($project->Uses("patch") ||
 	$row_count = db_fetch_array($res_count);
 
 	print " (";
-        printf(ngettext("%s open task", "%s open tasks", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s open item", "%s open items", $row_count[count]), "<strong>$row_count[count]</strong>");
 	$res_count = db_query("SELECT count(*) AS count FROM task WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
 	print ', ';
-        printf(ngettext("%s total", "%s total", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s total", "%s total", $row_count[count]), "<strong>$row_count[count]</strong>");
         print ")\n";
 
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Task"), 0, group_restrictions_check($group_id, "task"));
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Tasks"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse open items"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a new item"), 0, group_restrictions_check($group_id, "task"));
       }
     $i++;
   }
@@ -571,15 +584,15 @@ if ($project->Uses("patch") ||
 	$row_count = db_fetch_array($res_count);
 
         print " (";
-        printf(ngettext("%s open patch", "%s open patches", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s open item", "%s open items", $row_count[count]), "<strong>$row_count[count]</strong>");
 	$res_count = db_query("SELECT count(*) AS count FROM patch WHERE group_id=$group_id");
 	$row_count = db_fetch_array($res_count);
 	print ', ';
-        printf(ngettext("%s total", "%s total", $row_count[count]), "<b>$row_count[count]</b>");
+        printf(ngettext("%s total", "%s total", $row_count[count]), "<strong>$row_count[count]</strong>");
         print ")\n";
 
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a Patch"), 0, group_restrictions_check($group_id, "patch"));
-	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse Open Patches"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=browse&amp;set=open', _("Browse open items"));
+	print '<br /> &nbsp; - '.utils_link($url.'&amp;func=additem', _("Submit a new item"), 0, group_restrictions_check($group_id, "patch"));
       }
     $i++;
   }
