@@ -47,7 +47,8 @@ unset($feedback_html);
 
 unset($user_id, 
       $group_id, 
-      $group, 
+      $group,
+      $group_name,
       $item_id, 
       $forum_id, 
       $msg_id,
@@ -56,6 +57,7 @@ unset($user_id,
 $user_id = sane_all("user_id");
 $group_id = sane_all("group_id");
 $group = sane_all("group");
+$group_name = $group;
 $item_id = sane_all("item_id");
 $forum_id = sane_all("forum_id");
 $msg_id = sane_all("msg_id");
@@ -67,8 +69,7 @@ $export_id = sane_all("msg_id");
 if ($item_id && !ctype_digit($item_id))
 {
   preg_match("/(\d+)/", $item_id, $match);
-  $item_id = $match[0];
-  $_REQUEST["item_id"] = $match[0];
+  sane_set("item_id", $match[0]);
 }
 
 # Keep only numerical characters in the export_id
@@ -77,8 +78,7 @@ if ($item_id && !ctype_digit($item_id))
 if ($export_id && !ctype_digit($export_id))
 {
   preg_match("/(\d+)/", $export_id, $match);
-  $export_id = $match[0];
-  $_REQUEST["export_id"] = $match[0];
+  sane_set("export_id", $match[0]);
 }
 
 
@@ -88,8 +88,7 @@ if ($export_id && !ctype_digit($export_id))
 if ($group_id && !ctype_digit($group_id))
 {
   preg_match("/(\d+)/", $group_id, $match);
-  $group_id = $match[0];
-  $_REQUEST["group_id"] = $match[0];
+  sane_set("group_id", $match[0]);
 }
 
 # Keep only numerical characters in the user_id
@@ -98,8 +97,7 @@ if ($group_id && !ctype_digit($group_id))
 if ($user_id && !ctype_digit($user_id) && !is_array($user_id))
 {
   preg_match("/(\d+)/", $user_id, $match);
-  $user_id = $match[0];
-  $_REQUEST["user_id"] = $match[0];
+  sane_set("user_id", $match[0]);
 }
 
 
@@ -134,6 +132,8 @@ function safeinput ($string)
 # This should be used only where user can legitimately send data by
 # different methods.
 # (this is why it is called sane_all, to avoid having it used everywhere)
+# This does not take uploads depending on PHP version, so use sane_upload()
+# instead, if necessary.
 function sane_all($varname)
 {
   return safeinput($_REQUEST[$varname]);
@@ -158,6 +158,34 @@ function sane_cookie($varname)
   return safeinput($_COOKIE[$varname]);
 }
 
+# Does an isset. Not really necessary, just for cohesion sake
+function sane_isset($varname)
+{
+  return isset($_REQUEST[$varname]);
+}
+
+
+# Function to obtain user input submitted in a cookie
+function sane_upload($varname, $subvarname=false) 
+{
+  if (!$subvarname)
+    { return safeinput($_FILES[$varname]); }
+
+  return  safeinput($_FILES[$varname][$subvarname]);
+}
+
+# Function to set a variable in both $_REQUEST and global.
+# The global may be deleted by a call to register_globals_off(),
+# so the $_REQUEST will remain and should be safe
+# (this function should be used only to set safe values! Normally
+# it should be used only in include/ like pre.php)
+function sane_set($varname, $value)
+{
+  $GLOBALS[$varname] = $value;
+  $_REQUEST[$varname] = $value;
+}
+
+
 # Function to unregister globals on a page: this will be helpful to
 # make pages compliant with register globals set to off one by one.
 function register_globals_off ()
