@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: session.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: session.php 5697 2006-09-08 15:48:06Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -37,7 +37,7 @@ function session_login_valid($form_loginname,
 {
 
   # Password is crypted if we are coming from the brother site.
-  # Normally, users should use this feature
+  # Normally, users should not use this feature
   # if they never login at brother site.
   # FIXME: feel free to mess with PHP3 and crypt...
   global $session_hash;
@@ -58,6 +58,36 @@ function session_login_valid($form_loginname,
 
   $usr = db_fetch_array($resq);
 
+  # Check status first:
+  # if allowpending (for verify.php) then allow
+  if ($allowpending && ($usr['status'] == 'P')) 
+    {
+      #1;
+    } 
+  else 
+    {
+      if ($usr['status'] == 'P') 
+	{ 
+	  #account pending
+	  fb(_('Account Pending'), 1);
+	  return false;
+	} 
+      if ($usr['status'] == 'D' || $usr['status'] == 'S')
+	{ 
+	  #account deleted
+	  fb(_('Account Deleted'), 1);
+	  return false;
+	}
+      if ($usr['status'] != 'A') 
+	{
+	  #unacceptable account flag
+	  fb(_('Account Not Active'),1);
+	  return false;
+	}
+    }
+
+
+
   # TODO: Brother site login mechanism should be implemented later for
   #       all authentication methods:
   #
@@ -146,40 +176,7 @@ function session_login_valid($form_loginname,
 
     }
 
-
-  
-  # if allowpending (for verify.php) then allow
-  if ($allowpending && ($usr['status'] == 'P')) 
-    {
-      #1;
-    } 
-  else 
-    {
-      if ($usr['status'] == 'S') 
-	{ 
-	  #acount suspended
-	  fb(_('Account Suspended'), 1);
-	  return false;
-	}
-      if ($usr['status'] == 'P') 
-	{ 
-	  #account pending
-	  fb(_('Account Pending'), 1);
-	  return false;
-	} 
-      if ($usr['status'] == 'D') 
-	{ 
-	  #account deleted
-	  fb(_('Account Deleted'), 1);
-	  return false;
-	}
-      if ($usr['status'] != 'A') 
-	{
-	  #unacceptable account flag
-	  fb(_('Account Not Active'),1);
-	  return false;
-	}
-    }
+ 
   #create a new session
   session_set_new($usr['user_id'], $cookie_for_a_year, $stay_in_ssl);
 
@@ -213,29 +210,23 @@ function session_needsstayinssl()
   return db_result(db_query("SELECT stay_in_ssl FROM session WHERE session_hash='$GLOBALS[session_hash]'"), 0, 'stay_in_ssl');
 }
 
-function session_cookie($n,$v,$cookie_for_a_year=0) 
+# Define a cookie, just for session or for a year, https-only or not
+function session_cookie($name, $value, $cookie_for_a_year=0, $secure=0)
 {
-  
-  # yeupou--gnu.org 2004-09-21: this will pose problem on different servers
-  # with the same domain; on the other hand, it's helpful for servers that
-  # want multiple domains to be working.
-  # In the meantime, shut it off.
-  #
-  # Define the domain name, only the last part of it like .domain.org
-  # in order to permit any host of .domain.org to access it.
-  #preg_match("/[^\.\/]+\.[^\.\/]+$/", $GLOBALS['sys_default_domain'], $domain);
-  #$domain = ".".$domain[0];
-  $domain = $GLOBALS['sys_default_domain'];
+  $expiration = 0; # at the end of session
+  if ($cookie_for_a_year == 1)
+    $expiration = time() + 60*60*24*365; # for a year
 
-  if ($cookie_for_a_year=="1") 
-    {
-      # Set the cookie for a year.
-      setcookie($n,$v, time() + 60*60*24*365 ,$GLOBALS['sys_home'],$domain,0);
-    } 
-  else 
-    {
-      setcookie($n,$v,0,$GLOBALS['sys_home'],$domain,0);
-    }
+  $path = $GLOBALS['sys_home'];
+
+  # If we're using a real domain name, enable subdomain matching.
+  # $domain needs an embedded dot otherwise the cookie won't be
+  # accepted (eg 'localhost', cf. bug #6694 and rfc2109)
+  $domain = '.' . $GLOBALS['sys_default_domain'];
+  if (!eregi('[a-z0-9-]\.[a-z0-9-]', $domain))
+      $domain = '';
+
+  setcookie($name, $value, $expiration, $path, $domain, $secure);
 }
 
 # Removes a cookie. This is an alternative to setting it to an empty
@@ -243,7 +234,13 @@ function session_cookie($n,$v,$cookie_for_a_year=0)
 # it again.
 function session_delete_cookie($n)
 {
-  setcookie($n, '', 0, $GLOBALS['sys_home'], $GLOBALS['sys_default_domain'], 0);
+  $expiration = time() - 3600; # in the past
+  $path = $GLOBALS['sys_home'];
+  # specify domain? - cf. session_cookie ^^^
+  $domain = '.' . $GLOBALS['sys_default_domain'];
+  if (!eregi('[a-z0-9-]\.[a-z0-9-]', $domain))
+      $domain = '';
+  setcookie($n, '', $expiration, $path, $domain);
 }
 
 function session_redirect($loc) 
@@ -386,10 +383,6 @@ function session_set_new($user_id, $cookie_for_a_year=0, $stay_in_ssl=1)
   } 
   while (db_numrows(db_query("SELECT session_hash FROM session WHERE session_hash='$GLOBALS[session_hash]'")) > 0);
   
-  # set session cookies
-  session_cookie("session_hash",$GLOBALS['session_hash'],$cookie_for_a_year);
-  session_cookie("session_uid",$user_id,$cookie_for_a_year);
-  
   # make new session entries into db
   db_query("INSERT INTO session (session_hash, ip_addr, time, user_id, stay_in_ssl) VALUES ('".addslashes($GLOBALS[session_hash])."','".addslashes($GLOBALS[REMOTE_ADDR])."'," . time() . ",'$user_id','$stay_in_ssl')");
   
@@ -405,6 +398,30 @@ function session_set_new($user_id, $cookie_for_a_year=0, $stay_in_ssl=1)
       $G_SESSION = db_fetch_array($res);
       session_setglobals($G_SESSION['user_id']);
     }
+
+  # if the user specified he wants only one session to be opened at a time,
+  # kill the others sessions
+  if (user_get_preference("keep_only_one_session"))
+    {
+      db_query("DELETE FROM session WHERE session_hash<>'$GLOBALS[session_hash]' AND user_id='$user_id'");
+    }
+
+  session_set_new_cookies($user_id, $cookie_for_a_year, $stay_in_ssl);
+}
+
+function session_set_new_cookies($user_id, $cookie_for_a_year=0, $stay_in_ssl=1) 
+{
+  # set session cookies
+  # set a non-secure cookie so that Savane will automatically redirect to https
+  if ($stay_in_ssl)
+    {
+      # 0=non-https-only
+      session_cookie('redirect_to_https', 1, $cookie_for_a_year, 0);
+    }
+								       
+  session_cookie('session_uid', $user_id, $cookie_for_a_year, $stay_in_ssl);
+  session_cookie('session_hash', $GLOBALS['session_hash'], $cookie_for_a_year, $stay_in_ssl);
+  session_delete_cookie('cookie_probe');
 }
 
 function session_set() 
@@ -418,9 +435,11 @@ function session_set()
   $id_is_good = 0;
   
   # here also check for good hash, set if new session is needed
-  if ($_COOKIE['session_hash'] && $_COOKIE['session_uid']) 
+  $session_hash = sane_cookie("session_hash");
+  $session_uid = sane_cookie("session_uid");
+  if ($session_hash && $session_uid) 
     {
-      $result=db_query("SELECT * FROM session WHERE session_hash='".addslashes($_COOKIE[session_hash])."' AND user_id='".addslashes($_COOKIE[session_uid])."'");
+      $result=db_query("SELECT * FROM session WHERE session_hash='".$session_hash."' AND user_id='".$session_uid."'");
       $G_SESSION = db_fetch_array($result);
     
       # does hash exist?
@@ -448,7 +467,12 @@ function session_count ($uid)
 {
   return db_numrows(db_query("SELECT ip_addr FROM session WHERE "
 			     . "user_id = '".$uid."'"));
-  
+ 
+}
+
+function session_exists($uid, $hash) {
+  return (db_numrows(db_query("SELECT NULL FROM session WHERE "
+			     . "user_id = '".$uid."' and session_hash='".$hash."'")) == 1);
 }
 
 ?>
