@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: theme.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: theme.php 5878 2006-09-20 14:39:42Z yeupou $
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -29,7 +29,7 @@ function theme_rotate_jump($num)
 {
 
   utils_get_content("forbidden_theme");
-  $theme = theme_list(1);
+  $theme = theme_list();
  
   $num++;
 	
@@ -47,38 +47,41 @@ function theme_rotate_jump($num)
 
 # Return an array with all the themes, but not the special case "rotate" 
 # and "random"
-# By default, it does not skip forbidden themes (strict=0), in order to
-# avoid doing too many unrequired tests.
-function theme_list ($strict=0) 
+function theme_list ()
 {
-  if ($strict)
-    { utils_get_content("forbidden_theme"); }
+  utils_get_content("forbidden_theme");
 
   # Feed the array
   $theme = array();
   $dir = opendir($GLOBALS['sys_www_topdir']."/css/");
   while ($file = readdir($dir)) 
     {
+      # Ignore symlinks
+      if (is_link($GLOBALS['sys_www_topdir']."/css/$file"))
+	{ continue; }
+
       # take only correct css files
-      if (preg_match("/^(.*)\.css$/", $file, $matches)) 
-	{
-	  # base.css and printer.css are always ignored
-	  if ($matches[1] != "base" && $matches[1] != "printer") {
-	    if (!$strict)
-	      {
-		$theme[] = $matches[1];
-	      }
-	    elseif (!preg_match($GLOBALS['forbid_theme_regexp'], $matches[1]))
-	      {
-		$theme[] = $matches[1];
-	      }
-	  }
-	}
+      if (!preg_match("/^(.*)\.css$/", $file, $matches)) 
+	{ continue; }
+	  
+      # base.css and printer.css are always ignored
+      # (as of nov 2006, there are in the subdirectory internal, so this
+      # is only here for backward compat)
+      if ($matches[1] == "base" || 
+	  $matches[1] == "printer" ||
+	  $matches[1] == "msie-dirtyhacks") 
+	{ continue; }
+	  
+      # forbidden themes are also ignored
+      if (preg_match($GLOBALS['forbid_theme_regexp'], strtolower($matches[1])))
+	{ continue; }
+      
+      $theme[] = $matches[1];
     }
   closedir($dir);
   
-  # Sort themes
-  asort($theme);
+  # Sort themes - case insensitive
+  natcasesort($theme);
 
   # No result? Return only the default theme. 
   # (If there were no result, there is a problem anyway somewhere in the
@@ -114,7 +117,7 @@ if (isset($HTTP_COOKIE_VARS["SV_THEME"]))
 	} 
       else 
 	{
-	  $theme = theme_list(1);
+	  $theme = theme_list();
 	  mt_srand ((double)microtime()*1000000);
 	  $num = mt_rand(0,count($theme)-1);
 	  $random_theme = $theme[$num];
@@ -131,7 +134,7 @@ if (isset($HTTP_COOKIE_VARS["SV_THEME"]))
 	} 
       else 
 	{
-	  $theme = theme_list(1);
+	  $theme = theme_list();
 	  
 	  # we get a number and set a cookie with this number
 	  # if this number exist, +1 to his value
@@ -155,13 +158,24 @@ if (isset($HTTP_COOKIE_VARS["SV_THEME"]))
   else 
     {
       # the user picked a particular theme
-      define(SV_THEME, sane_cookie("SV_THEME"));       
+      $cookie_theme = sane_cookie("SV_THEME");
+
+      # look for invalid / outdated cookies
+      if (!file_exists($GLOBALS['sys_www_topdir']."/css/".$cookie_theme.".css"))
+	{
+	  define(SV_THEME, $GLOBALS['sys_themedefault']);
+	  setcookie("SV_THEME", SV_THEME, time() + 60*60*24*365, $GLOBALS['sys_url_topdir']);
+	}
+      else
+	{
+	  define(SV_THEME, $cookie_theme);
+	}
     }
 } 
 else 
 {
   # no theme was defined, we use the default one
-  define(SV_THEME, $sys_themedefault);
+  define(SV_THEME, $GLOBALS['sys_themedefault']);
 }
 
 # Check whether a theme follows latest GUIDELINES
