@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: timezones.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: timezones.php 5670 2006-09-06 14:53:01Z yeupou $
 #
-# Copyright 1999-2000 (c) The SourceForge Crew
+#  Copyright 2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,18 +20,12 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-$TZs[]='US/Alaska';
-$TZs[]='US/Aleutian';
-$TZs[]='US/Arizona';
-$TZs[]='US/Central';
-$TZs[]='US/Eastern';
-$TZs[]='US/East-Indiana';
-$TZs[]='US/Hawaii';
-$TZs[]='US/Indiana-Starke';
-$TZs[]='US/Michigan';
-$TZs[]='US/Mountain';
-$TZs[]='US/Pacific';
-$TZs[]='US/Samoa';
+# Valid timezones for PHP from php.net, except the ones of the category
+# others that seems to be duplicates for theses ones. We can expect people
+# to know in which country/city they are. Knowning if they are at GMT+3 or 
+# GMT+4 may be more picky, so since there are differents ways to tell the
+# timezone, we will take the easy one.
+
 $TZs[]='Africa/Abidjan';
 $TZs[]='Africa/Accra';
 $TZs[]='Africa/Addis_Ababa';
@@ -89,9 +83,21 @@ $TZs[]='America/Anchorage';
 $TZs[]='America/Anguilla';
 $TZs[]='America/Antigua';
 $TZs[]='America/Araguaina';
+$TZs[]='America/Argentina/Buenos_Aires';
+$TZs[]='America/Argentina/Catamarca';
+$TZs[]='America/Argentina/ComodRivadavia';
+$TZs[]='America/Argentina/Cordoba';
+$TZs[]='America/Argentina/Jujuy';
+$TZs[]='America/Argentina/La_Rioja';
+$TZs[]='America/Argentina/Mendoza';
+$TZs[]='America/Argentina/Rio_Gallegos';
+$TZs[]='America/Argentina/San_Juan';
+$TZs[]='America/Argentina/Tucuman';
+$TZs[]='America/Argentina/Ushuaia';
 $TZs[]='America/Aruba';
 $TZs[]='America/Asuncion';
 $TZs[]='America/Atka';
+$TZs[]='America/Bahia';
 $TZs[]='America/Barbados';
 $TZs[]='America/Belem';
 $TZs[]='America/Belize';
@@ -100,6 +106,7 @@ $TZs[]='America/Bogota';
 $TZs[]='America/Boise';
 $TZs[]='America/Buenos_Aires';
 $TZs[]='America/Cambridge_Bay';
+$TZs[]='America/Campo_Grande';
 $TZs[]='America/Cancun';
 $TZs[]='America/Caracas';
 $TZs[]='America/Catamarca';
@@ -107,20 +114,23 @@ $TZs[]='America/Cayenne';
 $TZs[]='America/Cayman';
 $TZs[]='America/Chicago';
 $TZs[]='America/Chihuahua';
+$TZs[]='America/Coral_Harbour';
 $TZs[]='America/Cordoba';
 $TZs[]='America/Costa_Rica';
 $TZs[]='America/Cuiaba';
 $TZs[]='America/Curacao';
+$TZs[]='America/Danmarkshavn';
 $TZs[]='America/Dawson';
 $TZs[]='America/Dawson_Creek';
 $TZs[]='America/Denver';
 $TZs[]='America/Detroit';
 $TZs[]='America/Dominica';
 $TZs[]='America/Edmonton';
+$TZs[]='America/Eirunepe';
 $TZs[]='America/El_Salvador';
 $TZs[]='America/Ensenada';
-$TZs[]='America/Fortaleza';
 $TZs[]='America/Fort_Wayne';
+$TZs[]='America/Fortaleza';
 $TZs[]='America/Glace_Bay';
 $TZs[]='America/Godthab';
 $TZs[]='America/Goose_Bay';
@@ -143,6 +153,8 @@ $TZs[]='America/Iqaluit';
 $TZs[]='America/Jamaica';
 $TZs[]='America/Jujuy';
 $TZs[]='America/Juneau';
+$TZs[]='America/Kentucky/Louisville';
+$TZs[]='America/Kentucky/Monticello';
 $TZs[]='America/Knox_IN';
 $TZs[]='America/La_Paz';
 $TZs[]='America/Lima';
@@ -155,8 +167,10 @@ $TZs[]='America/Martinique';
 $TZs[]='America/Mazatlan';
 $TZs[]='America/Mendoza';
 $TZs[]='America/Menominee';
+$TZs[]='America/Merida';
 $TZs[]='America/Mexico_City';
 $TZs[]='America/Miquelon';
+$TZs[]='America/Monterrey';
 $TZs[]='America/Montevideo';
 $TZs[]='America/Montreal';
 $TZs[]='America/Montserrat';
@@ -165,18 +179,21 @@ $TZs[]='America/New_York';
 $TZs[]='America/Nipigon';
 $TZs[]='America/Nome';
 $TZs[]='America/Noronha';
+$TZs[]='America/North_Dakota/Center';
 $TZs[]='America/Panama';
 $TZs[]='America/Pangnirtung';
 $TZs[]='America/Paramaribo';
 $TZs[]='America/Phoenix';
 $TZs[]='America/Port-au-Prince';
-$TZs[]='America/Porto_Acre';
 $TZs[]='America/Port_of_Spain';
+$TZs[]='America/Porto_Acre';
 $TZs[]='America/Porto_Velho';
 $TZs[]='America/Puerto_Rico';
 $TZs[]='America/Rainy_River';
 $TZs[]='America/Rankin_Inlet';
+$TZs[]='America/Recife';
 $TZs[]='America/Regina';
+$TZs[]='America/Rio_Branco';
 $TZs[]='America/Rosario';
 $TZs[]='America/Santiago';
 $TZs[]='America/Santo_Domingo';
@@ -193,6 +210,7 @@ $TZs[]='America/Tegucigalpa';
 $TZs[]='America/Thule';
 $TZs[]='America/Thunder_Bay';
 $TZs[]='America/Tijuana';
+$TZs[]='America/Toronto';
 $TZs[]='America/Tortola';
 $TZs[]='America/Vancouver';
 $TZs[]='America/Virgin';
@@ -206,8 +224,10 @@ $TZs[]='Antarctica/DumontDUrville';
 $TZs[]='Antarctica/Mawson';
 $TZs[]='Antarctica/McMurdo';
 $TZs[]='Antarctica/Palmer';
+$TZs[]='Antarctica/Rothera';
 $TZs[]='Antarctica/South_Pole';
 $TZs[]='Antarctica/Syowa';
+$TZs[]='Antarctica/Vostok';
 $TZs[]='Arctic/Longyearbyen';
 $TZs[]='Asia/Aden';
 $TZs[]='Asia/Almaty';
@@ -215,6 +235,7 @@ $TZs[]='Asia/Amman';
 $TZs[]='Asia/Anadyr';
 $TZs[]='Asia/Aqtau';
 $TZs[]='Asia/Aqtobe';
+$TZs[]='Asia/Ashgabat';
 $TZs[]='Asia/Ashkhabad';
 $TZs[]='Asia/Baghdad';
 $TZs[]='Asia/Bahrain';
@@ -224,10 +245,13 @@ $TZs[]='Asia/Beirut';
 $TZs[]='Asia/Bishkek';
 $TZs[]='Asia/Brunei';
 $TZs[]='Asia/Calcutta';
+$TZs[]='Asia/Choibalsan';
+$TZs[]='Asia/Chongqing';
 $TZs[]='Asia/Chungking';
 $TZs[]='Asia/Colombo';
 $TZs[]='Asia/Dacca';
 $TZs[]='Asia/Damascus';
+$TZs[]='Asia/Dhaka';
 $TZs[]='Asia/Dili';
 $TZs[]='Asia/Dubai';
 $TZs[]='Asia/Dushanbe';
@@ -250,21 +274,24 @@ $TZs[]='Asia/Kuala_Lumpur';
 $TZs[]='Asia/Kuching';
 $TZs[]='Asia/Kuwait';
 $TZs[]='Asia/Macao';
+$TZs[]='Asia/Macau';
 $TZs[]='Asia/Magadan';
+$TZs[]='Asia/Makassar';
 $TZs[]='Asia/Manila';
 $TZs[]='Asia/Muscat';
 $TZs[]='Asia/Nicosia';
 $TZs[]='Asia/Novosibirsk';
 $TZs[]='Asia/Omsk';
+$TZs[]='Asia/Oral';
 $TZs[]='Asia/Phnom_Penh';
+$TZs[]='Asia/Pontianak';
 $TZs[]='Asia/Pyongyang';
 $TZs[]='Asia/Qatar';
+$TZs[]='Asia/Qyzylorda';
 $TZs[]='Asia/Rangoon';
 $TZs[]='Asia/Riyadh';
-$TZs[]='Asia/Riyadh87';
-$TZs[]='Asia/Riyadh88';
-$TZs[]='Asia/Riyadh89';
 $TZs[]='Asia/Saigon';
+$TZs[]='Asia/Sakhalin';
 $TZs[]='Asia/Samarkand';
 $TZs[]='Asia/Seoul';
 $TZs[]='Asia/Shanghai';
@@ -275,6 +302,7 @@ $TZs[]='Asia/Tbilisi';
 $TZs[]='Asia/Tehran';
 $TZs[]='Asia/Tel_Aviv';
 $TZs[]='Asia/Thimbu';
+$TZs[]='Asia/Thimphu';
 $TZs[]='Asia/Tokyo';
 $TZs[]='Asia/Ujung_Pandang';
 $TZs[]='Asia/Ulaanbaatar';
@@ -294,21 +322,22 @@ $TZs[]='Atlantic/Jan_Mayen';
 $TZs[]='Atlantic/Madeira';
 $TZs[]='Atlantic/Reykjavik';
 $TZs[]='Atlantic/South_Georgia';
-$TZs[]='Atlantic/Stanley';
 $TZs[]='Atlantic/St_Helena';
+$TZs[]='Atlantic/Stanley';
 $TZs[]='Australia/ACT';
 $TZs[]='Australia/Adelaide';
 $TZs[]='Australia/Brisbane';
 $TZs[]='Australia/Broken_Hill';
 $TZs[]='Australia/Canberra';
+$TZs[]='Australia/Currie';
 $TZs[]='Australia/Darwin';
 $TZs[]='Australia/Hobart';
 $TZs[]='Australia/LHI';
 $TZs[]='Australia/Lindeman';
 $TZs[]='Australia/Lord_Howe';
 $TZs[]='Australia/Melbourne';
-$TZs[]='Australia/North';
 $TZs[]='Australia/NSW';
+$TZs[]='Australia/North';
 $TZs[]='Australia/Perth';
 $TZs[]='Australia/Queensland';
 $TZs[]='Australia/South';
@@ -323,25 +352,15 @@ $TZs[]='Brazil/East';
 $TZs[]='Brazil/West';
 $TZs[]='Canada/Atlantic';
 $TZs[]='Canada/Central';
-$TZs[]='Canada/Eastern';
 $TZs[]='Canada/East-Saskatchewan';
+$TZs[]='Canada/Eastern';
 $TZs[]='Canada/Mountain';
 $TZs[]='Canada/Newfoundland';
 $TZs[]='Canada/Pacific';
 $TZs[]='Canada/Saskatchewan';
 $TZs[]='Canada/Yukon';
-$TZs[]='CET';
 $TZs[]='Chile/Continental';
 $TZs[]='Chile/EasterIsland';
-$TZs[]='China/Beijing';
-$TZs[]='China/Shanghai';
-$TZs[]='CST6CDT';
-$TZs[]='Cuba';
-$TZs[]='EET';
-$TZs[]='Egypt';
-$TZs[]='Eire';
-$TZs[]='EST';
-$TZs[]='EST5EDT';
 $TZs[]='Europe/Amsterdam';
 $TZs[]='Europe/Andorra';
 $TZs[]='Europe/Athens';
@@ -366,9 +385,11 @@ $TZs[]='Europe/London';
 $TZs[]='Europe/Luxembourg';
 $TZs[]='Europe/Madrid';
 $TZs[]='Europe/Malta';
+$TZs[]='Europe/Mariehamn';
 $TZs[]='Europe/Minsk';
 $TZs[]='Europe/Monaco';
 $TZs[]='Europe/Moscow';
+$TZs[]='Europe/Nicosia';
 $TZs[]='Europe/Oslo';
 $TZs[]='Europe/Paris';
 $TZs[]='Europe/Prague';
@@ -393,17 +414,6 @@ $TZs[]='Europe/Warsaw';
 $TZs[]='Europe/Zagreb';
 $TZs[]='Europe/Zaporozhye';
 $TZs[]='Europe/Zurich';
-$TZs[]='Factory';
-$TZs[]='GB';
-$TZs[]='GB-Eire';
-$TZs[]='GMT';
-$TZs[]='GMT0';
-$TZs[]='GMT-0';
-$TZs[]='GMT+0';
-$TZs[]='Greenwich';
-$TZs[]='Hongkong';
-$TZs[]='HST';
-$TZs[]='Iceland';
 $TZs[]='Indian/Antananarivo';
 $TZs[]='Indian/Chagos';
 $TZs[]='Indian/Christmas';
@@ -415,24 +425,9 @@ $TZs[]='Indian/Maldives';
 $TZs[]='Indian/Mauritius';
 $TZs[]='Indian/Mayotte';
 $TZs[]='Indian/Reunion';
-$TZs[]='Iran';
-$TZs[]='Israel';
-$TZs[]='Jamaica';
-$TZs[]='Japan';
-$TZs[]='Kwajalein';
-$TZs[]='Libya';
-$TZs[]='MET';
 $TZs[]='Mexico/BajaNorte';
 $TZs[]='Mexico/BajaSur';
 $TZs[]='Mexico/General';
-$TZs[]='Mideast/Riyadh87';
-$TZs[]='Mideast/Riyadh88';
-$TZs[]='Mideast/Riyadh89';
-$TZs[]='MST';
-$TZs[]='MST7MDT';
-$TZs[]='Navajo';
-$TZs[]='NZ';
-$TZs[]='NZ-CHAT';
 $TZs[]='Pacific/Apia';
 $TZs[]='Pacific/Auckland';
 $TZs[]='Pacific/Chatham';
@@ -473,19 +468,18 @@ $TZs[]='Pacific/Truk';
 $TZs[]='Pacific/Wake';
 $TZs[]='Pacific/Wallis';
 $TZs[]='Pacific/Yap';
-$TZs[]='Poland';
-$TZs[]='Portugal';
-$TZs[]='PRC';
-$TZs[]='PST8PDT';
-$TZs[]='ROC';
-$TZs[]='ROK';
-$TZs[]='Singapore';
-$TZs[]='Turkey';
-$TZs[]='UCT';
-$TZs[]='Universal';
-$TZs[]='UTC';
-$TZs[]='WET';
-$TZs[]='W-SU';
-$TZs[]='Zulu';
+$TZs[]='US/Alaska';
+$TZs[]='US/Aleutian';
+$TZs[]='US/Arizona';
+$TZs[]='US/Central';
+$TZs[]='US/East-Indiana';
+$TZs[]='US/Eastern';
+$TZs[]='US/Hawaii';
+$TZs[]='US/Indiana-Starke';
+$TZs[]='US/Michigan';
+$TZs[]='US/Mountain';
+$TZs[]='US/Pacific';
+$TZs[]='US/Pacific-New';
+$TZs[]='US/Samoa';
 
 ?>
