@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: data.php 5280 2006-02-01 17:55:45Z yeupou $
+# $Id: data.php 5894 2006-09-21 07:44:53Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
@@ -25,7 +25,7 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
+ 
 /*
 
 Simple way of wrapping our SQL so it can be
@@ -46,63 +46,63 @@ function trackers_data_get_all_fields ($group_id=false,$reload=false)
 
   global $BF_USAGE_BY_ID,$BF_USAGE_BY_NAME, $AT_START;
 
-  # Do nothing if already set and reload not forced
+# Do nothing if already set and reload not forced
   if (isset($BF_USAGE_BY_ID) && !$reload)
     {
       return;
     }
 
-  # Clean up the array
+# Clean up the array
   $BF_USAGE_BY_ID=array();
   $BF_USAGE_BY_NAME=array();
 
-  # First get the all the defaults.
+# First get the all the defaults.
   $sql='SELECT '.ARTIFACT.'_field.bug_field_id, field_name, display_type, '.
-     'display_size,label, description,scope,required,empty_ok,keep_history,special, custom, '.
-     'group_id, use_it,show_on_add,show_on_add_members, place, custom_label,'.
-     'custom_description,custom_display_size,custom_empty_ok,custom_keep_history '.
-     'FROM '.ARTIFACT.'_field, '.ARTIFACT.'_field_usage '.
-     'WHERE group_id=100  '.
-     'AND  '.ARTIFACT.'_field.bug_field_id='.ARTIFACT.'_field_usage.bug_field_id ';
+    'display_size,label, description,scope,required,empty_ok,keep_history,special, custom, '.
+    'group_id, use_it,show_on_add,show_on_add_members, place, custom_label,'.
+    'custom_description,custom_display_size,custom_empty_ok,custom_keep_history '.
+    'FROM '.ARTIFACT.'_field, '.ARTIFACT.'_field_usage '.
+    'WHERE group_id=100  '.
+    'AND  '.ARTIFACT.'_field.bug_field_id='.ARTIFACT.'_field_usage.bug_field_id ';
 
   $res_defaults = db_query($sql);
 
-  # Now put all used fields in a global array for faster access
-  # Index both by field_name and bug_field_id
+# Now put all used fields in a global array for faster access
+# Index both by field_name and bug_field_id
   while ($field_array = db_fetch_array($res_defaults))
     {
       $BF_USAGE_BY_ID[$field_array['bug_field_id'] ] = $field_array;
       $BF_USAGE_BY_NAME[$field_array['field_name'] ] = $field_array;
     }
 
-  # Then select  all project specific entries
+# Then select  all project specific entries
   $sql='SELECT  '.ARTIFACT.'_field.bug_field_id, field_name, display_type, '.
-     'display_size,label, description,scope,required,empty_ok,keep_history,special, custom, '.
-     'group_id, use_it, show_on_add, show_on_add_members, place, custom_label,'.
-     'custom_description,custom_display_size,custom_empty_ok,custom_keep_history '.
-     'FROM '.ARTIFACT.'_field,  '.ARTIFACT.'_field_usage '.
-     'WHERE group_id='.$group_id.
-     ' AND  '.ARTIFACT.'_field.bug_field_id= '.ARTIFACT.'_field_usage.bug_field_id ';
+    'display_size,label, description,scope,required,empty_ok,keep_history,special, custom, '.
+    'group_id, use_it, show_on_add, show_on_add_members, place, custom_label,'.
+    'custom_description,custom_display_size,custom_empty_ok,custom_keep_history '.
+    'FROM '.ARTIFACT.'_field,  '.ARTIFACT.'_field_usage '.
+    'WHERE group_id='.$group_id.
+    ' AND  '.ARTIFACT.'_field.bug_field_id= '.ARTIFACT.'_field_usage.bug_field_id ';
 
 
   $res_project = db_query($sql);
 
-  # And override entries in the default array
+# And override entries in the default array
   while ($field_array = db_fetch_array($res_project))
     {
       $BF_USAGE_BY_ID[$field_array['bug_field_id'] ] = $field_array;
       $BF_USAGE_BY_NAME[$field_array['field_name'] ] = $field_array;
     }
 
-  #Debug code
-  #print "<br />DBG - At end of bug_get_all_fields: $rows";
-  #reset($BF_USAGE_BY_NAME);
-  #while (list($key, $val) = each($BF_USAGE_BY_NAME))
-  #{
-  #print "<br />DBG - $key -> use_it: $val[use_it], $val[place]";
-  #}
+#Debug code
+#print "<br />DBG - At end of bug_get_all_fields: $rows";
+#reset($BF_USAGE_BY_NAME);
+#while (list($key, $val) = each($BF_USAGE_BY_NAME))
+#{
+#print "<br />DBG - $key -> use_it: $val[use_it], $val[place]";
+#}
 
-  # rewind internal pointer of global arrays
+# rewind internal pointer of global arrays
   reset($BF_USAGE_BY_ID);
   reset($BF_USAGE_BY_NAME);
   $AT_START = true;
@@ -133,10 +133,10 @@ function &trackers_data_get_notification_settings($group_id, $tracker_name)
   $settings['private_exclude'] = db_result($result,0,$tracker_name."_private_exclude_address");
 
   $cat_field_name = "category_id";
-  # Warning: The hardcoded fiels names: bug_fv_id and bug_field_id will need to be changed
-  #          one day to generic names since they apply to bugs but also to suuports,tasks,
-  #          and patch related tables. For now these fileds are called bug_xxx whatever
-  #          the service related tables. Too much work to make all the changes in the code.
+# Warning: The hardcoded fiels names: bug_fv_id and bug_field_id will need to be changed
+#          one day to generic names since they apply to bugs but also to suuports,tasks,
+#          and patch related tables. For now these fileds are called bug_xxx whatever
+#          the service related tables. Too much work to make all the changes in the code.
   $sql="SELECT ".$tracker_name."_field_value.bug_fv_id,".$tracker_name."_field_value.value,".$tracker_name."_field_value.email_ad,".$tracker_name."_field_value.send_all_flag ".
     "FROM ".$tracker_name."_field, ".$tracker_name."_field_value ".
     "WHERE ".$tracker_name."_field_value.group_id='$group_id' ".
@@ -184,8 +184,7 @@ function trackers_data_show_notification_settings($group_id, $tracker_name, $sho
       }
       if ($grtrsettings['nb_categories'] > 0) {
 	if ($show_intro_msg != 0) {
-	  print '
-	  '.sprintf(_("As a project administrator you must decide if the list of persons to be systematically notified on new %s submissions (and possibly updates) depend on the categories or not and you must provide the corresponding email addresses (comma separated list)."), $tracker_name).'<br /><br />';
+	  print '<p>'.sprintf(_("As a project administrator you must decide if the list of persons to be systematically notified on new %s submissions (and possibly updates) depend on the categories or not and you must provide the corresponding email addresses (comma separated list)."), utils_get_tracker_name($tracker_name)).'</p>';
 
 	}
 	print '
@@ -210,20 +209,18 @@ function trackers_data_show_notification_settings($group_id, $tracker_name, $sho
 
       } else {
 	if ($show_intro_msg != 0) {
-	  print '
-	  '.sprintf(_("As a project administrator you must decide if the list of persons to be systematically notified on new %s submissions (and possibly updates) depend on the categories or not and you must provide the corresponding email addresses (comma separated list)."), $tracker_name).'<br /><br />';
+	  print '<p>'.sprintf(_("As a project administrator you must decide if the list of persons to be systematically notified on new %s submissions (and possibly updates) depend on the categories or not and you must provide the corresponding email addresses (comma separated list)."), utils_get_tracker_name($tracker_name)).'</p>';
 	}
       }
       print '<span class="preinput">'._("Global List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_new_item_address" VALUE="'.$grtrsettings['glnewad'].'" SIZE="50" MAXLENGTH="255" />
       &nbsp;&nbsp;<span class="preinput">(<INPUT TYPE="CHECKBOX" NAME="'.$tracker_name.'_send_all_changes" VALUE="1" '. (($grtrsettings['glsendall'])?'CHECKED':'') .'>'._("Send on all updates").')</span>';
 
-	print '<h4>'._("Private items exclude list").'</h4>';
-	if ($show_intro_msg != 0) {
-	  print '
-	  '._("Addresses registered in this list will be excluded from default mail notification for private items.").'<br /><br />';
-	}
+      print '<h4>'._("Private items exclude list").'</h4>';
+      if ($show_intro_msg != 0) {
+	print '<p>'._("Addresses registered in this list will be excluded from default mail notification for private items.").'</p>';
+      }
 
-	print '<span class="preinput">'._("Exclude List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_private_exclude_address" VALUE="'.$grtrsettings['private_exclude'].'" SIZE="50" MAXLENGTH="255" /><br />';
+      print '<span class="preinput">'._("Exclude List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="'.$tracker_name.'_private_exclude_address" VALUE="'.$grtrsettings['private_exclude'].'" SIZE="50" MAXLENGTH="255" /><br />';
 
     }
 }
@@ -234,8 +231,8 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   global $feedback;
 
   $local_feedback = "";
-  # build the variable names related to elements always present in the form
-  # and get their values
+# build the variable names related to elements always present in the form
+# and get their values
 
   $notif_scope_name = $tracker_name."_notif_scope";
   $notif_scope = $GLOBALS[$notif_scope_name];
@@ -248,24 +245,28 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
   $private_exclude_address_name = $tracker_name."_private_exclude_address";
   $private_exclude_address = $GLOBALS[$private_exclude_address_name];
 
-  if ($notif_scope != "global") {
-    if ($notif_scope == "category") {
-      $notif_value = 0;
-    }
-    if ($notif_scope == "both") {
-      $notif_value = 2;
-    }
+  if (isset($GLOBALS[$notif_scope_name])) {
+    if ($notif_scope != "global") {
+      if ($notif_scope == "category") {
+        $notif_value = 0;
+      }
+      if ($notif_scope == "both") {
+        $notif_value = 2;
+      }
+    } else {
+      $notif_value = 1; # global only
+			  }
   } else {
-    $notif_value = 1;
-  }
+    $notif_value = 1; # global only (scope not proposed = no categories)
+			}
 
-  # set global notification info for this group
+# set global notification info for this group
   $res_gl=db_query("UPDATE groups SET "
-	.$tracker_name."_glnotif='$notif_value', "
-	."send_all_".$tracker_name."='$send_all_changes', "
-	."new_".$tracker_name."_address=".($new_item_address? "'$new_item_address' " : "''").", "
-	.$private_exclude_address_name.'='.($private_exclude_address? "'$private_exclude_address' " : "''")
-	. " WHERE group_id=$group_id");
+		   .$tracker_name."_glnotif='$notif_value', "
+		   ."send_all_".$tracker_name."='$send_all_changes', "
+		   ."new_".$tracker_name."_address=".($new_item_address? "'$new_item_address' " : "''").", "
+		   .$private_exclude_address_name.'='.($private_exclude_address? "'$private_exclude_address' " : "''")
+		   . " WHERE group_id=$group_id");
   if (!$res_gl)
     { $local_feedback .= _("groups table Update failed.").' '.db_error(); }
 
@@ -285,9 +286,9 @@ function trackers_data_post_notification_settings($group_id, $tracker_name)
       $current_send_all_flag = $GLOBALS[$current_send_all_name];
 
       $res_cat=db_query("UPDATE ".$tracker_name."_field_value SET "
-	     ."email_ad='$current_email', "
-	     ."send_all_flag='$current_send_all_flag' "
-	     ." WHERE bug_fv_id=$current_fv_id");
+			."email_ad='$current_email', "
+			."send_all_flag='$current_send_all_flag' "
+			." WHERE bug_fv_id=$current_fv_id");
       if ($res_cat) {
         $ok++;
       } else {
@@ -307,55 +308,55 @@ function trackers_data_get_item_notification_info($item_id, $artifact, $updated)
 {
   $emailad = "";
   $sendemail = 0;
-  # Get group information bur new entity notification settings
+# Get group information bur new entity notification settings
   $sql="SELECT groups.$artifact"."_glnotif, groups.send_all_"."$artifact, groups.new_"."$artifact"."_address ".
-     "FROM "."$artifact, groups ".
-     "WHERE "."$artifact.bug_id='$item_id' ".
-     "AND groups.group_id="."$artifact.group_id";
+    "FROM "."$artifact, groups ".
+    "WHERE "."$artifact.bug_id='$item_id' ".
+    "AND groups.group_id="."$artifact.group_id";
   $result=db_query($sql);
 
   $glnotif = db_result($result,0,$artifact."_glnotif");
   $glsendall = db_result($result,0,"send_all_".$artifact);
   $glnewad = db_result($result,0,"new_".$artifact."_address");
   if ($glnotif != 1) {   # if not 'global only'
-    $cat_field_name = "category_id";
+			   $cat_field_name = "category_id";
 
-    $sql="SELECT "."$artifact"."_field_value.email_ad, "."$artifact"."_field_value.send_all_flag ".
-       "FROM "."$artifact"."_field_value, "."$artifact"."_field, $artifact ".
-       "WHERE "."$artifact.bug_id='$item_id' ".
-       "AND "."$artifact"."_field.field_name='$cat_field_name' ".
-       "AND "."$artifact"."_field_value.bug_field_id="."$artifact"."_field.bug_field_id ".
-       "AND "."$artifact"."_field_value.group_id="."$artifact.group_id ".
-       "AND "."$artifact"."_field_value.value_id="."$artifact.category_id";
+  $sql="SELECT "."$artifact"."_field_value.email_ad, "."$artifact"."_field_value.send_all_flag ".
+    "FROM "."$artifact"."_field_value, "."$artifact"."_field, $artifact ".
+    "WHERE "."$artifact.bug_id='$item_id' ".
+    "AND "."$artifact"."_field.field_name='$cat_field_name' ".
+    "AND "."$artifact"."_field_value.bug_field_id="."$artifact"."_field.bug_field_id ".
+    "AND "."$artifact"."_field_value.group_id="."$artifact.group_id ".
+    "AND "."$artifact"."_field_value.value_id="."$artifact.category_id";
 
-    $result=db_query($sql);
-    $rows=db_numrows($result);
-    if ($rows > 0) {
-      $sendallflag = db_result($result, 0, 'send_all_flag');
-      if (($updated == 0) || (($updated == 1) && ($sendallflag == 1))) {
-        $emailad .= db_result($result, 0, 'email_ad');
-      }
-    } else {
-      # could be that administrator closes category notification and forgot
-      # to define categories BUT in most cases it means the submitter selected
-      # the 'NONE' category for this bug
-      if (($updated == 0) || (($updated == 1) && ($glsendall == 1))) {
-        $emailad .= $glnewad;
-      }
+  $result=db_query($sql);
+  $rows=db_numrows($result);
+  if ($rows > 0) {
+    $sendallflag = db_result($result, 0, 'send_all_flag');
+    if (($updated == 0) || (($updated == 1) && ($sendallflag == 1))) {
+      $emailad .= db_result($result, 0, 'email_ad');
     }
-  }
-  if ($glnotif > 0) {   # if not 'category only'
+  } else {
+# could be that administrator closes category notification and forgot
+# to define categories BUT in most cases it means the submitter selected
+# the 'NONE' category for this bug
     if (($updated == 0) || (($updated == 1) && ($glsendall == 1))) {
-      if ($emailad != "") {
-        $emailad .= ',';
-      }
       $emailad .= $glnewad;
     }
   }
+  }
+  if ($glnotif > 0) {   # if not 'category only'
+			  if (($updated == 0) || (($updated == 1) && ($glsendall == 1))) {
+			    if ($emailad != "") {
+			      $emailad .= ',';
+			    }
+			    $emailad .= $glnewad;
+			  }
+  }
   if (trim($emailad) != "") {
     $sendemail = 1;
   }
-  #  print "EMAILAD=$emailad SENDEMAIL=$sendemail";
+#  print "EMAILAD=$emailad SENDEMAIL=$sendemail";
   return array($emailad, $sendemail);
 }
 
@@ -1675,7 +1676,9 @@ function trackers_data_handle_update ($group_id,
 
 
   # Enter the timestamp if we are changing to closed or declined
-  if (trackers_data_is_status_closed($vfl['status_id']))
+  # (if not already set)
+  if (trackers_data_is_status_closed($vfl['status_id']) &&
+      $vfl['status_id'] != db_result($result,0,'status_id'))
     {
       $now=time();
       $upd_list .= "close_date='$now',";
@@ -1685,7 +1688,7 @@ function trackers_data_handle_update ($group_id,
 				 $item_id);
     }
 
-  # Enter new dependancies
+  # Enter new dependencies
   $artifacts = array("support", "bugs", "task", "patch");
   while (list(, $dependent_on) = each($artifacts))
     {
@@ -1729,6 +1732,7 @@ function trackers_data_handle_update ($group_id,
 
       $sql="UPDATE ".ARTIFACT." SET $upd_list ".
 	 " WHERE bug_id='$item_id' AND group_id='$group_id'";
+
       $result=db_affected_rows(db_query($sql));
     }
   else
@@ -1790,6 +1794,8 @@ function trackers_data_reassign_item ($item_id,
 
       # To reassign an item, we close the item and we reopen a new one
       # at the appropriate place, copying information from the previous one
+      # We do this because trackers may have specific fields not compatible
+      # each others. Simply erase previous information could cause data loss.
 
       # Fetch all the information
       $sql = "SELECT * FROM ".ARTIFACT." WHERE bug_id='".$item_id."'";
@@ -1808,19 +1814,20 @@ function trackers_data_reassign_item ($item_id,
 
 		# move item
       $result = db_query("INSERT INTO ".$reassign_change_artifact.
-			 " (group_id,status_id,date,severity,submitted_by,summary,details,priority,planned_starting_date,planned_close_date,percent_complete)".
+			 " (group_id,status_id,date,severity,submitted_by,summary,details,priority,planned_starting_date,planned_close_date,percent_complete,originator_email)".
 			 " VALUES ".
 			 "(".$new_group_id.",'".
 			 "1','".
 			 $now."','".
 			 $row_data['severity']."','".
 			 $row_data['submitted_by']."','".
-			 "Reassigned item: ".addslashes($row_data['summary'])."','".
+			 addslashes($row_data['summary'])."','".
 			 addslashes($row_data['details'])."','".
 			 $row_data['priority']."','".
 			 $row_data['planned_starting_date']."','".
 			 $row_data['planned_close_date']."','".
-			 $row_data['percent_complete']."')");
+			 $row_data['percent_complete']."','".
+                         $row_data['originator_email']."')");
 
       if (!$result)
 	{
@@ -1835,30 +1842,29 @@ function trackers_data_reassign_item ($item_id,
 
       # Need to get the new item value
       $new_item_id =  mysql_insert_id();
+      if (!$new_item_id)
+	{
+	  fb(_("Unable to find the ID of the new item."), 1);
+	  return 0;
+	}
 
-      # Update item history
+      # Update items history
       trackers_data_add_history('Reassign Item',
-				'From group '.group_getname($group_id).', '.ARTIFACT.' tracker',
-				'To group '.group_getname($new_group_id).', '.$reassign_change_artifact.' tracker',
+				group_getname($group_id).', '.utils_get_tracker_prefix(ARTIFACT).' #'.$item_id,
+				group_getname($new_group_id).', '.utils_get_tracker_prefix($reassign_change_artifact).' #'.$new_item_id,
 				$item_id,
 				false,
 				ARTIFACT,
 				1);
 
       trackers_data_add_history('Reassign item',
-				'From group '.group_getname($group_id).', '.ARTIFACT.' tracker',
-				'To group '.group_getname($new_group_id).', '.$reassign_change_artifact.' tracker',
+				group_getname($group_id).', '.utils_get_tracker_prefix(ARTIFACT).' #'.$item_id,				
+				group_getname($new_group_id).', '.utils_get_tracker_prefix($reassign_change_artifact).' #'.$new_item_id,
 				$new_item_id,
 				false,
 				$reassign_change_artifact,
 				1);
 
-      if (!$new_item_id)
-	{
-	  fb(_("Unable to find the ID of the new item."), 1);
-	  return 0;
-	}
-
       # Duplicate the comments
       $sql = "SELECT * FROM ".ARTIFACT."_history WHERE bug_id='".$item_id."' AND type='100'";
       $res_history = db_query($sql);
@@ -1964,9 +1970,10 @@ function trackers_data_reassign_item ($item_id,
 	    }
 	}
 
+      # Update data of the original to make sure people dont get confused
       # Close the original item
-      $result = db_query("UPDATE ".ARTIFACT." SET status_id='3',close_date='".$now."' WHERE bug_id='".$item_id."'");
-      trackers_data_add_history('close_date',$now,$now,$item_id);
+      $result = db_query("UPDATE ".ARTIFACT." SET status_id='3',close_date='".$now."',summary='Reassigned to another tracker [was: ".addslashes($row_data['summary'])."]',details='<p class=\"warn\">THIS ITEM WAS REASSIGNED TO ".strtoupper(utils_get_tracker_prefix($reassign_change_artifact)).' #'.$new_item_id.".</p> ".addslashes($row_data['details'])."' WHERE bug_id='".$item_id."'");
+      trackers_data_add_history('close_date',$now,$now,$item_id);      
 
       if (!$result)
 	{
@@ -1976,7 +1983,21 @@ function trackers_data_reassign_item ($item_id,
 	{
 	  fb(_("Original item is now closed."));
 	}
-}
+      
+      # Finally put an extra comment so people dont get confused
+      # (it is not important, so run the sql without checks)
+      $sql = "INSERT INTO ".ARTIFACT."_history ".
+	 "(bug_id,field_name,old_value,mod_by,date,type)".
+	 " VALUES ".
+	 "('".$item_id."',".
+	 "'details',".
+	 "'<p class=\"warn\">THIS ITEM WAS REASSIGNED TO ".strtoupper(utils_get_tracker_prefix($reassign_change_artifact)).' #'.$new_item_id.".</p><p>Please, do not post any new comments to this item.</p>',".
+	 "'".user_getid()."',".
+	 "'".$now."',".
+	 "'100')";
+      db_query($sql);
+
+    }
 
 }
 
@@ -1984,17 +2005,17 @@ function trackers_data_update_dependent_items ($depends_on, $item_id, $artifact)
 {
   global $feedback,$ffeedback;
 
-  # Check if the dependancy does not already exists.
+  # Check if the dependency does not already exists.
   $sql = "SELECT item_id FROM ".ARTIFACT."_dependencies WHERE item_id='".$item_id."' AND is_dependent_on_item_id='".$depends_on."' AND is_dependent_on_item_id_artifact='".$artifact."'";
 
-  # If there is no dependancy know, insert it.
+  # If there is no dependency know, insert it.
   if (!db_numrows(db_query($sql)))
     {
       $sql="INSERT INTO ".ARTIFACT."_dependencies VALUES ('$item_id','$depends_on', '$artifact')";
       $result=db_query($sql);
       if (!$result)
 	{
-	  fb(_("Error inserting dependancy"), 1);
+	  fb(_("Error inserting dependency"), 1);
 	}
       else
 	{
@@ -2419,4 +2440,4 @@ function trackers_data_count_field_value_usage ($group_id, $field, $field_value_
   return db_numrows(db_query("SELECT bug_id FROM ".ARTIFACT." WHERE $field='$field_value_value_id' AND group_id='$group_id'"));
 }
 
-?>
\ No newline at end of file
+?>
