@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: format.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: format.php 6001 2006-09-28 14:37:05Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -28,14 +28,14 @@
 function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_to=false,$quoted=false)
 {
   ## ASCII must not be translated
-  
+
 
   #  Format the details rows from trackers_history
   global $sys_datefmt;
 
   if (!$ascii && user_get_preference("reverse_comments_order"))
     { $result = trackers_data_get_followups($item_id, false); }
-  else 
+  else
     { $result=trackers_data_get_followups($item_id); }
   $rows=db_numrows($result);
 
@@ -45,7 +45,7 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
       if ($ascii)
 	$out = "";
       else
-	$out = '<font class="warn">'._("No Followups Have Been Posted").'</font>';
+	$out = '<span class="warn">'._("No Followups Have Been Posted").'</span>';
       return $out;
     }
 
@@ -59,20 +59,20 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
       $title_arr=array();
       $title_arr[]=_("Comment");
       $title_arr[]=_("Posted By");
-      
+
       $out .= html_build_list_table_top ($title_arr);
     }
-    
+
   # Loop throuh the follow-up comments and format them
   for ($i=0; $i < $rows; $i++)
     {
-	
+
       $comment_type = db_result($result, $i, 'comment_type');
-      if ($comment_type == 'None') 
+      if ($comment_type == 'None')
 	{ $comment_type = ''; }
       else
 	{ $comment_type = '['.$comment_type.']'; }
-	
+
       if ($ascii)
 	{
 	  $fmt = "\n-------------------------------------------------------\n".
@@ -83,7 +83,7 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
 	    { $fmt .= "%s%s"; }
 	  $fmt .= "\n";
 	}
-    	
+
       # I wish we had sprintf argument swapping in PHP3 but
       # we dont so do it the ugly way...
       if ($ascii)
@@ -92,7 +92,7 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
             {
               $name = db_result($result, $i, 'realname')." <".db_result($result, $i, 'user_name').">";
             }
-          else 
+          else
             {
               $name = "Anonymous"; # must no be translated, part of mails notifs
 				     }
@@ -107,10 +107,10 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
 	{
 	  if ($comment_type)
 	    {
-	      # put the comment type in bold
-	      $comment_type = '<font class="bold">'.$comment_type.'</font><br />';
-	    } 
-	  
+	      # put the comment type in strong
+	      $comment_type = '<strong>'.$comment_type.'</strong><br />';
+	    }
+
 	  if (!user_get_preference("reverse_comments_order"))
 	    {
 	      $comment_number = ($rows-$i);
@@ -125,7 +125,7 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
 
 	  # Find out the user id of the comment author
 	  $poster_id = user_getid(db_result($result, $i, 'user_name'));
-	  
+
 	  # Ignore user 100 (anonymous)
 	  if ($poster_id != 100)
 	    {
@@ -136,17 +136,17 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
 		  # Highlight the latest comment of the assignee
 		  if ($previous != 1)
 		    {
-		      $class = "boxhighlight"; 
-		      $previous = 1; 
+		      $class = "boxhighlight";
+		      $previous = 1;
 		    }
-		  
+
 		  $assignee = 1;
 		}
-	      
+
 	      # Cosmetics if the user is project member (we wont go as far
               # as presenting a different icon for specific roles, like
 	      # manager etc..
-							
+
 	      if (member_check($poster_id, $group_id, 'A'))
 		{
 		  # Project admin case: if the group is the admin group,
@@ -170,27 +170,33 @@ function format_item_details ($item_id, $group_id, $ascii=false, $item_assigned_
 		}
 	    }
 
-	      if (! $quoted) 
+	      if (! $quoted)
 		{
-		  $out .= "\n".'<tr class="'.$class.'"><td valign="top"><a name="comment'.$comment_number.'" href="#comment'.$comment_number.'" class="preinput">'.format_date($sys_datefmt,db_result($result, $i, 'date')).', '.sprintf(_("comment #%s:"), $comment_number).'</a>'.$comment_type.'<p>'.utils_make_links(nl2br(db_result($result, $i, 'old_value'))).'</p>'.'</td>';
-		  $out .= '<td valign="top" align="center">'.utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'));
+                  $text_to_markup = db_result($result, $i, 'old_value');
 		}
 	      else
 		{
-		  $out .= "\n".'<tr class="'.$class.'"><td valign="top"><a name="comment'.$comment_number.'" href="#comment'.$comment_number.'" class="preinput">'.format_date($sys_datefmt,db_result($result, $i, 'date')).', '.sprintf(_("comment #%s:"), $comment_number).'</a>'.$comment_type.'<p>'.utils_make_links(nl2br(str_replace("\n", "> ", wordwrap("\n".db_result($result, $i, 'old_value'), 78, "\r\n")))).'</p>'.'</td>';
-		  $out .= '<td valign="top" align="center">'.utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'));
+                  $text_to_markup = str_replace("\n", "&gt; ",
+                    wordwrap("\n".db_result($result, $i, 'old_value'), 78, "\r\n"));
 		}
 
+              $out .= "\n".'<tr class="'.$class.'"><td valign="top">';
+              $out .= '<a name="comment'.$comment_number.'" href="#comment'.$comment_number.'" class="preinput">';
+              $out .= format_date($sys_datefmt,db_result($result, $i, 'date'));
+              $out .= ', '.sprintf(_("comment #%s:"), $comment_number).'</a><br />'.$comment_type;
+              $out .= utils_make_links(nl2br($text_to_markup)).'</td>';
+              $out .= '<td valign="top" align="center">'.utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'));
+
           if ($icon)
 	    {
-	      $out .= '<br /><font class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" /></font>';
+	      $out .= '<br /><span class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" /></span>';
 	    }
-	  
+
 	  if ($assignee)
 	    {
-	      $out .= '<font class="help" title="'._("In charge of this item.").'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/assignee.png" alt="'._("In charge of this item.").'" /></font>';
+	      $out .= '<span class="help" title="'._("In charge of this item.").'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/assignee.png" alt="'._("In charge of this item.").'" /></span>';
 	    }
-	  
+
 	  $out .= '</td></tr>';
 
 	}
@@ -227,14 +233,14 @@ function format_item_changes ($changes,$item_id,$group_id)
       if (!$h['del'] && !$h['add'])
 	{ continue; }
 
-      if ($field == "details" || $field == "attach") 
+      if ($field == "details" || $field == "attach")
         { continue; }
 
       # Since details is used for followups (creepy!), we are forced to play
       # with "realdetails" non existant field.
       if ($field == "realdetails")
         { $field = "details"; }
-     
+
       $label = trackers_data_get_label($field);
       if (!$label)
 	{ $label = $field; }
@@ -256,7 +262,7 @@ function format_item_changes ($changes,$item_id,$group_id)
 
       $out_com = "Follow-up Comment #".db_numrows(trackers_data_get_followups($item_id));
       if (!$out)
-        { 
+        {
           $out_com .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
         }
 
@@ -280,7 +286,7 @@ function format_item_changes ($changes,$item_id,$group_id)
 
       $out_att = "Additional Item Attachment";
       if (!$out)
-        { 
+        {
           $out_att .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
         }
       $out_att .= ":\n\n";
@@ -326,7 +332,7 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false,$sober=fals
       if ($ascii)
 	$out = "";
       else
-	$out = '<font class="warn">'._("No files currently attached").'</font>';
+	$out = '<span class="warn">'._("No files currently attached").'</span>';
       return $out;
     }
 
@@ -336,13 +342,13 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false,$sober=fals
       $out .= "    _______________________________________________________\n\nFile Attachments:\n\n";
     }
   else
-    {	
+    {
       if (!$sober)
 	{
 	  $out .= $HTML->box_top(_("Attached Files"),'',1);
 	}
     }
-  
+
   # Determine what the print out format is based on output type (Ascii, HTML
   if ($ascii)
     {
@@ -363,7 +369,7 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false,$sober=fals
 	{
 	  $href = $GLOBALS['sys_home'].ARTIFACT."/download.php?file_id=$item_file_id";
 	}
-      
+
       if ($ascii)
 	{
 	  $out .= sprintf($fmt,
@@ -377,35 +383,35 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false,$sober=fals
       else
 	{
 	  unset($html_delete);
-	  if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') && !$sober) 
+	  if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') && !$sober)
 	    {
 	      $html_delete = '<span class="trash"><a href="'.$PHP_SELF.'?func=delete_file&amp;item_id='.$item_id.'&amp;item_file_id='.$item_file_id.'">'.
 		'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" class="icon" alt="'._("Delete").'" /></a></span>';
 	    }
 
-	  
+
 	  if (!$sober)
 	    {
 	      $out .= '<div class="'.utils_get_alt_row_color($i).'">'.$html_delete;
 	    }
 	  else
 	    {
-	      $out .= '<div>&nbsp&nbsp;&nbsp;- ';
+	      $out .= '<div>&nbsp;&nbsp;&nbsp;- ';
 	    }
-	  
-	  $out .= '<a href="'.$href.'">file #'.$item_file_id.'</a>'._(": ").'&nbsp;';
+
+	  $out .= '<a href="'.$href.'">file #'.$item_file_id._(": ").'&nbsp;';
 
 	  if (!$sober)
 	    {
-	      $out .= sprintf(_('%s added by %s'), '<a href="'.$href.'">'.db_result($result, $i, 'filename').'</a>', utils_user_link(db_result($result, $i, 'user_name')));
+	      $out .= sprintf(_('%s added by %s'), db_result($result, $i, 'filename').'</a>', utils_user_link(db_result($result, $i, 'user_name')));
 	    }
 	  else
 	    {
 	      $out .= '<a href="'.$href.'">'.db_result($result, $i, 'filename').'</a>';
 	    }
 
-	  $out .= ' <font class="smaller">('.utils_filesize(0, intval(db_result($result, $i, 'filesize')));
-	  
+	  $out .= ' <span class="smaller">('.utils_filesize(0, db_result($result, $i, 'filesize'));
+
 	  if (db_result($result, $i, 'filetype'))
 	    {
 	      $out .= ' - '.db_result($result, $i, 'filetype');
@@ -413,14 +419,15 @@ function format_item_attached_files ($item_id,$group_id,$ascii=false,$sober=fals
 
 	  if (db_result($result, $i, 'description'))
 	    {
-	      $out .= ' - '.utils_make_links(db_result($result, $i, 'description'));
+	      $out .= ' - '
+                .utils_make_links(db_result($result, $i, 'description'));
 	    }
-	  $out .= ')</font></div>';							    
+	  $out .= ')</span></div>';
 	}
     }
-								 
+
   # final touch...
-								 
+
   if ($ascii || $sober)
   {
     $out .= "\n";
@@ -453,11 +460,11 @@ function format_item_cc_list ($item_id,$group_id, $ascii=false)
     {
       if ($ascii)
 	{
-	  $out .= ""; 
+	  $out .= "";
 	}
       else
 	{
-	  $out = '<font class="warn">'._("CC list is empty").'</font>';
+	  $out = '<span class="warn">'._("CC list is empty").'</span>';
 	}
       return $out;
     }
@@ -472,7 +479,7 @@ function format_item_cc_list ($item_id,$group_id, $ascii=false)
       $out .= "------------------------------------+-----------------------------\n";
     }
   else
-    {	
+    {
       $out .= $HTML->box_top(_("Carbon-Copy List"),'',1);
     }
 
@@ -480,16 +487,18 @@ function format_item_cc_list ($item_id,$group_id, $ascii=false)
   for ($i=0; $i < $rows; $i++)
     {
 
-      $email = utils_antispam_email(db_result($result, $i, 'email'));
-      $item_cc_id = db_result($result, $i, 'bug_cc_id');
-
-      # If the CC is a user point to its user page.
-      # Do not build mailto, we do not need to help spammers.
-      $res_username = user_get_result_set_from_unix($email);
-      if ($res_username && (db_numrows($res_username) == 1))
-	{ $href_cc = utils_user_link($email); }
+      if ($ascii)
+	{
+	  # We wont provide the CC address in the mail, we keep that
+	  # information only on the web interface
+	  $email = "Available only the item webpage";
+	}
       else
-	{ $href_cc = $email; }
+	{
+	  $email = utils_email(db_result($result, $i, 'email'));
+	}
+      $item_cc_id = db_result($result, $i, 'bug_cc_id');
+      $href_cc = $email;
 
       if ($ascii)
 	{
@@ -500,11 +509,11 @@ function format_item_cc_list ($item_id,$group_id, $ascii=false)
 
 	  # show CC delete icon if one of the condition is met:
 	  # a) current user is a tracker manager
-	  # b) then CC name is the current user 
+	  # b) then CC name is the current user
 	  # c) the CC email address matches the one of the current user
 	  # d) the current user is the person who added a given name in CC list
 	  if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') ||
-	      (user_getname(user_getid()) == $email) ||  
+	      (user_getname(user_getid()) == $email) ||
 	      (user_getemail(user_getid()) == $email) ||
 	      (user_getname(user_getid()) == db_result($result, $i, 'user_name') ))
             {
@@ -512,15 +521,15 @@ $html_delete = '<span class="trash"><a href="'.$PHP_SELF.'?func=delete_cc&amp;it
 		 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" class="icon" alt="'._("Delete").'" /></a></span>';
 	    }
 	  else
-	    {
+            {
 	      $html_delete = '';
 	    }
-            
+
           $out .= '<li class="'.utils_get_alt_row_color($i).'">'.$html_delete.
 	  sprintf(_('%s added by %s'), $email, utils_user_link(db_result($result, $i, 'user_name')));
           if (db_result($result, $i, 'comment'))
            {
-	     $out .= ' <font class="smaller">('.utils_make_links(db_result($result, $i, 'comment')).')</font>';
+	     $out .= ' <span class="smaller">('.utils_make_links(db_result($result, $i, 'comment')).')</span>';
            }
 
 #$href_cc,
