@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php 5286 2006-02-03 12:35:22Z ype $
+# $Id: general.php 5945 2006-09-22 12:30:18Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
@@ -25,7 +25,7 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
+ 
 # Return the file that should be included, according to the URL
 # requested. If the file start with ?, it's an index.
 function trackers_include()
@@ -392,7 +392,7 @@ function trackers_multiple_field_date($field_name,$date_begin='',$date_end='',$s
       if (!$size || !$maxlength)
 	list($size, $maxlength) = trackers_data_get_display_size($field_name);
 
-      $html = 'Start:<br /><INPUT TYPE="text" name="'.$field_name.
+      $html = 'Start:<br /><input type="text" name="'.$field_name.
 	 '" size="'.$size.'" MAXLENGTH="'.$maxlength.'" VALUE="'.$date_begin.'">'.
 	 '<a href="javascript:show_calendar(\'document.bug_form.'.$field_name.'\', document.bug_form.'.$field_name.'.value);">'.
 	 '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/task.png" border="0" alt="'._("Click Here to Pick up a date").'" /></a>'.
@@ -431,7 +431,7 @@ function trackers_field_text($field_name,$value='',$size=0,$maxlength=0)
     list($size, $maxlength) = trackers_data_get_display_size($field_name);
 
   $html = '<input type="text" name="'.$field_name.
-     '" size="'.$size.'" maxlength="'.$maxlength.'" value="'.$value.'">';
+     '" size="'.$size.'" maxlength="'.$maxlength.'" value="'.$value.'" />';
   return($html);
 
 }
@@ -649,7 +649,12 @@ function trackers_extract_field_list($post_method=true)
 	    }
 	  elseif (isset($BF_USAGE_BY_NAME[$key]) || $key == 'comment')
 	    {
-	      $vfl[$key] = $val;
+              if ($key == 'comment') {
+#               $vfl[$key] = "<pre>".$val."</pre>";
+	        $vfl[$key] = $val;
+              } else {
+                $vfl[$key] = $val;
+              }
 	    }
 	  else
 	    {
@@ -1106,20 +1111,61 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 
   while (list(,$cc) = each($arr_cc))
     {
-      if (validate_email($cc))
+      # Remove extra white spaces
+      $cc = trim($cc);
+
+      # The CC may have been added in the form like:
+      #    THIS NAME <this@address.net>
+      # So the validation check must be made only on the part in < >, if 
+      # it exists
+      unset($realaddress);
+      if (preg_match("/\<([\w\d\-\@\.]*)\>/", $cc, $realaddress))
+	{ $realaddress = $realaddress[1]; }
+      else
+	{ $realaddress = $cc; }
+   
+      if (validate_email($realaddress))
 	{
-	  $addresses[utils_normalize_email($cc)] = true;
+	  # We have an address like ablab@adad.net
+	  
+	  # FIXME: Should get back the THIS NAME info is existant
+	  # but sendmail_mail() is not yet capable of handling this
+	  # so for now, we simply ignore the real address.
+	  # Yes, that is a bit annoying, as we implicitely allow users to
+	  # add names that will not be later reused.
+	  # But it is not blocker and we could implement it later, if 
+	  # requested
+	  ## $extrainfo = str_replace("<$realaddress>", "", $cc);
+
+	  $addresses[utils_normalize_email($realaddress)] = true;
 	}
       else
 	{
-	  $res = user_get_result_set_from_unix($cc);
+	  # We have an address like ablab
+
+	  $res = user_get_result_set_from_unix($realaddress);
 	  $user_id = db_result($res,0,'user_id');
-	  if (!$user_ids[$user_id] && trackers_check_notification($user_id, 'CC', $changes))
+	  
+	  # If it as real user, check settings
+	  if ($user_id)
 	    {
-	      $user_ids[$user_id] = true;
+	      if (!$user_ids[$user_id] && trackers_check_notification($user_id, 'CC', $changes))
+		{
+		  $user_ids[$user_id] = true;
+		}
+	      continue;
 	    }
+
+	  # Otherwise, try to assume what savane would do 
+	  # (append @maildomain) and check if it is somehow valid.
+	  # If not, completly ignore
+	  $normalized = utils_normalize_email($realaddress);
+	  if (validate_email($normalized))
+	    { 
+	      $addresses[$normalized] = true;
+	    }	  
 	}
-    } # while
+    } 
 
 
   # check all commenters
@@ -1167,7 +1213,7 @@ function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$
   $sql="SELECT * from $artifact WHERE bug_id='$item_id'";
 
   $result = db_query($sql);
-  $bug_href = "http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."$artifact/?func=detailitem&item_id=$item_id";
+  $bug_href = "http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."$artifact/?$item_id";
 
   if ($result && db_numrows($result) > 0)
   {
@@ -1339,14 +1385,19 @@ function trackers_attach_file($item_id,
   #  - then with strlen after the call the addslashes(): the check must be
   #  made on the final size for import in the database.
   #
-  if (filesize($input_file) > 524288) {
-    fb(sprintf(_("File not attached: the allowed size is 512 kB, after escaping characters as required. The file you were trying to attach is %s kB large."), filesize($input_file)/1024), 1);
+  # Note: in english, use the expression kilobytes, and not kB, because
+  # feedback is in lowercase for the whole string.
+  $filesize = round(filesize($input_file) / 1024);
+  if ($filesize > $GLOBALS['sys_upload_max']) 
+  {
+    fb(sprintf(_("File not attached: the allowed size is %s kilobytes, after escaping characters as required. The file you were trying to attach is %s kilobytes large."), $GLOBALS['sys_upload_max'], $filesize), 1);
     return false;
   }
-  $data = addslashes(fread($data, filesize($input_file)));
-  if (strlen($data) > 524288)
+  $data = addslashes(fread($data, filesize($input_file))); 
+  $filesize = round(strlen($data) / 1024);
+  if ($filesize > $GLOBALS['sys_upload_max'])
     {
-      fb(sprintf(_("File not attached: the allowed size is 512 kB. After escaping characters as required, it sized %s kB."), strlen($data)/1024), 1);
+      fb(sprintf(_("File not attached: the allowed size is %s kilobytes. After escaping characters as required, it sized %s kilobytes."), $GLOBALS['sys_upload_max'], $filesize), 1);
       return false;
     }
 
@@ -1393,7 +1444,7 @@ function trackers_insert_cc($item_id,$cc,$added_by,$comment,$date)
 
   trackers_data_add_history("Carbon-Copy",
 			    "-",
-			    "Added ".utils_antispam_email($cc),
+			    "Added ".utils_email($cc,1),
 			    $item_id,
 			    0,0,1);
   return ($res);
@@ -1460,7 +1511,7 @@ function trackers_delete_cc($group_id=false,$item_id=false,$item_cc_id=false)
     {
       fb(_("CC Removed."));
       trackers_data_add_history("Carbon-Copy",
-				"Removed ".utils_antispam_email(db_result($res1, 0, 'email')),
+				"Removed ".utils_email(db_result($res1, 0, 'email'),1),
 				"-",
 				$item_id,
 				0,0,1);
@@ -2018,7 +2069,7 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
   for ($i=0; $i < $rows; $i++)
     {
 
-      $email = utils_antispam_email(db_result($result, $i, 'email'));
+      $email = db_result($result, $i, 'email');
       $item_cc_id = db_result($result, $i, 'bug_cc_id');
 
       # If the CC is a user point to its user page.
@@ -2057,8 +2108,10 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
   for ($i=0; $i < $rows; $i++)
     {
 
-      $item_file_id = db_result($result, $i, 'bug_file_id');
-	  $href = $GLOBALS['sys_home'].ARTIFACT."/download.php?item_id=$item_id&item_file_id=$item_file_id";
+      $item_file_id = db_result($result, $i, 'file_id');
+
+
+          $href = $GLOBALS['sys_home'].ARTIFACT."/download.php?file_id=$item_file_id";
 
        $out .= sprintf($fmt,
 			  format_date($sys_datefmt,db_result($result, $i, 'date')),
