@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: show.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: show.php 5972 2006-09-26 08:55:00Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@ function show_item_list ($result_arr,
     {
       $links_arr = array();
       while (list(,$field) = each($field_arr))
-	{	  
+	{
 	  $links_arr[] = $url.'&amp;order='.$field.'#results';
 	}
     }
@@ -58,17 +58,17 @@ function show_item_list ($result_arr,
       if ($offset > 0)
 	{
 	  $nav_bar .=
-	     '<font class="xsmall"><a href="'.$url.'&amp;offset=0#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/first.png" border="0" alt="'._("Begin").'" />'._("Begin").'</a>'.
+	     '<span class="xsmall"><a href="'.$url.'&amp;offset=0#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/first.png" border="0" alt="'._("Begin").'" />'._("Begin").'</a>'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
 	     '<a href="'.$url.'&amp;offset='.($offset-$chunksz).
-	     '#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'" />'._("Previous Results").'</a></font>';
+	     '#results"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previous.png" border="0" alt="'._("Previous Results").'" />'._("Previous Results").'</a></span>';
 	}
       else
 	{
 	  $nav_bar .=
-	     '<font class="xsmall"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/firstgrey.png" border="0" alt="'._("Begin").'" /><font class="italic">'._("Begin").'</font>'.
+	     '<span class="xsmall"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/firstgrey.png" border="0" alt="'._("Begin").'" /><em>'._("Begin").'</em>'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
-	     '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'" /><font class="italic">'._("Previous Results").'</font></font>';
+	     '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/previousgrey.png" border="0" alt="'._("Previous Results").'" /><em>'._("Previous Results").'</em></span>';
 	}
     }
 
@@ -95,17 +95,17 @@ function show_item_list ($result_arr,
 	  #fb("$offset_end offset_end");
 
 	  $nav_bar .=
-	     '<font class="xsmall"><a href="'.$url.'&amp;offset='.($offset+$chunksz).
+	     '<span class="xsmall"><a href="'.$url.'&amp;offset='.($offset+$chunksz).
 	     '#results">'._("Next Results").'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="'._("Next Results").'" /></a>'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
 	     '<a href="'.$url.'&amp;offset='.($offset_end).
-	     '#results">'._("End").'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/last.png" border="0" alt="'._("End").'" /></a></font>';
+	     '#results">'._("End").'<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/last.png" border="0" alt="'._("End").'" /></a></span>';
 	}
       else
 	{
-	  $nav_bar .= '<font class="xsmall"><font class="italic">'._("Next Results").'</font><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'" />'.
+	  $nav_bar .= '<span class="xsmall"><em>'._("Next Results").'</em><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/nextgrey.png" border="0" alt="'._("Next Results").'" />'.
 	     '&nbsp;&nbsp;&nbsp;&nbsp;'.
-	     '<font class="italic">'._("End").'</font><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/lastgrey.png" border="0" alt="'._("End").'" /></font></font>';
+	     '<em>'._("End").'</em><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/lastgrey.png" border="0" alt="'._("End").'" /></span>';
 	}
     }
   $nav_bar .= '</h3>';
@@ -121,9 +121,9 @@ function show_item_list ($result_arr,
   while (list(,$thisitem) = each($result_arr))
     {
       $thisitem_id = $thisitem['bug_id'];
-      
+
       print '<tr class="'.utils_get_priority_color($result_arr[$thisitem_id]["priority"], $result_arr[$thisitem_id]["status_id"]).'">'."\n";
-      
+
       for ($j=0; $j<$nb_of_fields; $j++)
 	{
            # If we are in digest mode, add the digest checkbox
@@ -134,7 +134,7 @@ function show_item_list ($result_arr,
 	      print '<td class="center">'.form_input("checkbox", "items_for_digest[]", "$thisitem_id\" checked=\"checked").'</td>';
 	      continue;
 	    }
-	  
+
 	  $value = $result_arr[$thisitem_id][$field_arr[$j]];
 	  if ($width_arr[$j])
 	    {
@@ -144,7 +144,7 @@ function show_item_list ($result_arr,
 	    {
 	      $width = '';
 	    }
-	  
+
 	  if (trackers_data_is_date_field($field_arr[$j]) )
 	    {
 	      if ($value)
@@ -159,37 +159,37 @@ function show_item_list ($result_arr,
 		}
 	      else
 		{ print "<td align=\"middle\" $width>-</td>\n"; }
-	      
+
 	    }
 	  else if ($field_arr[$j] == 'bug_id')
 	    {
-	      
+
 	      if ($nolink)
 		{ print "<td $width>#$value</td>\n"; }
 	      else
 		    {
 		      print "<td $width>";
-		      
-		      print '<a href="?func=detailitem&amp;item_id='.$value.'">';
-		      
+
+		      print '<a href="?'.$value.'">';
+
 		      print '&nbsp;#'.$value .'</a></td>'."\n";
-		      
+
 		    }
-	      
+
 	    }
 	  else if (trackers_data_is_username_field($field_arr[$j]))
 	    {
-	      
+
 	      if ($nolink)
 		{ print "<td $width>$value</td>\n"; }
 	      else
 		{ print "<td $width>".utils_user_link($value)."</td>\n"; }
-	      
+
 	    }
 	  else if (trackers_data_is_select_box($field_arr[$j]))
 	    {
 	      print "<td $width>". trackers_data_get_cached_field_value($field_arr[$j], $group_id, $value) .'</td>'."\n";
-	      
+
 	    }
 	  else
 		{
@@ -197,24 +197,23 @@ function show_item_list ($result_arr,
 		    { print "<td $width>". $value .'&nbsp;</td>'."\n"; }
 		  else
 		    {
-		      print "<td $width>".'<a href="?func=detailitem&amp;item_id='.
-			$thisitem_id.'">'.
+		      print "<td $width>".'<a href="?'.$thisitem_id.'">'.
 			$value .'</a></td>'."\n";
 		    }
 		}
-	  
+
 	}
       print "</tr>\n";
     }
-  
+
   print '</table>';
-  
+
   # Print prev/next links
   print "<br />".$nav_bar;
 
 }
 
-## 
+##
 # Do the same a item list but in sober output
 function show_item_list_sober ($result_arr,
 			       $total_rows,
@@ -224,7 +223,7 @@ function show_item_list_sober ($result_arr,
 
   $possible_contexts = cookbook_context_possiblevalues();
   $possible_audiences = cookbook_audience_possiblevalues();
-  
+
   # If we are on a project cookbook, take into account impossible values:
   # recipes of features unused by the project
   $impossible_contexts = array();
@@ -233,15 +232,15 @@ function show_item_list_sober ($result_arr,
       $impossible_contexts = cookbook_context_project_impossiblevalues();
     }
 
-  
+
   # Add the unset case, when the item is actually not bound to any context
   # or action
   # Build sql specific part for these
   unset($sql_unboundcontext, $sql_unboundaudience);
   $thisarray = array_merge($possible_contexts, $impossible_contexts);
   while (list($context,) = each($thisarray))
-    { 
-      $sql_unboundcontext .= "AND context_$context='0' "; 
+    {
+      $sql_unboundcontext .= "AND context_$context='0' ";
     }
   while (list($audience,) = each($possible_audiences))
     { $sql_unboundaudience .= "AND audience_$audience='0' "; }
@@ -249,9 +248,10 @@ function show_item_list_sober ($result_arr,
   # Built for scratch two groups of audiences possible for this page:
   # group members and non-group members
   $possible_audiences = array();
-  $possible_audiences['nonmembers'] = _("Non Project Members");
-  $possible_audiences['members'] = _("Project Members");
-    
+  #$possible_audiences['everybody'] = _("For Everybody");
+  $possible_audiences['nonmembers'] = _("For Everybody");
+  $possible_audiences['members'] = _("For Project Members Only");
+
   # Add unset cases to the arrays
   $possible_contexts['unbound'] = _("Other");
   $possible_audiences['unbound'] = _("Undefined");
@@ -260,22 +260,23 @@ function show_item_list_sober ($result_arr,
   #   project members / non project members
   $sql_nonmembers = "AND (audience_anonymous='1' OR audience_loggedin='1')";
   $sql_members = "AND (audience_members='1' OR audience_technicians='1' OR audience_managers='1')";
+  #$sql_everybody = $sql_nonmembers." ".$sql_members;
 
   unset($sql_privateitem);
 
   # Go through the list of possible context and then possible actions
   # print relevant items
-  print '<ul>';
   reset($possible_contexts);
   while (list($context,$context_label) = each($possible_contexts))
     {
+      $seen_before = array();
       unset($context_content);
       reset($possible_audiences);
       while (list($audience,$audience_label) = each($possible_audiences))
 	{
           # Get recipes contextual data
 	  # (no limit argument, expecting people not to use terrible scales)
-	  
+
 	  if ($audience == 'nonmembers')
 	    {
 	      $sql_audience = $sql_nonmembers;
@@ -284,7 +285,11 @@ function show_item_list_sober ($result_arr,
 	    {
 	      $sql_audience = $sql_members;
 	    }
- 
+	  #else
+	  #  {
+	  #    $sql_audience = $sql_everybody;
+	  #  }
+
 	  # Special deal for the item unbound
 	  if ($audience != 'unbound' && $context != 'unbound')
 	    {
@@ -306,7 +311,7 @@ function show_item_list_sober ($result_arr,
 	      # Not binded at all
 	      $sql_context = "SELECT * FROM cookbook_context2recipe WHERE (group_id='$group_id' OR group_id='$sys_group_id') $sql_unboundcontext $sql_unboundaudience";
 	    }
-	  
+
 	  $result_context = db_query($sql_context);
 	  $result_rows = db_numrows($result_context);
 
@@ -318,10 +323,10 @@ function show_item_list_sober ($result_arr,
 	      # We store the summary in lower case, to avoid having a case
 	      # sensitive sort.
 	      $thisaudience_results = array();
-	      for ($i = 0; $i < $result_rows; $i++) 
+	      for ($i = 0; $i < $result_rows; $i++)
 		{
 		  $thisitem_id = db_result($result_context, $i, 'recipe_id');
-		  $thisaudience_results[$thisitem_id] = 
+		  $thisaudience_results[$thisitem_id] =
 		    strtolower($result_arr[$thisitem_id]["summary"]);
 		}
 	      asort($thisaudience_results);
@@ -332,6 +337,15 @@ function show_item_list_sober ($result_arr,
 		  if ($result_arr[$thisitem_id]["resolution_id"] != '1')
 		    { continue; }
 
+		  # Ignore if seen before (probably because it an item for
+		  # for everybody and we are listing members or non-members
+		  # items)
+		  if (isset($seen_before[$thisitem_id]))
+		    { continue; }
+
+		  # Record that we seen it
+		  $seen_before[$thisitem_id] = true;
+
 		  # Detect if it is a site wide doc item. Ignore that if we
 		  # are on the site admin group
 		  unset($is_site_doc, $url_extra_arg);
@@ -352,26 +366,29 @@ function show_item_list_sober ($result_arr,
 		    {
 		      $audience_content .= '<span class="'.utils_get_priority_color($result_arr[$thisitem_id]["priority"]).'">';
 		    }
-		  
+
 		  # In this link, we need to mention from where we come from
-		  # so it is possible to know if we are actually inside a 
+		  # so it is possible to know if we are actually inside a
 		  # group cookbook if ever we look at a site wide documentation
+		  # (We use the long item url, with "detailitem" because we may
+		  # have extra arguments to include that would mess the short
+		  # item url interpretation)
 		  $audience_content .= utils_link($GLOBALS['sys_home'].'cookbook/?func=detailitem'.$url_extra_arg.'&amp;item_id='.$thisitem_id, $result_arr[$thisitem_id]["summary"]);
 		  if ($priority > 4)
 		    {
 		      $audience_content .= '</span>';
 		    }
-		  
+
 		  # If it comes from the site docs, mention it
 		  if ($is_site_doc)
 		    {
 		      $audience_content .= '&nbsp;&nbsp;<span class="smaller">('.sprintf(_("From %s User Docs"), $sys_name).')</span>';
 		    }
-		  
+
 		  $audience_content .= '</li>';
 		}
 
-	      # If there was valid results, save the subcontext 
+	      # If there was valid results, save the subcontext
 	      if (!$audience_content)
 		{ continue; }
 
@@ -381,31 +398,27 @@ function show_item_list_sober ($result_arr,
 	      $context_content .= '</ul>';
 	      $context_content .= '</li>';
 	    }
-	}  
-      # If there was valid results, print the context 
+	}
+      # If there was valid results, print the context
       if (!$context_content)
 	{ continue; }
-      
-      print '<li>'.html_anchor(sprintf(_("%s:"), $context_label), $context);
-      print '<ul>';
-      print $context_content;
-      print '</ul><br />';
-      print '</li>';
-      
+
+      print '
+  <h3>'.html_anchor(sprintf(_("%s:"), $context_label), $context).'</h3>
+  <ul>'.$context_content.'</ul>
+  <br />
+';
+
     }
-  print '</ul>';
 
 
-
-
-  
   return true;
   while (list(,$thisitem) = each($result_arr))
     {
       $thisitem_id = $thisitem['bug_id'];
-      
+
       print '<tr class="'.utils_get_priority_color($result_arr[$thisitem_id]["priority"], $result_arr[$thisitem_id]["status_id"]).'">'."\n";
-      
+
       for ($j=0; $j<$nb_of_fields; $j++)
 
 
@@ -416,7 +429,7 @@ function show_item_list_sober ($result_arr,
 	      print '<td class="center">'.form_input("checkbox", "items_for_digest[]", $thisitem_id).'</td>';
 	      continue;
 	    }
-	  
+
 	  $value = $result_arr[$thisitem_id][$field_arr[$j]];
 	  if ($width_arr[$j])
 	    {
@@ -426,7 +439,7 @@ function show_item_list_sober ($result_arr,
 	    {
 	      $width = '';
 	    }
-	  
+
 	  if (trackers_data_is_date_field($field_arr[$j]) )
 	    {
 	      if ($value)
@@ -441,37 +454,37 @@ function show_item_list_sober ($result_arr,
 		}
 	      else
 		{ print "<td align=\"middle\" $width>-</td>\n"; }
-	      
+
 	    }
 	  else if ($field_arr[$j] == 'bug_id')
 	    {
-	      
+
 	      if ($nolink)
 		{ print "<td $width>#$value</td>\n"; }
 	      else
 		    {
 		      print "<td $width>";
-		      
-		      print '<a href="?func=detailitem&amp;item_id='.$value.'">';
-		      
+
+		      print '<a href="?'.$value.'">';
+
 		      print '&nbsp;#'.$value .'</a></td>'."\n";
-		      
+
 		    }
-	      
+
 	    }
 	  else if (trackers_data_is_username_field($field_arr[$j]))
 	    {
-	      
+
 	      if ($nolink)
 		{ print "<td $width>$value</td>\n"; }
 	      else
 		{ print "<td $width>".utils_user_link($value)."</td>\n"; }
-	      
+
 	    }
 	  else if (trackers_data_is_select_box($field_arr[$j]))
 	    {
 	      print "<td $width>". trackers_data_get_cached_field_value($field_arr[$j], $group_id, $value) .'</td>'."\n";
-	      
+
 	    }
 	  else
 		{
@@ -479,18 +492,17 @@ function show_item_list_sober ($result_arr,
 		    { print "<td $width>". $value .'&nbsp;</td>'."\n"; }
 		  else
 		    {
-		      print "<td $width>".'<a href="?func=detailitem&amp;item_id='.
-			$thisitem_id.'">'.
+		      print "<td $width>".'<a href="?'.$thisitem_id.'">'.
 			$value .'</a></td>'."\n";
 		    }
 		}
-	  
+
 	}
       print "</tr>\n";
     }
-  
+
   print '</table>';
-  
+
   # Print prev/next links
   print "<br />".$nav_bar;
 
@@ -638,7 +650,7 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
     }
   else
     {
-      print "\n".'<font class="warn">'._("No Changes Have Been Made to This Item").'</font>';
+      print "\n".'<span class="warn">'._("No Changes Have Been Made to This Item").'</span>';
     }
 }
 
@@ -676,8 +688,6 @@ function show_dependent_item ($item_id, $dependson=0)
   global $group_id;
 
   $artifacts = array("support", "bugs", "task", "patch");
-  $result = array();
-  $rows = array();
   $is_manager = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1');
 
   if (!$dependson)
@@ -685,12 +695,18 @@ function show_dependent_item ($item_id, $dependson=0)
   else
     { $title = _("Depends on the following items"); }
 
+  # Create hash that will contain every relevant info
+  # with keys like $date.$item_id so it will be sorted by date (first)
+  # and item_id (second)
+  $content = array();
+
   # Slurps the database.
-  while (list($num, $art) = each($artifacts))
+  unset($item_exists, $item_exists_tracker);
+  while (list(,$art) = each($artifacts))
     {
       if (!$dependson)
 	{
-	  $sql = "SELECT ".$art.".bug_id,".$art.".summary,".$art.".status_id,".$art.".resolution_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by ".
+	  $sql = "SELECT ".$art.".bug_id,".$art.".date,".$art.".summary,".$art.".status_id,".$art.".resolution_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by ".
 	     " FROM ".$art.",".$art."_dependencies ".
 	     " WHERE ".$art.".bug_id=".$art."_dependencies.item_id ".
 	     " AND ".$art."_dependencies.is_dependent_on_item_id='$item_id'".
@@ -698,126 +714,173 @@ function show_dependent_item ($item_id, $dependson=0)
 	}
       else
 	{
-	  $sql = "SELECT ".$art.".bug_id,".$art.".summary,".$art.".status_id,".$art.".resolution_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by".
+	  $sql = "SELECT ".$art.".bug_id,".$art.".date,".$art.".summary,".$art.".status_id,".$art.".resolution_id,".$art.".group_id,".$art.".priority,".$art.".privacy,".$art.".submitted_by".
 	     " FROM ".$art.",".ARTIFACT."_dependencies ".
 	     " WHERE ".$art.".bug_id=".ARTIFACT."_dependencies.is_dependent_on_item_id ".
 	     " AND ".ARTIFACT."_dependencies.item_id='$item_id'".
 	     " AND ".ARTIFACT."_dependencies.is_dependent_on_item_id_artifact='".$art."' ORDER by ".$art.".bug_id ";
 
 	}
+      
+      $res_all = db_query($sql);
+      $numrows_all = db_numrows($res_all);
+      for ($i=0; $i < $numrows_all; $i++)
+	{
+	  # Note for later that at least one item was found
+	  $item_exists = 1;
+	  $item_exists_tracker[$art] = 1;
+	  
+	  # Generate unique key date.tracker#nnn
+	  $key = db_result($res_all, $i, 'date').'.'.
+	    $art.'#'.
+	    db_result($res_all,$i,'bug_id');
+	  
+          # Store relevant data
+	  $content[$key]['item_id'] = db_result($res_all,$i,'bug_id');
+	  $content[$key]['tracker'] = $art;
+	  $content[$key]['date'] = db_result($res_all,$i,'date');
+	  $content[$key]['summary'] = db_result($res_all,$i,'summary');
+	  $content[$key]['status_id'] = db_result($res_all,$i,'status_id');
+	  $content[$key]['resolution_id'] = db_result($res_all,$i,'resolution_id');
+	  $content[$key]['group_id'] = db_result($res_all,$i,'group_id');
+	  $content[$key]['priority'] = db_result($res_all,$i,'priority');
+	  $content[$key]['privacy'] = db_result($res_all,$i,'privacy');
+	  $content[$key]['submitted_by'] = db_result($res_all,$i,'submitted_by');
+	}
+      
+    }
 
-      $result[$art] = db_query($sql);
-      $rows[$art] = db_numrows($result[$art]);
+  # No item found? Exit here
+  if (!$item_exists)
+    {
+      print '<p class="warn">'.sprintf(_("%s: %s"), $title, _("None found")).'</p>';
+      return;
     }
 
   # Give back the HTML output, if we have some data.
-  if ($rows["support"] > 0 ||
-      $rows["bugs"] > 0 ||
-      $rows["task"] > 0 ||
-      $rows["patch"] > 0)
+  global $HTML;
+  print $HTML->box_top($title,'',1);
+
+  # Create a hash to avoid looking several times for the same
+  # info 
+  $dstatus = array();
+  $allowed_to_see = array();
+  $group_getname = array();
+
+  # Sort the content by key, which contain the date as first field
+  # (so order by date)
+  ksort($content);
+  unset($i);
+  
+  while (list($key,) = each($content))
     {
-
-      global $HTML;
-      print $HTML->box_top($title,'',1);
-
-      reset($artifacts);
-      while (list($num, $art) = each($artifacts))
+      $current_item_id = $content[$key]['item_id'];
+      $tracker = $content[$key]['tracker'];
+      $current_group_id = $content[$key]['group_id'];
+      $link_to_item = $GLOBALS['sys_home'].$tracker.'/?'.$current_item_id;
+	  
+      # Found out the status full text name:
+      # this is project specific. If there is no project setup for this
+      # then go to the default for the site
+      if (!array_key_exists($current_group_id.$tracker.$content[$key]['resolution_id'],
+			    $dstatus))
 	{
-	  for ($i=0; $i < $rows[$art]; $i++)
-	    {
-
-	      $link_to_item = $GLOBALS['sys_home'].$art.'/?func=detailitem&amp;item_id='. db_result($result[$art], $i, 'bug_id');
-
-	      $dstatus = db_result(db_query("SELECT value FROM ".$art."_field_value WHERE bug_field_id='108' AND (group_id='".db_result($result[$art], $i, 'group_id')."' OR group_id='100') AND value_id='".db_result($result[$art], $i, 'resolution_id')."' ORDER BY bug_fv_id DESC LIMIT 1"), 0, 'value');
-
-
-	      print '
-  <li class="'.get_priority_color(db_result($result[$art], $i, 'priority'), db_result($result[$art], $i, 'status_id')).'">';
-
-	      # Ability to remove a dependency is only given to technician
-	      # level members of a project.
-	      if ($dependson && $is_manager)
-		{
-		  print '<span class="trash"><a href="'.$PHP_SELF.'?func=delete_dependancy&amp;item_id='.$item_id.'&amp;item_depends_on='.db_result($result[$art], $i, 'bug_id').
-		    '&amp;item_depends_on_artifact='.$art.'">'.
-		    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Delete this dependancy?").'" class="icon" /></a></span>';
-		}
-
-              # Link to the item
-	      print '
-   	<a href="'.$link_to_item.'">';
-
-	      # Show the item type with an icon
-	      print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.utils_get_tracker_icon($art).'.png" class="icon" alt="'.$art.'" />';
-
-	      print utils_get_tracker_prefix($art).' #'.db_result($result[$art], $i, 'bug_id');
-
-	      print '</a> : <a href="'.$link_to_item.'">';
-
-              # Print summary only if the item is not private
-	      if (db_result($result, $i, 'privacy') == "2" &&
-		  !member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2') &&
-		  db_result($result[$art],$i,'submitted_by') != user_getid())
-		{ print _("---- Private ----");	}
-	      else
-		{ print db_result($result[$art], $i, 'summary'); }
-	      print '</a>';
-
-	      if (db_result($result[$art], $i, 'group_id') != $group_id)
-		{
-		  print ', '.group_getname(db_result($result[$art], $i, 'group_id'));
-		}
-
-              # Mention the status
-	      print '&nbsp;<font class="smaller">['.$dstatus.']</font>';
-
-	      print '</li>';
-	    }
+	  $dstatus[$current_group_id.$tracker.$content[$key]['resolution_id']] = 
+	    db_result(db_query("SELECT value FROM ".$tracker."_field_value WHERE bug_field_id='108' AND (group_id='".$group_id."' OR group_id='100') AND value_id='".$content[$key]['resolution_id']."' ORDER BY bug_fv_id DESC LIMIT 1"), 0, 'value');
 	}
-      print $HTML->box_bottom(1);
-
-     # Link to digest dependant items
-      if ($dependson)
+      $status = $dstatus[$current_group_id.$tracker.$content[$key]['resolution_id']];
+      
+      print '
+  <div class="'.get_priority_color($content[$key]['priority'], $content[$key]['status_id']).'">';
+	  
+      # Ability to remove a dependency is only given to technician
+      # level members of a project.
+      if ($dependson && $is_manager)
 	{
-	  reset($artifacts);
-	  while (list(,$art) = each($artifacts))
-	    {
-	      if ($rows[$art] > 0)
-		{
-                  switch ($art)
-                    {
-                      case "support":
-                        $linktitle = _("Digest support dependencies");
-                        break;
-                      case "bugs":
-                        $linktitle = _("Digest bug dependencies");
-                        break;
-                      case "task":
-                        $linktitle = _("Digest task dependencies");
-                        break;
-                      case "patch":
-                        $linktitle = _("Digest patch dependencies");
-                        break;
-                      # add an emergency fallback
-                      default:
-                        $linktitle = sprintf(_("Digest %s dependencies"), $art);
-                    }
-		  print utils_link($GLOBALS['sys_home'].$art.'/?group_id='.$group_id.'&amp;func=digestselectfield&amp;dependencies_of_item='.$item_id.'&amp;dependencies_of_tracker='.ARTIFACT, "[$linktitle]").' ';
-		}
-	    }
+	  print '<span class="trash"><a href="'.$_SERVER['PHP_SELF'].'?func=delete_dependancy&amp;item_id='.$item_id.'&amp;item_depends_on='.$current_item_id.
+	    '&amp;item_depends_on_artifact='.$tracker.'">'.
+	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Delete this dependancy?").'" class="icon" /></a></span>';
+	}
+	  
+      # Link to the item
+      print '
+   	<a href="'.$link_to_item.'" class="block">';
+      
+      # Show the item type with an icon
+      print '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.utils_get_tracker_icon($tracker).'.png" class="icon" alt="'.$tracker.'" /> ';
+      
+      # Print summary only if the item is not private
+      # Check privacy right (dont care about the tracker specific
+      # rights, being project member is enough)
+      if (!array_key_exists($current_group_id, $allowed_to_see))
+	{
+	  $allowed_to_see[$current_group_id] = member_check(0,$current_group_id,member_create_tracker_flag(ARTIFACT).'2');
+	  
+	}
+      
+      if ($content[$key]['privacy'] == "2" &&
+	  !$allowed_to_see[$current_group_id] &&
+	  $content[$key]['submitted_by'] != user_getid())
+	{ 
+	      print _("---- Private ----");		
 	}
-
-    }
-  else
-    {
-      print '<br /><font class="warn">';
-      if (!$dependson)
-	{ print _("No items are dependent on this one"); }
       else
-	{ print _("This item doesn't depend on any other items"); }
-      print '</font>';
-      print db_error();
+	{ 
+	  print $content[$key]['summary']; 
+	}
+	  
+       # Print group info if the item is from another group
+      unset($fromgroup);
+      if ($current_group_id != $group_id)
+	{
+	  if (!array_key_exists($current_group_id, $group_getname))
+	    {
+	      $group_getname[$current_group_id] = group_getname($content[$key]['group_id']).', ';
+	    }
+	  
+	  $fromgroup = $group_getname[$current_group_id];
+	}
+      
+      # Mention the status
+      print '&nbsp;<span class="xsmall">('.utils_get_tracker_prefix($tracker).' #'.$current_item_id.', '.$fromgroup.$status.')</span></a>';
+      print '</div>';
+      
+      $i++;
     }
+  print $HTML->box_bottom(1);
+
+      
+  # Add links to make digests
+  reset($artifacts);
+  print '<p><span class="preinput">'._("Digest:").'</span><br />&nbsp;&nbsp;&nbsp;';
+  unset($content);
+  while (list(, $tracker) = each($artifacts))
+    {
+      if ($item_exists_tracker[$tracker])
+	{
+	  switch ($tracker)
+	    {
+	    case "support":
+	      $linktitle = _("support dependencies");
+	      break;
+	    case "bugs":
+	      $linktitle = _("bug dependencies");
+	      break;
+	    case "task":
+	      $linktitle = _("task dependencies");
+	      break;
+	    case "patch":
+		  $linktitle = _("patch dependencies");
+		  break;
+	    default:
+	      $linktitle = sprintf(_("%s dependencies"), $tracker);
+	    }
+	  $content .= utils_link($GLOBALS['sys_home'].$tracker.'/?group_id='.$group_id.'&amp;func=digestselectfield&amp;dependencies_of_item='.$item_id.'&amp;dependencies_of_tracker='.ARTIFACT, "$linktitle", 'noprint').', ';
+	      
+	}
+    }
+  print rtrim($content, ', ').'.</p>';
+
 }
 
 
