@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: add.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: add.php 5945 2006-09-22 12:30:18Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
@@ -38,7 +38,15 @@ $max_size=40;
 # First display the message preamble
 $res_preamble = db_query("SELECT ".ARTIFACT."_preamble FROM groups WHERE group_id=$group_id");
 
-print utils_unconvert_htmlspecialchars(db_result($res_preamble,0,ARTIFACT.'_preamble'));
+$preamble = db_result($res_preamble,0,ARTIFACT.'_preamble');
+if ($preamble)
+{ 
+  # The h3 is necessary to keep the layout correct in every case
+  print '<h3>'._("Preamble").'</h3>'.
+    utils_unconvert_htmlspecialchars($preamble); 
+}
+
+
 print '<h3>'._("Details").'</h3>';
 
 # Beginning of the submission form with fixed fields
@@ -91,7 +99,7 @@ while ($field_name = trackers_list_all_fields())
 	  $mandatory_flag = trackers_data_mandatory_flag($field_name);
 	  if ($mandatory_flag == 3 || $mandatory_flag == 0)	    
 	    {
-	      $star = '<font class="warn"> *</font>';
+	      $star = '<span class="warn"> *</span>';
 	      $mandatory_flag = 0;
 	    }
 
@@ -175,18 +183,20 @@ while ($field_name = trackers_list_all_fields())
 
 
 print '</table>';
-print '<p class="warn"><font class="smaller">* '._("Mandatory Fields").'</font></p>';
+print '<p class="warn"><span class="smaller">* '._("Mandatory Fields").'</span></p>';
 	     
 #  possibility of attachment
 
 
 print '<p>&nbsp;</p>';
 print '<h3>'._("Attached Files").'</h3>';
-print '<font class="preinput"> '._("Attach File:").'</font><br />
-      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
+print sprintf(_("(Note: file size limit is set to %s kB, after insertion of the required escape characters.)"), $GLOBALS['sys_upload_max']);
+
+print '<span class="preinput"> '._("Attach File:").'</span><br />
+      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40" />
       <br />
-      <font class="preinput">'._("File Description:").'</font><br />
-      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
+      <span class="preinput">'._("File Description:").'</span><br />
+      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255" />
       </p><p>';
 	  
 
@@ -197,22 +207,22 @@ if (user_isloggedin())
   print '<p>&nbsp;</p>';
   print '<h3>'._("Mail Notification CC").'</h3>';
   
-  printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
+  print sprintf(_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
   
-  print '<p><font class="preinput">'
-    ._("Add CC:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40">&nbsp;&nbsp;&nbsp;
+  print '<p><span class="preinput">'
+    ._("Add Email Addresses (comma as separator):").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" />&nbsp;&nbsp;&nbsp;
         <br />
-        <font class="preinput">'
-    ._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255">';
+        <span class="preinput">'
+    ._("Comment:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" />';
   print '<p></p>';
 }
 
 
 print '<p>&nbsp;</p>';
-print '<p><font class="warn">'._("Did you check to see if this item has already been submitted?").'</font></p>';
-print '<p align="center">';
-print '<input type="submit" name="submit" class="bold" value="'._("Submit").'">';
-print '</p>';
+print '<p><span class="warn">'._("Did you check to see if this item has already been submitted?").'</span></p>';
+print '<div align="center">';
+print '<input type="submit" name="submit" class="bold" value="'._("Submit").'" />';
+print '</div>';
 print '</form>';
 
 
