@@ -2,11 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_usage.php 4868 2005-09-26 18:27:51Z yeupou $
+# $Id: field_usage.php 5964 2006-09-26 07:56:21Z yeupou $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -117,7 +117,7 @@ if ($group_id && user_ismember($group_id,'A')) {
       <h2>'
 	._("Field Label:").' ';
 
-      $closetag = ' &nbsp;&nbsp; <font class="smaller">('.utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group='.$group_name.'&amp;list_value=1&amp;field='.$field, _("Jump to this field values")).")</font></h2>\n";
+      $closetag = ' &nbsp;&nbsp; <span class="smaller">('.utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group='.$group_name.'&amp;list_value=1&amp;field='.$field, _("Jump to this field values")).")</span></h2>\n";
 
       # If it is a custom field let the user change the label and description
       if (trackers_data_is_custom($field))
@@ -324,8 +324,10 @@ if ($group_id && user_ismember($group_id,'A')) {
 ###########################################################################
       ## Show main page
 
-      trackers_header_admin(array ('title'=>_("Field Usage")));
+      trackers_header_admin(array ('title'=>_("Select Fields")));
 
+      # Add space to avoid overlaps
+      print '<br />';
 
       # Show all the fields currently available in the system
       $i=0;
@@ -371,7 +373,7 @@ if ($group_id && user_ismember($group_id,'A')) {
 	     trackers_data_get_label($field_name).'</a></td>'.
 	     "\n<td>".trackers_data_get_display_type_in_clear($field_name).'</td>'.
 	     "\n<td>".trackers_data_get_description($field_name).
-	     (($is_custom && $is_used) ? ' - <b>['._("Custom Field").']</b>':'').'</td>'.
+	     (($is_custom && $is_used) ? ' - <strong>['._("Custom Field").']</strong>':'').'</td>'.
 	     "\n<td align =\"center\">".$place_label.'</td>'.
 	     "\n<td align =\"center\">".$scope_label.'</td>'.
 	     "\n<td align =\"center\">".$status_label.'</td>';
@@ -410,17 +412,17 @@ if ($group_id && user_ismember($group_id,'A')) {
 	}
       else
 	{
-	  $hu= '<tr><td colspan="5"><center><b>---- '._("USED FIELDS").' ----</b></center></tr>'.$hu;
+	  $hu= '<tr><td colspan="5"><center><strong>---- '._("USED FIELDS").' ----</strong></center></tr>'.$hu;
 	  if ($in)
 	    {
 	      $hn = '<tr><td colspan="5"> &nbsp;</td></tr>'.
-		 '<tr><td colspan="5"><center><b>---- '._("UNUSED STANDARD FIELDS").' ----</b></center></tr>'.$hn;
+		 '<tr><td colspan="5"><center><strong>---- '._("UNUSED STANDARD FIELDS").' ----</strong></center></tr>'.$hn;
 	    }
 
 	  if ($inc)
 	    {
 	      $hnc = '<tr><td colspan="5"> &nbsp;</td></tr>'.
-		 '<tr><td colspan="5"><center><b>---- '._("UNUSED CUSTOM FIELDS").' ----</b></center></tr>'.$hnc;
+		 '<tr><td colspan="5"><center><strong>---- '._("UNUSED CUSTOM FIELDS").' ----</strong></center></tr>'.$hnc;
 	    }
 	}
       print $hdr.$hu.$hn.$hnc.'</table>';
