@@ -2,11 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_values.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: field_values.php 5964 2006-09-26 07:56:21Z yeupou $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
@@ -58,12 +58,14 @@ if ($group_id && user_ismember($group_id,'A'))
       if ($create_value)
 	{
 # A form was posted to update a field value
-	  if ($value)
+	  if ($title)
 	    {
-	      trackers_data_create_value($field,$group_id,
-					 htmlspecialchars($value),
+	      trackers_data_create_value($field,
+					 $group_id,
+					 htmlspecialchars($title),
 					 htmlspecialchars($description),
-					 $order_id,'A');
+					 $order_id,
+					 'A');
 	    }
 	  else
 	    {
@@ -74,12 +76,15 @@ if ($group_id && user_ismember($group_id,'A'))
       else if ($update_value)
 	{
 # A form was posted to update a field value
-	  if ($value)
+	  if ($title)
 	    {
-	      trackers_data_update_value($fv_id, $field, $group_id,
-					 htmlspecialchars($value),
+	      trackers_data_update_value($fv_id, 
+					 $field, 
+					 $group_id,
+					 htmlspecialchars($title),
 					 htmlspecialchars($description),
-					 $order_id,$status);
+					 $order_id,
+					 $status);
 	    }
 	  else
 	    {
@@ -189,11 +194,11 @@ if ($group_id && user_ismember($group_id,'A'))
 
 # Display the List of values for a given bug field
 
-      $hdr = sprintf(_("Manage Field Values for '%s'"),trackers_data_get_label($field));
+      $hdr = sprintf(_("Edit Field Values for '%s'"),trackers_data_get_label($field));
 
       trackers_header_admin(array ('title'=>$hdr));
 
-      print '<h2>'._("Field Label:").' '.trackers_data_get_label($field).' &nbsp;&nbsp; <font class="smaller">('.utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_usage.php?group='.$group_name.'&amp;update_field=1&amp;field='.$field, _("Jump to this field usage")).")</font></h2>\n";
+      print '<h2>'._("Field Label:").' '.trackers_data_get_label($field).' &nbsp;&nbsp; <span class="smaller">('.utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_usage.php?group='.$group_name.'&amp;update_field=1&amp;field='.$field, _("Jump to this field usage")).")</span></h2>\n";
 
 
 
@@ -270,7 +275,7 @@ if ($group_id && user_ismember($group_id,'A'))
 
 		  if ($status == 'H' && $usage > 0)
 		    {
-		      $html .= '<td align="center"><b class="warn">'.$usage.'</b></td>';
+		      $html .= '<td align="center"><strong class="warn">'.$usage.'</strong></td>';
 		    }
 		  else
 		    {
@@ -297,16 +302,16 @@ if ($group_id && user_ismember($group_id,'A'))
 # Display the list of values now
 	      if ($ia == 0)
 		{
-		  $hdr = '<p>'._("No Active value for this field. Create one or reactivate a hidden value (if any)").'</p>'.$hdr;
+		  $hdr = '<p>'._("No active value for this field. Create one or reactivate a hidden value (if any)").'</p>'.$hdr;
 		}
 	      else
 		{
-		  $ha = '<tr><td colspan="4"><center><b>'._("---- ACTIVE VALUES ----").'</b></center></tr>'.$ha;
+		  $ha = '<tr><td colspan="4" class="center"><strong>'._("---- ACTIVE VALUES ----").'</strong></tr>'.$ha;
 		}
 	      if ($ih)
 		{
 		  $hh = '<tr><td colspan="4"> &nbsp;</td></tr>'.
-		    '<tr><td colspan="4"><center><b>'._("---- HIDDEN VALUES ----").'</b></center></tr>'.$hh;
+		    '<tr><td colspan="4"><center><strong>'._("---- HIDDEN VALUES ----").'</strong></center></tr>'.$hh;
 		}
 
 	      print $hdr.$ha.$hh.'</table>';
@@ -340,23 +345,24 @@ if ($group_id && user_ismember($group_id,'A'))
       <input type="hidden" name="list_value" value="y" />
       <input type="hidden" name="field" value="'.$field.'" />
       <input type="hidden" name="group_id" value="'.$group_id.'" />
-      <span class="preinput">'._("Value:").' </span>
-      <input type="text" name="value" value="" size="30" maxlength="60"/>
+      <span class="preinput">'._("Value:").' </span>'.
+		form_input("text", "title", "", 'size="30" maxlength="60"').'
       &nbsp;&nbsp;
-      <span class="preinput">'._("Rank:").' </span>
-      <input type="text" name="order_id" value="" size="6" maxlength="6" />';
+      <span class="preinput">'._("Rank:").' </span>'.
+		form_input("text", "order_id", "", 'size="6" maxlength="6"');
 
 	      if (isset($none_rk))
 		{
-		  print "&nbsp;&nbsp;<b> (must be &gt; $none_rk)</b><br /></p>";
+		  print "&nbsp;&nbsp;<strong> (must be &gt; $none_rk)</strong><br /></p>";
 		}
 
 	      print '
       <p>
       <span class="preinput">'._("Description (optional):").'</span><br />
       <textarea name="description" rows="4" cols="65" wrap="hard"></textarea></p>
-      <p class="center">
-      <input type="submit" name="submit" value="'._("Update").'" /></p>
+      <div class="center">
+        <input type="submit" name="submit" value="'._("Update").'" />
+      </div>
       </form>';
 
 	    }
@@ -370,7 +376,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	    print '<form action="field_values_reset.php" method="post" class="center">';
 	    print '<input type="hidden" name="group_id" value="'.$group_id.'" />';
 	    print '<input type="hidden" name="field" value="'.$field.'" />';
-	    print '<input type="submit" name="submit" value="'._("Reset Values").'" /> ';
+	    print '<input type="submit" name="submit" value="'._("Reset values").'" /> ';
 	    print '</form>';
 
 
@@ -395,7 +401,7 @@ if ($group_id && user_ismember($group_id,'A'))
 		    if ($previous)
 		      { print ", "; }
 
-		    print '<font class="bold">'.$value.'</font> <font class="smaller">('.$order.', "'.$description.'")</font>';
+		    print '<strong>'.$value.'</strong> <span class="smaller">('.$order.', "'.$description.'")</span>';
 		    $previous = 1;
 		  }
 
@@ -503,7 +509,7 @@ if ($group_id && user_ismember($group_id,'A'))
 		    }
 		  else
 		    {
-		      print '<td  align="center">'._("* - Any").'</td>';
+		      print '<td align="center">'._("* - Any").'</td>';
 		    }
 
 		  print '<td align="center">'.$val_label[$transition['to_value_id']].'</td>'
@@ -601,7 +607,7 @@ if ($group_id && user_ismember($group_id,'A'))
 
 	  print $mlist.'</tr></table>';
 
-	  print '<p align="center"><input type="submit" name="submit" value="'._("Update Transition").'" /></p>
+	  print '<div align="center"><input type="submit" name="submit" value="'._("Update Transition").'" /></div>
                      </form>';
         }
       else
@@ -618,7 +624,7 @@ if ($group_id && user_ismember($group_id,'A'))
 # Show the form to update an existing field_value
 # Display the List of values for a given bug field
 
-      trackers_header_admin(array ('title'=>_("Update Field Values")));
+      trackers_header_admin(array ('title'=>_("Edit Fields Values")));
 
 # Get all attributes of this value
       $res = trackers_data_get_field_value($fv_id);
@@ -631,12 +637,11 @@ if ($group_id && user_ismember($group_id,'A'))
       <input type="hidden" name="field" value="'.$field.'" />
       <input type="hidden" name="group_id" value="'.$group_id.'" />
       <p><span class="preinput">'
-	._("Value:").' </span><br />
-      <input type="text" name="value" value="'.db_result($res,0,'value').'" size="30" maxlength="60" />
+	._("Value:").' </span><br />'.
+		form_input("text", "title", db_result($res,0,'value'), 'size="30" maxlength="60"').'
       &nbsp;&nbsp;
-      <span class="preinput">'
-	._("Rank:").' </span>
-      <input type="text" name="order_id" value="'.db_result($res,0,'order_id').'" size="6" maxlength="6"/>
+      <span class="preinput">'._("Rank:").' </span>'.
+		form_input("text", "order_id", db_result($res,0,'order_id'), 'size="6" maxlength="6"').'
       &nbsp;&nbsp;
       <span class="preinput">'
 	._("Status:").' </span>
@@ -658,8 +663,9 @@ if ($group_id && user_ismember($group_id,'A'))
           printf(_("If you hide this field value, the related items will have no value in the field '%s'."), $field).'</p>';
 	}
       print '
-      <p class="center">
-      <input type="submit" name="submit" value="'._("Submit").'" /></p>';
+      <div class="center">
+        <input type="submit" name="submit" value="'._("Submit").'" />
+      </p>';
 
 
     }
@@ -685,7 +691,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	  $title_arr[]=_("Title");
 	  $title_arr[]=_("Body (abstract)");
 	  $title_arr[]=_("Rank");
-	  $title_arr[]=_("Delete");
+	  $title_arr[]=_("Delete?");
 
 	  print html_build_list_table_top ($title_arr);
 
@@ -698,9 +704,9 @@ if ($group_id && user_ismember($group_id,'A'))
 		db_result($result, $i, 'bug_canned_id').'&amp;group_id='.$group_id.'">'.
 		db_result($result, $i, 'title').'</A></TD>'.
 		'<td>'.substr(db_result($result, $i, 'body'),0,360).'...'.
-		'<td>'.db_result($result, $i, 'order_id').'<td><a href="'.$PHP_SELF.'?delete_canned=1&amp;item_canned_id='.
-		db_result($result, $i, 'bug_canned_id').'&amp;group_id='.$group_id.'">
-		Delete</a></td></tr>';
+		'<td>'.db_result($result, $i, 'order_id').'<td class="center"><a href="'.$PHP_SELF.'?delete_canned=1&amp;item_canned_id='.
+		db_result($result, $i, 'bug_canned_id').'&amp;group_id='.$group_id.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" border="0" alt="'._("Delete this canned answer?").'" />
+		</a></td></tr>';
 	    }
 	  print '</table>';
 
@@ -716,21 +722,19 @@ if ($group_id && user_ismember($group_id,'A'))
       print '<h3>'._("Create a new response").'</h3>
      <p>
      '._("Creating generic quick responses can save a lot of time when giving common responses.").'</p>
-     <p>
      <form action="'.$PHP_SELF.'" method="post">
-     <input type="hidden" name="create_canned" value="y">
-     <input type="hidden" name="group_id" value="'.$group_id.'">
-     <input type="hidden" name="post_changes" value="y">
+     <input type="hidden" name="create_canned" value="y" />
+     <input type="hidden" name="group_id" value="'.$group_id.'" />
+     <input type="hidden" name="post_changes" value="y" />
      <span class="preinput">'._("Title:").'</span><br />
-     &nbsp;&nbsp;<input type="text" name="title" value="" size="50" maxlength="50"></p>
-     <p>
+     &nbsp;&nbsp;<input type="text" name="title" value="" size="50" maxlength="50" /><br />
      <span class="preinput">'._("Rank (useful in multiple canned responses):").'</span><br />
-     &nbsp;&nbsp;<input type="text" name="order_id" value="" maxlength="50"></p>
-     <p>
+     &nbsp;&nbsp;<input type="text" name="order_id" value="" maxlength="50" /><br />
      <span class="preinput">'._("Message Body:").'</span><br />
-     &nbsp;&nbsp;<textarea name="body" rows="20" cols="65" wrap="hard"></textarea></p>
-     <p class="center">
-     <input type="submit" name="submit" value="'._("Submit").'"></p>
+     &nbsp;&nbsp;<textarea name="body" rows="20" cols="65" wrap="hard"></textarea>
+     <div class="center">
+       <input type="submit" name="submit" value="'._("Submit").'" />
+     </div>
      </form>';
 
 
@@ -758,20 +762,21 @@ if ($group_id && user_ismember($group_id,'A'))
 	    ._("Creating generic messages can save you a lot of time when giving common responses.").'</p>
       <p>
       <form action="'.$PHP_SELF.'" method="post">
-      <input type="hidden" name="update_canned" value="y">
-      <input type="hidden" name="group_id" value="'.$group_id.'">
-      <input type="hidden" name="item_canned_id" value="'.$item_canned_id.'">
-      <input type="hidden" name="post_changes" value="y">
+      <input type="hidden" name="update_canned" value="y" />
+      <input type="hidden" name="group_id" value="'.$group_id.'" />
+      <input type="hidden" name="item_canned_id" value="'.$item_canned_id.'" />
+      <input type="hidden" name="post_changes" value="y" />
       <span class="preinput">'._("Title").':</span><br />
-      &nbsp;&nbsp;<input type="text" name="title" value="'.db_result($result,0,'title').'" size="50" maxlength="50"></p>
+      &nbsp;&nbsp;<input type="text" name="title" value="'.db_result($result,0,'title').'" size="50" maxlength="50" /></p>
       <p>
       <span class="preinput">'._("Rank").':</span><br />
-      &nbsp;&nbsp;<input type="text" name="order_id" value="'.db_result($result,0,'order_id').'"></p>
+      &nbsp;&nbsp;<input type="text" name="order_id" value="'.db_result($result,0,'order_id').'" /></p>
       <p>
       <span class="preinput">'._("Message Body:").'</span><br />
       &nbsp;&nbsp;<textarea name="body" rows="20" cols="65" wrap="hard">'.db_result($result,0,'body').'</textarea></p>
-      <p class="center">
-      <input type="submit" name="submit" value="Submit"></p>
+      <div class="center">
+        <input type="submit" name="submit" value="Submit" />
+      </div>
       </form>';
 
 	}
@@ -782,7 +787,10 @@ if ($group_id && user_ismember($group_id,'A'))
 
 ######## Complete list of fields
 
-      trackers_header_admin(array ('title'=>_("Field Values Management")));
+      trackers_header_admin(array ('title'=>_("Edit Fields Values")));
+
+      # Add space to avoid overlaps
+      print '<br />';
 
 # Loop through the list of all used fields that are project manageable
       $i=0;
@@ -815,7 +823,7 @@ if ($group_id && user_ismember($group_id,'A'))
 # Now the special canned response field
       print '<tr class="'. utils_get_alt_row_color($i) .'">';
       print "<td><a href=\"$PHP_SELF?group_id=$group_id&amp;create_canned=1\">"._("Canned Responses").'</a></td>';
-      print "\n<td>"._("Create or Change generic quick response messages for this issue tracker. Theses pre-written messages can then be used to quickly reply to item submission.").' </td>';
+      print "\n<td>"._("Create or change generic quick response messages for this issue tracker. These pre-written messages can then be used to quickly reply to item submissions.").' </td>';
       print "\n<td>"._("Project").'</td></tr>';
       print '</table>';
     }
