@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_values_transition-ofields-update.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: field_values_transition-ofields-update.php 5565 2006-08-14 09:18:01Z toddy $
 #
 #  Copyright      2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
@@ -106,8 +106,8 @@ if ($group_id && member_check(0,$group_id,'A'))
 
 # here begin the form  
 print '<form action="'.$PHP_SELF.'" method="post">
-<input type="hidden" name="group" value="'.$group_name.'">
-<input type="hidden" name="transition_id" value="'.$transition_id.'">
+<input type="hidden" name="group" value="'.$group_name.'" />
+<input type="hidden" name="transition_id" value="'.$transition_id.'" />
 ';
   
   $title_arr=array();
@@ -139,7 +139,7 @@ print '<form action="'.$PHP_SELF.'" method="post">
 	}
     }
   print '</table>
-<p align="center"><input type="submit" name="update" value="'._("Update").'"></p>
+<p align="center"><input type="submit" name="update" value="'._("Update").'" /></p>
 ';
 
   trackers_footer(array());
