@@ -2,11 +2,11 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: other_settings.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: other_settings.php 5900 2006-09-21 08:40:33Z yeupou $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -73,7 +73,7 @@ if ($submit)
 # Show main page #
 ##################
 
-trackers_header_admin(array ('title'=>_("Other Configuration Settings")));
+trackers_header_admin(array ('title'=>_("Other Settings")));
 
 $res_grp = db_query("SELECT * FROM groups WHERE group_id=$group_id");
 if (db_numrows($res_grp) < 1)
@@ -92,7 +92,7 @@ echo '<span class="preinput">'._("Introductory message showing at the top of the
 <br />('._("HTML tags allowed").')';
 
 echo '
-<p class="center"><input type="submit" name="submit" value="'._("Submit").'"></p>
+<div class="center"><input type="submit" name="submit" value="'._("Submit").'" /></div>
 </form>';
 
 trackers_footer(array());
