@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: browse.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: browse.php 5988 2006-09-27 16:32:30Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -351,8 +351,11 @@ else if ($set=='custom')
 }
 else
 {
-  # Open bugs - backwards compat can be removed 9/10
+  # We want to reset to all open items?
+  # Force the status_id to open, set nothing else, trash the prefes
   $url_params['status_id'][]=1;
+  user_unset_preference($preference_prefix.'_brow_cust'.$group_id);
+  
 }
 
 # ==================================================
@@ -419,6 +422,19 @@ else
 {
   $where = 'WHERE '.ARTIFACT.'.group_id='.$group_id.' ';
 }
+
+# If the user asked for more than 150 items to be shown but is not in printer
+# mode, restrict arbitrarily to 150: 
+# It would be too heavy on the database if this was done very frequently
+# and we already found some project giving direct links to 500 the browse
+# item page with 500 items shown by default.
+# Save the wanted number of chunksz, for later
+$wanted_chunksz = $chunksz;
+if ($chunksz > 150 && 
+    !$printer &&
+    !$digest)
+{ $chunksz = 150; }
+
 # No limit on sober output, we want all recipes
 unset($limit);
 if (!$sober)
@@ -578,7 +594,7 @@ while ($field = trackers_list_all_fields(cmp_place_query))
     }
 
   $labels .= '<td>'.trackers_field_label_display($field,$group_id,false,false).'</td>';
-  $boxes .= '<td><font class="smaller">';
+  $boxes .= '<td><span class="smaller">';
 
   if (trackers_data_is_select_box($field))
     {
@@ -614,7 +630,7 @@ while ($field = trackers_list_all_fields(cmp_place_query))
 	($printer ? $url_params[$field][0] : trackers_field_text($field,$url_params[$field][0],15,80)) ;
     }
 
-  $boxes .= "</font></td>\n";
+  $boxes .= "</span></td>\n";
 
   $ib++;
 
@@ -1087,8 +1103,19 @@ if (!$sober)
 {
   if (!$printer)
     {
-      $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), '<input type="text" name="chunksz" size="3" maxlength="5" '.
-					     'value="'.$chunksz.'" />').'</p>';
+      # I18N
+      # %s in this message is an input field, so it is impossible to use ngettext.
+      $form .= '<p class="smaller">'.sprintf(_("Show %s items at once."), 
+					     '<input type="text" name="chunksz" size="3" maxlength="5" value="'.$wanted_chunksz.'" />');
+      if ($wanted_chunksz != $chunksz)
+	{
+          # No use of ngettext as $chunkz will never be below 10, otherwise
+	  # it would mean that Savane would be modified to never list more
+          # than 10 items at once, which is almost nothing.
+	  $form .= ' <span class="warn">'.sprintf(_("Warning: only %s items can be shown at once, unless using Printer Version."), $chunksz).'</span>';
+	}
+      
+      $form .= '</p>';
     }
   else
     {
