@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: detail.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: detail.php 5963 2006-09-26 07:52:15Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
@@ -24,42 +24,42 @@
 # You should have received a copy of the GNU General Public License
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- 
+
 $sql="SELECT * FROM ".ARTIFACT." WHERE bug_id='$item_id' AND group_id='$group_id'";
 $fields_per_line=2;
 $max_size=40;
 
 $result=db_query($sql);
 
-if (db_numrows($result) > 0) 
+if (db_numrows($result) > 0)
 {
   # ################################ Start the form
-  
+
   # Defines the item name, converting bugs to bug.
   # (Ideally, the artifact bugs should be named bug)
   $item_name = utils_get_tracker_prefix(ARTIFACT)." #".$item_id;
   # Defines the item link
-  $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
+  $item_link = utils_link("?".$item_id, $item_name);
 
-  # Check whether this item is private or not. If it is private, show only to 
+  # Check whether this item is private or not. If it is private, show only to
   # the submitter
   unset($private_intro);
-  if (db_result($result,0,'privacy') == "2") 
+  if (db_result($result,0,'privacy') == "2")
     {
-      if (member_check_private(0, $group_id)) 
+      if (member_check_private(0, $group_id))
 	{
 	  # Nothing worth being mentioned
 	}
-      elseif (db_result($result,0,'submitted_by') == user_getid()) 
+      elseif (db_result($result,0,'submitted_by') == user_getid())
 	{
 	  $private_intro = _("This item is private. However, you are allowed to read it as you submitted it.");
 	}
-      else 
+      else
 	{
 	  exit_error(_("This item is private."));
 	}
     }
-  
+
   # Check if it is possible for the current user to post a comment. If not
   # add a message
   if (!group_restrictions_check($group_id, ARTIFACT, 2))
@@ -70,9 +70,9 @@ if (db_numrows($result) > 0)
 
   trackers_header(array ('title'=>$item_name.", ".utils_cutstring(db_result($result,0,'summary'))));
 
-  print $private_intro;
+  print '<p>'.$private_intro.'</p>';
 
-  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
+  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
 
   print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" name="item_form"');
   print form_input("hidden", "func", "postaddcomment");
@@ -94,7 +94,7 @@ if (db_numrows($result) > 0)
       <tr>
           <td class="preinput" width="15%">'._("Submitted by:").'&nbsp;</td>
           <td width="35%">'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
-          <td colspan="'.($fields_per_line).'" align="center"  width="50%" valign="top"><span class="noprint"><input class="bold" type="submit" name="submit" value="'._("Submit Changes").'" ></span></td>
+          <td colspan="'.($fields_per_line).'" align="center"  width="50%" valign="top"><span class="noprint">'.form_submit(_("Submit Changes").'" class="bold', "submit").'</span></td>
       </tr>
       <tr>
           <td class="preinput" width="15%">'._("Submitted on:").'&nbsp;</td>
@@ -103,7 +103,7 @@ if (db_numrows($result) > 0)
       </tr>';
   $votes = db_result($result,0,'vote');
 
-  if ($votes) 
+  if ($votes)
     {
       # display vote here if any, anything else is handled below
       print '
@@ -116,17 +116,17 @@ if (db_numrows($result) > 0)
 
     }
 
-  print '<tr><td colspan="'.($fields_per_line*2).'">&nbsp</td></tr>';
+  print '<tr><td colspan="'.($fields_per_line*2).'">&nbsp;</td></tr>';
 
   # Print special fields
   $i=0;
   $j=0;
-  while ( $field_name = trackers_list_all_fields() ) 
+  while ( $field_name = trackers_list_all_fields() )
     {
-      # if the field is a special field (except summary and details) 
+      # if the field is a special field (except summary and details)
       # or if not used by this project  then skip it.
       if ( (!trackers_data_is_special($field_name)  || $field_name=='summary' || $field_name=='details') &&
-	   trackers_data_is_used($field_name) ) 
+	   trackers_data_is_used($field_name) )
 	{
 
 	  # print the originator email field only if it was posted by
@@ -134,27 +134,27 @@ if (db_numrows($result) > 0)
 	  if ($field_name != 'originator_email' ||
 	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
 	    {
-	   
+
 	  # display the bug field
 	  # if field size is greatest than max_size chars then force it to
 	  # appear alone on a new line or it wont fit in the page
 	      $field_value = db_result($result,0,$field_name);
 	      list($sz,) = trackers_data_get_display_size($field_name);
 
-	      if ($field_name == 'details') 
+	      if ($field_name == 'details')
 		{ $field_value = utils_make_links($field_value); }
-	      
+
 	      $field_display = trackers_field_display($field_name,$group_id,$field_value,false,true,true);
 
 	      $label = trackers_field_label_display($field_name,$group_id,false,false);
 	      $value = trackers_field_display($field_name,$group_id,$field_value,false,false,true);
-	
+
               # Save the assigned to value for later.
 	      # Also make the user link for this same field
 	      if ($field_name == 'assigned_to')
-		{ 
-		  $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true); 
-		  
+		{
+		  $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true);
+
 		  $value = utils_user_link(user_getname($field_value), user_getrealname($field_value));
 		}
 	      # Details need a specific div
@@ -167,8 +167,8 @@ if (db_numrows($result) > 0)
               # Fields colors
 	      unset($field_class, $row_class);
 	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
-		{  
-                  # We highlight fields that were not properly/completely 
+		{
+                  # We highlight fields that were not properly/completely
 		  # filled.
 		  $field_class = ' class="highlight"';
 		}
@@ -179,12 +179,12 @@ if (db_numrows($result) > 0)
 		  #
 		  # We also use the boxitem background color only one time
 		  # out of two, to keep the page light
-		  $row_class = ' class="'.utils_altrow($j+1).'"'; 
+		  $row_class = ' class="'.utils_altrow($j+1).'"';
 		}
-		  
+
 	      if ($sz > $max_size)
 		{
-		  # Field getting one line for itself 
+		  # Field getting one line for itself
 
                   # Each time change the background color
 		  $j++;
@@ -198,15 +198,15 @@ if (db_numrows($result) > 0)
 		}
 	      else
 		{
-                  # Field getting half of a line for itself 
-		  
-		  
+                  # Field getting half of a line for itself
+
+
 		  if (!($i % $fields_per_line))
 		    {
 		      # Every one out of two, prepare the background color change.
    		      # We do that at this moment because we cannot be sure
  		      # there will be another field on this line.
-		      $j++;		  
+		      $j++;
 		    }
 
 		  print ($i % $fields_per_line ? '':"\n<tr".$row_class.">");
@@ -215,17 +215,17 @@ if (db_numrows($result) > 0)
 		  $i++;
 		  print ($i % $fields_per_line ? '':"\n</tr>");
 		}
-	      
-	      
-	      
-// 	      if ($sz > $max_size) 
+
+
+
+// 	      if ($sz > $max_size)
 // 		{
 // 		  print "\n<tr>".
 // 		    '<td valign="top" colspan="'.$fields_per_line.'">'.
 // 		    $field_display.'</td>'."\n</tr>";
 // 		  $i=0;
-// 		} 
-// 	      else 
+// 		}
+// 	      else
 // 		{
 // 		  print ($i % $fields_per_line ? '':"\n<tr>");
 // 		  print '<td valign="top">'.$field_display.'</td>';
@@ -235,14 +235,14 @@ if (db_numrows($result) > 0)
 	    }
         }
     }
-      
+
   print '</table>';
   print '<p>&nbsp;</p>';
 
   # ################################ Shortcuts
 
-  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
-  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';  
+  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> details:"), $item_link).'</h2>';
+  print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#cc">'._("Mail Notification Carbon-Copy List").'</a><br />';
@@ -254,24 +254,29 @@ if (db_numrows($result) > 0)
   print '<p>&nbsp;</p></div>';
 
 
-# ################################ Comments 
+# ################################ Comments
 
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3><div class="noprint">';
-  if (group_restrictions_check($group_id, ARTIFACT, 2)) 
+  if (group_restrictions_check($group_id, ARTIFACT, 2))
    {
-     printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
-	  "<font class=\"italic\">artifact #nnn</font>",
-	  "<font class=\"italic\">artifact</font>",
-	  "<font class=\"italic\">support, bug, task, patch, recipe, file</font>",
-	  "<font class=\"italic\">nnn</font>");
+     # I18N
+     # The sentence will be shown as follows:
+     # (Note: you can add pointers to other items by typing artifact #nnn
+     # where artifact is one of support, bug, task, patch, recipe, file
+     # and nnn is the item id number.)
+     printf (_("(Note: you can add pointers to other items by typing %s where %s is one of %s and %s is the item id number.)"),
+	  "<em>artifact #nnn</em>",
+	  "<em>artifact</em>",
+	  "<em>support, bug, task, patch, recipe, file</em>",
+	  "<em>nnn</em>");
      print '<p>&nbsp;&nbsp;&nbsp;';
      print trackers_field_textarea('comment','');
      print '<p>';
 
-     if (!user_isloggedin()) 
+     if (!user_isloggedin())
        {
          print '<h2 class="warn">'._("You are not logged in").'</h2><p>';
-         printf (_("Please %slog in,%s so followups can be emailed to you."),'<a href="'.$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($REQUEST_URI).'">','</a>');
+         printf (_("Please %slog in,%s so followups can be emailed to you."),'<a href="'.$GLOBALS['sys_home'].'account/login.php?uri='.urlencode($REQUEST_URI.$extraurl).'">','</a>');
          print '</p>';
        }
      print '<p>&nbsp;</p></div>';
@@ -284,22 +289,24 @@ if (db_numrows($result) > 0)
   # ################################ Attached Files
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
-  
-  if (group_restrictions_check($group_id, ARTIFACT, 2)) 
+
+  if (group_restrictions_check($group_id, ARTIFACT, 2))
    {
-     print '<p class="noprint"><font class="preinput"> '._("Attach File:").'</font><br />
-      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
+     print '<p class="noprint">';
+     print sprintf(_("(Note: file size limit is set to %s kB, after insertion of the required escape characters.)"), $GLOBALS['sys_upload_max']);
+     print '</p><p class="noprint"><span class="preinput"> '._("Attach File:").'</span><br />
+      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40" />
       <br />
-      <font class="preinput">'._("File Description:").'</font><br />
-      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
+      <span class="preinput">'._("File Description:").'</span><br />
+      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255" />
       </p><p>';
    }
-	  
+
   print show_item_attached_files($item_id,$group_id);
 
-  print '</p>&nbsp;<p>';
+  print '</p><p>&nbsp;</p>';
 
-  # ################################ Dependancies 
+  # ################################ Dependancies
 
   print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';
 
@@ -312,19 +319,19 @@ if (db_numrows($result) > 0)
   print '<p>&nbsp;</p>';
 
   # ################################ Mail notification
-  
+
   print '<h3>'.html_anchor(_("Mail Notification Carbon-Copy List"), "cc").'</h3>';
-  if (user_isloggedin()) 
+  if (user_isloggedin())
     {
       print '<p class="noprint">';
       printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
       print '</p><p class="noprint">
-	   <font class="preinput">'._("Add an email address that should receive carbon copies of updates of this item:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="30"><br />
-	   <font class="preinput">'._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255"><p>';
+	   <span class="preinput">'._("Add Email Addresses (comma as separator):").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="30" /><br />
+	   <span class="preinput">'._("Comment:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" /><p>';
     }
 
   show_item_cc_list($item_id, $group_id);
-    
+
   print '<p>&nbsp;</p>';
 
   # ################################ Votes
@@ -333,56 +340,54 @@ if (db_numrows($result) > 0)
     {
          print '<h3>'.html_anchor(_("Votes"), "votes").'</h3>';
       print '<p>'.sprintf(ngettext("There is %s vote so far.", "There are %s votes so far.", $votes), $votes).' '._("Votes easily highlight which items people would like to see resolved in priority, independantly of the priority of the item set by tracker managers.").'</p><p class="noprint">';
-       
+
       if (trackers_data_is_showed_on_add("vote") || member_check(user_getid(), $group_id))
         {
-           
-          if (user_isloggedin()) 
+
+          if (user_isloggedin())
             {
-            
+
               $votes_given = trackers_votes_user_giventoitem_count(user_getid(), ARTIFACT, $item_id);
               $votes_remaining = trackers_votes_user_remains_count(user_getid()) + $votes_given;
-              if (!$new_vote) 
+              if (!$new_vote)
                 { $new_vote = $votes_given; }
 
-              # Show how many vote he already gave and allows to remove 
+              # Show how many vote he already gave and allows to remove
               # or give more
               # votes.
               # The number of remaining points must be 100 - others votes
 
-              print '<font class="preinput">'._("Your vote:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
+              print '<span class="preinput">'._("Your vote:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
               print '</p>';
             }
           else
             {
-              print '<font class="warn">'._("Only logged-in users can vote.").'</font></p>';
+              print '<span class="warn">'._("Only logged-in users can vote.").'</span></p>';
             }
          }
        else
          {
-            print '<font class="warn">'._("Only project members can vote.").'</font></p>';       
+            print '<span class="warn">'._("Only project members can vote.").'</span></p>';
          }
-     
+
         print '<p>&nbsp;</p>';
     }
 
 
-  #  ################################  Submit 
+  #  ################################  Submit
 
-  print '<p align="center" class="noprint">
-	  <input type="submit" name="submit" class="bold" value="'._("Submit Changes").'">
-	  </form>
-	</p>';
+  print '<div align="center" class="noprint">'.form_submit(_("Submit Changes").'" class="bold', "submit").'</form></div>
+';
 
 
 
-  # History 
+  # History
 
   print '<p>&nbsp;</p><p>&nbsp;</p>';
   show_item_history($item_id,$group_id);
 
   trackers_footer(array());
-} 
+}
 else
 {
   exit_error(_("No item found with that id."));
