@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: download.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: download.php 5565 2006-08-14 09:18:01Z toddy $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -28,7 +28,6 @@ if (isset($item_file_id))
 {
   $file_id = $item_file_id;
 }
-#$file_id = safeinput($file_id);
 
 # check if the provided file_id is a valid numerical id
 if (!$file_id || !ctype_digit($file_id))
@@ -36,7 +35,7 @@ if (!$file_id || !ctype_digit($file_id))
   exit_missing_param();
 }
 
-$sql="SELECT description,file,filename,filesize,filetype FROM trackers_file WHERE file_id='$file_id' LIMIT 1";
+$sql="SELECT filename,filesize FROM trackers_file WHERE file_id='$file_id' LIMIT 1";
 $result=db_query($sql);
 
 if ($result && db_numrows($result) > 0) 
@@ -44,27 +43,23 @@ if ($result && db_numrows($result) > 0)
 
   if (db_result($result,0,'filesize') == 0) 
     {
-
-      exit_error('Error',_('nothing in here - File has a null size'));
-
+      
+      exit_error(_('Nothing in here - File has a null size'));
+      
     } 
   else 
     {
-	
-      # Download the patch with the correct filetype
-      header('Content-Type: '.db_result($result,0,'filetype'));
-      header('Content-Length: '.db_result($result,0,'filesize'));
-      header('Content-Disposition: filename='.db_result($result,0,'filename'));
-      header('Content-Description: '. db_result($result,0,'description'));
-
-      print db_result($result,0,'file');
+      # Redirect to an url that will pretend the file really exists with
+      # this name, so all browsers will propose its name as filename when
+      # saving it.
+      session_redirect($GLOBALS['sys_home'].'file/'.db_result($result,0,'filename').'?file_id='.$file_id);
 
     }
 
 } 
 else
 {
-  exit_error(_('Error'),_("Couldn't find attached file ")."(file #$file_id)");
+  exit_error(_("Couldn't find attached file")." (file #$file_id)");
 }
 
 ?>
