@@ -4,7 +4,7 @@
 #
 # $Id: download.php 4969 2005-11-15 10:32:43Z yeupou $
 #
-#  Copyright 2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2005-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -28,9 +28,12 @@ register_globals_off();
 # Yes, job and task can be considered as synonym. But as long as we havent
 # got such jobs completely managed via the task tracker, we need to avoid
 # confusions.
+$group_id = sane_all("group_id");
+$group = sane_all("group");
+$group_name = $group;
 
 if (!$group_id)
-{ exit_no_group(); }
+{ print exit_no_group(); }
 
 $project=project_get_object($group_id);
 
@@ -294,7 +297,7 @@ if (sane_all("update"))
       # First add an entry in trackers_export. Create the export with the
       # status invalid (I) so it wont be handled by the backend before
       # the next step is done on the frontend side
-      $sql = "INSERT INTO trackers_export (task_id, artifact, unix_group_name , user_name, sql, status, date, frequency_day, frequency_hour) VALUES ('0', '".ARTIFACT."', '".$group_name."', '".user_getname()."', '".$export_sql."', 'I', '".$timestamp."', '".$requested_day."', '".$requested_hour."')";
+      $sql = "INSERT INTO trackers_export (task_id, artifact, unix_group_name , user_name, sql, status, date, frequency_day, frequency_hour) VALUES ('0', '".ARTIFACT."', '".$group_name."', '".user_getname()."', '".addslashes($export_sql)."', 'I', '".$timestamp."', '".$requested_day."', '".$requested_hour."')";
       $result = db_query($sql);
       if (!$result)
 	{
@@ -311,7 +314,7 @@ if (sane_all("update"))
       # We could have imagined using a simple task to manage the whole
       # export stuff, but that would be probably overkill for now.
       # Maybe we wil reconsider this later.
-      session_redirect($GLOBALS['sys_home']."task/export-createtask.php?group=".rawurlencode($group_name)."&export_id=$insert_id&from=".ARTIFACT);
+      session_redirect($GLOBALS['sys_home']."task/export-createtask.php?group=".rawurlencode($group)."&export_id=$insert_id&from=".ARTIFACT);
 
     }
 
@@ -329,7 +332,7 @@ if (sane_all("update"))
 	{
 	  fb(sprintf(_("Export job #%s successfully removed"), $export_id));
 
-	  session_redirect($GLOBALS['sys_home']."task/export-updatetask.php?group=".rawurlencode($group_name)."&export_id=$export_id&task_id=$task_id&from=".ARTIFACT);
+	  session_redirect($GLOBALS['sys_home']."task/export-updatetask.php?group=".rawurlencode($group)."&export_id=$export_id&task_id=$task_id&from=".ARTIFACT);
 
 	}
       else
@@ -414,23 +417,15 @@ else
 	 $export_url = $GLOBALS['sys_https_url'].$GLOBALS['sys_home']."export/$group_name/".user_getname()."/".db_result($res_export, $i, 'export_id').".xml";
 	 print '<br />'.sprintf(_("URL: %s"), utils_link($export_url, $export_url));
 
-	 unset($type);
-	 switch (db_result($res_export, $i, 'artifact'))
-	   {
-	   case 'cookbook': $type = _("recipes"); break;
-	   case 'bugs': $type = _("bugs"); break;
-	   case 'task': $type = _("tasks"); break;
-	   case 'patch': $type = _("patches"); break;
-	   case 'support': $type = _("support requests"); break;
-	   }
+	 $type = utils_get_tracker_name(db_result($res_export, $i, 'artifact'));
 
 	 if (db_result($res_export, $i, 'frequency_day'))
 	   {
 	     # I18N
-	     # First string is the weekday, second the time of day
+	     # First string is 'every weekday', second the time of day
 	     # Example: "every Wednesday at 16:45 hours"
-	     $date = sprintf(_("every %s at %s hours"),
-			     calendar_day_name(db_result($res_export, $i, 'frequency_day')),
+	     $date = sprintf(_("%s at %s hours"),
+			     calendar_every_weekday_name(db_result($res_export, $i, 'frequency_day')),
 			     db_result($res_export, $i, 'frequency_hour'));
 	   }
 	 else
@@ -502,7 +497,7 @@ else
 
       ##
       # Display criteria
-      print form_header($PHP_SELF, '');
+      print form_header($_SERVER['PHP_SELF'], '');
       print form_input("hidden", "group", $group_name);
       print form_input("hidden", "create", "1");
       $current_time = time();
@@ -542,7 +537,7 @@ else
 	    }
 
 	  $labels .= '<td>'.trackers_field_label_display($field,$group_id,false,false).'</td>';
-	  $boxes .= '<td><font class="smaller">';
+	  $boxes .= '<td><span class="smaller">';
 
 	  if (trackers_data_is_select_box($field))
 	    {
@@ -589,7 +584,7 @@ else
 		($printer ? $url_params[$field][0] : trackers_field_text($field,$url_params[$field][0],15,80)) ;
 	    }
 
-	  $boxes .= "</font></td>\n";
+	  $boxes .= "</span></td>\n";
 
 	  $ib++;
 
@@ -673,16 +668,16 @@ else
       # priority is to have this working)
       $valid_days = array();
       for ($day = 1; $day <= 7; $day++)
-	{ $valid_days[] = calendar_day_name($day); }
+	{ $valid_days[] = calendar_every_weekday_name($day); }
 
       print '&nbsp;&nbsp;&nbsp;'.form_input("radio", "date_mainchoice", "frequent").' '.
         # I18N
-        # First string is the weekday, second the time of day,
+        # First string is 'every weekday', second the time of day,
 	# third is the timezone
         # Example: "every Wednesday at 16:45 hours GMT"
 	# Note that the GMT string may not be set, so dont put it beween 
 	# parenthesis.
-	sprintf(_("every %s at %s hours %s"),
+	sprintf(_("%s at %s hours %s"),
 		html_build_select_box_from_array($valid_days,
 						 "date_frequent_day"),
 		html_build_select_box_from_array($valid_hours,
