@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: index.php 5847 2006-09-19 12:28:38Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 #
@@ -27,10 +27,15 @@
 
 # This page does not give access to sober mode
 unset($sober);
-
-if ($group_id)
+ 
+# No group, no item was passed
+if (!$group_id)
 {
-# Initialize the global data structure before anything else
+  exit_no_group();
+}
+
+
+  # Initialize the global data structure before anything else
   trackers_init($group_id);
 
   $project=project_get_object($group_id);
@@ -122,21 +127,21 @@ if ($group_id)
 
         # Data control layer
 	$address = "";
-	$item_id=trackers_data_create_item($group_id,$vfl,$address);
+	$item_id = trackers_data_create_item($group_id,$vfl,$address);
 
 	if ($item_id)
 	  {
 
             # Attach new file if there is one
-	    if ($input_file != "none" && $input_file)
+	    if (sane_upload("input_file", "tmp_name"))
 	      {
 		$changed |= trackers_attach_file($item_id,
 						 $group_id,
-						 $input_file, 
-						 $input_file_name, # 4
-						 $input_file_type,
-						 $input_file_size, # 6
-						 $file_description,
+						 sane_upload("input_file", "tmp_name"),
+						 sane_upload("input_file", "name"),
+						 sane_upload("input_file", "type"),			 
+						 sane_upload("input_file", "size"),
+						 sane_post("file_description"),
 						 $changes);
 
 	      }
@@ -155,6 +160,14 @@ if ($group_id)
             # (if different from the submitter field, add address to CC list)"
 	    # Only apply this behavior if the field is present and used
 	    $oe_field_name = "originator_email";
+
+            $is_trackeradmin = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2');
+
+            # $oem=sane_post($oe_field_name);
+            # $valoem=validate_email(sane_post($oe_field_name));
+            # $used=trackers_data_is_used($oe_field_name);
+            # print "OEM=$oem VALID=$valoem USED=$used ITA=$is_trackeradmin \n";
+
 	    if (trackers_data_is_used($oe_field_name))
 	      {
 		if  (($is_trackeradmin && trackers_data_is_showed_on_add_members($oe_field_name)) ||
@@ -162,23 +175,24 @@ if ($group_id)
 		     (!user_isloggedin() && trackers_data_is_showed_on_add_nologin($oe_field_name))) 
 		  {
                     # cannot be a registered user
-		    if (validate_email(sane_post("oe_field_name")))
+		    if (validate_email(sane_post($oe_field_name)))
 		      {
                         # must be different from the submitter field
 			$user=user_getid();
 			$submitter_email = db_result(db_query("SELECT email FROM user WHERE user_id=".$user),
 						     0, 'email');
-			if (sane_post("oe_field_name") != $submitter_email)
+			if (sane_post($oe_field_name) != $submitter_email)
 			  {
 			    trackers_add_cc($item_id,
 					    $group_id,
-					    sane_post("oe_field_name"),
+					    sane_post($oe_field_name),
 					    "Originator Email",
 					    $changes);
 			  }
 		      }
 		    else
 		      {
+			$oem=sane_post($oe_field_name);
 			fb(_("Originator E-mail is not valid, thus was not added to the Carbon-Copy list."), 1);
 		      }
 		  }
@@ -196,8 +210,6 @@ if ($group_id)
 	    $address .= $additional_address;
 
 	    trackers_mail_followup($item_id, $address);
-	        
-	    form_clean($form_id);
 
 	  }
 	else
@@ -209,8 +221,15 @@ if ($group_id)
 	    # trackers_data_create_item.
 	    # Reshow the same page
 	    if ($previous_form_bad_fields)
-	      {
-		form_clean($form_id);
+	      {		   
+		# Mention if there was an attached file: we cannot
+		# pre-fill an HTML input file. 
+		if (sane_upload("input_file", "tmp_name"))
+		  {
+		    fb(sprintf(_("Warning: do not forget to re-attach your file '%s'"), sane_upload("input_file", "name", 1)));
+		    
+		  }
+		
 		include '../include/trackers_run/add.php';
 		break;
 	      }
@@ -249,11 +268,11 @@ if ($group_id)
 	      {
 		if ($depends_search)
 		  {
-		    fb(_("You provided search words to get a list of items this one may depends on. Below, in the section \"Dependencies\", you can now select the appropriate one(s) and submit the form."));
+		    fb(_("You provided search words to get a list of items this one may depend on. Below, in the section \"Dependencies\", you can now select the appropriate one(s) and submit the form."));
 		  }
 		if ($reassign_change_project_search)
 		  {
-		    fb(_("You provided search words to get a list of project this item should maybe reassigned to. Below, in the section \"Reassign this item\", you can now select the appropriate project and submit the form."));
+		    fb(_("You provided search words to get a list of projects this item should maybe reassigned to. Below, in the section \"Reassign this item\", you can now select the appropriate project and submit the form."));
 		  }
 		if ($canned_response == "!multiple!")
 		  {
@@ -297,21 +316,27 @@ if ($group_id)
 	    # the rest of the action normally done
 	    if (!$changed && $previous_form_bad_fields)
 	      {
-		form_clean($form_id);
+		# Mention if there was an attached file: we cannot
+		# pre-fill an HTML input file.
+		if (sane_upload("input_file", "tmp_name"))
+		  {
+		    fb(sprintf(_("Warning: do not forget to re-attach your file '%s'"), sane_upload("input_file", "name", 1)));
+		  }
+		    
 		include '../include/trackers_run/mod.php';
 		break;
 	      }
 
             # Attach new file if there is one
-	    if ($input_file != "none" && $input_file)
+	    if (sane_upload("input_file", "tmp_name"))
 	      {
 		$changed |= trackers_attach_file($item_id,
 						 $group_id,
-						 $input_file, 
-						 $input_file_name, # 4
-						 $input_file_type,
-						 $input_file_size, # 6
-						 $file_description,
+						 sane_upload("input_file", "tmp_name"),
+						 sane_upload("input_file", "name"),
+						 sane_upload("input_file", "type"),			 
+						 sane_upload("input_file", "size"),
+						 sane_post("file_description"),
 						 $changes);
 	      }
 
@@ -362,7 +387,6 @@ if ($group_id)
 					     sane_post("reassign_change_artifact"));
 	      }
 	    
-	    form_clean($form_id);    
 	    
             # show browse item page, unless the user want to get back
             # to the 
@@ -391,6 +415,21 @@ if ($group_id)
 	if (!form_check($form_id))
 	  { exit_error(_("Exiting")); }
 
+       # in principle the code below is useless since the item form wont
+       # be supplied to anonymous for private items. However it seems that 
+       # some people managed to get in in spite of that. 
+       # So, the following code is supposed to filter those out!
+        $sql="SELECT * FROM ".ARTIFACT." WHERE bug_id='$item_id' AND group_id='$group_id'";
+        $result=db_query($sql);
+	
+        if (db_numrows($result) > 0) 
+	  {
+	    if ((db_result($result,0,'privacy') == '2') && 
+		!member_check(user_getid(), $group_id)) 
+	      {
+		exit_error(_("Exiting [anonymous attempt to post to private item]")); 
+	      }
+	  }                                                                        
         # Add a new comment if there is one
 	if ($comment != '')
 	  {
@@ -401,22 +440,24 @@ if ($group_id)
 	    $changes['details']['add'] = stripslashes($comment);
 	    $changes['details']['type'] = 'None';
 	    $changed = true;
-
+	    
 	    fb(_("Comment added to item."));
 	  }
 	
         # Attach new file if there is one
-	if ($input_file != "none" && $input_file)
+	if (sane_upload("input_file", "tmp_name"))
 	  {
 	    $changed |= trackers_attach_file($item_id,
 					     $group_id,
-					     $input_file, 
-					     $input_file_name, # 4
-					     $input_file_type,
-					     $input_file_size, # 6
-					     $file_description,
+					     sane_upload("input_file", "tmp_name"),
+					     sane_upload("input_file", "name"),
+					     sane_upload("input_file", "type"),			 
+					     sane_upload("input_file", "size"),
+					     sane_post("file_description"),
 					     $changes);
-	  }
+
+	 }
+
         # Add new cc if any, only accepted from logged in users.
 	if ($add_cc && user_isloggedin())
 	  {
@@ -454,7 +495,6 @@ if ($group_id)
 	    trackers_mail_followup($item_id, $address, $changes);
 	  }
 	    
-	form_clean($form_id);
 	
 	include '../include/trackers_run/browse.php';
 	break;
@@ -583,9 +623,5 @@ if ($group_id)
 
     }
 
-}
-else
-{
-  exit_no_group();
-}
+
 ?>
