@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: mod.php 5945 2006-09-22 12:30:18Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -28,6 +28,10 @@
 # Need search functions.
 require_directory("search");
 
+# Get parameters
+$depends_search_only_artifact = sane_post('depends_search_only_artifact');
+$depends_search_only_project = sane_post('depends_search_only_project');
+
 $sql="SELECT * FROM ".ARTIFACT." WHERE bug_id='$item_id' AND group_id='$group_id'";
 $fields_per_line=2;
 $max_size=40;
@@ -41,7 +45,7 @@ if (db_numrows($result) > 0)
 # (Ideally, the artifact bugs should be named bug)
   $item_name = utils_get_tracker_prefix(ARTIFACT)." #".$item_id;
 # Defines the item link
-  $item_link = utils_link("?func=detailitem&item_id=".$item_id, $item_name);
+  $item_link = utils_link("?".$item_id, $item_name);
 
 # Check whether this item is private or not. If it is private, show only to
 # the submitter or to people that got the right to see private items
@@ -86,7 +90,7 @@ if (db_numrows($result) > 0)
 #  $task_details = db_result($result,0,'details')."\n\nSee ".ARTIFACT." #$item_id\nhttp://".
 #    $GLOBALS['sys_default_domain']."/bugs/?func=detailitem&item_id=$item_id&group_id=$group_id";
 #
-  
+
   trackers_header(array ('title'=>$item_name.", ".utils_cutstring(db_result($result,0,'summary')),
 #			 'create_task'=>'Create task',
 #			 'summary' => db_result($result,0,'summary'),
@@ -100,37 +104,37 @@ if (db_numrows($result) > 0)
 
   if (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'2', 1))
     {
-      print help(_("You are both technician and manager for this tracker."),
+      print '<p>'.help(_("You are both technician and manager for this tracker."),
 		 array(
 		       _("technician")=>_("can be assigned items, cannot change status or priority"),
 		       _("manager")=>_("fully manage the items")
-		       ));
+		       )).'</p>';
 
     }
   elseif (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1', 1))
     {
-      print help(_("You are technician for this tracker."),
+      print '<p>'.help(_("You are technician for this tracker."),
 		 array(
 		       _("technician")=>_("you can be assigned tracker's items, but you cannot reassign items, change priority nor open/close")
-		       ));
+		       )).'</p>';
     }
   elseif (member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'3', 1))
     {
-      print help(_("You are manager for this tracker."),
+      print '<p>'.help(_("You are manager for this tracker."),
 		 array(
 		       _("manager")=>_("you can fully manage the trackers items, including assigning items to technicians, reassign items over trackers and projects, changing priority and open/close items")
-		       ));
+		       )).'</p>';
     }
 
 # ################################ Start the form
-  
-  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
-  
+
+  print '<h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> overview:"), $item_link).' '.db_result($result,0,'summary').'</h2>';
+
   print form_header($PHP_SELF, $form_id, "post", 'enctype="multipart/form-data" name="item_form"');
   print form_input("hidden", "func", "postmoditem");
   print form_input("hidden", "group_id", $group_id);
   print form_input("hidden", "item_id", $item_id);
-  
+
   # Colspan explanation:
   #
   #  We want the following, twice much space for the value than for the label
@@ -139,23 +143,23 @@ if (db_numrows($result) > 0)
   #  | Label:  Value_____________________________ |
   #
   #  So we have 4 column large via colspan.
-  
+
   print '
 
   <table cellpadding="0" width="100%">
       <tr>
           <td class="preinput" width="15%">'._("Submitted by:").'&nbsp;</td>
           <td width="35%">'.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))).'</td>
-          <td colspan="'.($fields_per_line).'" width="50%" align="center" valign="top"><span class="noprint"><input class="bold" type="submit" name="submit" value="'._("Submit Changes and Browse Items").'" ></span></td>
+          <td colspan="'.($fields_per_line).'" width="50%" align="center" valign="top"><span class="noprint">'.form_submit(_("Submit Changes and Browse Items").'" class="bold', "submit").'</span></td>
       </tr>
       <tr>
           <td class="preinput" width="15%">'._("Submitted on:").'&nbsp;</td>
           <td width="35%">'.format_date($sys_datefmt,db_result($result,0,'date')).'</td>
-          <td colspan="'.($fields_per_line).'" width="50%" align="center" valign="top"><input class="noprint" type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></td>
+          <td colspan="'.($fields_per_line).'" width="50%" align="center" valign="top"><span class="noprint">'.form_submit(_("Submit Changes and Return to this Item"), "submitreturn").'</span></td>
       </tr>';
-  
+
   $votes = db_result($result,0,'vote');
-  if ($votes) 
+  if ($votes)
     {
       # display vote here if any, anything else is handled below
       print '
@@ -168,7 +172,7 @@ if (db_numrows($result) > 0)
 
     }
 
-  print '<tr><td colspan="'.($fields_per_line*2).'">&nbsp</td></tr>';
+  print '<tr><td colspan="'.($fields_per_line*2).'">&nbsp;</td></tr>';
 
   # Now display the variable part of the field list (depend on the project)
 
@@ -184,19 +188,19 @@ if (db_numrows($result) > 0)
       if ((!trackers_data_is_special($field_name) || $field_name=='summary' || $field_name=='details') &&
 	  trackers_data_is_used($field_name))
 	{
-	  
+
           # if the submitter was anonymous, print the originator email field
 	  if ($field_name != 'originator_email' ||
 	      ($field_name == 'originator_email' && db_result($result,0,'submitted_by') == '100'))
 	    {
-	      
+
              # display the bug field
              # if field size is greatest than max_size chars then force it to
              # appear alone on a new line or it wont fit in the page
 
              # Look for the field value in the database only if we missing
              # its values. If we already have a value, we are probably in
-             # step 2 of a search on item/group (dependancy, reassignation).
+             # step 2 of a search on item/group (dependency, reassignation).
 
              # If nocache is set, we were explicetely asked to rely only
              # on database content
@@ -215,10 +219,10 @@ if (db_numrows($result) > 0)
 
 	      list($sz,) = trackers_data_get_display_size($field_name);
 	      $label = trackers_field_label_display($field_name,$group_id,false,false);
-	      
+
               # Save the assigned to value for later
 	      if ($field_name == 'assigned_to')
-		{ $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true); 
+		{ $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true);
 		}
 
                # original submission field must be displayed read-only,
@@ -236,13 +240,13 @@ if (db_numrows($result) > 0)
 		{
 		  dbg("field_name:$field_name is read-only, mbcheck_is_not_manager:$mbcheck_is_not_manager");
 		  $value = utils_make_links(trackers_field_display($field_name,$group_id,$field_value,false,false,true));
-		  
+
 		  # Details need a specific div
 		  if ($field_name == 'details')
 		    {
 		      $value = '<div class="trackersoriginalsubmission">'.$value.'</div>';
 		    }
-		  
+
 		}
 	      else
 		{
@@ -253,9 +257,9 @@ if (db_numrows($result) > 0)
 	      unset($star);
 	      $mandatory_flag = trackers_data_mandatory_flag($field_name);
 	      if ($mandatory_flag == 3 ||
-		  ($mandatory_flag == 0 && 
+		  ($mandatory_flag == 0 &&
 		   trackers_check_is_shown_to_submitter($field_name, $group_id, db_result($result,0,'submitted_by'))))
-		  
+
 		{
 		  $star = '<span class="warn"> *</span>';
 		}
@@ -269,9 +273,9 @@ if (db_numrows($result) > 0)
 		  #
 		  # We also use the boxitem background color only one time
 		  # out of two, to keep the page light
-		  $row_class = ' class="'.utils_altrow($j+1).'"'; 
+		  $row_class = ' class="'.utils_altrow($j+1).'"';
 		}
-		 
+
 	      # If we are working on the cookbook, present checkboxes to
 	      # defines context before the summary line;
 	      if (CONTEXT == 'cookbook' && $field_name == 'summary')
@@ -279,16 +283,16 @@ if (db_numrows($result) > 0)
 		  cookbook_print_form();
 		}
 
-              # We highlight fields that were not properly/completely 
+              # We highlight fields that were not properly/completely
 	      # filled.
 	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
-		{  
+		{
 		  $field_class = ' class="highlight"';
 		}
 
 	      if ($sz > $max_size)
 		{
-		  # Field getting one line for itself 
+		  # Field getting one line for itself
 
                   # Each time prepare the change of the background color
 		  $j++;
@@ -302,15 +306,15 @@ if (db_numrows($result) > 0)
 		}
 	      else
 		{
-		  # Field getting half of a line for itself 
-		  
-		  
+		  # Field getting half of a line for itself
+
+
 		  if (!($i % $fields_per_line))
 		    {
 		      # Every one out of two, prepare the background color change.
    		      # We do that at this moment because we cannot be sure
  		      # there will be another field on this line.
-		      $j++;		  
+		      $j++;
 		    }
 
 		  print ($i % $fields_per_line ? '':"\n<tr".$row_class.">");
@@ -328,7 +332,7 @@ if (db_numrows($result) > 0)
 
 # ################################ Shortcuts
 
-  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<i>%s</i> details:"), $item_link).'</h2>';
+  print '<div class="noprint"><h2 class="'.utils_get_priority_color(db_result($result,0,'priority'), db_result($result,0,'status_id')).'">'.sprintf(_("<em>%s</em> details:"), $item_link).'</h2>';
   print '&nbsp;&nbsp;- <a href="#comments">'._("Follow-up Comments").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#attached">'._("Attached Files").'</a><br />';
   print '&nbsp;&nbsp;- <a href="#dependencies">'._("Dependencies").'</a><br />';
@@ -343,25 +347,25 @@ if (db_numrows($result) > 0)
     }
 
   print '&nbsp;&nbsp;- <a href="#history">'._("History").'</a><br />';
-  print '<p>&nbsp;<p></div>';
+  print '<p>&nbsp;</p></div>';
 
 # ################################ Comments
 
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
   print '<p class="noprint">';
-  printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"),
-	  "<span class=\"italic\">artifact #nnn</span>",
-	  "<span class=\"italic\">artifact</span>",
-	  "<span class=\"italic\">support, bug, task, recipe, patch, file</span>",
-	  "<span class=\"italic\">nnn</span>");
+  printf (_("(Note: you can add pointers to other items by typing %s where %s is one of %s and %s is the item id number.)"),
+	  "<em>artifact #nnn</em>",
+	  "<em>artifact</em>",
+	  "<em>support, bug, task, recipe, patch, file</em>",
+	  "<em>nnn</em>");
 
   print '<p class="noprint"><span class="preinput"> '._("Add a New Comment:").'</span><br />
       &nbsp;&nbsp;&nbsp;';
   print trackers_field_textarea('comment',  htmlspecialchars(stripslashes($comment)));
-  print '<p>';
+  print '</p>';
 
   print '<p class="noprint"><span class="preinput">';
-  print _("Comment Type:").'</span><br />&nbsp;&nbsp;&nbsp';
+  print _("Comment Type:").'</span><br />&nbsp;&nbsp;&nbsp;';
   print trackers_field_box('comment_type_id',$comment_type_id,$group_id,'',true,'None');
 
 
@@ -377,7 +381,7 @@ if (db_numrows($result) > 0)
 	  while ($canned = db_fetch_array($result_canned))
 	    {
 
-              print '<input type="checkbox" name="canned_response[]" value="'.$canned['bug_canned_id'].'" />'.$canned['title'];
+              print form_input("checkbox", "canned_response[]", $canned['bug_canned_id']).' '.$canned['title'];
               print '<br />&nbsp;&nbsp;&nbsp;';
 
 	    }
@@ -392,101 +396,118 @@ if (db_numrows($result) > 0)
     {
 
       print trackers_canned_response_box ($group_id,'canned_response');
-      print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">('._("Or define a new Canned Response").')</a>';
+      print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&amp;create_canned=1">('._("Or define a new Canned Response").')</a>';
 
     }
   print '<br /><span class="preinput">'._("Previous Comment Style:").'</span><br />&nbsp;&nbsp;&nbsp;';
-  if ($quotation_style != "quoted") 
+  if ($quotation_style != "quoted")
     {
-      print '<input type="submit" name="change_quotation_style" value="'._("Quoted, ready to be copied/pasted into your new comment").'" />';
+      print form_submit(_("Quoted, ready to be copied/pasted into your new comment"), "change_quotation_style");
     }
-  else 
+  else
     {
-      print '<input type="submit" name="change_quotation_style" value="'._("Verbatim, unmodified").'" />';
+      print form_submit(_("Verbatim, unmodified"), "change_quotation_style");
 
     }
 
-   
+
 
   print '</p>&nbsp;<p>';
 
   print show_item_details($item_id,$group_id,0,$item_assigned_to,$quotation_style);
 
-  print '</p>&nbsp;<p>';
+  print '</p><p>&nbsp;</p>';
 
 # ################################ Attached Files
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
-
-  print '<p class="noprint"><span class="preinput"> '._("Attach File:").'</span><br />
-      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
+  print '<p class="noprint">';
+  print sprintf(_("(Note: file size limit is set to %s kB, after insertion of the required escape characters.)"), $GLOBALS['sys_upload_max']);
+  print '</p><p class="noprint"><span class="preinput"> '._("Attach File:").'</span><br />
+      &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40" />
       <br />
       <span class="preinput">'._("File Description:").'</span><br />
-      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
+      &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255" />
       </p><p>';
 
   show_item_attached_files($item_id,$group_id);
 
-  print '</p>&nbsp;<p>';
+  print '</p><p>&nbsp;</p>';
 
 # ################################ Dependencies
 
   print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';
   print '<p class="noprint"><span class="preinput">';
   if (!$depends_search)
-    { print _("Search an item (to fill a dependancy against):"); }
+    { print _("Search an item (to fill a dependency against):"); }
   else
     {
 # Print a specific message if we are already at step 2 of filling
 # a dependency.
-      print _("New search, in case the previous one was not satisfactory (to fill a dependancy against):");
+      print _("New search, in case the previous one was not satisfactory (to fill a dependency against):");
     }
 
   print '</span><br />
-      &nbsp;&nbsp;&nbsp;<input type="text" name="depends_search" size="40" maxlength="255"><br />';
+      &nbsp;&nbsp;&nbsp;<input type="text" name="depends_search" size="40" maxlength="255" /><br />';
 
 
-  function specific_depends_on_artifact ($art, $content)
+  print '<span class="preinput">'._("Of:").'</span><br />';
+  print '&nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">';
+
+  # Generate the list of searchable trackers
+  $tracker_list = array(
+    'all'     => _("Any Tracker"),
+    'support' => _("The Support Tracker Only"),
+    'bugs'    => _("The Bug Tracker Only"),
+    'task'    => _("The Task Manager Only"),
+    'patch'   => _("The Patch Manager Only"),
+  );
+  foreach ($tracker_list as $option_value => $text)
     {
-# Function too trivial to generalized in usual includes.
-      if (ARTIFACT == $art)
-	{ $checked = ' selected="selected"'; }
-      print '<option value="'.$art.'"'.$checked.'>'.$content.'</option>';
-      unset($checked);
+      unset($selected);
+      if ($option_value == $depends_search_only_artifact)
+        { $selected = ' selected="selected"'; }
+      print "<option value=\"$option_value\"$selected>$text</option>\n";
     }
+  print "</select>\n";
 
-  print '<span class="preinput">'._("Of:").'</span><br />
-&nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">'
-    .'<option value="all">'._("any Trackers").'</option>';
-
-  specific_depends_on_artifact("support", _("the Support Tracker Only"));
-  specific_depends_on_artifact("bugs", _("the Bug Tracker Only"));
-  specific_depends_on_artifact("task", _("the Task Tracker Only"));
-  specific_depends_on_artifact("patch", _("the Patch Tracker Only"));
-
-  print '</select> ';
   print _("of");
-  print ' <select name="depends_search_only_project">'
-    .'<option value="any">'._("any Project").'</option>'
-    .'<option value="notany" selected="selected">'._("this Project Only").'</option>
+
+  print ' <select name="depends_search_only_project">';
+
+  # By default, search restricted to the project (lighter for the CPU, probably
+  # also more accurate)
+  unset($selected);
+  if ($depends_search_only_project == "any")
+    { $selected = ' selected="selected"'; }
+
+  print '<option value="any"'.$selected.'>'._("Any Project").'</option>';
+  
+  # Not yet a select? It means we are in the default case
+  if (!$selected)
+    { $selected = ' selected="selected"'; }
+  else
+    { unset($selected); }
+
+  print '<option value="notany"'.$selected.'>'._("This Project Only").'</option>
    </select>&nbsp;';
 
   if (!$depends_search)
     {
-      print '<input type="submit" name="submit" value="'._("Search").'">';
+      print form_submit(_("Search"), "submit");
     }
   else
     {
 # Print a specific message if we are already at step 2 of filling
 # a dependency.
-      print '<input type="submit" name="submit" value="'._("New search").'">';
+      print form_submit(_("New search"), "submit");
     }
 
 # Search results, if we are already at step 2 of filling
   if ($depends_search)
     {
       print '</p><p><span class="preinput">';
-      printf (_("Please select a dependancy to add in the result of your search of '%s' in the database:"), $depends_search);
+      printf (_("Please select a dependency to add in the result of your search of '%s' in the database:"), $depends_search);
       print '</span>';
 
       unset($success);
@@ -520,7 +541,7 @@ if (db_numrows($result) > 0)
 		  while (list($res_id, $res_summary, $res_date, $res_privacy, $res_submitter_id, $res_submitter_name, $res_group)  = db_fetch_array($result_search))
 		    {
 # Avoid item depending on itself.
-# Hide private items. For now, they are excluded for dependancies.
+# Hide private items. For now, they are excluded for dependencies.
 # We ll implement that later if necessary.
 		      if ($res_privacy == 2)
 			{ continue; }
@@ -529,8 +550,8 @@ if (db_numrows($result) > 0)
 # Right now only print id, summary and group.
 # We may change that depending on users feedback.
 			  print '<br />';
-			  print '&nbsp;&nbsp;&nbsp;<input type="checkbox" name="dependent_on_'.$tracker.'[]" value="'.$res_id.'">'.$tracker.' #'.$res_id._(': ').$res_summary;
-			  print ', '._("group").' '.group_getname($res_group); 
+			  print '&nbsp;&nbsp;&nbsp;'.form_input("checkbox", "dependent_on_".$tracker."[]", $res_id).' '.$tracker.' #'.$res_id._(': ').$res_summary;
+			  print ', '._("group").' '.group_getname($res_group);
 			}
 		    }
 		}
@@ -564,7 +585,7 @@ if (db_numrows($result) > 0)
   printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
 
   print '</p><p class="noprint"><span class="preinput">'
-    ._("Add an email address that should receive carbon copies of updates of this item:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'">&nbsp;&nbsp;&nbsp;
+    ._("Add Email Addresses (comma as separator):").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'" />&nbsp;&nbsp;&nbsp;
         <br />
         <span class="preinput">'
     ._("Comment:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'" />';
@@ -579,14 +600,14 @@ if (db_numrows($result) > 0)
     {
       $votes_given = trackers_votes_user_giventoitem_count(user_getid(), ARTIFACT, $item_id);
       $votes_remaining = trackers_votes_user_remains_count(user_getid()) + $votes_given;
-      if (!$new_vote) 
+      if (!$new_vote)
         { $new_vote = $votes_given; }
 
 # ATM, the mod page is only for technicians/manager. They always have
 # the right to vote, as they are project member anyway.
       print '<h3>'.html_anchor(_("Votes"), "votes").'</h3>';
-      print '<p>'.sprintf(ngettext("There is %s vote so far.", "There are %s votes so far.", $votes), $votes).' '._("Votes easily highlight which items people would like to see resolved in priority, independantly of the priority of the item set by tracker managers.").'</p><p class="noprint">';
-       
+      print '<p>'.sprintf(ngettext("There is %s vote so far.", "There are %s votes so far.", $votes), $votes).' '._("Votes easily highlight which items people would like to see resolved in priority, independently of the priority of the item set by tracker managers.").'</p><p class="noprint">';
+
 # Show how many vote he already gave and allows to remove or give more
 # votes.
 # The number of remaining points must be 100 - others votes
@@ -631,16 +652,16 @@ if (db_numrows($result) > 0)
 	  print _("New search, in case the previous one was not satisfactory (to reassign the item to another project):");
 	}
 
-      print '</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255">';
+      print '</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255" />';
       if (!$reassign_change_project_search)
 	{
-	  print ' <input type="submit" name="submit" value="'._("Search").'">';
+	  print form_submit(_("Search"), "submit");
 	}
       else
 	{
 # Print a specific message if we are already at step 2 of filling
 # a ressign.
-	  print ' <input type="submit" name="submit" value="'._("New search").'">';
+	  print form_submit(_("New search"), "submit");
 	}
 
 
@@ -653,7 +674,7 @@ if (db_numrows($result) > 0)
 
 # Print a null-option, someone may change his mine without having
 # to use the back button of his browser.
-	  print '<br />&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="0" checked> '._("Do not reassign to another project.");
+	  print '<br />&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="0" checked="checked" /> '._("Do not reassign to another project.");
 
 	  unset($success);
 	  $result_search = search_run($reassign_change_project_search, "soft", 0);
@@ -668,7 +689,7 @@ if (db_numrows($result) > 0)
 		  if ($res_unix_group_name != $group_name)
 		    {
 		      print '<br />';
-		      print '&nbsp;&nbsp;&nbsp;<input type="radio" name="reassign_change_project" value="'.$res_unix_group_name.'"> ['.$res_unix_group_name.', #'.$res_group_id.'] '.$res_group_name;
+		      print '&nbsp;&nbsp;&nbsp;'.form_input("radio", "reassign_change_project", $res_unix_group_name).' ['.$res_unix_group_name.', #'.$res_group_id.'] '.$res_group_name;
 		    }
 		}
 	    }
@@ -689,7 +710,7 @@ if (db_numrows($result) > 0)
 
   print '<p>&nbsp;</p>';
 
-  print '<p align="center" class="noprint"><input type="submit" name="submit" class="bold" value="'._("Submit Changes and Browse Items").'"> <input type="submit" name="submitreturn" value="'._("Submit Changes and Return to this Item").'"></form><p>';
+  print '<div align="center" class="noprint">'.form_submit(_("Submit Changes and Browse Items").'" class="bold', "submit").' '.form_submit(_("Submit Changes and Return to this Item"), "submitreturn").'</form></div>';
 
 
 # ################################ History
