@@ -2,9 +2,10 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: search.php 4754 2005-09-14 11:02:00Z yeupou $
+# $Id: search.php 5565 2006-08-14 09:18:01Z toddy $
 #
-#  Copyright 2003 (c) Frederik Orellana <frederik.orellana@cern.ch>
+#  Copyright 2003-2006 (c) Frederik Orellana <frederik.orellana--cern.ch>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -22,8 +23,10 @@
 
 
 trackers_header(array ('title'=>_("Search")));
-print _("With the following form, you can perform a search in the items summaries and details. If you need to perform more complex search, use the query forms in Browse items page");
-print html_show_boxoptions($title, search_box('', ARTIFACT, 45));
+print '<p>'._("With the following form, you can perform a search in the items summaries and details. If you need to perform more complex search, use the query forms in Browse items page").'</p>';
+# this must not be in a boxoption, it is no option, it is the only purpose of
+# the page
+print '<p>'.search_box('', ARTIFACT, 45).'</p>';
 trackers_footer(array());
 
 ?>
