@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: user.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: user.php 5571 2006-08-14 19:13:27Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -213,13 +213,13 @@ function user_getname($user_id=0, $getrealname=0)
 	      if ($getrealname == 0)
 		{
 		  #invalid user - store and return
-		  $USER_NAMES["user_$user_id"]="<B>Invalid User ID</B>";
+		  $USER_NAMES["user_$user_id"]="<strong>Invalid User ID</strong>";
 		  return $USER_NAMES["user_$user_id"];
 		}
 	      else
 		{
 		  #invalid user - store and return
-		  $USER_NAMES["realname_$user_id"]="<B>Invalid User ID</B>";
+		  $USER_NAMES["realname_$user_id"]="<strong>Invalid User ID</strong>";
 		  return $USER_NAMES["realname_$user_id"];
 		}
 	    }
