@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: utils.php 5950 2006-09-22 13:27:39Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>,
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>,
 #                          Tobias Toedter <t.toedter--gmx.net>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -67,7 +67,7 @@ function utils_makereal ($data, $string="%PROJECT", $replacement=0)
 }
 
 # Add unavailable css class to a link if required
-function utils_link ($url, $title, $defaultclass=0, $available=1, $help=0)
+function utils_link ($url, $title, $defaultclass=0, $available=1, $help=0, $extra='')
 {
   if (!$available)
     { $defaultclass = 'unavailable'; }
@@ -78,10 +78,102 @@ function utils_link ($url, $title, $defaultclass=0, $available=1, $help=0)
     { $return .= ' class="'.$defaultclass.'"'; }
   if ($help)
     { $return .= ' title="'.$help.'"'; }
+  if ($extra)
+    { $return .= ' '.$extra; }
   $return .= '>'.$title.'</a>';
   return $return;
 }
 
+# make an clean email link depending on the authentification level of the user
+function utils_email ($address, $nohtml=0)
+{
+  if (user_isloggedin())
+    {
+      if ($nohtml)
+	{ return $address; }
+
+      # Remove eventual extra white spaces
+      $address = trim($address);
+
+      # If we have < > in the address, only this content must go in the 
+      # mailto
+      unset($realaddress);
+      if (preg_match("/\<([\w\d\-\@\.]*)\>/", $address, $matches))
+	{ $realaddress = $matches[1]; }
+
+      # We have a user name
+      if (!strpos($address, "@"))
+	{
+          # We found a real address and it is a user login
+	  if ($realaddress && user_exists(user_getid($realaddress)))
+	    {
+	      return utils_user_link($realaddress, user_getrealname(user_getid($realaddress)));  
+	    }
+	  
+          # The whole address is a user login
+	  if (user_exists(user_getid($address)))
+	    {
+	      return utils_user_link($address, user_getrealname(user_getid($address)));
+	    }
+
+	  # No @, no real addresses and spaces inside? Looks like someone
+	  # forgot commas
+	  if (!$realaddress && strpos($address, " "))
+	    {
+	      return htmlspecialchars($address).
+		' <span class="warn">'._("(seems invalid and will probably be ignored)").'</span>';
+	    }
+
+	  # No @ but and not a login? P
+	  return htmlspecialchars($address).
+	    ' <span class="warn">'.sprintf(_("(unknown to Savane, will fail if not valid at %s)"), $GLOBALS['sys_mail_domain']).'</span>';
+
+	}
+
+      # If we are here, it means that we have an @ in the address,
+      # Even if the address is invalid, the system is likely to try to
+      # send the mail, and we have no way to know if the address is valid.
+      # We will only do a check on the address syntax
+
+      # We found a real address that is syntexically correct
+      if ($realaddress && validate_email($realaddress))
+	{
+	  return '<a href="mailto:'.htmlspecialchars($realaddress).'">'.htmlspecialchars($address).'</a>';
+
+	}
+
+      # We found real address but it does not seem correct
+      # Print a warning
+      if ($realaddress)
+	{
+	  return htmlspecialchars($address).
+	    ' <span class="warn">'._("(seems invalid and will probably be ignored)").'</span>';
+	}
+
+
+      # We have no realaddress found, only one string that is an address
+      if (validate_email($address))
+	{
+	  return '<a href="mailto:'.htmlspecialchars($address).'">'.htmlspecialchars($address).'</a>';
+	}
+       
+      # Nothing was valid, print a warning
+      return htmlspecialchars($address).
+	' <span class="warn">'._("(seems invalid and will probably be ignored)").'</span>';
+
+    }
+  else
+    {
+      if ($nohtml)
+	{ return _("-unavailable-"); }
+
+      return utils_help(_("-unavailable-"),
+			_("This information is not provided to anonymous users"),
+			1);
+    }
+
+}
+
 # Found out if a string is pure ASCII or not
 function utils_is_ascii ($string)
 {
@@ -211,20 +303,23 @@ function utils_read_file($filename)
 function utils_filesize($filename, $file_size=0)
 {
   # If file size is defined, assume that we just want an unit conversion.
+
+  # Round results: Savane is not a math software
+
   if (!$file_size)
     {   $file_size = filesize($filename); }
 
   if ($file_size >= 1048576)
     {
-      $file_size = round($file_size / 1048576 * 100) / 100 . _("MB");
+      $file_size = sprintf(_("%sMB"), round($file_size / 1048576));
     }
   elseif ($file_size >= 1024)
     {
-      $file_size = round($file_size / 1024 * 100) / 100 . _("KB");
+      $file_size = sprintf(_("%skB"), round($file_size / 1024));
     }
   else
     {
-      $file_size = $file_size . _("B");
+      $file_size = sprintf(_("%sB"), round($file_size));
     }
 
   return $file_size;
@@ -320,14 +415,6 @@ function utils_unconvert_htmlspecialchars($string)
     }
 }
 
-# transform homepage url in the same way than $project->getUrl("homepage")
-# we shouldnt use this but $project->getUrl("homepage")
-function utils_gethomepage($html_cvs, $isgnu, $unix_group_name)
-{
-  print 'This function should not be used, report it to savannah-hackers@gnu.org';
-
-}
-
 function utils_remove_htmlheader($string)
 {
   $string = eregi_replace('(^.*<html[^>]*>.*<body[^>]*>)|(</body[^>]*>.*</html[^>]*>.*$)', '', $string);
@@ -611,6 +698,38 @@ function utils_get_tracker_prefix ($tracker)
 }
 
 
+
+##
+# Returns the translation for the given tracker, if available.
+# Otherwise, return the input string.
+#
+function utils_get_tracker_name($tracker)
+{
+  switch ($tracker)
+    {
+      case 'bugs':
+        $name = _('bugs');
+        break;
+      case 'cookbook':
+        $name = _('recipes');
+        break;
+      case 'patch':
+        $name = _('patches');
+        break;
+      case 'support':
+        $name = _('support requests');
+        break;
+      case 'task':
+        $name = _('tasks');
+        break;
+      default:
+        $name = $tracker;
+    }
+  return $name;
+}
+
+
+
 function utils_get_priority_color ($index, $closed="")
 {
   global $bgpri;
@@ -821,11 +940,7 @@ function utils_graph_it ($name_string,$value_string,$title)
 		<!-- end outer graph table -->';
 }
 
-# deprecated name
-function ShowResultSet($result,$title="Untitled",$linkify=false)
-{
-  utils_show_result_set($result,$title,$linkify);
-}
+
 
 function utils_show_result_set ($result,$title="Untitled",$linkify=false)
 {
@@ -840,34 +955,28 @@ function utils_show_result_set ($result,$title="Untitled",$linkify=false)
     $rows  =  db_numrows($result);
     $cols  =  db_numfields($result);
 
-    print '
-			<TABLE BORDER="0" WIDTH="100%">';
-
-    /*  Create the title  */
-
-    print '
-		<TR BGCOLOR="'.$HTML->COLOR_HTMLBOX_TITLE.'">
-		<TD COLSPAN="'.$cols.'"><B><FONT COLOR="'. $HTML->FONTCOLOR_HTMLBOX_TITLE .'">'.$title.'</FONT></B></TD></TR>';
+    # Show title
+    print "<h4>$title</h4>\n";
+    print '<table border="0" width="100%" summary="'.$title.'">'."\n";
 
     /*  Create  the  headers  */
-    print '
-			<tr>';
+    print "<tr>\n";
     for ($i=0; $i < $cols; $i++)
       {
-	print '<td><B>'.db_fieldname($result,  $i).'</B></TD>';
+	print '<th>'.db_fieldname($result,  $i)."</th>\n";
       }
-    print '</tr>';
+    print "</tr>\n";
 
     /*  Create the rows  */
     for ($j = 0; $j < $rows; $j++)
       {
-	print '<TR class="'. html_get_alt_row_color($j) .'">';
+	print '<tr class="'. html_get_alt_row_color($j) .'">';
 	for ($i = 0; $i < $cols; $i++)
 	  {
 	    if ($linkify && $i == 0)
 	      {
-		$link = '<A HREF="'.$PHP_SELF.'?';
-		$linkend = '</A>';
+		$link = '<a href="'.$PHP_SELF.'?';
+		$linkend = '</a>';
 		if ($linkify == "bug_cat")
 		  {
 		    $link .= 'group_id='.$group_id.'&bug_cat_mod=y&bug_cat_id='.db_result($result, $j, 'bug_category_id').'">';
@@ -898,7 +1007,7 @@ function utils_show_result_set ($result,$title="Untitled",$linkify=false)
 	  }
 	print '</tr>';
       }
-    print '</table>';
+    print "</table>\n";
   }
   else
     {
@@ -910,7 +1019,14 @@ function utils_show_result_set ($result,$title="Untitled",$linkify=false)
 # Clean up email address (remove spaces...) and put to lower case
 function utils_cleanup_emails ($addresses)
 {
-  return strtolower(preg_replace("/\s/","", $addresses));
+  # It was previously removing white spaces:
+  # This is a bad idea. If we want to remove spaces, we have to check user
+  # input, not to corrupt manually entered data afterwards.
+  # If we allow white space to be entered, then we have to keep them.
+  # For instance, if we allow to be entered: Robert <bob@bla.org>
+  # it must not end up in Robert<bob@bla.org>.
+  # (And we want to allow CC to be added like in a mail client).
+  return strtolower($addresses);
 }
 
 # Clean up email address (remove spaces...) and add @... if it is a simple
@@ -921,19 +1037,10 @@ function utils_normalize_email ($address)
   if (validate_email($address))
     return $address;
   else
-    return $address."@".$GLOBALS['sys_default_domain'];
+    return $address."@".$GLOBALS['sys_mail_domain'];
 }
 
 
-function utils_antispam_email ($address)
-{
-  if (user_isloggedin())
-    { return $address; }
-  $fakemail = preg_replace("/\\@/",' '._("--AT--").' ', $address);
-  $fakemail = preg_replace("/\\./",' '._("--DOT--").' ', $fakemail);
-  return $fakemail;
-}
-
 # Clean up email address (remove spaces...) and split comma separated emails
 function utils_split_emails($addresses)
 {
@@ -945,6 +1052,7 @@ function utils_split_emails($addresses)
 # Email Verification
 function validate_email ($address)
 {
+  # FIXME: this allows in domain names some characters that are not allowed
   return (ereg('^[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+'. '@'. '[-!#$%&\'*+\\/0-9=?A-Z^_`a-z{|}~]+\.' . '[-!#$%&\'*+\\./0-9=?A-Z^_`a-z{|}~]+$', $address));
 }
 
@@ -1073,25 +1181,33 @@ function fb_dbsuccess()
   fb(_("Database successfully updated"));
 }
 
+
 # alias
-function util_help ($text, $explanation_array)
+function utils_help ($text, $explanation_array, $noarray=0)
 {
-  help($text, $explanation_array);
+  return help($text, $explanation_array, $noarray);
 }
 
 # print help about a word
 #   $text  is the sentence where ballons are
 #   $explanation_array is the table word->explanation, must be in the
 #   array syntax.
-function help ($text, $explanation_array)
+function help ($text, $explanation_array, $noarray=0)
 {
-  while (list($word,$explanation) = each($explanation_array))
+  if (!$noarray)
     {
-      $text = str_replace($word,
-			     '<font class="help" title="'.$explanation.'">'.$word.'</font>',
-			     $text);
+      while (list($word,$explanation) = each($explanation_array))
+	{
+	  $text = str_replace($word,
+			      '<span class="help" title="'.$explanation.'">'.$word.'</span>',
+			      $text);
+	}
+      return $text;
     }
-  return $text;
+
+
+  return '<span class="help" title="'.$explanation_array.'">'.$text.'</span>';
+
 }
 
 ?>
