@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 4817 2005-09-20 09:22:59Z yeupou $
+# $Id: index.php 5843 2006-09-19 09:13:28Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #
@@ -29,14 +29,13 @@ require_directory("news");
 require_directory("stats");
 require "include/features_boxes.php";
 
-
 # Check if the PHP Frontend is acceptably configured.
 # Do progressive little checks, to avoid creating to much extra load.
 # Not gettextized for now, already lot of more important strings to 
 # translate.
 if (!$GLOBALS['sys_unix_group_name'])
 {
-  fb(_("Configuration serious problem: sys_unix_group_name is not set"), 1);   
+  fb(_("Serious configuration problem: sys_unix_group_name is not set"), 1);
   if (!$GLOBALS['sys_name'])
     {
       fb(_("Configuration problem: sys_name is not set"), 1); 
@@ -73,7 +72,7 @@ if ($conn && !$sys_group_id)
   fb(sprintf(_("By the way, have you checked the setup of your web server at %s?"), 'http://127.0.0.1'.$GLOBALS['sys_home'].'testconfig.php'), 1);
 }
 
-$HTML->header(array('title'=>_("Welcome")));
+$HTML->header(array('title'=>_("Welcome"), 'notopmenu'=>1));
 html_feedback_top();
 
 print '
@@ -84,16 +83,7 @@ print '
    </div><!-- end indexright --> 
 ';
 
-# yeupou--gnu.org 2004-09-01:
-# Dirty hack to get rid of serious issue in MSIE handling of 
-# CSS.
-# Please, do never add such an hack in savane somewhere else without
-# talking about it on savane-dev.
-unset($style);
-if (strpos($_SERVER['HTTP_USER_AGENT'], "MSIE"))
-{ $style = ' style="width: 100%;"'; }
-
-print '   <div class="indexcenter"'.$style.'>';
+print '   <div class="indexcenter">';
 
 utils_get_content("homepage");
 
