@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: majordomo_interface.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: majordomo_interface.php 5549 2006-08-10 22:23:34Z toddy $
 #
 #  Copyright 2002-2003 (c) CERN LCG/SPI.
 # 
@@ -135,23 +135,23 @@ if (user_isloggedin())
 	<INPUT TYPE="HIDDEN" NAME="list" VALUE="<?php print $list_name ?>">
 	<INPUT TYPE="HIDDEN" NAME="mailserver" VALUE="<?php print $mailserver ?>">
 
-	<B>Your Email Address:</B><BR>
-	<B><?php print user_getemail(user_getid())?></B>
+	<strong>Your Email Address:</strong><BR>
+	<strong><?php print user_getemail(user_getid())?></strong>
 	<INPUT TYPE="HIDDEN" NAME="user_email" VALUE="<?php print user_getemail(user_getid()); ?>">
 	<P>
-	<B>Your Name:</B><BR>
-	<B><?php 
+	<strong>Your Name:</strong><BR>
+	<strong><?php 
 
 	$my_name=user_getrealname(user_getid());
 
-	print $my_name; ?></B>
+	print $my_name; ?></strong>
 	<INPUT TYPE="HIDDEN" NAME="name" VALUE="<?php print $my_name; ?>">
 	<P>
-        <B>Mail Server Address:</B> <?php print $mailserver ?>
+        <strong>Mail Server Address:</strong> <?php print $mailserver ?>
 	<P>
-	<B>Subject:</B> <?php print $subject ?> <BR>
+	<strong>Subject:</strong> <?php print $subject ?> <BR>
 	<P>
-	<B>Message:</B><BR>
+	<strong>Message:</strong><BR>
 	<TEXTAREA NAME="body" ROWS="15" COLS="60" WRAP="HARD"><?php print $body ?></TEXTAREA>
 	<P>
 	<CENTER>
@@ -172,7 +172,7 @@ else
         <P>
         You can subscribe to this list without logging in by
         sending an email message containing the following
-        lines to the mail server <B>'.$mailserver.'</B>
+        lines to the mail server <strong>'.$mailserver.'</strong>
         (you will have to replace the generic address with your email
         address).';
 
