@@ -170,7 +170,7 @@ print '
 
 for ($i=0; $i<$num_roles; $i++)
 {
-  print '<td align="center" width="10%" class="boxtitle"><font class="smaller">'.$arr_roles[$i]['short_description']."</font></td>\n";
+  print '<td align="center" width="10%" class="boxtitle"><span class="smaller">'.$arr_roles[$i]['short_description']."</span></td>\n";
 }
 print "</tr>\n";
 
