@@ -27,11 +27,25 @@
 require "../../include/pre.php";
 require_directory("people");
 
+register_globals_off();
+
 if ( ! user_isloggedin()) 
 {
   exit_not_logged_in();
 }
 
+$update_profile = sane_post("update_profile");
+$people_resume = sane_post("people_resume");
+$people_view_skills = sane_post("people_view_skills");
+
+$add_to_skill_inventory = sane_post("add_to_skill_inventory");
+$update_skill_inventory = sane_post("update_skill_inventory");
+$delete_from_skill_inventory = sane_post("delete_from_skill_inventory");
+$skill_id = sane_post("skill_id");
+$skill_level_id = sane_post("skill_level_id");
+$skill_year_id = sane_post("skill_year_id");
+$skill_inventory_id = sane_post("skill_inventory_id");
+
 if ($update_profile) 
 {
   if (!$people_resume) 
@@ -111,41 +125,46 @@ else if ($update_skill_inventory)
 
 # Fill in the info to edit the resume
 
-site_user_header(array('title'=>_("Edit Your Resume"),'context'=>'account'));
+site_user_header(array('title'=>_("Edit Your Resume & Skills"),'context'=>'account'));
+
+
+print '<p>'._("Details about your experience and skills may be of interest to others users or visitors.").'</p>';
+
 
 
 $sql="SELECT * FROM user WHERE user_id='". user_getid() ."'";
 $result=db_query($sql);
-if (!$result || db_numrows($result) < 1) {
-  fb(_("No such user"),1);
+if (!$result || db_numrows($result) < 1) 
+{
+  exit_error(_("No such user"));
 }
 
 # we get site-specific content
-utils_get_content("people/editprofile");
+utils_get_content("people/editresume");
 
 
 $viewableoptions = array("0" => _("No"),
 			 "1" => _("Yes"));
 
-print '<form action="'.$PHP_SELF.'" method="post"><p>'
-._("The following option determines if others can see your resume online. If they can't, you can still enter your skills, and search for matching jobs.").'</p>'
+
+
+print '<form action="'.$PHP_SELF.'" method="post">'
 .'<h3>'._("Publicly Viewable").'</h3>'
-.'<span class="preinput">'._("Do you want your resume to be publicly viewable:").'</span>&nbsp;&nbsp;'
+.'<span class="preinput">'._("Do you want your resume to be activated:").'</span>&nbsp;&nbsp;'
 .html_build_select_box_from_array(array("0" => _("No"),"1" => _("Yes")),
 				  'people_view_skills',
 				  db_result($result,0,'people_view_skills'));
 
-print '<h3>'._("Resume / Description of Experience").'</h3>
+print '<h3>'._("Resume - Description of Experience").'</h3>
 	<textarea name="people_resume" rows="15" cols="60" wrap="soft">'. db_result($result,0,'people_resume') .'</textarea>';
 
-print '<p class="center"><input type="submit" name="update_profile" value="'._("Update Profile").'"></p></form>';
+print '<br /><br /><div class="center"><input type="submit" name="update_profile" value="'._("Update Profile").'" /></div></form>';
 
 print '<h3>'._("Skills").'</h3>';
 
 #now show the list of desired skills
-people_edit_skill_inventory( user_getid() );
+people_edit_skill_inventory(user_getid());
 
-  #echo '<form action="'.$GLOBALS['sys_home'].'people/" method="POST"><input type="SUBMIT" name="SUBMIT" value="'._("Finished").'"></form></p>'; 
 
 site_user_footer(array());
 
