@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: confirm.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: confirm.php 5550 2006-08-10 22:28:44Z toddy $
 #
 #  Copyright 2001 (c) Jaime Villate <villate@gnu.org>
 #
@@ -41,15 +41,15 @@ of project <?php echo $group_name; ?>?.
 <?php
 
 echo '<form action="rmproject.php" method="get">';
-echo '<input type="hidden" name="group_id" value="'.$group_id.'">';
+echo '<input type="hidden" name="group_id" value="'.$group_id.'" />';
 ?>
-<input type="submit" value="Yes">
+<input type="submit" value="Yes" />
 </form>
 </td><td>
 
 <!-- No, don't remove user from project -->
 <form action="index.php" method="get">
-<input type="submit" value="No!">
+<input type="submit" value="No!" />
 </form>
 
 </td></tr></table>
