@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: groups.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: groups.php 6037 2006-10-02 15:02:14Z yeupou $
 #
-#  Copyright 2003-2005 (c) Frederik Orellana <frederik.orellana--cern.ch>
+#  Copyright 2003-2006 (c) Frederik Orellana <frederik.orellana--cern.ch>
 #                          Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -131,7 +131,7 @@ if (sane_post("update"))
   if (!form_check($form_id))
     { return 0; }
   unset($form_cleaned_already);
-  
+
   while ($val = db_fetch_array($result_upd))
     {
       if(sane_post("form_groups_$val[group_id]"))
@@ -149,7 +149,7 @@ if (sane_post("update"))
 		{
 		  if(member_add($row_user[user_id], $val[group_id], 'P'))
 		    {
-		      send_pending_user_email($val[group_id], $row_user[user_id], $GLOBALS["form_message"]);
+		      send_pending_user_email($val[group_id], $row_user[user_id], sane_post("form_message"));
 		      if (!$form_cleaned_already)
 			{
 			  form_clean($form_id);
@@ -226,10 +226,10 @@ if ($rows_without_history != $rows)
 # page header
 site_user_header(array('context'=>'mygroups'));
 
+print '<p>'._("Here is the list of groups you are member of, plus a form which allows you to ask for inclusion in a Group. Clicking on the trash permits you to quit a project.").'</p>';
 
 # we get site-specific content
 utils_get_content("my/groups");
-print "<br /><br />\n\n";
 
 
 ################ RIGHT PART ###########################
@@ -243,7 +243,7 @@ $rows_w=db_numrows($result_w);
 
 if (!$result_w || $rows_w < 1)
     {
-      print _("I am not watching any partners.");
+      print '<p>'._("You are not watching any partners.").'</p>';
       print '<p>'._("Watching a partner (receiving a copy of all notifications sent to them) permits you to be their backup when they are away from the office, or to review all their activities on a project.");
       print '</p><p>'._("To watch someone, click 'Watch partner' in the project memberlist page. You need to be member of that project yourself.");
       print '<br />';
@@ -254,10 +254,10 @@ else
       print '<table>';
       for ($i=0; $i<$rows_w; $i++)
 	{
-	  print '<tr class="'.utils_get_alt_row_color($i).'"><td width="99%"><font class="bold">'.
+	  print '<tr class="'.utils_get_alt_row_color($i).'"><td width="99%"><strong>'.
 	    utils_user_link(user_getname(db_result($result_w, $i, 'watchee_id')), user_getrealname(db_result($result_w, $i, 'watchee_id'))).
-	    '</font> <font class="smaller">['.group_getname(db_result($result_w, $i, 'group_id')).']'.
-	    '</font>';
+	    '</strong> <span class="smaller">['.group_getname(db_result($result_w, $i, 'group_id')).']'.
+	    '</span>';
 
 	  print '</td>'.
 	    '<td><a href="'.$_SERVER['PHP_SELF'].'?func=delwatchee&amp;group_id='.db_result($result_w,$i,'group_id').'&amp;watchee_id='.db_result($result_w, $i, 'watchee_id').
@@ -272,7 +272,7 @@ else
   $arr_watchers = array();
   while ($row_watcher = db_fetch_array($result_w))
     {
-      $watchers .= utils_user_link(user_getname($row_watcher['user_id']), user_getrealname($row_watcher['user_id'])).'</font> <font class="smaller">['.group_getname($row_watcher['group_id']).']</font>, ';
+      $watchers .= utils_user_link(user_getname($row_watcher['user_id']), user_getrealname($row_watcher['user_id'])).' <span class="smaller">['.group_getname($row_watcher['group_id']).']</span>, ';
     }
 
   if ($watchers)
@@ -295,13 +295,13 @@ print "<br />\n";
 
 print $HTML->box_top(_("Request for Inclusion"),'',1);
 
-print '<div class="boxitem">'._("Search a Group")."\n";
-  print '<p class="text">';
+print '<div class="boxitem">'."\n";
+  print '<p>';
 print _("If there is a project - or several - you would like to be member of, to be able to fully contribute, it is possible to search for the names in the whole group database with the following search tool. A list of groups will be generated, depending on the word(s) typed in this form.")."\n";
 print '</p>';
 
 print '
-	<form action="'.$PHP_SELF.'#searchgroup" method="post">
+	<form action="'.$_SERVER["PHP_SELF"].'#searchgroup" method="post">
 	<input type="hidden" name="action" value="searchgroup" />
         <input type="text" size="35" name="words" value="'.$words.'" /><br />
 	<br /><br />
@@ -314,22 +314,23 @@ print '
 $words = sane_all("words");
 if ($words)
 {
-  # Avoid to big search by asking for more than 3 characters.
-  if (strlen($words) > 3)
+  # Avoid to big search by asking for more than 1 characters.
+  # Restricting to more than 2 chars skips a great deal of project names (eg: gv, gdb)
+  if (strlen($words) > 1)
     {
       $result_search = search_run($words, "soft", 0);
     }
   else
     { $result_search = 0; }
 
-  print '<div class="boxitemalt"><a name="searchgroup"></a>'._("Requesting Inclusion");
-  print '<p class="text">';
+  print '<div class="boxitemalt"><a name="searchgroup"></a>';
+  print '<p>';
   print _("Below is the result of the research in the groups database.");
   print '</p>';
 
   if (db_numrows($result_search) < 1)
     {
-      print '<br /><span class="warn">'._("None found. Please note that only search words of more than three characters are valid.").'</span><br />';
+      print '<p class="warn">'._("None found. Please note that only search words of more than one character are valid.").'</p>';
     }
   else
     {
@@ -338,8 +339,8 @@ if ($words)
       # box or click on the link?).
       # This tool is to search groups for inclusion, not to look around
       # to get information about groups.
-      print '<p class="text">';
-      print _("To request inclusion in one or several groups, check the correspondant boxes, write a meaningful message for the project administrator who will approve or disapprove the request, and submit the form.");
+      print '<p>';
+      print _("To request inclusion in one or several groups, check the correspondent boxes, write a meaningful message for the project administrator who will approve or disapprove the request, and submit the form.");
 
       print '</p>'.form_header($PHP_SELF);
 
@@ -403,10 +404,10 @@ else
 	    {
 	      # If the group history is flawed (site install problem), the
 	      # date may be unavailable
-	      $content .= '<font class="smaller">'.
+	      $content .= '<span class="smaller">'.
 	        sprintf(_("Member since %s"),
 	        format_date('', $date_joined)).
-	        '</font>';
+	        '</span>';
 	    }
 	  $content .= '</li>';
 	  $exists=1;
@@ -450,10 +451,10 @@ else
 	    {
 	      # If the group history is flawed (site install problem), the
 	      # date may be unavailable
-	      $content .= '<font class="smaller">'.
+	      $content .= '<span class="smaller">'.
 	        sprintf(_("Member since %s"),
 	        format_date('', $date_joined)).
-	        '</font>';
+	        '</span>';
 	    }
 	  $content .= '</li>';
 	  $exists=1;
