@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: index.php 5999 2006-09-28 12:56:20Z yeupou $
 #
-#  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2005-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,11 +26,16 @@ require_directory("trackers");
 
 register_globals_off();
 
+global $item_data, $group_data;
+$item_data = array();
+$group_data = array();
+
+
 if (user_isloggedin())
 {
   site_user_header(array('context'=>'my'));
 
-  print _("Here's a list of recent items (< 16 days) we think you should have a look at. These are items recently posted on trackers you manage that are still unassigned, items that have been recently assigned to you (by someone else) or news posted on a project you are member of.");
+  print '<p>'._("Here's a list of recent items (< 16 days) we think you should have a look at. These are items recently posted on trackers you manage that are still unassigned or assigned to you and news posted on a project you are member of.").'</p>';
 
   # Get the list of projects the user is member of
 
@@ -58,8 +63,6 @@ if (user_isloggedin())
 	  $usergroups[$unixname] = db_result($result,$j,'group_name');
 	  $usergroups_groupid[$unixname] = db_result($result,$j,'group_id');
 	}
-      reset($usergroups);
-      reset($usergroups_groupid);
     }
   else
     { $nogroups = 1; }
@@ -114,7 +117,7 @@ if (user_isloggedin())
 	  print '<div class="'.utils_get_alt_row_color($j).'">';
 	  print '<a href="'.$GLOBALS[sys_home].'news/approve.php?approve=1&amp;id='.db_result($result, $j, 'id').'&amp;group='.group_getunixname(db_result($result, $j, 'group_id')).'">'.db_result($result, $j, 'summary').'</a><br />';
 	  # FIXME: num. of new comments?
-	  print '<font class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</font>';
+	  print '<span class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</span>';
 	  print '</div>';
 	}
       print '</div>';
@@ -143,7 +146,7 @@ if (user_isloggedin())
 	  print '<div class="'.utils_get_alt_row_color($j).'">';
 	  print '<a href="'.$GLOBALS[sys_home].'forum/forum.php?forum_id='.db_result($result, $j, 'forum_id').'">'.db_result($result, $j, 'summary').'</a><br />';
 	  # FIXME: num. of new comments?
-	  print '<font class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</font>';
+	  print '<span class="smaller">'.sprintf(_("Project %s, %s"), group_getname(db_result($result, $j, 'group_id')), format_date($sys_datefmt,db_result($result,$j,'date'))).'</span>';
 	  print '</div>';
 	}
     }
@@ -161,15 +164,15 @@ if (user_isloggedin())
   #### New items to assign
   # shown only if the user is tracker manager somewhere and if any item found
   # (so the title is included in the function called)
-  reset($usergroups);
-  reset($usergroups_groupid);
-  my_incoming_unassigned_item_list($usergroups);
+
+  print '<br /><div class="box"><div class="boxtitle">'._("New and Unassigned Items").'</div>';
+  print my_item_list("unassigned");
+  print '</div>';
+
 
   ### Items newly assigned (not necessarily new items)
-  print '<br /><div class="box"><div class="boxtitle">'._("Newly Assigned Items").'</div>';
-  reset($usergroups);
-  reset($usergroups_groupid);
-  my_incoming_assigned_item_list($usergroups);
+  print '<br /><div class="box"><div class="boxtitle">'._("New and Assigned Items").'</div>';
+  print my_item_list("newlyassigned");
   print '</div>';
 
   print html_splitpage(3);
