@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: items.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: items.php 6003 2006-09-28 18:39:09Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
-#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -29,8 +29,43 @@ require_directory("trackers");
 
 register_globals_off();
 
+global $item_data, $group_data;
+$item_data = array();
+$group_data = array();
+
 if (user_isloggedin())
 {
+
+
+  # Get the list of projects the user is member of
+  $sql = "SELECT groups.group_name,"
+    . "groups.group_id,"
+    . "groups.unix_group_name,"
+    . "groups.status "
+    . "FROM groups,user_group "
+    . "WHERE groups.group_id=user_group.group_id "
+    . "AND user_group.user_id='".user_getid()."' "
+    . "AND groups.status='A' "
+    . "GROUP BY groups.unix_group_name "
+    . "ORDER BY groups.unix_group_name";
+
+  $result = db_query($sql);
+  $rows = db_numrows($result);
+  $usergroups = array();
+  $usergroups_groupid = array();
+  if ($result && $rows > 0)
+    {
+      for ($j=0; $j<$rows; $j++)
+	{
+	  unset($nogroups);
+	  $unixname = db_result($result,$j,'unix_group_name');
+	  $usergroups[$unixname] = db_result($result,$j,'group_name');
+	  $usergroups_groupid[$unixname] = db_result($result,$j,'group_id');
+	}
+    }
+  else
+    { $nogroups = 1; }
+
   $form_threshold = sane_all("form_threshold");
   $form_open = sane_all("form_open");
   unset($threshold);
@@ -70,6 +105,7 @@ if (user_isloggedin())
 
   site_user_header(array('context'=>'myitems'));
 
+  print '<p>'._("This page contains lists of items assigned to or submitted by you.").'</p>';
 
   # we get site-specific content
   utils_get_content("my/items");
@@ -134,8 +170,8 @@ if (user_isloggedin())
 // 	    my_hide_url('forum',$group_id,$hide_item_id,$rows2,$hide_forum);
 
 // 	  $html_hdr = ($j ? '<td colspan="2">' : '').
-// 	     $hide_url.'<A HREF="'.$GLOBALS['sys_home'].'forum/?group_id='.$group_id.'"><B>'.
-// 	     db_result($result,$j,'group_name').'</B></A>&nbsp;&nbsp;&nbsp;&nbsp;';
+// 	     $hide_url.'<A HREF="'.$GLOBALS['sys_home'].'forum/?group_id='.$group_id.'"><strong>'.
+// 	     db_result($result,$j,'group_name').'</strong></A>&nbsp;&nbsp;&nbsp;&nbsp;';
 
 // 	  $html = '';
 // 	  $count_new = max(0, $count_diff);
