@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: quitproject.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: quitproject.php 5550 2006-08-10 22:28:44Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #                          Wallace Lee
 #
-#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -54,8 +54,8 @@ if (!$confirm && !$pending)
 
   print '<form action="'.$GLOBALS[PHP_SELF].'" method="post">';
   print '<input type="hidden" name="quitting_group_id" value="'.$quitting_group_id.'" />';  
-  print '<font class="preinput">'.sprintf(_("You are about to leave the group %s, please confirm:"), group_getname($quitting_group_id)).'</font>';
-print '<p class="center"><input type="submit" name="confirm" value="'._("Confirm").'" /> <input type="submit" name="cancel" value="'._("Cancel").'" /></p>';
+  print '<span class="preinput">'.sprintf(_("You are about to leave the group %s, please confirm:"), group_getname($quitting_group_id)).'</span>';
+print '<div class="center"><input type="submit" name="confirm" value="'._("Confirm").'" /> <input type="submit" name="cancel" value="'._("Cancel").'" /></div>';
   print '</form>';
 }
 else
