@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: votes.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: votes.php 5802 2006-09-14 12:40:09Z yeupou $
 #
-#  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2005-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,12 +24,13 @@
 require '../include/pre.php';
 require_directory("trackers");
 
+register_globals_off();
 
 if (user_isloggedin())
 {
   $remaining_votes = trackers_votes_user_remains_count(user_getid());
 
-  if ($submit)
+  if (sane_post("submit"))
     {
       $sql = "SELECT vote_id,tracker,item_id FROM user_votes WHERE user_id='".user_getid()."' ORDER BY howmuch DESC , item_id ASC LIMIT 100 ";
       $result = db_query($sql);
@@ -41,11 +42,12 @@ if (user_isloggedin())
       $new_votes_list_item_id = array();
       $new_votes_list_tracker = array();
 
-      while ($row=db_fetch_array($result)) 
+      while ($row = db_fetch_array($result)) 
 	{
-	  $new_vote="new_vote_$row[vote_id]";
-	  $count = $count + $$new_vote;
-	  $new_votes_list[$row[vote_id]] = $$new_vote;
+	  $new_vote = "new_vote_$row[vote_id]";
+	  $new_vote = sane_post($new_vote);
+	  $count = $count + $new_vote;
+	  $new_votes_list[$row[vote_id]] = $new_vote;
 	  $new_votes_list_item_id[$row[vote_id]] = $row[item_id];
 	  $new_votes_list_tracker[$row[vote_id]] = $row[tracker];
 	}
@@ -82,7 +84,7 @@ if (user_isloggedin())
     {
       print '<p>'._("To change your votes, type in new numbers (using zero removes the entry from your votes list).").'</p>';
       
-      print '<form action="'.$PHP_SELF.'" method="post">';
+      print '<form action="'.$_SERVER["PHP_SELF"].'" method="post">';
       
       $sql = "SELECT * FROM user_votes WHERE user_id='".user_getid()."' ORDER BY howmuch DESC , item_id ASC LIMIT 100 ";
       $result = db_query($sql);
@@ -99,17 +101,14 @@ if (user_isloggedin())
 	    '<input type="text" name="new_vote_'.$row['vote_id'].'" size="3" maxlength="3" value="'.$row['howmuch'].'" /> / '.($row['howmuch']+$remaining_votes).
 	    '&nbsp;&nbsp;&nbsp;&nbsp;<a href="'.$GLOBALS['sys_home'].$row['tracker'].'/?func=detailitem&amp;item_id='.$row['item_id'].'">'.
 	    '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" class="icon" alt="'.$row['tracker'].'" />'.
-	    $prefix .' #'.$row['item_id'].'</a>'.
-	    _(": ").'&nbsp;'.
-	    '<a href="'.$GLOBALS['sys_home'].$row['tracker'].'/?func=detailitem&amp;item_id='.$row['item_id'].'">'.stripslashes(db_result($res_item, 0, 'summary')).', '.sprintf(ngettext("%s vote", "%s votes", db_result($res_item, 0, 'vote')), db_result($res_item, 0, 'vote')).'</a> <font class="smaller">['.group_getname(db_result($res_item, 0, 'group_id')).']</font>'.
-	    '&nbsp;</div>';
+	    ' '.stripslashes(db_result($res_item, 0, 'summary')).', '.sprintf(ngettext("%s vote", "%s votes", db_result($res_item, 0, 'vote')), db_result($res_item, 0, 'vote')).'&nbsp;<span class="xsmall">('.$prefix .' #'.$row['item_id'].', '.group_getname(db_result($res_item, 0, 'group_id')).')</span></div>';
 	  
 	  
 	}
       
 #  ################################ Submit
       
-      print '<p align="center" class="noprint"><input type="submit" name="submit" class="bold" value="'._("Submit Changes").'" /></form><p>';
+      print '<br /><div align="center" class="noprint"><input type="submit" name="submit" class="bold" value="'._("Submit Changes").'" /></div></form>';
       
 # End
       print "\n\n".show_priority_colors_key();
