@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: index.php 5954 2006-09-22 14:44:10Z yeupou $
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -49,10 +49,10 @@ if ($group_id && user_ismember($group_id,'A'))
   print '<h3>'._("News Tracker Email Notification Settings").'</h3>';
   print '
 <form action="'.$PHP_SELF.'" method="post">
-<input type="hidden" name="group_id" value="'.$group_id.'">';
+<input type="hidden" name="group_id" value="'.$group_id.'" />';
   print '<span class="preinput">'._("Carbon-Copy List:").'</span><br />&nbsp;&nbsp;<INPUT TYPE="TEXT" NAME="form_news_address" VALUE="'.$row_grp['new_news_address'].'" SIZE="40" MAXLENGTH="255" />';
   print '
-<p align="center"><input type="submit" name="update" value="'._("Update").'">
+<p align="center"><input type="submit" name="update" value="'._("Update").'" />
 </form>
 ';
 
