@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: approve.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: approve.php 5956 2006-09-25 07:37:47Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
 
 require '../include/pre.php';
 
+# FIXME: should use register_globals_off() instead
 if ($_POST['group_id'])
    { 
    $group_id= $_POST['group_id']; 
@@ -104,6 +105,7 @@ elseif ($_GET['id'])
    { 
    $id = $_GET['id']; 
    }      
+
 # This page can be used to manage the whole news system for a server
 # or news for a project.
 # That's why, when required, we test if group_id = sys_group_id.
@@ -163,7 +165,7 @@ if ($group_id && member_check(0, $group_id,'N3'))
         {
            # get notification address and submitter id
            $to = db_result(db_query("SELECT new_news_address FROM groups WHERE group_id=$group_id"), 0, 'new_news_address');
-           $from = user_getname(db_result(db_query("SELECT submitted_by FROM news_bytes WHERE id='$id' AND group_id='$for_group_id'"), 0, 'submitted_by'));
+           $from = user_getrealname(db_result(db_query("SELECT submitted_by FROM news_bytes WHERE id='$id' AND group_id='$for_group_id'"), 0, 'submitted_by'),1).' <'.$GLOBALS['sys_mail_replyto'].'@'.$GLOBALS['sys_mail_domain'].'>';
 
 
            # Run stripslashes to avoid slashes added by magic quotes and 
@@ -223,18 +225,20 @@ if ($group_id && member_check(0, $group_id,'N3'))
         { $submitted_by = user_getname(db_result($result,0,'submitted_by')); }
 
 
+      print '<p>'._("Submitted by:").' '.utils_user_link($submitted_by, user_getrealname(db_result($result,0,'submitted_by'))).'</p>';
       print '
 		<form action="'.$PHP_SELF.'" method="post">
 		<input type="hidden" name="id" value="'.db_result($result,0,'id').'" />';
 
-      print '<h3>'.sprintf(_("Approve a news item for %s submitted by %s"),'<a href="'.$GLOBALS['sys_home'].'projects/'.group_getunixname(db_result($result,0,'group_id')).'/">'.group_getname(db_result($result,0,'group_id')).'</a>',utils_user_link($submitted_by)).'</h3>';
+     # Useless title
+     # print '<h3>'.sprintf(_("Approve a news item for %s submitted by %s"),'<a href="'.$GLOBALS['sys_home'].'projects/'.group_getunixname(db_result($result,0,'group_id')).'/">'.group_getname(db_result($result,0,'group_id')).'</a>',utils_user_link($submitted_by)).'</h3>';
       print '
 		<input type="hidden" name="approve" value="y" />
 		<input type="hidden" name="post_changes" value="y" />';
 
       if (user_is_super_user() && $group_id == $GLOBALS['sys_group_id'])
 	{
-	  print '<input type="radio" name="status" value="1" />&nbsp;&nbsp';
+	  print '<input type="radio" name="status" value="1" />&nbsp;&nbsp;';
 	  print '<span class="preinput">'.sprintf(_("Approve For %s' Front Page"),$GLOBALS['sys_name']).'</span><br />';
 	  print '<input type="radio" name="status" value="0" checked="checked" />&nbsp;&nbsp;<span class="preinput">'._("Do Nothing").'</span><br />';
 	  print '<input type="radio" name="status" value="2" />&nbsp;&nbsp;<span class="preinput">'._("Refuse").'</span><br />';
@@ -255,8 +259,8 @@ if ($group_id && member_check(0, $group_id,'N3'))
 	._("Details:").'</span><br />&nbsp;&nbsp;
 		<textarea name="details" ROWS="20" COLS="65" WRAP="SOFT">'.db_result($result,0,'details').'</textarea><p>';
       print '<p>'.sprintf (_("Note: If this item is on the %s home page and you edit it, it will be removed from the home page."),$GLOBALS['sys_name']).'</p>';
-      print '<p class="center">
-		<input type="submit" name="submit" value="'._("submit").'"></p>
+      print '<div class="center">
+		<input type="submit" name="submit" value="'._("submit").'" /></div>
 		</form>';
 
     }
