@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: submit.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: submit.php 5551 2006-08-10 22:30:03Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@
 
 require "../include/pre.php";
 
+# FIXME: this should use register_globals_off() instead
 if ($_POST['group_id'])
    { $group_id= $_POST['group_id'];  }
 elseif ($_GET['group_id'])
@@ -127,10 +128,10 @@ print '
 		</p>'.
 form_header($PHP_SELF, $form_id).
 form_input("hidden", "group_id", $group_id).'
-               	<font class="preinput">'._("Subject:").'</font><br/>&nbsp;&nbsp;
+               	<span class="preinput">'._("Subject:").'</span><br/>&nbsp;&nbsp;
 		<input type="text" name="summary" value="'.$summary.'" size="65" maxlenght="80" />
 		<br />
-		<font class="preinput">'._("Details:").'</font><br />&nbsp;&nbsp;
+		<span class="preinput">'._("Details:").'</span><br />&nbsp;&nbsp;
 		<textarea name="details" rows="20" cols="65" wrap="soft">'.$details.'</textarea><br />'.
 form_footer();
 
