@@ -159,25 +159,25 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 
       print '
 		<form action="'.$PHP_SELF.'" method="POST">
-		<input type="hidden" name="group_id" value="'.$group_id.'">
-		<input type="hidden" name="job_id" value="'.$job_id.'">
-		<b>'
-	._("Category:").'</b><br />'
+		<input type="hidden" name="group_id" value="'.$group_id.'" />
+		<input type="hidden" name="job_id" value="'.$job_id.'" />
+		<strong>'
+	._("Category:").'</strong><br />'
 	. people_job_category_box('category_id',db_result($result,0,'category_id')) .'
 		<p>
-		<b>'
-	._("Status").':</b><br />'
+		<strong>'
+	._("Status").':</strong><br />'
 	. people_job_status_box('status_id',db_result($result,0,'status_id')) .'
 		<p>
-		<b>'
-	._("Short Description:").'</b><br />
-		<input type="text" name="title" value="'. db_result($result,0,'title') .'" size="40" maxlength="60">
+		<strong>'
+	._("Short Description:").'</strong><br />
+		<input type="text" name="title" value="'. db_result($result,0,'title') .'" size="40" maxlength="60" />
 		<p>
-		<b>'
-	._("Long Description:").'</b><br />
+		<strong>'
+	._("Long Description:").'</strong><br />
 		<textarea name="description" rows="10" cols="60" wrap="soft">'. htmlentities(db_result($result,0,'description')) .'</textarea>
 		<p>
-		<input type="submit" name="update_job" value="'._("Update Descriptions").'">
+		<input type="submit" name="update_job" value="'._("Update Descriptions").'" />
 		</form>';
 
       #now show the list of desired skills
