@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: viewjob.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: viewjob.php 5559 2006-08-14 08:34:08Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -62,9 +62,9 @@ if ($group_id && $job_id)
       print db_result($result,0,'category_name');
 
       print  ' '._("wanted for").' <a href="'.$GLOBALS['sys_home'].'project/?group_id='. $group_id .'">'. db_result($result,0,'group_name') .'</a></h2>'.
-	'<font class=preinput>'._("Submitted By:").'</font></b> <A HREF="'.$GLOBALS['sys_home'].'users/'. db_result($result,0,'user_name') .'">'. db_result($result,0,'user_name').'</a><br />'.
-	'<font class=preinput>'._("Date:").'</font>'. format_date($sys_datefmt,db_result($result,0,'date')) .'<br />'.
-	'<font class=preinput>'._("Status").':</font> '. db_result($result,0,'status_name');
+	'<p><span class="preinput">'._("Submitted By:").'</span> <a href="'.$GLOBALS['sys_home'].'users/'. db_result($result,0,'user_name') .'">'. db_result($result,0,'user_name').'</a><br />'.
+	'<span class="preinput">'._("Date:").'</span>'. format_date($sys_datefmt,db_result($result,0,'date')) .'<br />'.
+	'<span class="preinput">'._("Status:").'</span> '. db_result($result,0,'status_name').'</p>';
 
 
 
@@ -84,7 +84,7 @@ if ($group_id && $job_id)
 	    }
 	}
       $license = $project->getLicense();
-      print '<p><font class=preinput>'._("License").'</font> ';
+      print '<p><span class="preinput">'._("License").'</span> ';
       if ($LICENSE_URL[$license] != "0")
 	{
 	  print '<a href="'.$LICENSE_URL[$license].'" target="_blank">'.$LICENSE[$license].'</a>';
@@ -94,14 +94,14 @@ if ($group_id && $job_id)
 	  print $LICENSE[$license];
 	}
       $devel_status = $project->getDevelStatus();
-      print '<font class=preinput><br />'
-	._("Development Status").'</font>: '.$DEVEL_STATUS[$devel_status];
+      print '<span class="preinput"><br />'
+	._("Development Status").'</span>: '.$DEVEL_STATUS[$devel_status];
 
-      print '<p><font class=preinput>'._("Details (job description, contact...):").'</font></b><br />
-			'. utils_make_links(nl2br(db_result($result,0,'description'))).'<p><h3>'
-		._("Required Skills:").'</h3>';
+      print '<p><span class="preinput">'._("Details (job description, contact ...):").'</span></p>';
+      print utils_make_links(nl2br(db_result($result,0,'description')));
+      print '<h3>'._("Required Skills:").'</h3>';
       #now show the list of desired skills
-      print '<p>'.people_show_job_inventory($job_id);
+      print people_show_job_inventory($job_id);
     }
 
   site_project_footer(array());
