@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: bulk_admin_users.php,v 1.8 2005/06/30 17:19:36 toddy Exp $
+# $Id: bulk_admin_users.php 4977 2005-11-15 17:38:40Z yeupou $
 #
 #  Copyright 2003 (c) Frederik Orellana <Frederik.Orellana@cern.ch>
 # 
@@ -35,7 +35,7 @@ $action = $HTTP_GET_VARS['action'];
 
 function check_file($file)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_file($file)';  if(empty($file)){
+	if(empty($file)){
     exit_error('You have to upload something.', $file['error']);
   }
   if(!$file['name']){
@@ -54,7 +54,7 @@ function check_file($file)
 
 function check_user_name($name)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_user_name($name)';  global $err;
+	global $err;
   $retval = 1;
 
 	if (db_numrows(db_query("SELECT user_id FROM user WHERE "
@@ -78,7 +78,7 @@ function check_user_name($name)
 
 function check_real_name($name, $real_name)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_real_name($name, $real_name)';  global $err;
+	global $err;
   # The MySQL field is varchar(32)
 #  if(strlen(trim($real_name))>32 || !ereg('^[\. _a-zA-Z0-9-]*$', trim($real_name))) {
   if(strlen(trim($real_name))>32 || !ereg('^[\.\' _a-zA-Z0-9-]*$', trim($real_name))) {
@@ -92,7 +92,7 @@ function check_real_name($name, $real_name)
 
 function check_email($name, $email) 
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_email($name, $email) ';  global $err;
+	global $err;
   if(/*Does full chekc of host, etc. but takes a very long time*/
      /*is_emailable_address(trim($email))*/
      validate_email(trim($email))){
@@ -106,7 +106,7 @@ function check_email($name, $email)
 
 function check_user_exists($name)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_user_exists($name)';  global $err;
+	global $err;
   $result = db_query("SELECT user_id FROM user WHERE " .
     "user_name='".trim($name)."'");
   $id = db_fetch_array($result);
@@ -121,7 +121,7 @@ function check_user_exists($name)
 
 function check_flags($name, $flags)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_flags($name, $flags)';  global $err;
+	global $err;
   $retval = 1;
   foreach($flags as $flagname => $flag){
     $flag = trim($flag);
@@ -156,7 +156,7 @@ function check_flags($name, $flags)
 
 function check_user_in_group($name)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_user_in_group($name)';  global $err;
+	global $err;
   global $group_id;
   $retval = 1;
   $id_arr = check_user_exists($name);
@@ -173,7 +173,8 @@ function check_user_in_group($name)
 
 function check_passwd($name, $password, $password1, $method)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':check_passwd($name, $password, $password1, $method)';  # Check a a MySQL encrypted password (or "PAM") or non-encrypted password
+
+ # Check a a MySQL encrypted password (or "PAM") or non-encrypted password
   # From register_valid in register.php - should be abstracted
   global $err;
   global $GLOBALS;
@@ -220,7 +221,7 @@ function check_passwd($name, $password, $password1, $method)
 
 function add_user($name, $real_name, $email, $password, $method)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':add_user($name, $real_name, $email, $password, $method)';  # From register_valid in register.php - should be abstracted
+ # From register_valid in register.php - should be abstracted
   global $err;
   global $GLOBALS;
   if ($GLOBALS['sys_use_pamauth'] == "yes" && ($method=="PAM" || $password=="PAM")) {
@@ -275,7 +276,7 @@ function add_user($name, $real_name, $email, $password, $method)
 
 function update_users($file_name)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':update_users($file_name)';  $ret=1;
+$ret=1;
   global $err;
   global $action;
   global $group_id;
@@ -412,7 +413,8 @@ check_file($HTTP_POST_FILES['file']);
 
 update_users($HTTP_POST_FILES['file']['tmp_name']);
 
-site_project_header(array('title'=>"Project Members Management",'group'=>$group_id,'toptab'=>'ahome'));
+site_project_header(array('title'=>"Project Members Management",'group'=>$group_id,'context'=>'ahome'));
+
 
 echo "You have uploaded a file: ".$HTTP_POST_FILES['file']['name'].".<br />";
 echo "Temporary location: ".$HTTP_POST_FILES['file']['tmp_name'].".<br />";
