@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: conf-copy.php,v 1.3 2005/06/30 17:19:36 toddy Exp $
+# $Id: conf-copy.php 4977 2005-11-15 17:38:40Z yeupou $
 #
 #  Copyright 2004-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #
@@ -32,16 +32,16 @@ if ($group_id && user_ismember($group_id,'A'))
       trackers_conf_copy(addslashes($group_id), $artifact, addslashes($from_group_id));
     }
   
-  
-  site_project_header(array('toptab'=>'ahome','group'=>$group_id,'title'=>_("Copy Configuration")));
+  site_project_header(array('context'=>'ahome','group'=>$group_id,'title'=>_("Copy Configuration")));
 
-  print '<h2>'.("Support Trackers Configuration Copy").'</h2>';
+  
+  print '<h3>'.("Support Trackers Configuration Copy").'</h3>';
   conf_form($group_id, "support");
-  print '<h2>'.("Bugs Trackers Configuration Copy").'</h2>';
+  print '<h3>'.("Bugs Trackers Configuration Copy").'</h3>';
   conf_form($group_id, "bugs");
-  print '<h2>'.("Task Trackers Configuration Copy").'</h2>';
+  print '<h3>'.("Task Trackers Configuration Copy").'</h3>';
   conf_form($group_id, "task");
-  print '<h2>'.("Patch Trackers Configuration Copy").'</h2>';
+  print '<h3>'.("Patch Trackers Configuration Copy").'</h3>';
   conf_form($group_id, "patch");
   
   site_project_footer(array());
