@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: editgroupinfo.php 5263 2005-12-12 10:03:02Z toddy $
+# $Id: editgroupinfo.php 5934 2006-09-22 07:21:49Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004      (c) ...
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,25 +26,29 @@
 
 
 require "../../include/pre.php";
+
+register_globals_off();
+$group_id = sane_all("group_id");
+
 require $GLOBALS['sys_www_topdir']."/include/vars.php";
 
 session_require(array('group'=>$group_id,'admin_flags'=>'A'));
 
-if ($update)
+if (sane_post("update"))
 {
-
   group_add_history ('Changed Public Info','',$group_id);
 
-  $result=db_query('UPDATE groups SET '
-		   ."group_name='".htmlspecialchars($form_group_name)."',"
-		   ."short_description='".htmlspecialchars($form_shortdesc)."',"
-		   ."long_description='".$form_longdesc."',"
-
-		   ."devel_status='$form_devel_status' "
-		   ."WHERE group_id=$group_id");
+  $sql = 'UPDATE groups SET '
+    ."group_name='".htmlspecialchars(sane_post("form_group_name"))."',"
+    ."short_description='".htmlspecialchars(sane_post("form_shortdesc"))."',"
+    ."long_description='".sane_post("form_longdesc")."',"
+    
+    ."devel_status='".sane_post("form_devel_status")."' "
+    ."WHERE group_id=$group_id";
 
+  $result = db_query($sql);
   if (!$result)
-    { fb(_("Update failed.").' '.db_error()); }
+    { fb(_("Update failed."), 1); }
 }
 
 # update info for page
@@ -62,27 +66,27 @@ site_project_header(array('title'=>_("Editing Public Info"),'group'=>$group_id,'
 
 # ####################################### General Description
 
+print form_header($PHP_SELF)
+     .form_input("hidden", "group_id", $group_id);
+
 print '
-<form action="'.$PHP_SELF.'" method="post">
-<input type="hidden" name="group_id" value="'.$group_id.'">
-</p>
+<p><span class="preinput">'._("Descriptive Group Name (no HTML):").'</span>
+<br />&nbsp;&nbsp;&nbsp;'.form_input("text", 
+				     "form_group_name", 
+				     $row_grp['group_name'],
+				     'size="60" maxlen="254"').'</p>';
 
-<p><font class="preinput">'
-._("Descriptive Group Name (no HTML):").'
-</font>
-<br /><input type="text" size="60" maxlen="254" name="form_group_name" value="'.$row_grp['group_name'].'">
-</p>
+print '
+<p><span class="preinput">'._("Short Description (255 Character Max, no HTML):").'</span>
+<br />&nbsp;&nbsp;&nbsp;'.form_textarea("form_shortdesc",
+					$row_grp['short_description'],
+					'cols="70" rows="3" wrap="virtual"').'</p>';
 
-<p><font class="preinput">'
-._("Short Description (255 Character Max, no HTML):").'
-</font>
-<br /><textarea cols="70" rows="3" wrap="virtual" name="form_shortdesc">
-'.$row_grp['short_description'].'</textarea></p>
-
-<p><font class="preinput">'
-._("Long Description:").'
-</font>
-<br /><textarea cols="70" rows="10" wrap="virtual" name="form_longdesc">'.$row_grp['long_description'].'</textarea></p>';
+print '
+<p><span class="preinput">'._("Long Description:").'</span>
+<br />&nbsp;&nbsp;&nbsp;'.form_textarea("form_longdesc",
+					$row_grp['long_description'],
+					'cols="70" rows="10" wrap="virtual"').'</p>';
 
 $type_id = $row_grp['type'];
 $result1 = db_query("SELECT * FROM group_type WHERE type_id='$type_id'");
@@ -95,24 +99,21 @@ if($DEVEL_STATUS1 = $row_grp1['devel_status_array']){
 if ($project->CanUse("devel_status"))
 {
   print '
-<p><font class="preinput">'
-    ._("Development Status:").'</font><br /><select name="form_devel_status">';
+<p><span class="preinput">'
+    ._("Development Status:").'</span><br />&nbsp;&nbsp;&nbsp;<select name="form_devel_status">';
   while (list($k,$v) = each($DEVEL_STATUS))
     {
       print '<option value="'.$k.'"';
       if ($k == $row_grp['devel_status'])
 	{ print ' SELECTED'; }
       print '>'.$v;
-      echo '</option>';
+      print '</option>';
     }
   print '</select></p>';
 }
 
-echo '
-<p><input type="submit" name="update" value="'._("Update").'">
-</form>
-';
+print form_footer();
 
-project_admin_footer(array());
+site_project_footer(array());
 
 ?>
