@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: history.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: history.php 5794 2006-09-14 07:58:20Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) ..
+#  Copyright 2006      (c) Mathieu Roy <yeupou--gnu.org>
+#
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -24,16 +25,18 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 
-require ('../../include/pre.php');
+require "../../include/pre.php";
 
+register_globals_off();
+
+$group_id = sane_all("group_id");
 if (member_check(0, $group_id))
 {
   site_project_header(array('title'=>_("Project History"),'group'=>$group_id,'context'=>'ahome'));
-
   
   show_grouphistory($group_id);
 
-  project_admin_footer(array());
+  site_project_footer(array());
 }
 else
 {
