@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5263 2005-12-12 10:03:02Z toddy $
+# $Id: index.php 5902 2006-09-21 08:50:57Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2002-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -56,8 +56,8 @@ print "\n\n".html_splitpage(1);
 print $HTML->box_top(_("Features"));
 
 # Activate features
-print '<a href="editgroupfeatures.php?group='.$group_name.'">'._("Select Active Features").'</a>';
-print '<p class="text">'._("Define which features you want to use for this project.").'</p>';
+print '<a href="editgroupfeatures.php?group='.$group_name.'">'._("Select Features").'</a>';
+print '<p class="smaller">'._("Define which features you want to use for this project.").'</p>';
 
 unset($i);
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
@@ -80,14 +80,14 @@ while (list($case, $name) = each($features))
 }
 $link = rtrim($link, ', ');
 print sprintf(_("Configure Features: %s"), $link);
-print '<p class="text">'._("You can manage fields used, define query forms, manage mail notifications, etc.").'</p>';
+print '<p class="smaller">'._("You can manage fields used, define query forms, manage mail notifications, etc.").'</p>';
 
 $i++;
 
 # Mail notifs
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
-print '<a href="editgroupnotifications.php?group='.$group_name.'">'._("Configure Mail Notifications").'</a>';
-print '<p class="text">'._("For many features, you can modify the type of notification (global/per category), the related address lists and the notification triggers.").'</p>';
+print '<a href="editgroupnotifications.php?group='.$group_name.'">'._("Set Notifications").'</a>';
+print '<p class="smaller">'._("For many features, you can modify the type of email notification (global/per category), the related address lists and the notification triggers.").'</p>';
 
 
 $i++;
@@ -95,7 +95,7 @@ $i++;
 # Conf copy
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 print '<a href="conf-copy.php?group='.$group_name.'">'._("Copy Configuration").'</a>';
-print '<p class="text">'._("Copy the configuration of trackers of other projects you are member of.").'</p>';
+print '<p class="smaller">'._("Copy the configuration of trackers of other projects you are member of.").'</p>';
 
 
 print $HTML->box_bottom();
@@ -111,14 +111,14 @@ print $HTML->box_top(_('Information'));
 
 # Public info
 print '<a href="editgroupinfo.php?group='.$group_name.'">'._("Edit Public Information").'</a>';
-print '<p class="text">'.sprintf(_("Your current short description is: %s"), db_result($res_grp,0,'short_description'));
+print '<p class="smaller">'.sprintf(_("Your current short description is: %s"), db_result($res_grp,0,'short_description'));
 print '</p>';
 
 unset($i);
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 # Public info
 print '<a href="history.php?group='.$group_name.'">'._("Show History").'</a>';
-print '<p class="text">'._("This allows you to keep tracks of important changes occuring on your project configuration.").'</p>';
+print '<p class="smaller">'._("This allows you to keep tracks of important changes occuring on your project configuration.").'</p>';
 
 print $HTML->box_bottom();
 
@@ -131,25 +131,25 @@ print $HTML->box_top(_('Members'));
 
 # Add/Remove members
 print '<a href="useradmin.php?group='.$group_name.'">'._("Manage Members").'</a>';
-print '<p class="text">'. _("Add, remove members, approve or reject requests for inclusion.").'</p>';
+print '<p class="smaller">'. _("Add, remove members, approve or reject requests for inclusion.").'</p>';
 
 unset($i);
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 # Edit permissions members
 print '<a href="userperms.php?group='.$group_name.'">'._("Set Permissions").'</a>';
-print '<p class="text">'._("Set members and group default permissions, set posting restrictions.").'</p>';
+print '<p class="smaller">'._("Set members and group default permissions, set posting restrictions.").'</p>';
 
 $i++;
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 # Add job offers
 print '<a href="../../people/createjob.php?group='.$group_name.'">'._("Post Jobs").'</a>';
-print '<p class="text">'._("Add a job offer.").'</p>';
+print '<p class="smaller">'._("Add a job offer.").'</p>';
 
 $i++;
 print $HTML->box_nextitem(utils_get_alt_row_color($i));
 # Job offers list
 print '<a href="../../people/editjob.php?group='.$group_name.'">'._("Edit Jobs").'</a>';
-print '<p class="text">'._("Edit jobs offers for this project.").'</p>';
+print '<p class="smaller">'._("Edit jobs offers for this project.").'</p>';
 
 
 print $HTML->box_bottom();
