@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: useradmin.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: useradmin.php 5554 2006-08-14 08:19:56Z toddy $
 #
 #  Copyright 2003-2005 (c) Frederik Orellana <frederik.orellana--cern.ch>
 #                          Derek Feichtinger <derek.feichtinger--cern.ch>
@@ -37,7 +37,7 @@ function show_pending_users_list ($result, $group_id)
 	<p>
         "._("Users that have requested to be member of the group are listed here. To approve their requests, select their name and click on the button below. To discard requests, go to the next section called \"Removing users from group\".")."
 	<form action=\"$PHP_SELF\" method=\"post\">
-	<input type=\"HIDDEN\" name=\"action\" VALUE=\"approve_for_group\">
+	<input type=\"HIDDEN\" name=\"action\" VALUE=\"approve_for_group\" />
   <select name=\"user_id[]\" size=\"10\" multiple>\n";
 
   while ($usr = db_fetch_array($result)) {
@@ -53,9 +53,9 @@ function show_pending_users_list ($result, $group_id)
     }
 
   print "</select>
-	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\">
+	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\" />
 	<P>
-	<input type=\"submit\" name=\"Submit\" value=\""._("Approve users for group")."\">
+	<input type=\"submit\" name=\"Submit\" value=\""._("Approve users for group")."\" />
 	</form>";
 }
 
@@ -68,7 +68,7 @@ function show_all_users_remove_list ($result, $result2, $group_id)
 	<p>
         "._("To remove users, select their name and click on the button below. The administrators of a project cannot be removed unless they quit. Pending users are at the bottom of the list.")."
 	<form action=\"$PHP_SELF\" method=\"post\">
-	<input type=\"HIDDEN\" name=\"action\" VALUE=\"remove_from_group\">
+	<input type=\"HIDDEN\" name=\"action\" VALUE=\"remove_from_group\" />
   <select name=\"user_id[]\" size=\"10\" multiple>\n";
 
   while ($usr = db_fetch_array($result)) {
@@ -96,9 +96,9 @@ function show_all_users_remove_list ($result, $result2, $group_id)
 
   print "</select>
 	<br />
-	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\">
+	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\" />
 	<p>
-	<input type=\"submit\" name=\"Submit\" value=\""._("Remove users from group")."\">
+	<input type=\"submit\" name=\"Submit\" value=\""._("Remove users from group")."\" />
 	</form>";
 
 }
@@ -112,11 +112,11 @@ function show_all_users_add_searchbox ($group_id, $previous_search)
         '._("You can search one or several users to add in the whole users database with the following search tool. A list of users, depending on the names you'll type in this form, will be generated.").'
 
 	<form action="'.$PHP_SELF.'#searchuser" method="post">
-	<input type="hidden" name="action" value="add_to_group_list">
-        <input type="text" size="35" name="words" value="'.$previous_search.'"><br />
+	<input type="hidden" name="action" value="add_to_group_list" />
+        <input type="text" size="35" name="words" value="'.$previous_search.'" /><br />
 	<p>
-	<input type="hidden" name="group_id" value="'.$group_id.'">
-	<input type="submit" name="Submit" value="'._("Search users").'">
+	<input type="hidden" name="group_id" value="'.$group_id.'" />
+	<input type="submit" name="Submit" value="'._("Search users").'" />
 	</form>';
 }
 
@@ -129,7 +129,7 @@ function show_all_users_add_list ($result, $group_id)
 
 	<P></P>
 	<form action=\"$PHP_SELF\" method=\"post\">
-	<input type=\"HIDDEN\" name=\"action\" VALUE=\"add_to_group\">
+	<input type=\"HIDDEN\" name=\"action\" VALUE=\"add_to_group\" />
   <select name=\"user_id[]\" size=\"10\" multiple>\n";
 
   while ($usr = db_fetch_array($result)) {
@@ -145,9 +145,9 @@ function show_all_users_add_list ($result, $group_id)
 
   print "</select>
 	<br />
-	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\">
+	<input type=\"HIDDEN\" name=\"group_id\" VALUE=\"$group_id\" />
 	<p>
-	<input type=\"submit\" name=\"Submit\" value=\""._("Add users to group")."\">
+	<input type=\"submit\" name=\"Submit\" value=\""._("Add users to group")."\" />
 	</form>";
 }
 
@@ -162,10 +162,10 @@ function show_bulk_add_users ($group_id)
   <br />
 
 	<form action=\"bulk_admin_users.php?action=test&group_id=".$group_id."\" method=\"post\"  enctype=\"multipart/form-data\">
-	<input type=\"HIDDEN\" name=\"action\" VALUE=\"check\">
-  <input type=\"file\" name=\"file\" size=\"40\">
+	<input type=\"HIDDEN\" name=\"action\" VALUE=\"check\" />
+  <input type=\"file\" name=\"file\" size=\"40\" />
 	<P>
-	<input type=\"submit\" name=\"Submit\" value=\""._("Submit")."\">
+	<input type=\"submit\" name=\"Submit\" value=\""._("Submit")."\" />
 	</P>
   </form>
   <br />
@@ -179,10 +179,10 @@ function show_bulk_add_users ($group_id)
   <br />
 
 	<form action=\"bulk_admin_users.php?action=execute&group_id=".$group_id."\" method=\"post\"  enctype=\"multipart/form-data\">
-	<input type=\"HIDDEN\" name=\"action\" VALUE=\"check\">
-  <input type=\"file\" name=\"file\" size=\"40\">
+	<input type=\"HIDDEN\" name=\"action\" VALUE=\"check\" />
+  <input type=\"file\" name=\"file\" size=\"40\" />
 	<P>
-	<input type=\"submit\" name=\"Submit\" value=\""._("Submit")."\">
+	<input type=\"submit\" name=\"Submit\" value=\""._("Submit")."\" />
 	</P>
   </form>";
 }
@@ -301,6 +301,6 @@ if ($words) {
   $HTML->box1_bottom();
   */
 
-project_admin_footer(array());
+site_project_footer(array());
 
 ?>
