@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: userperms.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: userperms.php 5902 2006-09-21 08:50:57Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -240,7 +240,7 @@ if ($update)
 
 
 # start HTML
-site_project_header(array('title'=>_("Permissions Management"),'group'=>$group_id,'context'=>'ahome'));
+site_project_header(array('title'=>_("Set Permissions"),'group'=>$group_id,'context'=>'ahome'));
 
 
 $sql = "select user.user_name AS user_name,"
@@ -262,7 +262,7 @@ $sql = "select user.user_name AS user_name,"
 $result = db_query($sql);
 
 print '<form action="'.$PHP_SELF.'" method="post">
-<input type="hidden" name="group" value="'.$group_name.'">';
+<input type="hidden" name="group" value="'.$group_name.'" />';
 
 ########################### POSTING RESTRICTIONS
 # Exists also in trackers config (missing for news).
@@ -358,7 +358,7 @@ print '  </tr>';
  
 print '
 </table>
-<p align="center"><input type="submit" name="update" value="'._("Update Permissions").'"></p>';
+<p align="center"><input type="submit" name="update" value="'._("Update Permissions").'" /></p>';
 
 
 ########################### GROUP DEFAULTS
@@ -414,7 +414,7 @@ html_select_permission_box("news", group_getpermissions($group_id, "news"), "gro
 
 print '  </tr>
 </table>
-<p align="center"><input type="submit" name="update" value="'._("Update Permissions").'"></p>';
+<p align="center"><input type="submit" name="update" value="'._("Update Permissions").'" /></p>';
 
 
 ########################### PER MEMBERS
@@ -477,7 +477,7 @@ else
     <td class="smaller">';
      if ($row['user_id'] == user_getid())
        {
-	 print '<i>'._("You are Admin").'</i>';
+	 print '<em>'._("You are Admin").'</em>';
        }
      else
        {
@@ -524,11 +524,11 @@ else
 
   print '
 </table>
-<p align="center"><input type="submit" name="update" value="'._("Update Permissions").'"></p></form>';
+<p align="center"><input type="submit" name="update" value="'._("Update Permissions").'" /></p></form>';
 
 
 }
 
-project_admin_footer(array());
+site_project_footer(array());
 
 ?>
\ No newline at end of file
