@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: memberlist.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: memberlist.php 5554 2006-08-14 08:19:56Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--at--gnu.org>
 #
-#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Lorenzo Hernandez Garcia-Hierro
 #                                      <lorenzohgh--tuxedo-es.org >
 #
@@ -42,34 +42,32 @@ if ((!$group_id) && $form_grp)
 			       'context'=>'people'));
 
      
-     if ($detailed)
+if ($detailed)
 { $checked = " selected=\"selected\""; }
 # I18N
 # %s currently is "basic" or "detailed"
   $form_opening = '<form action="'.$PHP_SELF.'#options" method="get">';
   $form_submit = '<input class="bold"  type="submit" value="'._("Apply").'" />';
-print html_show_displayoptions(sprintf(_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("basic").'</option><option value="1"'.$checked.'>'._("detailed").'</option></select>').'<input type="hidden" name="group" value="'.$group_name.'">',
+print html_show_displayoptions(sprintf(_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("basic").'</option><option value="1"'.$checked.'>'._("detailed").'</option></select>').'<input type="hidden" name="group" value="'.$group_name.'" />',
 			       $form_opening,
 			       $form_submit);
 
 
 if (!member_check(0,$group_id))
 {
-  printf(_("If you would like to contribute to this project by becoming a member, %scontact one of the project admins%s, designated in bold text below."),
-	 '<a href="'.$GLOBALS['sys_home'].'my/groups.php?words='.group_getname($group_id).'#searchgroup">', '</a>');
-  print '<br /><br />';
+  print '<p>'.sprintf(_("If you would like to contribute to this project by becoming a member, %scontact one of the project admins%s, designated in bold text below."),
+	 '<a href="'.$GLOBALS['sys_home'].'my/groups.php?words='.group_getname($group_id).'#searchgroup">', '</a>').'</p>';
 }
 else
 {
-  print _("Note that you can 'watch' a member of your project. It allows you, for instance, to be the backup of someone when they are away from the office, or to review all their activities on this project: you will receive a copy of their mail notifications related to this project.");
-  print '<br /><br />';
+  print '<p>'._("Note that you can 'watch' a member of your project. It allows you, for instance, to be the backup of someone when they are away from the office, or to review all their activities on this project: you will receive a copy of their mail notifications related to this project.").'</p>';
 
 }
 
 if ($detailed)
 {
   member_explain_roles();
-  # FIXME: yeupou@gnu.org 2003-11-07
+  # FIXME: yeupou--gnu.org 2003-11-07
   # The best would be to print non-specific roles but roles in any case.
   # It requires more, so we will see if there are people interested in that
   # or not.
@@ -166,13 +164,13 @@ while ($row_memb=db_fetch_array($res_memb))
 	      $icon_alt = _("Site Administrator");
 	    }
 
-	  print "\t\t".'<td class="center"><font class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /></font></td><td>'.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
+	  print "\t\t".'<td class="center"><span class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /></span></td><td>'.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
 	}
       else
 	{
 	  $icon = "project-member";
 	  $icon_alt = _("Project Member");
-	  print "\t\t".'<td><font class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /></font></td><td>'.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
+	  print "\t\t".'<td><span class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /></span></td><td>'.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
 	}
 
       # Role
@@ -202,14 +200,11 @@ while ($row_memb=db_fetch_array($res_memb))
 # yeupou--gnu.org, 2004-11-04, remove email from this page; this data
 # is accessible elsewhere, via links. It saves us extra tests on whether
 # users want to hide their email or not.
-#$title_arr[]=_("Email");
-#      print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."sendmessage.php?touser=".$row_memb['user_id'].
-#	"\">".utils_antispam_email($row_memb['email'])."</td>\n";
 
       # Skills
       if ($row_memb['people_view_skills'] == 1)
 	{
-	  print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."people/viewprofile.php?user_id=".$row_memb['user_id']."\">"._("View Skills")."</a></td>\n";
+	  print "\t\t<td align=\"middle\"><a href=\"".$GLOBALS['sys_home']."people/resume.php?user_id=".$row_memb['user_id']."\">"._("View Skills")."</a></td>\n";
 	}
       else
 	{
