@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: confirmation.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: confirmation.php 5937 2006-09-22 08:42:18Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -37,8 +37,14 @@ if ($show_confirm && $rand_hash)
     {
       exit_error(_("No group type has been selected. Use the back button."));
     }
-
+  
+  # Create the page header just like if there was not yet any group_id
+  $group_id_not_yet_valid = $group_id;
+  unset($group_id);
   $HTML->header(array('title'=>_("Final Step: Confirmation")));
+  $group_id = $group_id_not_yet_valid;
+
+
   $sql="UPDATE groups SET type='$group_type' WHERE group_id='$group_id' AND rand_hash='__$rand_hash'";
   $result=db_query($sql);
 
@@ -46,13 +52,12 @@ if ($show_confirm && $rand_hash)
   $result=db_query($sql);
 
   print '
-<h2>'._("Final Step: Confirmation").'</h2>
-<div align="center"><font class="warn">'._("Do not click the back button").'</font></div>
+<div align="center"><span class="warn">'._("Do not click the back button").'</span></div>
 
 <form action="'.$PHP_SELF.'" method="post">
-<input type="hidden" name="no_redirection" value="1">
-<input type="hidden" name="group_id" value="'.$group_id.'">
-<input type="hidden" name="rand_hash" value="'.$rand_hash.'">
+<input type="hidden" name="no_redirection" value="1" />
+<input type="hidden" name="group_id" value="'.$group_id.'" />
+<input type="hidden" name="rand_hash" value="'.$rand_hash.'" />
 
 <h5>'._("Description:").'</h5>
 <textarea name="form_purpose" wrap="virtual" cols="70" rows="15">'.db_result($result,0,'register_purpose').'</textarea>
@@ -64,7 +69,7 @@ if ($show_confirm && $rand_hash)
 <textarea name="form_comments" wrap="virtual" cols="70" rows="4">'.db_result($result,0,'other_comments').'</textarea>
 
 <h5>'._("Full Name:").'</h5>
-<input size="40" maxlength="40" type="text" name="form_full_name" value="'.db_result($result,0,'group_name').'">
+<input size="40" maxlength="40" type="text" name="form_full_name" value="'.db_result($result,0,'group_name').'" />
 
 <h5>'._("System Name:").'</h5>'
     . db_result($result,0,'unix_group_name')
@@ -94,12 +99,12 @@ if ($show_confirm && $rand_hash)
 <p>'
     ._("If you confirm it, your project registration will be saved, waiting for a system administrator to approve it. If you reject it, this registration will be discarded.").'
 </p>
-<p class="center">
+<div class="center">
 <input type="submit" name="i_agree" value="'
     ._("Confirm").'">
 <input type="submit" name="i_disagree" value="'
     ._("Reject").'">
-</p>
+</div>
 </form>';
 
   $HTML->footer(array());
@@ -156,29 +161,29 @@ else if ($i_agree && $group_id && $rand_hash)
      ."----RERegistration-URL-END-------\n";
 
   $message_admin = "A new project has been registered at ".$GLOBALS['sys_name']." 
-The project account will remain inactive until a site admin approve or discard the registration.
+This project account will remain inactive until a site admin approves or discards the registration.
 
 
-######### REGISTRATION ADMINISTRATION #########
+== REGISTRATION ADMINISTRATION ==
 
 While this item will be useful to track the registration process, approving or discarding the registration must be done using the specific \"Group Administration\" page, accessible only to site administrators, effectively logged as site administrators (superuser):
 
   <".$GLOBALS['sys_https_url'].$GLOBALS['sys_home']."siteadmin/groupedit.php?group_id=".$group_id.">
 
 
-######### REGISTRATION DETAILS ######### 
+== REGISTRATION DETAILS ==
 
 Full Name:
 ----------
-  $form_full_name
+  *".$form_full_name."*
 
 System Group Name:
 -----------------
-  $unix_name
+  *".$unix_name."*
 
 Type:
 -----
-  $type
+  ".$type."
 
 License:
 -------- 
@@ -187,23 +192,23 @@ License:
   if ($form_license_other) {
     $message_admin .= "Other License: 
 --------------
-  $form_license_other\n\n";
+  ".$form_license_other."\n\n";
   }
 
 $message_admin .= "Description:
 ------------
-  $form_purpose\n\n";
+  ".$form_purpose."\n\n";
 
  if ($form_required_sw) {
    $message_admin .= "Other Software Required:
 ------------------------
-  $form_required_sw\n\n";
+  ".$form_required_sw."\n\n";
  }
  
  if ($form_comments) {
    $message_admin .= "Other Comments:
 ---------------
-  $form_comments\n\n";
+  ".$form_comments."\n\n";
  }
  
   # a mail for the submitter
@@ -229,14 +234,44 @@ $message_admin .= "Description:
   if ($GLOBALS['sys_group_id'] == $group_id)
     {
       db_query("UPDATE groups SET status='A' WHERE group_id='$group_id' AND rand_hash='__$rand_hash'");
+
       # We also add a specific field for the task tracker
       # (we need to copy the None field)
       db_query("INSERT INTO task_field_value (bug_field_id,group_id,value_id,value,description,order_id,status) VALUES (103,$group_id,100,'None','',10,'P')");
       db_query("INSERT INTO task_field_value (bug_field_id,group_id,value_id,value,description,order_id,status) VALUES (103,$group_id,1,'Project Approval','Pending project registration',11,'P')");
+
       # We also need to make the task tracker post restriction of comment
       # accepting posting from logged-in users, otherwise they wont be able
       # to comment their registration
       db_query("INSERT INTO groups_default_permissions (group_id,task_rflags) VALUES ($group_id,300)");
+
+      
+      # We finally add the default recipes grabbed from update/1.3/
+      $query = db_query("INSERT INTO cookbook (group_id, status_id , severity , privacy , category_id , submitted_by , assigned_to , date , summary , details , resolution_id) VALUES ('$group_id', '3', '5', '1', '100', '100', '100', '1133253163', 'Getting back lost password', '".addslashes("If you lose your password simply visit the login page and click \"Lost Your Password?\". 
+
+A confirmation mail will be sent to the address we have on file for you. Then, load the URL in the email to reset your password.")."', '1')");
+      $item_id = db_insertid($query);
+      db_query("INSERT INTO cookbook_context2recipe (recipe_id, group_id, audience_anonymous , audience_loggedin , audience_members , audience_technicians , audience_managers , context_project , context_homepage , context_cookbook , context_download , context_support , context_bugs , context_task , context_patch , context_news , context_mail , context_cvs , context_arch , context_svn , context_my , context_stats , context_siteadmin , context_people , subcontext_browsing , subcontext_postitem , subcontext_edititem , subcontext_search , subcontext_configure ) VALUES ('$item_id', '$group_id', '1', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '1', '1', '1', '0', '0')");
+
+      $query = db_query("INSERT INTO cookbook (group_id, status_id , severity , privacy , category_id , submitted_by , assigned_to , date , summary , details , resolution_id) VALUES ('$group_id', '3', '5', '1', '100', '100', '100', '1133253163', 'Why log in?', '".addslashes("The log-in mechanism used in these webpages is just a simple way of keeping track of users who work in projects hosted in this site. When a user logs in, she/he is conducted to a personal page that lists the projects she/he is collaborating with and any pending tasks that she/he might have.
+
+If you are involved in any project, if you do not intend to post items on the site, you don't need to log in since it will make no difference. 
+If you want to register a project of your own to be hosted in this site, you must first log in, because every project must have at least one administrator and we need to know your user name to make you the administrator of the project.
+
+In order to log in, you must be registered (using \"New User\" in the menu) and give the user name and password selected during your registration.
+
+If you lost your password, read recipe #$item_id.")."', '1')");
+      $item_id = db_insertid($query);
+      db_query("INSERT INTO cookbook_context2recipe (recipe_id, group_id, audience_anonymous , audience_loggedin , audience_members , audience_technicians , audience_managers , context_project , context_homepage , context_cookbook , context_download , context_support , context_bugs , context_task , context_patch , context_news , context_mail , context_cvs , context_arch , context_svn , context_my , context_stats , context_siteadmin , context_people , subcontext_browsing , subcontext_postitem , subcontext_edititem , subcontext_search , subcontext_configure ) VALUES ('$item_id', '$group_id', '1', '0', '0', '0', '0', '0', '0', '0', '0', '1', '1', '1', '1', '0', '0', '0', '0', '0', '0', '0', '0', '0', '1', '1', '1', '0', '0')");
+
+
+      $query = db_query("INSERT INTO cookbook (group_id, status_id , severity , privacy , category_id , submitted_by , assigned_to , date , summary , details , resolution_id) VALUES ('$group_id', '3', '5', '1', '100', '100', '100', '1133253163', 'Delays on update', '".addslashes("Several function related to mail aliases, external services access (SVN, CVS...), user additions, group member changes, CVS, etc, are performed via a cronjob on a regular basis. 
+
+Changes made on the web site may appear to be live but will not take effect until the next cron update.")."', '1')");
+      $item_id = db_insertid($query);
+      db_query("INSERT INTO cookbook_context2recipe (recipe_id, group_id, audience_anonymous , audience_loggedin , audience_members , audience_technicians , audience_managers , context_project , context_homepage , context_cookbook , context_download , context_support , context_bugs , context_task , context_patch , context_news , context_mail , context_cvs , context_arch , context_svn , context_my , context_stats , context_siteadmin , context_people , subcontext_browsing , subcontext_postitem , subcontext_edititem , subcontext_search , subcontext_configure ) VALUES ('$item_id', '$group_id', '0', '1', '1', '0', '0', '1', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '0', '1', '0', '0', '0', '0', '0', '0', '0', '1')");
+      
+
     }
   else
     {
@@ -268,7 +303,12 @@ $message_admin .= "Description:
   if ($GLOBALS['sys_group_id'] != $group_id)
     {
       # get site-specific content, if it is not the localadmin project
+      # Create the page header just like if there was not yet any group_id
+      $group_id_not_yet_valid = $group_id;
+      unset($group_id);
       site_header(array('title'=>_("Registration Complete")));
+      $group_id = $group_id_not_yet_valid;
+
       utils_get_content("register/confirmation");
       site_footer(array());
     }
@@ -281,7 +321,12 @@ $message_admin .= "Description:
 }
 else if ($i_disagree && $group_id && $rand_hash)
 {
+  # Create the page header just like if there was not yet any group_id
+  $group_id_not_yet_valid = $group_id;
+  unset($group_id);
   $HTML->header(array('title'=>_("Registration Deleted")));
+  $group_id = $group_id_not_yet_valid;
+
   $result=db_query("DELETE FROM groups "
 		   .	"WHERE group_id='$group_id' AND rand_hash='__$rand_hash'");
 
@@ -294,9 +339,10 @@ else if ($i_disagree && $group_id && $rand_hash)
 }
 else
 {
+  unset($group_id);
   exit_error('Error',_("This is an invalid state.").' '
 	     ._("Some form variables were missing.").' '
-	     .sprintf(_("If you are certain you entered everything, %sPLEASE%s report to %s including info on your browser and platform configuration."),'<b>','</b>',$GLOBALS['sys_email_address']));
+	     .sprintf(_("If you are certain you entered everything, %sPLEASE%s report to %s including info on your browser and platform configuration."),'<strong>','</strong>',$GLOBALS['sys_email_address']));
 }
 
 ?>
