@@ -2,14 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: index.php 5825 2006-09-18 07:51:58Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
-#
-#  Copyright 2004      (c) ...
+#                          Mathieu Roy <yeupou--gnu.org>
 #
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -30,8 +29,6 @@ require "../include/pre.php";  # Initial db and session library, opens session
 #session_require(array(isloggedin=>1));
 $HTML->header(array(title=>_("New Project Registration")));
 
-print '<h2>'._("New Project Registration").'</h2>';
-
 if (db_numrows(db_query("SELECT type_id FROM group_type")) < 1) {
 	# group_type is empty; it's not prossible to register projects
 	print _("No group type has been set. Admins need to create at least one group type. They can make it so clicking on the link \"Group Type Admin\", on the Administration section of the left side menu, while logged in as admin");
@@ -42,7 +39,7 @@ if (db_numrows(db_query("SELECT type_id FROM group_type")) < 1) {
 
 print '<form action="requirements.php" method="post">';
 print '<div align="center">';
-print '<input type="submit" name="Submit" value="'._("Step 1: Services and Requirements").'">';
+print '<input type="submit" name="Submit" value="'._("Step 1: Services and Requirements").'" />';
 print '</div>';
 print '</form>';
 
