@@ -2,13 +2,14 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: requirements.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: requirements.php 5825 2006-09-18 07:51:58Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
-#                          Mathieu Roy <yeupou--at--gnu.org>
+#                          Mathieu Roy <yeupou--gnu.org>
 #
-#  Copyright 2005      (c) Sylvain Beucler <beuc--beuc.net>
+#  Copyright 2005-2006 (c) Sylvain Beucler <beuc--beuc.net>
+#                          Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -27,16 +28,15 @@
 
 require "../include/pre.php";  # Initial db and session library, opens session
 #session_require(array(isloggedin=>1));
-$HTML->header(array(title=>_("Services and Requirements")));
+$HTML->header(array(title=>_("Step 1: Services and Requirements")));
 
-print '<h2>'._("Step 1: Services and Requirements").'</h2>';
 
 # get site-specific content
 utils_get_content("register/requirements");
 
 print '<form action="basicinfo.php" method="post">';
 print '<div align="center">';
-print '<input type=submit name="Submit" value="'._("Step 2: Project Description and Dependencies (Requires Login)").'">';
+print '<input type=submit name="Submit" value="'._("Step 2: Project Description and Dependencies (Requires Login)").'" />';
 print '</div>';
 print '</form>';
 
