@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: index.php 5556 2006-08-14 08:22:48Z toddy $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--gnu.org>
-# 
-#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#
+#  Copyright 2004-2006 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
@@ -28,38 +28,39 @@
 
 require '../include/pre.php';
 
+# FIXME: This should be replaced by a call to register_globals_off()
 if ($_POST['group_id'])
-   { 
-   $group_id = $_POST['group_id']; 
+   {
+   $group_id = $_POST['group_id'];
    }
 elseif ($_GET['group_id'])
-   { 
-   $group_id = $_GET['group_id']; 
+   {
+   $group_id = $_GET['group_id'];
    }
 if ($_POST['words'])
-   { 
-   $words = $_POST['words']; 
+   {
+   $words = $_POST['words'];
    }
 elseif ($_GET['words'])
-   { 
-   $words = $_GET['words']; 
+   {
+   $words = $_GET['words'];
    }
 if ($_POST['type_of_search'])
-   { 
-   $type_of_search = $_POST['type_of_search']; 
+   {
+   $type_of_search = $_POST['type_of_search'];
    }
 elseif ($_GET['type_of_search'])
-   { 
-   $type_of_search = $_GET['type_of_search']; 
+   {
+   $type_of_search = $_GET['type_of_search'];
    }
 if ($_POST['func'])
-   { 
-   $func = $_POST['func']; 
+   {
+   $func = $_POST['func'];
    }
 elseif ($_GET['func'])
-   { 
-   $func = $_GET['func']; 
-   }   
+   {
+   $func = $_GET['func'];
+   }
 
 # Prevent xss when displaying the search string
 $words = htmlspecialchars($words);
@@ -140,8 +141,8 @@ if ($type_of_search == "soft")
 	. '<td>'.db_result($res_type, 0, 'name')."</td></tr>\n";
 	}
       print "</table>\n";
-      
-      print '<p> Note that <span class="bold">private</span> projects are not shown on this page </p>';
+
+      print '<p> Note that <strong>private</strong> projects are not shown on this page </p>';
     }
 
 }
@@ -235,7 +236,7 @@ else if ($type_of_search == "people")
       for ( $i = 0; $i < $rows; $i++ )
 	{
 	  print	"<tr class=\"". html_get_alt_row_color($i) ."\"><td><a href=\"".$GLOBALS['sys_home']."forum/message.php?msg_id="
-	    . db_result($result, $i, "msg_id")."\"><img src=\"".$GLOBALS['sys_home']."images/msg.png\" border=0 height=12 width=10> "
+	    . db_result($result, $i, "msg_id")."\"><img src=\"".$GLOBALS['sys_home']."images/msg.png\" border=0 height=12 width=10 /> "
 	    . db_result($result, $i, "subject")."</a></td>"
 	    . "<td>".db_result($result, $i, "user_name")."</td>"
 	    . "<td>".format_date($sys_datefmt,db_result($result,$i,"date"))."</td></tr>\n";
@@ -287,15 +288,15 @@ else if ($type_of_search == 'bugs' ||
           # Do even show private item
 	  if (db_result($result, $i, 'privacy') == "2" &&
 	      !member_check_private(0, $group_id)  &&
-	      db_result($result,$i,'user_name') != user_getname()) 
+	      db_result($result,$i,'user_name') != user_getname())
 	    {
 	      dbg("Private item.");
 	    }
-	  else 
+	  else
 	    {
 
 	      $url = $GLOBALS['sys_home'].$type_of_search."/?func=detailitem&amp;item_id=".db_result($result, $i, "bug_id");
-	      
+
 	      print	'<tr class="'.html_get_alt_row_color($j).'">'
 		. '<td><a href="'.$url.'">#'.db_result($result, $i, "bug_id").'</a></td>'
 		. '<td><a href="'.$url.'">'.db_result($result, $i, "summary").'</a></td>'
