@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmessage.php 4567 2005-06-30 17:19:37Z toddy $
+# $Id: sendmessage.php 5802 2006-09-14 12:40:09Z yeupou $
 # 
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundatio
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2003-2006 (c) Mathieu Roy <yeupou--gnu.org>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,16 +25,14 @@
 
 require "./include/pre.php";
     
-# lorenzo lorenzohgh@tuxedo-es.org 
-# Declaring variables BY method 
+register_globals_off();
 
-# Replaced the old if/elseif statements w/ $_REQUEST
-
-$touser = $_REQUEST['touser'];
-$send_mail = $_REQUEST['send_mail'];
-$subject = $_REQUEST['subject'];
-$body = $_REQUEST['body'];
-$freedback = $_REQUEST['feedback'];
+$touser = sane_all("touser");
+$fromuser = sane_all("fromuser");
+$send_mail = sane_all("send_mail");
+$subject = sane_all("subject");
+$body = sane_all("body");
+$freedback = sane_all("feedback");
 
 if (user_isloggedin()) 
 {
@@ -43,7 +41,7 @@ if (user_isloggedin())
   if ($touser) 
     {
       # Search infos in the database about the user
-      $result=db_query("SELECT email,user_name FROM user WHERE user_id='$touser'");
+      $result=db_query("SELECT email,user_name FROM user WHERE user_id='$touser' AND status='A'");
       if (!$result || db_numrows($result) < 1) 
 	{
 	  exit_error(_('That user does not exist'));
@@ -78,7 +76,7 @@ if (user_isloggedin())
     {
     
       $HTML->header(array('title'=>_('Send a message')));
-      sendmail_form_message($PHP_SELF, $touser);
+      sendmail_form_message($_SERVER["PHP_SELF"], $touser);
       $HTML->footer(array());
     
     }
