@@ -2,9 +2,9 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: group_type.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: group_type.php 5753 2006-09-12 12:06:40Z yeupou $
 #
-#  Copyright (C) 2002-2005 Mathieu Roy <yeupou--gnu.org>
+#  Copyright (C) 2002-2006 Mathieu Roy <yeupou--gnu.org>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -30,13 +30,13 @@ session_require(array('group'=>'1','admin_flags'=>'A'));
 function specific_showinput ($title, $form)
 {
   return '
-<font class="preinput">'.$title.'</font><br />
+<span class="preinput">'.$title.'</span><br />
 &nbsp;&nbsp; '.$form.'<br />';
 }
 function specific_showinput_inverted ($title, $form)
 {
   return '
-<br />&nbsp;&nbsp;'.$form.' <font class="preinput">'.$title.'</font><br />';
+<br />&nbsp;&nbsp;'.$form.' <span class="preinput">'.$title.'</span><br />';
 }
 
 
@@ -94,6 +94,7 @@ if ($update) {
      . "url_mailing_list_archives_private='$form_url_mailing_list_archives_private',"
      . "url_mailing_list_admin='$form_url_mailing_list_admin',"
      . "mailing_list_address='$form_mailing_list_address',"
+     . "mailing_list_virtual_host='$form_mailing_list_virtual_host',"
      . "mailing_list_format='$form_mailing_list_format',"
      . "can_use_forum='$form_can_use_forum',"
      . "can_use_patch='$form_can_use_patch',"
@@ -277,9 +278,9 @@ else
 
   html_select_typedir_box("form_dir_type_homepage",
 			  $row_grp['dir_type_homepage']);
-  print specific_showinput(_("Homepage Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_homepage" value="'.$row_grp['dir_homepage'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Homepage URL:"), '<input type="text" name="form_url_homepage" value="'.$row_grp['url_homepage'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Homepage CVS view URL (webcvs, viewcvs):"), '<input type="text" name="form_url_cvs_viewcvs_homepage" value="'.$row_grp['url_cvs_viewcvs_homepage'].'" size="'.$textfield_size.'">');
+  print specific_showinput(_("Homepage Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_homepage" value="'.$row_grp['dir_homepage'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Homepage URL:"), '<input type="text" name="form_url_homepage" value="'.$row_grp['url_homepage'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Homepage CVS view URL (webcvs, viewcvs):"), '<input type="text" name="form_url_cvs_viewcvs_homepage" value="'.$row_grp['url_cvs_viewcvs_homepage'].'" size="'.$textfield_size.'" />');
 
   print $HTML->box_bottom();
   print '<br /><br />';
@@ -291,8 +292,8 @@ else
   print specific_showinput_inverted(_("Can use CVS"), '<INPUT TYPE="CHECKBOX" NAME="form_can_use_cvs" VALUE="1"'.(($row_grp['can_use_cvs']==1) ? ' checked="checked"' : '').' />');
   html_select_typedir_box("form_dir_type_cvs",
 			  $row_grp['dir_type_cvs']);
-  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_cvs" value="'.$row_grp['dir_cvs'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Repository view URL (cvsweb, viewcvs, archzoom...):"), '<input type="text" name="form_url_cvs_viewcvs" value="'.$row_grp['url_cvs_viewcvs'].'" size="'.$textfield_size.'">');
+  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_cvs" value="'.$row_grp['dir_cvs'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Repository view URL (cvsweb, viewcvs, archzoom...):"), '<input type="text" name="form_url_cvs_viewcvs" value="'.$row_grp['url_cvs_viewcvs'].'" size="'.$textfield_size.'" />');
 
   print $HTML->box_bottom();
   print '<br /><br />';
@@ -304,8 +305,8 @@ else
   print specific_showinput_inverted(_("Can use GNU Arch"), '<INPUT TYPE="CHECKBOX" NAME="form_can_use_arch" VALUE="1"'.(($row_grp['can_use_arch']==1) ? ' checked="checked"' : '').' />');
   html_select_typedir_box("form_dir_type_arch",
 			  $row_grp['dir_type_arch']);
-  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_arch" value="'.$row_grp['dir_arch'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Repository view URL (cvsweb, viewcvs, archzoom...):"), '<input type="text" name="form_url_arch_viewcvs" value="'.$row_grp['url_arch_viewcvs'].'" size="'.$textfield_size.'">');
+  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_arch" value="'.$row_grp['dir_arch'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Repository view URL (cvsweb, viewcvs, archzoom...):"), '<input type="text" name="form_url_arch_viewcvs" value="'.$row_grp['url_arch_viewcvs'].'" size="'.$textfield_size.'" />');
 
   print $HTML->box_bottom();
   print '<br /><br />';
@@ -317,8 +318,8 @@ else
   print specific_showinput_inverted(_("Can use Subversion"), '<INPUT TYPE="CHECKBOX" NAME="form_can_use_svn" VALUE="1"'.(($row_grp['can_use_svn']==1) ? ' checked="checked"' : '').' />');
   html_select_typedir_box("form_dir_type_svn",
 			  $row_grp['dir_type_svn']);
-  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_svn" value="'.$row_grp['dir_svn'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Repository view URL (cvsweb, viewcvs, archzoom...):"), '<input type="text" name="form_url_svn_viewcvs" value="'.$row_grp['url_svn_viewcvs'].'" size="'.$textfield_size.'">');
+  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_svn" value="'.$row_grp['dir_svn'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Repository view URL (cvsweb, viewcvs, archzoom...):"), '<input type="text" name="form_url_svn_viewcvs" value="'.$row_grp['url_svn_viewcvs'].'" size="'.$textfield_size.'" />');
 
   print $HTML->box_bottom();
   print '<br /><br />';
@@ -330,8 +331,8 @@ else
   print specific_showinput_inverted(_("Can use Download Area"), '<INPUT TYPE="CHECKBOX" NAME="form_can_use_download" VALUE="1"'.(($row_grp['can_use_download']==1) ? ' checked="checked"' : '').' />');
   html_select_typedir_box("form_dir_type_download",
 			  $row_grp['dir_type_download']);
-  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Repository URL:"), '<input type="text" name="form_url_download" value="'.$row_grp['url_download'].'" size="'.$textfield_size.'">');
+  print specific_showinput(_("Repository Dir (path on the filesystem) [BACKEND SPECIFIC]:"), '<input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Repository URL:"), '<input type="text" name="form_url_download" value="'.$row_grp['url_download'].'" size="'.$textfield_size.'" />');
 
   print $HTML->box_bottom();
   print '<br /><br />';
@@ -366,24 +367,25 @@ else
    # ###########  Mailing List
 
   print $HTML->box_top(_("Mailing List"));
-  print '<div class="warn">Important: Everytime a mailing-list name should appear, use the special string %LIST.<br />Note that if you do not want the Savane Frontend to interact with your mail host (for instance to truly create mailing list), do not fill the mail host information, the backend does not need that field to be set!</div>';
+  print '<div class="warn">Important: Everytime a mailing-list name should appear, use the special string %LIST.</div><div>Do not configure Mailing-list Host, this is a deprecated feature left for backward compatibility.</div><div>Mailing-list virtual host only need to be set if you use mailman list, set up via the backend, and have several mailman virtual hosts set.';
 
   print specific_showinput_inverted(_("Can use mailing-lists"), '<INPUT TYPE="CHECKBOX" NAME="form_can_use_mailing_list" VALUE="1"'.( ($row_grp['can_use_mailing_list']==1) ? ' checked="checked"' : '' ).' />');
 
   print '<br />';
 
-  print specific_showinput(_("Mailing-list Host (DEPRECATED):"), '<input type="text" name="form_mailing_list_host" value="'.$row_grp['mailing_list_host'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Mailing-list address (would be %LIST@gnu.org for GNU projects at sv.gnu.org):"), '<input type="text" name="form_mailing_list_address" value="'.$row_grp['mailing_list_address'].'" size="'.$textfield_size.'">');
+  print specific_showinput(_("Mailing-list Host (DEPRECATED):"), '<input type="text" name="form_mailing_list_host" value="'.$row_grp['mailing_list_host'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Mailing-list address (would be %LIST@gnu.org for GNU projects at sv.gnu.org):"), '<input type="text" name="form_mailing_list_address" value="'.$row_grp['mailing_list_address'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Mailing-list virtual host (would be lists.gnu.org or lists.nongnu.org at sv.gnu.org) [BACKEND SPECIFIC]:"), '<input type="text" name="form_mailing_list_virtual_host" value="'.$row_grp['mailing_list_virtual_host'].'" size="'.$textfield_size.'">');
 
   print '<br /><br />';
-  print '<div>With the following, you can force projects to follow a specific policy for the name of the %LIST. Here you should use the special wildcard %NAME, which is the part the of the mailing list name that the project admin can define (would be %PROJECT-%NAME for non-GNU projects at sv.gnu.org).<br /><font class="warn">Do no add any @hostname here!</font></div>';
-  print specific_showinput(_("Mailing list name format:"), '<input type="text" name="form_mailing_list_format" value="'.$row_grp['mailing_list_format'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Listinfo URL:"), '<input type="text" name="form_url_mailing_list_listinfo" value="'.$row_grp['url_mailing_list_listinfo'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Subscribe URL (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):"), '<input type="text" name="form_url_mailing_list_subscribe" value="'.$row_grp['url_mailing_list_subscribe'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Unsubscribe URL (for majordomo at CERN, it is majordomo_interface.php?func=unsubscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):"), '<input type="text" name="form_url_mailing_list_unsubscribe" value="'.$row_grp['url_mailing_list_unsubscribe'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Archives URL:"), '<input type="text" name="form_url_mailing_list_archives" value="'.$row_grp['url_mailing_list_archives'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Private Archives URL:"), '<input type="text" name="form_url_mailing_list_archives_private" value="'.$row_grp['url_mailing_list_archives_private'].'" size="'.$textfield_size.'">');
-  print specific_showinput(_("Administrative Interface URL:"), '<input type="text" name="form_url_mailing_list_admin" value="'.$row_grp['url_mailing_list_admin'].'" size="'.$textfield_size.'">');
+  print '<div>With the following, you can force projects to follow a specific policy for the name of the %LIST. Here you should use the special wildcard %NAME, which is the part the of the mailing list name that the project admin can define (would be %PROJECT-%NAME for non-GNU projects at sv.gnu.org).<br /><span class="warn">Do no add any @hostname here!</span></div>';
+  print specific_showinput(_("Mailing list name format:"), '<input type="text" name="form_mailing_list_format" value="'.$row_grp['mailing_list_format'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Listinfo URL:"), '<input type="text" name="form_url_mailing_list_listinfo" value="'.$row_grp['url_mailing_list_listinfo'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Subscribe URL (for majordomo at CERN, it is majordomo_interface.php?func=subscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):"), '<input type="text" name="form_url_mailing_list_subscribe" value="'.$row_grp['url_mailing_list_subscribe'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Unsubscribe URL (for majordomo at CERN, it is majordomo_interface.php?func=unsubscribe&amp;list=%LIST&amp;mailserver=listbox.server@cern.ch):"), '<input type="text" name="form_url_mailing_list_unsubscribe" value="'.$row_grp['url_mailing_list_unsubscribe'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Archives URL:"), '<input type="text" name="form_url_mailing_list_archives" value="'.$row_grp['url_mailing_list_archives'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Private Archives URL:"), '<input type="text" name="form_url_mailing_list_archives_private" value="'.$row_grp['url_mailing_list_archives_private'].'" size="'.$textfield_size.'" />');
+  print specific_showinput(_("Administrative Interface URL:"), '<input type="text" name="form_url_mailing_list_admin" value="'.$row_grp['url_mailing_list_admin'].'" size="'.$textfield_size.'" />');
 
   print $HTML->box_bottom();
   print '<br /><br />';
@@ -451,8 +453,8 @@ else
 
 print '
 <p align="center">
-<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
-<input type="submit" name="delete" value="'._("Delete this Group Type").'">';
+<input type="submit" name="update" value="'.$update_button_text.'" /> &nbsp;
+<input type="submit" name="delete" value="'._("Delete this Group Type").'" />';
 
 
   print '<br /><br />';
@@ -473,7 +475,7 @@ print '
 	{ $i++; }
       print '<li class="'.utils_get_alt_row_color($i).'">';
       html_build_checkbox("form_is_menu_configurable_".$val, $row_grp["is_menu_configurable_".$val]);
-      print '<font class="preinput">'.$explanation.'</font></li>';
+      print '<span class="preinput">'.$explanation.'</span></li>';
     }
 
   specific_checkbox("homepage",
@@ -526,8 +528,8 @@ print '
 
   print $HTML->box_bottom(1);
 
-  print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
-<input type="submit" name="delete" value="'._("Delete this Group Type").'">';
+  print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'" /> &nbsp;
+<input type="submit" name="delete" value="'._("Delete this Group Type").'" />';
 
   print '<br /><br />';
 
@@ -560,8 +562,8 @@ print '
 
   $HTML->box1_bottom();
 
- print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
-<input type="submit" name="delete" value="'._("Delete this Group Type").'">';
+ print '<p align="center"><input type="submit" name="update" value="'.$update_button_text.'" /> &nbsp;
+<input type="submit" name="delete" value="'._("Delete this Group Type").'" />';
 
   print '<br /><br />';
 
@@ -584,8 +586,8 @@ print '
   $HTML->box1_bottom();
 
   print '<p align="center">
-<input type="submit" name="update" value="'.$update_button_text.'"> &nbsp;
-<input type="submit" name="delete" value="'._("Delete this Group Type").'"></p>
+<input type="submit" name="update" value="'.$update_button_text.'" /> &nbsp;
+<input type="submit" name="delete" value="'._("Delete this Group Type").'" /></p>
 </form>';
 
 
