@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: groupedit.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: groupedit.php 5823 2006-09-15 14:10:15Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #
@@ -89,8 +89,8 @@ utils_get_content("admin/groupedit_intro");
 
 # MODIFICATORS SHORTCUTS
 print '<h3>'._("Registration Management Shortcuts").'</h3>';
-print '<a href="'.$PHP_SELF.'?status=A&amp;updatefast=1&amp;group='.$group_name.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.orig.png" alt="'._("Approve").'" /></a>&nbsp;&nbsp;&nbsp;';
-print '<a href="'.$PHP_SELF.'?status=D&amp;updatefast=1&amp;group='.$group_name.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.orig.png" alt="'._("Discard").'" /></a>&nbsp;&nbsp;&nbsp;';
+print '<a href="'.$PHP_SELF.'?status=A&amp;updatefast=1&amp;group_id='.$group_id.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.orig.png" alt="'._("Approve").'" /></a>&nbsp;&nbsp;&nbsp;';
+print '<a href="'.$PHP_SELF.'?status=D&amp;updatefast=1&amp;group_id='.$group_id.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.orig.png" alt="'._("Discard").'" /></a>&nbsp;&nbsp;&nbsp;';
 print '<a href="triggercreation.php?group_id='.$group_id.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/preferences.orig.png" alt="'._("Send New Project Instruction Email and Trigger Project Creation (should be done only once)").'" /></a>';
 
 # MODIFICATORS
@@ -98,23 +98,23 @@ print '<form action="'.$PHP_SELF.'" method="POST">';
 print '<h3>'._("Detailed Interface").'</h3>';
 $HTML->box1_top(_("General Settings"));
 
-print '<p><font class="preinput">'._("Group Type:").' </font><br />';
-print '<i>';
+print '<p><span class="preinput">'._("Group Type:").' </span><br />';
+print '<em>';
 utils_get_content("admin/groupedit_grouptype");
-print '</i><br />';
+print '</em><br />';
 print show_group_type_box('group_type',$row_grp['type']);
 
 
 $i=0;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("System Name").':</font><br /> ';
-print '<input type="text" name="form_name" value="'.$row_grp['unix_group_name'].'">';
+print '<p><span class="preinput">'._("System Name").':</span><br /> ';
+print '<input type="text" name="form_name" value="'.$row_grp['unix_group_name'].'" />';
 
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Status").':</font><br />';
+print '<p><span class="preinput">'._("Status").':</span><br />';
 
 print '<select name="form_status">';
 
@@ -133,9 +133,9 @@ print '<p>'._("Project marked as deleted will be removed from the database by a
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Public?").'</font><br />
+print '<p><span class="preinput">'._("Public?").'</span><br />
 '._("A private project will be completly invisible from the web interface.").'
-'._("You must clear the HTML repository field below when setting the private flag otherwise unpredictable result will occur.").'</i><br />';
+'._("You must clear the HTML repository field below when setting the private flag otherwise unpredictable result will occur.").'</em><br />';
 print '<select name="form_public">';
 print '<option '.(($row_grp['is_public'] == 1)?'selected ':'').'value="1">'._("Yes").'</option>';
 print '<option '.(($row_grp['is_public'] == 0)?'selected ':'').'value="0">'._("No").'</option>';
@@ -144,8 +144,8 @@ print '</select>';
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("License:").' </font><br />';
-print _("Note: this has influence only if the group type of which this group belongs to accepts this information.").'<br /></i>';
+print '<p><span class="preinput">'._("License:").' </span><br />';
+print _("Note: this has influence only if the group type of which this group belongs to accepts this information.").'<br /></em>';
 print '<select name="form_license">';
 print '<option value="none">'._("N/A").'</option>';
 print '<option value="other">'._("Other").'</option>';
@@ -159,7 +159,7 @@ while (list($k,$v) = each($LICENSE))
 }
 
 print '</select>';
-print '<input type="hidden" name="group_id" value="'.$group_id.'">';
+print '<input type="hidden" name="group_id" value="'.$group_id.'" />';
 
 
 $i++;
@@ -184,32 +184,32 @@ $HTML->box1_bottom();
 # BACKEND SPECIFIC
 print '<p>';
 $HTML->box1_top(_("Specific Backend Settings"));
-print '[BACKEND SPECIFIC] If this group must have specific directories for homepage, sourcecode, download, which are not the default of the group type it belongs to, you can fill the following fields. You may need to also edit the urls in  \'This Project Active Features\'. You should avoid as possible using these fields and consider creating new group types. Exceptions are a pain to handle in the long run.';
+print _('[BACKEND SPECIFIC] If this group must have specific directories for homepage, sourcecode, download, which are not the default of the group type it belongs to, you can fill in the following fields. You may need to also edit the urls in \'This Project Active Features\'. If possible, you should avoid using these fields and consider creating new group types. Exceptions are a pain to handle in the long run.');
 $i=0;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Primary SCM (CVS) directory:").'</font><br /> ';
-print '<input type="text" name="form_dir_cvs" value="'.$row_grp['dir_cvs'].'" size="50">';
+print '<p><span class="preinput">'._("Primary SCM (CVS) directory:").'</span><br /> ';
+print '<input type="text" name="form_dir_cvs" value="'.$row_grp['dir_cvs'].'" size="50" />';
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Secondary SCM (Arch) directory:").'</font><br /> ';
-print '<input type="text" name="form_dir_arch" value="'.$row_grp['dir_arch'].'" size="50">';
+print '<p><span class="preinput">'._("Secondary SCM (Arch) directory:").'</span><br /> ';
+print '<input type="text" name="form_dir_arch" value="'.$row_grp['dir_arch'].'" size="50" />';
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Tertiary SCM (Subversion) directory:").'</font><br /> ';
-print '<input type="text" name="form_dir_svn" value="'.$row_grp['dir_svn'].'" size="50">';
+print '<p><span class="preinput">'._("Tertiary SCM (Subversion) directory:").'</span><br /> ';
+print '<input type="text" name="form_dir_svn" value="'.$row_grp['dir_svn'].'" size="50" />';
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Homepage directory:").'</font><br /> ';
-print '<input type="text" name="form_dir_homepage" value="'.$row_grp['dir_homepage'].'" size="50">';
+print '<p><span class="preinput">'._("Homepage directory:").'</span><br /> ';
+print '<input type="text" name="form_dir_homepage" value="'.$row_grp['dir_homepage'].'" size="50" />';
 $i++;
 print '</td></tr><tr><td class="'.utils_get_alt_row_color($i).'">';
 
-print '<p><font class="preinput">'._("Download directory:").'</font><br /> ';
-print '<input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="50">';
+print '<p><span class="preinput">'._("Download directory:").'</span><br /> ';
+print '<input type="text" name="form_dir_download" value="'.$row_grp['dir_download'].'" size="50" />';
 print '
 <p><INPUT type="submit" name="update" value="'._("Update").'">';
 
