@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: usergroup.php 5187 2005-12-01 16:22:29Z yeupou $
+// $Id: usergroup.php 5557 2006-08-14 08:25:30Z toddy $
 //
 //
 // 
@@ -97,7 +97,7 @@ $row_user = db_fetch_array($res_user);
 
 ?>
 <p>
-Savannah User Group Edit for user: <b><?php print $user_id . ": " . user_getname($user_id); ?></b>
+Savannah User Group Edit for user: <strong><?php print $user_id . ": " . user_getname($user_id); ?></strong>
 <p>
 Account Info:
 <FORM method="post" action="<?php echo $PHP_SELF; ?>">
@@ -122,7 +122,7 @@ Account Info:
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: usergroup.php 5187 2005-12-01 16:22:29Z yeupou $
+// $Id: usergroup.php 5557 2006-08-14 08:25:30Z toddy $
 //
 /*
 	Iterate and show groups this user is in
@@ -134,7 +134,7 @@ $res_cat = db_query("SELECT groups.group_name AS group_name, "
 	. "groups.group_id=user_group.group_id");
 
 	while ($row_cat = db_fetch_array($res_cat)) {
-		print ("<br /><hr><b>" . group_getname($row_cat[group_id]) . "</b> "
+		print ("<br /><hr><strong>" . group_getname($row_cat[group_id]) . "</strong> "
 			. "<a href=\"usergroup.php?user_id=$user_id&action=remove_user_from_group&group_id=$row_cat[group_id]\">"
 			. "[Remove User from Group]</a>");
 		// editing for flags
@@ -148,7 +148,7 @@ $res_cat = db_query("SELECT groups.group_name AS group_name, "
 		<BR>
 		<input type="text" name="admin_flags" value="<?php print $row_cat[admin_flags]; ?>">
 		<BR>
-		<input type="submit" name="Update_Group" value="Update">
+		<input type="submit" name="Update_Group" value="Update" />
 		</form>
 		<?php
 	}
@@ -165,9 +165,9 @@ $res_cat = db_query("SELECT groups.group_name AS group_name, "
 <p>
 Add User to Group (group_id):
 <br />
-<input type="text" name="group_id" LENGTH="4" MAXLENGTH="5">
+<input type="text" name="group_id" LENGTH="4" MAXLENGTH="5" />
 <p>
-<input type="submit" name="Submit" value="Submit">
+<input type="submit" name="Submit" value="Submit" />
 </form>
 
 <P><A href="user_changepw.php?user_id=<?php print $user_id; ?>">[Change User PW]</A>
@@ -176,7 +176,7 @@ Add User to Group (group_id):
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: usergroup.php 5187 2005-12-01 16:22:29Z yeupou $
+// $Id: usergroup.php 5557 2006-08-14 08:25:30Z toddy $
 //
 html_feedback_bottom($feedback);
 $HTML->footer(array());
