@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: userlist.php 5187 2005-12-01 16:22:29Z yeupou $
+// $Id: userlist.php 5557 2006-08-14 08:25:30Z toddy $
 //
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -61,7 +61,7 @@ function show_users_list ($result)
 			default: print _("Unknown status")." : ".$usr[status]; break;
 		}
 		if ($usr[people_view_skills] == 1 ) {
-			print '<td><a href="'.$GLOBALS['sys_home'].'people/viewprofile.php?user_id='.$usr[user_id].'">['._("View").']</a></td>';
+			print '<td><a href="'.$GLOBALS['sys_home'].'people/resume.php?user_id='.$usr[user_id].'">['._("View").']</a></td>';
 		} else {
 			print '<td>('._("Private").')</td>';
 		}
@@ -120,9 +120,9 @@ for ($i=0; $i < count($abc_array); $i++) {
 print '<br />'._("or search by email, username, realname or userid").' :';
 print '
 <form name="usersrch" action="search.php" method="POST">
-  <input type="text" name="search">
-  <input type="hidden" name="usersearch" value="1">
-  <input type="submit" value="get">
+  <input type="text" name="search" />
+  <input type="hidden" name="usersearch" value="1" />
+  <input type="submit" value="get" />
 </form>
 </p>';
 
@@ -136,7 +136,7 @@ print '
 print '<h3>'._("Savane user list for group:");
 
 if (!$group_id) {
-	print '<b>'._("All Groups").'</b></h3>';
+	print '<strong>'._("All Groups").'</strong></h3>';
 
 
 	if ($user_name_search) {
@@ -149,7 +149,7 @@ if (!$group_id) {
 	/*
 		Show list for one group
 	*/
-	print " <b>" . group_getname($group_id) . "</b></h3>";
+	print " <strong>" . group_getname($group_id) . "</strong></h3>";
 
 
 	$result = db_query("SELECT user.user_id AS user_id, user.user_name AS user_name, user.status AS status ,user.people_view_skills AS people_view_skills"
@@ -169,9 +169,9 @@ if (!$group_id) {
 	// FIXME: not conform to the coding style
 	?>
 
-	<input type="HIDDEN" name="action" VALUE="add_to_group">
+	<input type="HIDDEN" name="action" VALUE="add_to_group" />
 	<input type="HIDDEN" name="group_id" VALUE="<?php print $group_id; ?>">
-	<input name="user_id" type="TEXT" value="">
+	<input name="user_id" type="TEXT" value="" />
 	<input type="submit" name="Submit" value="<?php print _("Add"); ?>">
 	</form>
 
