@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
+# $Id: index.php 6016 2006-09-29 15:26:05Z yeupou $
 #
 #  Copyright 2004-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
@@ -53,7 +53,7 @@ $since = mktime($hour,$min,0,$since_month, $since_day, $since_year);
 $until = mktime($hour,$min,0,$until_month, $until_day, $until_year);
 
 $form_opening = '<form action="'.$PHP_SELF.'#options" method="GET">';
-$form_submit = '<input class="bold" value="'._("Apply").'" name="update" type="submit">';
+$form_submit = '<input class="bold" value="'._("Apply").'" name="update" type="submit" />';
 # I18N
 # The strings are two dates.
 # Example: "From 12. September 2005 till 14. September 2005"
@@ -234,7 +234,7 @@ print '&nbsp;&nbsp;- '
 .sprintf(ngettext("%s project,", "%s projects,", $count_groups), $count_groups)." "
 .sprintf(ngettext("including %s in private state", "including %s in private state", $count_groups_private), $count_groups_private)."<br />\n";
 
-$result = db_query("SELECT type_id,name FROM group_type ORDER BY type_id");
+$result = db_query("SELECT type_id,name FROM group_type ORDER BY name");
 while ($eachtype = db_fetch_array($result))
 {
   $content[$eachtype['name']] = stats_getprojects($eachtype['type_id']);
@@ -334,14 +334,14 @@ print '</p>
 ';
 
 # Get the more popular themes. 7 at most, all superior to 0%
-$themes_list = theme_list(1);
+$themes_list = theme_list();
 $popular_themes = array();
 while (list(,$theme) = each($themes_list))
 {
   # Get the number of users of the theme
   unset($count);
-  $count = stats_getthemeusers($theme);
-  if ($theme == $GLOBALS['sys_themedefault'])
+  $count = stats_getthemeusers(strtolower($theme));
+  if (strtolower($theme) == strtolower($GLOBALS['sys_themedefault']))
     { 
       # If it is the default theme, add the users that use the default
       $count += stats_getthemeusers("");
