@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.3 2005/06/30 17:19:37 toddy Exp $
+# $Id: index.php 4977 2005-11-15 17:38:40Z yeupou $
 #
 #  Copyright 2005      (c) Mathieu Roy <yeupou--gnu.org>
 #
@@ -34,7 +34,8 @@ if (!$project->Uses("svn") && !$project->UsesForHomepage("svn"))
 }
 
 
-site_project_header(array('group'=>$group_id,'toptab'=>'svn'));
+site_project_header(array('group'=>$group_id,'context'=>'svn'));
+
 
 
 # ####################### CVS Browsing
