@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: Util.pm 4565 2005-06-30 16:47:39Z toddy $
+# $Id: Util.pm 5651 2006-09-05 15:02:38Z yeupou $
 #
 #  Copyright 2005 (c) Sylvain Beucler <beuc--beuc.net>
 #
@@ -23,10 +23,11 @@
 #
 
 ##
-## Desc: any subs related to users.
+## Desc: any subs that may be useful in very rare cases
 ##
 
 use strict "vars";
+use Fcntl ':flock';
 require Exporter;
 
 # Exports
@@ -43,3 +44,5 @@ sub SQLStringEscape {
     $str =~ s/\n/\\n/g;
     return $str;
 }
+
+
